(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    398495,       9743]*)
(*NotebookOutlinePosition[    399514,       9777]*)
(*  CellTagsIndexPosition[    399470,       9773]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["\<\
Undulator focusing and generation of a map file suitable for \
electron tracking.\
\>", "Title"],

Cell[TextData[{
  "P. Elleaume (elleaume@esrf.fr)\nDecembre 20  2000, Version 1.6\nThis \
notebook has been developed using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.0 on a PowerMac. It should execute on other platforms with the same \
version of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". Users of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3.0 may also use it after removing (or commenting) the sections which are \
flagged to only operate with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 4.0. The production of the map file will not be possible on Mathmatica \
version prior to 4 . "
}], "Text"],

Cell[CellGroupData[{

Cell["To Read before Starting ", "Section"],

Cell[TextData[{
  "Do not hesitate to report (to elleaume@esrf.fr) any bug  and/or  error in \
the explanations and the content of this file. I shall make use of your \
comments to improve it for future users. This notebook requires ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Version 4.0 for producing the map files but all RADIA computations work \
in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Version 3. The structure of this  notebook is not difficult to follow , \
however,  it is not  for  beginners. The section \"Initialization\" loads \
RADIA and defines a number of global mathematica functions which are used in \
all other sections. In the following the word \"undulator\" is a generic word \
for a periodic magnetic field, it can also represent a wiggler. \nThis \
notebook  can be used for a number of different  purposes:\n- It generates an \
arbitrary periodic undulator (Vertical field Pure Permanent Magnet, \
Horizontal Field Pure Permanent Magnet, Hybrid, Apple II, Helios, Spring-8 \
type..). Incorporating other types of undulators is straightforward. \
Illustrations are made with the BL11 SPEAR wiggler and the  HU88 and HU56  \
ESRF Apple II undulators. \n- The undulators geometry is displayed and the  \
field produced by the undulator is  analysed and plotted.\n- The second order \
steering, focusing, non linear effect (proportional to the inverse of the \
electron energy)  is computed and a map file characterizing its effect  is \
produced to be read in a tracking code such as BETA[1]. The physical method \
for tracking an electron in such a magnetic field is  described in [2]. It \
has been applied to simulate the reduction of dynamic aperture observed on \
the SPEAR BL11 wiggler[3] and to predict the focusing and dynamic aperture \
reduction induced by Apple II undulators [4].  The information contained in \
the undulator  field is reduced to two tables which are placed in the map \
file that can be visualized in any spreadsheet software. This undulator map \
file can be read by the tracking code BETA.  The structure of the file is \
described in the section \"Generate Input Data for the tracking of electrons  \
in BETA\". A short explanation on how to use it in BETA is presented in  the \
same section. The latest BETA code which reads these files can be obtained \
from Thomas Gunzel (guenzel@esrf.fr).  The magnetic  field  being studied is \
assumed to be periodic  which is a good approximation for undulators or \
wigglers. It is not a good approximation for a 3 pole wiggler. 3 pole \
wigglers  are usually short enough with a long effective period and therefore \
do not make any  important reduction of the dynamic aperure. Nevertheless, if \
needed,  a similar file could be produced for such a wiggler, one would need \
to modify a number of  functions of this notebook. Modifying any existing \
tracking code to process the RADIA generated map  files should not be \
difficult, the person interested in this exercise should read the \
introduction of the section \"Generating a Map File\" and ref[2]. Note that \
the  model is such that in all circumstances the tracking in the undulator by \
means of such a map  file is always symplectic.\n",
  StyleBox["References",
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "\n[1] L. Farvacque, et al., \"BETA User\[CloseCurlyQuote]s Guide\", \
ESRF-SR/LAT-88-08, 1989.\n[2] P. Elleaume, \"A New Approach to the Electron \
Beam Dynamics in Undulators and Wigglers\", EPAC\[CloseCurlyQuote]92, March \
1992.\n[3] J. Safranek et al., \"",
  StyleBox["NonLinear  Dynamics in SPEAR wigglers",
    FontWeight->"Bold"],
  "\", presented at the EPAC 2000 Conference\n[4] J. Chavanne et al., \"",
  StyleBox["Recent Achievements and Future Prospects of ID Activities at the \
ESRF",
    FontWeight->"Bold"],
  "\", presented at the EPAC 2000 Conference"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["How to Use this Notebook", "Section"],

Cell["\<\
1 - Execute all cells in the  section \"Initialization\" before \
anything else .
2 - Open the section \"Build an Undulator\" . Depending of the undulator \
under consideration, open a single sub-section on Apple II, Spring 8 or \
hybrid,... Edit the parameters and execute the section. Check that the field \
is correct and execute. If necessary, edit the parameters and re-execute the \
section. 
3 - Open the section \"Display Geometry\" or \"Plot Magnetic Fields\" or \
\"Angle and Focusing\" , Edit the parameters  and execute the cells of \
interest.
4-  Go to the last section for preparing the map file.  Edit the parameters \
and execute. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Section"],

Cell[CellGroupData[{

Cell["Load Radia", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Radia`;\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(<< Graphics`MultipleListPlot`;\)\), "\[IndentingNewLine]", 
    \(\(Off[General::"\<spell1\>"];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[Plot, PlotRange \[Rule] All, 
        Frame \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[ListPlot, PlotRange \[Rule] All, Frame \[Rule] True, 
        PlotJoined \[Rule] True];\)\), "\[IndentingNewLine]", 
    \(\(SetOptions[MultipleListPlot, PlotRange \[Rule] All, 
        Frame \[Rule] True, 
        PlotJoined \[Rule] True];\)\[IndentingNewLine] (*\ 
      Set\ the\ default\ Directory\ for\ creation\ of\ files\ *) \), "\
\[IndentingNewLine]", 
    \(\($NotebookDirectory = 
        ToFileName@
          First["\<FileName\>" /. 
              NotebookInformation[
                EvaluationNotebook[]]];\)\), "\[IndentingNewLine]", 
    \(\(SetDirectory[$NotebookDirectory];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Radia Version: "\[InvisibleSpace]4.098`\
\[InvisibleSpace]" is loaded"\),
      SequenceForm[ "Radia Version: ", 4.0979999999999999, " is loaded"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Radia is copyright ESRF, Grenoble France \nPortions copyright Wolfram \
Research, Inc."\)], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Global Functions", "Subsection"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(hyb[p_, per_, gap_, nper_, 
          gapoffset_, {lp_, np_, matp_, cp_}, {lm_, nm_, matm_, cm_}, {lms_, 
            nms_, matms_, cms_}]\), ":=", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({Grp, zer, yy, initm, i, in}\), ",", 
            "\[IndentingNewLine]", 
            
            RowBox[{\(zer = {0, 0, 0}\), ";", \(in = \(-1\)\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"Grp", "=", 
                RowBox[{
                  StyleBox["radObjCnt",
                    FontColor->RGBColor[1, 0, 0]], "[", \({}\), "]"}]}], ";", 
              "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(yy = lp[\([2]\)]/4\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["RadObjFullMag",
                  FontColor->RGBColor[1, 0, 0]], 
                "[", \(p + {lp[\([1]\)]/4, 
                    yy, \(-lp[\([3]\)]\)/2 - gap/2}, {lp[\([1]\)]/2, 
                  lp[\([2]\)]/2, lp[\([3]\)]}, zer, np, Grp, matp, cp\), 
                "]"}], ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(yys = 
                yy + \((lms[\([2]\)] - lp[\([2]\)])\)/4\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["RadObjFullMag",
                  FontColor->RGBColor[1, 0, 0]], 
                "[", \(p + {lp[\([1]\)]/2 + lms[\([1]\)]/2, 
                    yys, \(-lms[\([3]\)]\)/2 - gap/2 - 
                      gapoffset}, {lms[\([1]\)], lms[\([2]\)]/2, 
                  lms[\([3]\)]}, {in, 0, 0}, nms, Grp, matms, cms\), "]"}], 
              ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", \(yy += lp[\([2]\)]/4\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{"For", "[", 
                
                RowBox[{\(i = 1\), ",", \(i \[LessEqual] nper\), ",", \(i++\),
                   ",", 
                  RowBox[{"(", 
                    
                    RowBox[{\(initm = {0, Mod[i + 1, 2] - Mod[i, 2], 0}\), 
                      ";", "\[IndentingNewLine]", \(yy += lm[\([2]\)]/2\), 
                      ";", "\[IndentingNewLine]", 
                      RowBox[{
                        StyleBox["RadObjFullMag",
                          FontColor->RGBColor[1, 0, 0]], 
                        "[", \(p + {lm[\([1]\)]/4, 
                            yy, \(-lm[\([3]\)]\)/2 - gap/2 - 
                              gapoffset}, {lm[\([1]\)]/2, lm[\([2]\)], 
                          lm[\([3]\)]}, initm, nm, Grp, matm, cm\), "]"}], 
                      ";", "\[IndentingNewLine]", \(yy += \((lm[\([2]\)] + 
                              lp[\([2]\)])\)/2\), ";", "\[IndentingNewLine]", 
                      
                      RowBox[{
                        StyleBox["RadObjFullMag",
                          FontColor->RGBColor[1, 0, 0]], 
                        "[", \(p + {lp[\([1]\)]/4, 
                            yy, \(-lp[\([3]\)]\)/2 - gap/2}, {lp[\([1]\)]/2, 
                          lp[\([2]\)], lp[\([3]\)]}, zer, np, Grp, matp, cp\),
                         "]"}], ";", "\[IndentingNewLine]", \(in *= \(-1\)\), 
                      ";", "\[IndentingNewLine]", 
                      RowBox[{
                        StyleBox["RadObjFullMag",
                          FontColor->RGBColor[1, 0, 0]], 
                        "[", \(p + {lp[\([1]\)]/2 + lms[\([1]\)]/2, 
                            yy, \(-lms[\([3]\)]\)/2 - gap/2 - 
                              gapoffset}, {lms[\([1]\)], lms[\([2]\)], 
                          lms[\([3]\)]}, {in, 0, 0}, nms, Grp, matms, cms\), 
                        "]"}], ";", "\[IndentingNewLine]", 
                      "\[IndentingNewLine]", \(yy += lp[\([2]\)]/2\), ";"}], 
                    ")"}]}], "]"}], ";", 
              "\[IndentingNewLine]", \(initm = {0, 
                  Mod[nper, 2] - Mod[nper + 1, 2], 0}\), ";", 
              "\[IndentingNewLine]", \(yy += lm[\([2]\)]/4\), ";", 
              "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["RadObjFullMag",
                  FontColor->RGBColor[1, 0, 0]], 
                "[", \(p + {lm[\([1]\)]/4, 
                    yy, \(-lm[\([3]\)]\)/2 - gap/2 - gapoffset}, {lm[\([1]\)]/
                    2, lm[\([2]\)]/2, lm[\([3]\)]}, initm, nm, Grp, matm, 
                cm\), "]"}], ";", "\[IndentingNewLine]", \( (*Mirrors*) \), 
              "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["RadTrfZerPerp",
                  FontColor->RGBColor[1, 0, 0]], "[", \(Grp, p, {1, 0, 0}\), 
                "]"}], ";", "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["RadTrfZerPara",
                  FontColor->RGBColor[1, 0, 0]], "[", \(Grp, p, {0, 0, 1}\), 
                "]"}], ";", "\[IndentingNewLine]", 
              RowBox[{
                StyleBox["RadTrfZerPerp",
                  FontColor->RGBColor[1, 0, 0]], "[", \(Grp, p, {0, 1, 0}\), 
                "]"}], ";", "\[IndentingNewLine]", "Grp"}]}], "]"}]}], 
      ";"}]], "Input"],

Cell[BoxData[
    \(\(\( (*wv = {lx, ly, 
            lz}\ for\ verticallly\ magnetized\ magnets*) \)\( (*wh = {lx, ly, 
            lz}\ for\ Horizontally\ magnetized\ magnets*) \)\( (*si\ \
determines\ in\ which\ direction\ the\ magnetization\ is\ turning*) \)\( \
(*axe = Pi/2\ \((0)\) : 
          means\ undulator\ with\ horizontal\ \((vertical)\)\ and\ \
longitudinal\\\nmagnetization*) \)\(und[po_, wv_, wh_, np_, per_, br_, si_, 
          axe_:  0] := 
        Module[{g, ma, m, p, i, t, s, w}, 
          g = radObjCnt[{}]; \[IndentingNewLine]p = 
            po - {0, np*per/2, 0}; \[IndentingNewLine]For[i = 0, 
            i < 4*np + 1, \(i++\), 
            If[i \[Equal] 0 || i \[Equal] 4*np, s = 0.5, 
              s = 1]; \[IndentingNewLine]If[Mod[i, 2] \[Equal] 0, w = wv, 
              w = wh]; \[IndentingNewLine]t = \(-\((i - 1)\)\)*Pi/2*
                si; \[IndentingNewLine]m = {Sin[axe]*Sin[t], Cos[t], 
                  Cos[axe]*Sin[t]}*br*s; \[IndentingNewLine]ma = 
              radObjRecMag[p, w, m]; \[IndentingNewLine]radObjAddToCnt[
              g, {ma}]; \[IndentingNewLine]p = 
              p + {0, per/4, 0};]; \[IndentingNewLine]radObjDrwAtr[
            g, {0, 0, 1}]; \ g];\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(apple2G[pos_, per_, gap_, gapx_, {plr_, pll_, pur_, pul_}, lx_, 
          lz_, airgap_, br_, nper_] := 
        Module[{g, wv, wh, m, g1, g2, g3, g4, px, 
            pz}, \[IndentingNewLine]wv = {lx/2, per/4 - airgap, lz}; 
          wh = wv; \[IndentingNewLine]px = 
            lx/4 + gapx/2; \[IndentingNewLine]pz = 
            gap/2 + lz/2; \[IndentingNewLine]\[IndentingNewLine]g1 = 
            und[pos + {px, pur, pz}, wv, wh, nper, per, br, 
              1]; \[IndentingNewLine]g2 = 
            und[pos + {\(-px\), pul, pz}, wv, wh, nper, per, br, 
              1]; \[IndentingNewLine]g3 = 
            und[pos + {px, plr, \(-pz\)}, wv, wh, nper, 
              per, \(-br\), \(-1\)]; \[IndentingNewLine]g4 = 
            und[pos + {\(-px\), pll, \(-pz\)}, wv, wh, nper, 
              per, \(-br\), \(-1\)]; \[IndentingNewLine]\[IndentingNewLine]g \
= radObjCnt[{g1, g2, g3, 
                g4}]\[IndentingNewLine]];\)\(\[IndentingNewLine]\)\( \
(*\[IndentingNewLine]plr, \ pll, \ pur, \ 
      pul\  : \ \ phase\ of\ lower\ right, \ lower\ left, \ upper\ right, \ 
      upper\ left\ \ magnet\ array\ in\ [
          mm]\ \((resppectively)\)\[IndentingNewLine]\ \[IndentingNewLine]*) \
\)\)\)], "Input"],

Cell[BoxData[
    \(\(apple2[pos_, per_, gap_, gapx_, phase_, lx_, lz_, airgap_, br_, 
          nper_] := Module[{g, wv, wh, m, g1, g2, g3, g4, px, 
            pz}, \[IndentingNewLine]wv = {lx/2, per/4 - airgap, lz}; 
          wh = wv; \[IndentingNewLine]px = 
            lx/4 + gapx/2; \[IndentingNewLine]pz = 
            gap/2 + lz/2; \[IndentingNewLine]\[IndentingNewLine]g1 = 
            und[pos + {px, phase/2, pz}, wv, wh, nper, per, br, 
              1]; \[IndentingNewLine]g2 = 
            und[pos + {\(-px\), \(-phase\)/2, pz}, wv, wh, nper, per, br, 
              1]; \[IndentingNewLine]g3 = 
            und[pos + {px, \(-phase\)/2, \(-pz\)}, wv, wh, nper, 
              per, \(-br\), \(-1\)]; \[IndentingNewLine]g4 = 
            und[pos + {\(-px\), phase/2, \(-pz\)}, wv, wh, nper, 
              per, \(-br\), \(-1\)]; \[IndentingNewLine]\[IndentingNewLine]g \
= radObjCnt[{g1, g2, g3, g4}]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(\(sp8[pos_, per_, gap_, gapx_, 
          phase_, {lxc_, lzc_, colc_}, {lxs_, lzs_, cols_}, airgap_, br_, 
          nper_] := Module[{g, wc, g1, g2, g3, g4, g5, g6, px, 
            pz}, \[IndentingNewLine]wc = {lxc, per/4 - airgap, 
              lzc}; \[IndentingNewLine]px = 0; \[IndentingNewLine]pz = 
            gap/2 + lzc/2; \[IndentingNewLine]g1 = 
            und[pos + {px, \(-phase\)/2, pz}, wc, wc, nper, per, br, 1]; 
          radObjDrwAtr[g1, colc]; \[IndentingNewLine]g2 = 
            und[pos + {px, \(-phase\)/2, \(-pz\)}, wc, wc, nper, 
              per, \(-br\), \(-1\)]; 
          radObjDrwAtr[g2, 
            colc]; \[IndentingNewLine]\[IndentingNewLine]wc = {lxs, 
              per/4 - airgap, lzs}; \[IndentingNewLine]px = 
            lxc/2 + gapx + lxs/2; \[IndentingNewLine]pz = 
            gap/2 + lzs/2; \[IndentingNewLine]\[IndentingNewLine]g3 = 
            und[pos + {px, phase/2, pz}, wc, wc, nper, per, br, 1]; 
          radObjDrwAtr[g3, cols]; \[IndentingNewLine]g4 = 
            und[pos + {px, phase/2, \(-pz\)}, wc, wc, nper, per, br, \(-1\)]; 
          radObjDrwAtr[g4, cols]; \[IndentingNewLine]g5 = 
            und[pos + {\(-px\), phase/2, pz}, wc, wc, nper, per, \(-br\), 1]; 
          radObjDrwAtr[g5, cols]; \[IndentingNewLine]g6 = 
            und[pos + {\(-px\), phase/2, \(-pz\)}, wc, wc, nper, 
              per, \(-br\), \(-1\)]; 
          radObjDrwAtr[g6, cols]; \[IndentingNewLine]\[IndentingNewLine]g = 
            radObjCnt[{g1, g2, g3, g4, g5, 
                g6}]\[IndentingNewLine]];\)\(\[IndentingNewLine]\)\)\)], \
"Input"],

Cell[BoxData[
    \(\(harm[gg_, typ_, per_, pos_, n_:  1] := 
        Module[{c, s, t}, \[IndentingNewLine]nn = 9*n; \[IndentingNewLine]t = 
            radFldLst[gg, typ, pos - {0, per/2, 0}, pos + {0, per/2, 0}, 
              nn]; \[IndentingNewLine]t[\([nn]\)]\  /= 2; 
          t[\([1]\)]\  /= 2; \[IndentingNewLine]c = 
            Table[Cos[n*2*\[Pi]*\((i - 1)\)/\((nn - 1)\)], {i, 1, 
                nn}]; \[IndentingNewLine]s = 
            Table[Sin[n*2*\[Pi]*\((i - 1)\)/\((nn - 1)\)], {i, 1, 
                nn}]; \[IndentingNewLine]c = 
            Apply[Plus, c*t]*2/\((nn - 1)\); \[IndentingNewLine]s = 
            Apply[Plus, s*t]*2/\((nn - 1)\); \[IndentingNewLine]{Sqrt[
              c*c + s*s], ArcTan[s/c]}\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(brms[gg_, typ_, per_, pos_, n_:  1] := 
        Module[{s, t}, \[IndentingNewLine]nn = 
            Round[9*n]; \[IndentingNewLine]t = 
            radFldLst[gg, typ, pos - {0, per/2, 0}, pos + {0, per/2, 0}, 
              nn]; \[IndentingNewLine]t = 
            t*t; \[IndentingNewLine]t[\([nn]\)]\  /= 2; 
          t[\([1]\)]\  /= 2; \[IndentingNewLine]s = 
            Sqrt[Apply[Plus, 
                  t]/\((nn - 1)\)]\[IndentingNewLine]];\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*\ 
      return\ the\ fundamental\ in\ keV\ \ *) \)\(\[IndentingNewLine]\)\(fund[
          gg_, p_, per_, ener_] := 
        Module[{bx, 
            bz}, \[IndentingNewLine]bz = \(harm[gg, "\<bz\>", per, {0, 0, 0}, 
                1]\)[\([1]\)]; \[IndentingNewLine]bx = \(harm[gg, "\<bx\>", 
                per, {0, 0, 0}, 1]\)[\([1]\)]; \[IndentingNewLine]9.5*
            ener*\(ener/
                per\)/\((1 + 0.5*\((0.0934*per*bz)\)^2 + 
                  0.5*\((0.0934*per*
                          bx)\)^2)\)\[IndentingNewLine]];\)\)\)], "Input"],

Cell[BoxData[
    \(\(\( (*\ 
      en\ T2mm3\ \ *) \)\(\[IndentingNewLine]\)\(pot[gg_, {x_, z_}, per_, 
          len_, prec_:  1] := 
        Module[{tx, 
            tz}, \[IndentingNewLine]tz = \(harm[gg, "\<bz\>", per, {x, 0, z}, 
                1]\)[\([1]\)]; \[IndentingNewLine]tx = \(harm[gg, "\<bx\>", 
                per, {x, 0, z}, 
                1]\)[\([1]\)]; \[IndentingNewLine]0.5*\((tx*tx + tz*tz)\)*
            len*\((\(per/2\)/Pi)\)^2\[IndentingNewLine]];\)\)\)], "Input"],

Cell[BoxData[{
    \( (*\ ener\ in\ GeV\ per\ and\ len\ in\ millimeter\ \[IndentingNewLine]\ 
        angx, angz\ and\ in\ micro - rad\ \[IndentingNewLine]vx\ , \ 
      vz\ in\ meter - 
        1\ \ *) \[IndentingNewLine]\[IndentingNewLine]\(angx[gg_, {x_, z_}, 
          per_, len_, ener_, prec_:  1] := \ 
        Module[{p1, p2, h}, \[IndentingNewLine]h = 
            0.2; \[IndentingNewLine]p1 = 
            pot[gg, {x - h/2, z}, per, len, prec]; \[IndentingNewLine]p2 = 
            pot[gg, {x + h/2, z}, per, len, 
              prec]; \[IndentingNewLine]\((p2 - p1)\)/
              h*0.5*\((0.3/
                  ener)\)^2\[IndentingNewLine]];\)\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(angz[gg_, {x_, z_}, per_, len_, ener_, prec_:  1] := \ 
        Module[{p1, p2, h}, \[IndentingNewLine]h = 
            0.2; \[IndentingNewLine]p1 = 
            pot[gg, {x, z - h/2}, per, len, prec]; \[IndentingNewLine]p2 = 
            pot[gg, {x, z + h/2}, per, len, 
              prec]; \[IndentingNewLine]\((p2 - p1)\)/
              h*0.5*\((0.3/
                  ener)\)^2\[IndentingNewLine]];\)\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(vx[gg_, {x_, z_}, per_, len_, ener_, prec_:  1] := \ 
        Module[{p1, p2, p3, h}, \[IndentingNewLine]h = 
            0.2; \[IndentingNewLine]p1 = 
            pot[gg, {x - h/2, z}, per, len, prec]; \[IndentingNewLine]p2 = 
            pot[gg, {x, z}, per, len, prec]; \[IndentingNewLine]p3 = 
            pot[gg, {x + h/2, z}, per, len, prec]; \[IndentingNewLine]4/
              1000*\((p1 + p3 - 2*p2)\)/
              h^2*0.5*\((0.3/
                  ener)\)^2\[IndentingNewLine]];\)\[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(vz[gg_, {x_, z_}, per_, len_, ener_, prec_:  1] := \ 
        Module[{p1, p2, p3, h}, \[IndentingNewLine]h = 
            0.2; \[IndentingNewLine]p1 = 
            pot[gg, {x, z - h/2}, per, len, prec]; \[IndentingNewLine]p2 = 
            pot[gg, {x, z}, per, len, prec]; \[IndentingNewLine]p3 = 
            pot[gg, {x, z + h/2}, per, len, prec]; \[IndentingNewLine]4/
              1000*\((p1 + p3 - 2*p2)\)/
              h^2*0.5*\((0.3/
                  ener)\)^2\[IndentingNewLine]];\)\[IndentingNewLine]\ \), "\
\[IndentingNewLine]", 
    \(\(vc[gg_, {x_, z_}, per_, len_, ener_, prec_:  1] := \ 
        Module[{p1, p2, p3, h}, \[IndentingNewLine]h = 
            0.2; \[IndentingNewLine]p1 = 
            pot[gg, {x + h/2, z - h/2}, per, len, 
              prec]; \[IndentingNewLine]p2 = 
            pot[gg, {x + h/2, z + h/2}, per, len, 
              prec]; \[IndentingNewLine]p3 = 
            pot[gg, {x - h/2, z - h/2}, per, len, 
              prec]; \[IndentingNewLine]p4 = 
            pot[gg, {x - h/2, z + h/2}, per, len, 
              prec]; \[IndentingNewLine]\(\((p2 + p3 - p1 - p4)\)/1000\)/
              h^2*0.5*\((0.3/ener)\)^2\[IndentingNewLine]];\)\)}], "Input"],

Cell[BoxData[
    \(maketable[] := 
      Module[{prec}, \[IndentingNewLine]prec = 1; \[IndentingNewLine]nptx = 
          Round[\((xmax - xmin)\)/dx + 1]; \[IndentingNewLine]nptz = 
          Round[\((zmax - zmin)\)/dz + 1]; \[IndentingNewLine]If[nptx > 100, 
          Print["\<Error to many points in horizontal\>"]]; \
\[IndentingNewLine]If[nptz > 100, 
          Print["\<Error to many points in vertical\>"]]; \[IndentingNewLine]\
\[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine]\[IndentingNewLine] \
(*\ compute\ the\ tables\ *) \[IndentingNewLine]px = 
          Table[i, {i, xmin, xmax, \((xmax - xmin)\)/\((nptx - 1)\)}]/1000 // 
            N; \[IndentingNewLine]pz = 
          Table[j, {j, zmax, zmin, \(-\((zmax - zmin)\)\)/\((nptz - 1)\)}]/
              1000 // N; \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]rx[gg_, xx_, zz_, per_, len_, pre_:  1] := 
          Module[{h, p1, p2}, \[IndentingNewLine]h = 
              0.2; \[IndentingNewLine]p1 = 
              pot[gg, {xx - h/2, zz}, per, len, pre]; \[IndentingNewLine]p2 = 
              pot[gg, {xx + h/2, zz}, per, len, 
                pre]; \[IndentingNewLine]\(-\((p2 - p1)\)\)/
                h*0.5\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]rz[gg_, xx_, zz_, per_, len_, pre_:  1] := 
          Module[{h, p1, p2}, \[IndentingNewLine]h = 
              0.2; \[IndentingNewLine]p1 = 
              pot[gg, {xx, zz - h/2}, per, len, pre]; \[IndentingNewLine]p2 = 
              pot[gg, {xx, zz + h/2}, per, len, 
                pre]; \[IndentingNewLine]\(-\((p2 - p1)\)\)/
                h*0.5\[IndentingNewLine]]; \[IndentingNewLine]\
\[IndentingNewLine]n[a_, np_] := 
          N[Round[a*10^np]/
              10^np]; \[IndentingNewLine]\[IndentingNewLine]\
\[IndentingNewLine]resx = 
          n[Table[rx[g, i, j, per, len, prec], {j, zmax, 
                  zmin, \(-\((zmax - zmin)\)\)/\((nptz - 1)\)}, {i, xmin, 
                  xmax, \((xmax - xmin)\)/\((nptx - 1)\)}]/1000000, 
            digit]; \[IndentingNewLine]\[IndentingNewLine]resz = 
          n[Table[rz[g, i, j, per, len, prec], {j, zmax, 
                  zmin, \(-\((zmax - zmin)\)\)/\((nptz - 1)\)}, {i, xmin, 
                  xmax, \((xmax - xmin)\)/\((nptx - 1)\)}]/1000000, 
            digit]; \[IndentingNewLine]\[IndentingNewLine]gz = 
          ListPlot3D[
            resz, \[IndentingNewLine]MeshRange \[Rule] {{xmin, xmax}, {zmin, 
                  zmax}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<X[mm]\>", \
"\<Z[mm]\>", "\<[T2m2]\>"}, \[IndentingNewLine]PlotLabel \[Rule] "\<Vertical \
Angle\>"]; \[IndentingNewLine]\[IndentingNewLine]gx = 
          ListPlot3D[
            resx, \[IndentingNewLine]MeshRange \[Rule] {{xmin, xmax}, {zmin, 
                  zmax}}, \[IndentingNewLine]AxesLabel \[Rule] {"\<X[mm]\>", \
"\<Z[mm]\>", "\<[T2m2]\>"}, \[IndentingNewLine]PlotLabel \[Rule] \
"\<Horizontal Angle\>"]; \[IndentingNewLine]{gx, 
          gz}\[IndentingNewLine]]\)], "Input"],

Cell[BoxData[
    \(\(exportable[Author_String, Comment_String] := 
        Module[{}, \[IndentingNewLine]data = {}; \[IndentingNewLine]data = 
            Append[data, "\<# Author : \>" <> 
                author]; \[IndentingNewLine]data = 
            Append[data, "\<#\>" <> comment]; \[IndentingNewLine]data = 
            Append[data, "\<# Undulator Length [m]\>"]; \
\[IndentingNewLine]data = 
            Append[data, N[len/1000]]; \[IndentingNewLine]data = 
            Append[data, "\<# Number of Horizontal Points\>"]; \
\[IndentingNewLine]data = Append[data, nptx]; \[IndentingNewLine]data = 
            Append[data, "\<# Number of Vertical Points\>"]; \
\[IndentingNewLine]data = 
            Append[data, nptz]; \[IndentingNewLine]\[IndentingNewLine]data = 
            Append[data, "\<# Horizontal Kick in T2m2 \>"]; \
\[IndentingNewLine]data = 
            Append[data, "\<START\>"]; \[IndentingNewLine]data = 
            Append[data, Insert[px, "\< \>", 1]]; \[IndentingNewLine]Table[
            data = Append[data, Insert[resx[\([i]\)], pz[\([i]\)], 1]], {i, 
              1, nptz}]; \[IndentingNewLine]\[IndentingNewLine]data = 
            Append[data, "\<# Vertical Kick in T2m2 \>"]; \
\[IndentingNewLine]data = 
            Append[data, "\<START\>"]; \[IndentingNewLine]data = 
            Append[data, Insert[px, "\< \>", 1]]; \[IndentingNewLine]Table[
            data = Append[data, Insert[resz[\([i]\)], pz[\([i]\)], 1]], {i, 
              1, nptz}]; \[IndentingNewLine]data];\)\)], "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Build an Undulator ", "Section"],

Cell["\<\
All cells of the Initialization section must be  executed  before \
executing any cell of this section 
It is assumed that the magnetic field is periodic and one must create enough \
periods to be sure that the field in the middle period of the short undulator \
created is a good approximate of the periodic field . To do so one uses the \
parameter nper. A value nper=3 is typically a good compromise between speed \
and accuracy. Once the undulator has been created it is very importnat to \
check its geoemetry and field (in the next sections).\
\>", "Text"],

Cell[CellGroupData[{

Cell["   Vertical Field,  Pure Permanent Magnet   ", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*___  ___  __\ \ Input\ Parameters\ \((to\ edit\ )\)\ ___  ___  ___  \
___  ___  ___  _*) \[IndentingNewLine]\(per = 35;\)\ \  (*\ 
      Undulator\ period\ in\ [mm]\ *) \), "\[IndentingNewLine]", 
    \(\(gap = 10;\)\ \ \  (*\ 
      Magnetic\ Gap\ in\ [mm]*) \), "\[IndentingNewLine]", 
    \(\(br = 1.2;\)\ \ \  (*\ 
      Remanent\ Field\ of\ the\ material\ in\ [
          T]*) \), "\[IndentingNewLine]", 
    \(\(nper = 3;\)\ \  (*\ 
      Number\ of\ periods\ *) \), "\[IndentingNewLine]", 
    \(\(lx = 30;\)\  (*\ 
      Horizontal\ width\ of\ the\ magnet\ blocks\ in\ [
          mm]*) \), "\[IndentingNewLine]", 
    \(\(lz = 18;\)\  (*\ 
      Vertical\ height\ of\ the\ magnet\ blocks\ in\ [
          mm]*) \), "\[IndentingNewLine]", 
    \(\(airgap = 0.5;\) (*\ 
      Airgap\ between\ the\ magnets\ in\ [
          mm]*) \[IndentingNewLine]\[IndentingNewLine] (*___  ___  ___  ___  \
___  _\ \ Start\ Computations\ ___  ___  ___  ___  ___  ___  _*) \), "\
\[IndentingNewLine]", 
    \(\(wv = {lx, per/4 - airgap, lz};\)\), "\[IndentingNewLine]", 
    \(\(wh = wv;\)\), "\[IndentingNewLine]", 
    \(\(p = {0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(radUtiDelAll[];\)\), "\[IndentingNewLine]", 
    \(\(g = 
        und[p + {0, 0, gap/2 + lz/2}, wv, wh, nper, per, br, 
          1];\)\), "\[IndentingNewLine]", 
    \(\(RadTrfZerPara[g, 
        p, {0, 0, 1}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(x = 0;\)\), "\[IndentingNewLine]", 
    \(\(z = 0;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Bz = \>", \(harm[g, "\<bz\>", per, {x, 0, z}, 
            1]\)[\([1]\)], "\< T\>"];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Bz = "\[InvisibleSpace]0.7803482935341416`\
\[InvisibleSpace]" T"\),
      SequenceForm[ "Bz = ", 0.78034829353414159, " T"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["   Horizontal Field ,  Pure Permanent Magnet ", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*___  ___  __\ \ Input\ Parameters\ \((to\ edit\ )\)\ ___  ___  ___  \
___  ___  ___  _*) \[IndentingNewLine]\(per = 35;\)\ \  (*\ 
      Undulator\ period\ in\ [mm]*) \), "\[IndentingNewLine]", 
    \(\(gap = 10;\)\ \  (*\ 
      Magnetic\ Gap\ in\ [mm]*) \), "\[IndentingNewLine]", 
    \(\(gapx = 1;\)\ \ \  (*\ 
      Horizontal\ Gap\ between\ magnet\ arrays\ in\ [
          mm]*) \), "\[IndentingNewLine]", 
    \(\(br = 1.2;\)\ \ \ \  (*\ 
      Remanent\ Field\ of\ the\ material\ in\ [
          T]*) \), "\[IndentingNewLine]", 
    \(\(nper = 3;\)\ \ \ \  (*\ 
      Number\ of\ periods\ *) \), "\[IndentingNewLine]", 
    \(\(lx = 20*2;\)\  (*\ 
      Total\ Horizontal\ width\ of\ the\ magnet\ arrays\ in\ [
          mm]*) \), "\[IndentingNewLine]", 
    \(\(lz = 18;\)\  (*\ 
      Vertical\ height\ of\ the\ magnet\ blocks\ in\ [
          mm]*) \), "\[IndentingNewLine]", 
    \(\(airgap = 0.5;\) (*\ 
      Airgap\ between\ the\ magnets\ in\ [
          mm]*) \[IndentingNewLine]\[IndentingNewLine] (*___  ___  ___  ___  \
___  _\ \ Start\ Computations\ ___  ___  ___  ___  ___  ___  _*) \), "\
\[IndentingNewLine]", 
    \(\(wv = {lx/2, per/8 - airgap, lz};\)\), "\[IndentingNewLine]", 
    \(\(wh = wv;\)\), "\[IndentingNewLine]", 
    \(p = {0, 0, 0}; radUtiDelAll[];\), "\[IndentingNewLine]", 
    \(\(g1 = 
        und[p + {gapx/2 + lx/4, 0, gap/2 + lz/2}, wv, wh, nper, per, br, 
          1];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        und[p + {\(-gapx\)/2 - lx/4, 0, gap/2 + lz/2}, wv, wh, nper, 
          per, \(-br\), 1];\)\), "\[IndentingNewLine]", 
    \(\(g = radObjCnt[{g1, g2}];\)\), "\[IndentingNewLine]", 
    \(\(RadTrfZerPerp[g, 
        p, {0, 0, 1}];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Print["\<Bx = \>", \(harm[g, "\<bx\>", per, {0, 0, 0}, 
            1]\)[\([1]\)], "\< T\>"];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Bx = "\[InvisibleSpace]0.2661048073819471`\
\[InvisibleSpace]" T"\),
      SequenceForm[ "Bx = ", 0.26610480738194708, " T"],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["  \"Hybrid\" with side Magnets", "Subsection"],

Cell[CellGroupData[{

Cell["SPEAR BL11 Wiggler", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\( (*___  ___  __\ \ Input\ Parameters\ \((to\ edit\ )\)\ ___  \
___  ___  ___  ___  ___  _*) \), 
      "\[IndentingNewLine]", \( (*___  ___  ___\ General\ \ \ ___  ___  ___\ *) \
\), "\[IndentingNewLine]", \(gap = 16;\), 
      "                 ", \( (*\ 
        Magnetic\ gap\ in\ [mm]\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(nper = 3;\), 
      "                ", \( (*\ 
        Number\ of\ periods\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(per = 175;\), 
      "             ", \( (*\ Period\ in[mm]\ *) \)}], "\[IndentingNewLine]", 
  
    RowBox[{\(gapoffset = 5;\), 
      "   ", \( (*\ 
        Vertical\ offset\ beween\ poles\ and\ magnets\ in\ [
            mm]\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(\(br = 1.25;\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\( (*\ 
        Remanent\ field\ of\ the\ magnet\ blocks\ in\ [T]\ *) \)\), 
      "\[IndentingNewLine]", \( (*___  ___  ___\ Pole\ \ \ ___  ___  ___\ *) \
\)}], "\[IndentingNewLine]", 
    RowBox[{\(lp = {50, 42, 90};\), 
      " ", \( (*\ 
        Width\ of\ the\ pole\ {\(\(Hor\)\(.\)\), \(\(Long\)\(.\)\), \
\(\(Vert\)\(.\)\)}\ in\ [mm]\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(np = {2, 2, 10};\), 
      "     ", \( (*\ 
        Segmentation\ of\ the\ pole\ {\(\(Hor\)\(.\)\), \(\(Long\)\(.\)\), \(\
\(Vert\)\(.\)\)}\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(\(cp = {1, 0, 1};\)\(\ \ \ \ \ \ \ \ \ \)\( (*\ 
        RGB\ color\ of\ the\ pole\ *) \)\), 
      "\[IndentingNewLine]", \( (*___  ___  ___\ Main\ Magnet\ \ \ \ ___  ___ \
 ___\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(lm = {126, per/2 - lp[\([2]\)], 110};\), 
      "  ", \( (*\ 
        Width\ of\ the\ magnet\ {\(\(Hor\)\(.\)\), \(\(Long\)\(.\)\), \
\(\(Vert\)\(.\)\)}\ in\ [mm]\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(nm = {1, 3, 1};\), 
      "        ", \( (*\ 
        Segmentation\ of\ the\ magnet\ {\(\(Hor\)\(.\)\), \(\(Long\)\(.\)\), \
\(\(Vert\)\(.\)\)}\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(\(cm = {0, 1, 1};\)\(\ \ \ \ \ \ \ \)\( (*\ 
        RGB\ color\ of\ the\ magnet\ *) \)\), 
      "\[IndentingNewLine]", \( (*___  ___  ___\ Side\ Magnet\ \ \ \ ___  ___ \
 ___\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(lms = {36, lp[\([2]\)] - 1, 110};\), 
      "  ", \( (*\ 
        Width\ of\ the\ side\ magnet\ {\(\(Hor\)\(.\)\), \(\(Long\)\(.\)\), \
\(\(Vert\)\(.\)\)}\ in\ [mm]\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(nms = {1, 1, 1};\), 
      "     ", \( (*\ 
        Segmentation\ of\ the\ side\ magnet\ {\(\(Hor\)\(.\)\), \(\(Long\)\(.\
\)\), \(\(Vert\)\(.\)\)}\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(\(cms = {0, 1, 0};\)\(\ \ \ \ \)\( (*\ 
        RGB\ color\ of\ the\ side\ magnet\ *) \)\), "\[IndentingNewLine]", 
      "\[IndentingNewLine]", \( (*___  ___  ___  ___  ___  _\ \ Start\ \
Computations\ ___  ___  ___  ___  ___  ___  _*) \)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["radUtiDelAll",
          FontColor->RGBColor[1, 0, 0]], "[", "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"matp", "=", 
        RowBox[{
          StyleBox["RadMatSteel42",
            FontColor->RGBColor[1, 0, 0]], "[", "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"matm", "=", 
        RowBox[{
          StyleBox["RadMatNdFeB",
            FontColor->RGBColor[1, 0, 0]], "[", "br", "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"matms", "=", 
        RowBox[{
          StyleBox["RadMatNdFeB",
            FontColor->RGBColor[1, 0, 0]], "[", "br", "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(g = 
        hyb[{0, 0, 0}, per, gap, nper, 
          gapoffset, {lp, np, matp, cp}, {lm, nm, matm, cm}, {lms, nms, 
            matms, cms}];\), "\[IndentingNewLine]", 
    RowBox[{"re", "=", 
      RowBox[{
        StyleBox["RadSolve",
          FontColor->RGBColor[1, 0, 0]], "[", \(g, 0.0003, 1000\), 
        "]"}]}], "\[IndentingNewLine]", \(Print["\<Bz(0,0,0) = \>", 
      radFld[g, "\<Bz\>", {0, 0, 0}]]\)}], "Input"],

Cell[BoxData[
    \({0.0002858058916970409`, 2.063799999940187`, 1.1635678960256766`, 
      21}\)], "Output"],

Cell[BoxData[
    InterpretationBox[\("Bz(0,0,0) = "\[InvisibleSpace]1.9905422771159194`\),
      SequenceForm[ "Bz(0,0,0) = ", 1.9905422771159194],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ESRF  W150 on  ID17", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\( (*___  ___  __\ \ Input\ Parameters\ \((to\ edit\ )\)\ ___  \
___  ___  ___  ___  ___  _*) \), 
      "\[IndentingNewLine]", \( (*___  ___  ___\ General\ \ \ ___  ___  ___\ *) \
\), "\[IndentingNewLine]", \(gap = 20;\), 
      "                 ", \( (*\ 
        Magnetic\ gap\ in\ [mm]\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(nper = 3;\), 
      "                ", \( (*\ 
        Number\ of\ periods\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(per = 150;\), 
      "             ", \( (*\ Period\ in[mm]\ *) \)}], "\[IndentingNewLine]", 
  
    RowBox[{\(gapoffset = 0.2;\), 
      "   ", \( (*\ 
        Vertical\ offset\ beween\ poles\ and\ magnets\ in\ [
            mm]\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(\(br = 1.2;\)\(\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \)\( (*\ 
        Remanent\ field\ of\ the\ magnet\ blocks\ in\ [T]\ *) \)\), 
      "\[IndentingNewLine]", \( (*___  ___  ___\ Pole\ \ \ ___  ___  ___\ *) \
\)}], "\[IndentingNewLine]", 
    RowBox[{\(lp = {38, 24, 90};\), 
      " ", \( (*\ 
        Width\ of\ the\ pole\ {\(\(Hor\)\(.\)\), \(\(Long\)\(.\)\), \
\(\(Vert\)\(.\)\)}\ in\ [mm]\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(np = {2, 2, 7};\), 
      "     ", \( (*\ 
        Segmentation\ of\ the\ pole\ {\(\(Hor\)\(.\)\), \(\(Long\)\(.\)\), \(\
\(Vert\)\(.\)\)}\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(\(cp = {1, 0, 1};\)\(\ \ \ \ \ \ \ \ \ \)\( (*\ 
        RGB\ color\ of\ the\ pole\ *) \)\), 
      "\[IndentingNewLine]", \( (*___  ___  ___\ Main\ Magnet\ \ \ \ ___  ___ \
 ___\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(lm = {105, per/2 - lp[\([2]\)], 120};\), 
      "  ", \( (*\ 
        Width\ of\ the\ magnet\ {\(\(Hor\)\(.\)\), \(\(Long\)\(.\)\), \
\(\(Vert\)\(.\)\)}\ in\ [mm]\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(nm = {1, 3, 1};\), 
      "        ", \( (*\ 
        Segmentation\ of\ the\ magnet\ {\(\(Hor\)\(.\)\), \(\(Long\)\(.\)\), \
\(\(Vert\)\(.\)\)}\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(\(cm = {0, 1, 1};\)\(\ \ \ \ \ \ \ \)\( (*\ 
        RGB\ color\ of\ the\ magnet\ *) \)\), 
      "\[IndentingNewLine]", \( (*___  ___  ___\ Side\ Magnet\ \ \ \ ___  ___ \
 ___\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(lms = {30, lp[\([2]\)] - 1, 100};\), 
      "  ", \( (*\ 
        Width\ of\ the\ side\ magnet\ {\(\(Hor\)\(.\)\), \(\(Long\)\(.\)\), \
\(\(Vert\)\(.\)\)}\ in\ [mm]\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(nms = {1, 1, 1};\), 
      "     ", \( (*\ 
        Segmentation\ of\ the\ side\ magnet\ {\(\(Hor\)\(.\)\), \(\(Long\)\(.\
\)\), \(\(Vert\)\(.\)\)}\ *) \)}], "\[IndentingNewLine]", 
    RowBox[{\(\(cms = {0, 1, 0};\)\(\ \ \ \ \)\( (*\ 
        RGB\ color\ of\ the\ side\ magnet\ *) \)\), "\[IndentingNewLine]", 
      "\[IndentingNewLine]", \( (*___  ___  ___  ___  ___  _\ \ Start\ \
Computations\ ___  ___  ___  ___  ___  ___  _*) \)}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{
        StyleBox["radUtiDelAll",
          FontColor->RGBColor[1, 0, 0]], "[", "]"}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"matp", "=", 
        RowBox[{
          StyleBox["RadMatSteel42",
            FontColor->RGBColor[1, 0, 0]], "[", "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"matm", "=", 
        RowBox[{
          StyleBox["RadMatNdFeB",
            FontColor->RGBColor[1, 0, 0]], "[", "br", "]"}]}], 
      ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"matms", "=", 
        RowBox[{
          StyleBox["RadMatNdFeB",
            FontColor->RGBColor[1, 0, 0]], "[", "br", "]"}]}], 
      ";"}], "\[IndentingNewLine]", \(g = 
        hyb[{0, 0, 0}, per, gap, nper, 
          gapoffset, {lp, np, matp, cp}, {lm, nm, matm, cm}, {lms, nms, 
            matms, cms}];\), "\[IndentingNewLine]", 
    RowBox[{"re", "=", 
      RowBox[{
        StyleBox["RadSolve",
          FontColor->RGBColor[1, 0, 0]], "[", \(g, 0.0003, 1000\), 
        "]"}]}], "\[IndentingNewLine]", \(Print["\<Bz(0,0,0) = \>", 
      radFld[g, "\<Bz\>", {0, 0, 0}], "\< T\>"]\)}], "Input"],

Cell[BoxData[
    \({0.0002939070635209451`, 2.063799999762368`, 1.1144841351451367`, 
      22}\)], "Output"],

Cell[BoxData[
    InterpretationBox[\("Bz(0,0,0) = "\[InvisibleSpace]1.837362058990482`\
\[InvisibleSpace]" T"\),
      SequenceForm[ "Bz(0,0,0) = ", 1.837362058990482, " T"],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["   \"Helios\"    Type Helical/Planar  ", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*___  ___  __\ \ Input\ Parameters\ \((to\ edit\ )\)\ ___  ___  ___  \
___  ___  ___  _*) \[IndentingNewLine]\(per = 
        42;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Undulator\ Period\ in\ [mm]\ *) \), "\[IndentingNewLine]", 
    \(\(lx = 30*2;\)\ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Total\ Horizontal\ width\ of\ the\ magnet\ array\ in\ [
          mm]\ *) \), "\[IndentingNewLine]", 
    \(\(lz = 12;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Vertical\ height\ of\ the\ magnet\ blocks\ *) \), \
"\[IndentingNewLine]", 
    \(\(gapx = 1;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Horizontal\ gap\ between\ magnet\ arrays\ in\ [
          mm]\ *) \), "\[IndentingNewLine]", 
    \(\(dgapx = 8;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Dist . \ bw\ Beam\ axis\ to\ magnet\ array\ producing\ Horiz . \ 
          field\ in\ [mm]\ *) \), "\[IndentingNewLine]", 
    \(\(dgapz = 8;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Dist . \ bw\ Beam\ axis\ to\ magnet\ array\ producing\ Vertic . \ 
          field\ in\ [mm]\ *) \), "\[IndentingNewLine]", 
    \(\(phase = 0*per/4;\)\ \ \  (*\ 
      Phase\ in\ [mm]\ *) \), "\[IndentingNewLine]", 
    \(\(br = 1.2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Remanent\ field\ of\ the\ magnet\ blocks\ in\ [
          T]\ *) \), "\[IndentingNewLine]", 
    \(\(nper = 4;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Number\ of\ periods\ *) \), "\[IndentingNewLine]", 
    \(\(airgap = 0;\)\ \ \ \ \ \ \ \ \ \ \  (*\ 
      longitudinal\ airgap\ between\ magnets\ in\ [
          mm]\ *) \[IndentingNewLine] (*___  ___  ___  ___  ___  _\ \ Start\ \
Computations\ ___  ___  ___  ___  ___  ___  _*) \), "\[IndentingNewLine]", 
    \(\(wv = {lx/2, per/4 - airgap, lz};\)\), "\[IndentingNewLine]", 
    \(\(wh = wv;\)\), "\[IndentingNewLine]", 
    \(p = {0, 0, 0}; radUtiDelAll[];\), "\[IndentingNewLine]", 
    \(\(g1 = 
        und[p + {gapx/2 + lx/4, 0, dgapx + lz/2}, wv, wh, nper, per, br, 
          1];\)\), "\[IndentingNewLine]", 
    \(\(g2 = 
        und[p + {\(-gapx\)/2 - lx/4, 0, dgapx + lz/2}, wv, wh, nper, 
          per, \(-br\), 1];\)\), "\[IndentingNewLine]", 
    \(\(g3 = 
        und[p + {0, phase, \(-dgapz\) - lz/2}, wv + {wv[\([1]\)], 0, 0}, 
          wh + {wh[\([1]\)], 0, 0}, nper, per, 
          br, \(-1\)];\)\), "\[IndentingNewLine]", 
    \(\(g = radObjCnt[{g1, g2, g3}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<B (0,0,0) = \>", \(harm[g, "\<b\>", per, {0, 0, 0}, 
            1]\)[\([1]\)], "\< T\>"];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("B (0,0,0) = "\[InvisibleSpace]{0.17169041497300838`, 
          0.26987260159952037`, 0.2714168111273624`}\[InvisibleSpace]" T"\),
      SequenceForm[ 
      "B (0,0,0) = ", {0.17169041497300838, 0.26987260159952037, 
        0.27141681112736238}, " T"],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["  \"Apple II\" Type Helical/Planar  ", "Subsection"],

Cell[CellGroupData[{

Cell["ESRF  HU88 on ID8", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*___  ___  __\ \ Input\ Parameters\ \((to\ edit\ )\)\ ___  ___  ___  \
___  ___  ___  _*) \[IndentingNewLine]\(per = 
        88;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Undulator\ Period\ in\ [mm]\ *) \), "\[IndentingNewLine]", 
    \(\(lx = 30*2;\)\ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Total\ Horizontal\ width\ of\ the\ magnet\ array\ in\ [
          mm]\ *) \), "\[IndentingNewLine]", 
    \(\(lz = 12;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Vertical\ height\ of\ the\ magnet\ blocks\ *) \), \
"\[IndentingNewLine]", 
    \(\(gapx = 1;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Horizontal\ gap\ between\ magnet\ arrays\ in\ [
          mm]\ *) \), "\[IndentingNewLine]", 
    \(\(gap = 16;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Magnetic\ Gap\ in[mm]\ *) \), "\[IndentingNewLine]", 
    \(\(p1 = per*0;\)\ \ \ \ \ \ \ \ \  (*\ 
      Antisym . \ \ motion\ of\ the\ \(girders\ \  : \ 
          Rotate\ the\ Linear\ \(\(Pol\)\(.\)\)\)\ *) \), \
"\[IndentingNewLine]", 
    \(\(p2 = per*0.25;\)\ \  (*\ 
      Symmetric\ L\ motion\ of\ the\ \(girders\  : \ 
            Linear\) \[Rule] \ \(Circular \[Rule] \ 
          Linear\)\ \ *) \), "\[IndentingNewLine]", 
    \(\(br = 1.2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Remanent\ field\ of\ the\ magnet\ blocks\ in\ [
          T]\ *) \), "\[IndentingNewLine]", 
    \(\(nper = 4;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Number\ of\ periods\ *) \), "\[IndentingNewLine]", 
    \(\(airgap = 0;\)\ \ \ \ \ \ \ \ \ \ \  (*\ 
      longitudinal\ airgap\ between\ magnets\ in\ [
          mm]\ *) \[IndentingNewLine] (*___  ___  ___  ___  ___  _\ \ Start\ \
Computations\ ___  ___  ___  ___  ___  ___  _*) \[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(p = {0, 0, 0};\)\), "\[IndentingNewLine]", 
    \(\(radUtiDelAll[];\)\), "\[IndentingNewLine]", 
    \(\(g = 
        apple2G[p, per, gap, 
          gapx, {\(-p1\) + p2/2, \(-p2\)/2, \(-p2\)/2, p1 + p2/2}, lx, lz, 
          airgap, br, nper];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<B (0,0,0) = \>", \(harm[g, "\<b\>", per, {0, 0, 0}, 
            1]\)[\([1]\)], "\< T\>"];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("B (0,0,0) = "\[InvisibleSpace]{0.428339718791376`, 
          2.53991302779065`*^-10, 0.4637915086436354`}\[InvisibleSpace]" T"\),
      
      SequenceForm[ 
      "B (0,0,0) = ", {0.428339718791376, 2.5399130277906502*^-10, 
        0.46379150864363539}, " T"],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["ESRF  HU38 on ID12", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*___  ___  __\ \ Input\ Parameters\ \((to\ edit\ )\)\ ___  ___  ___  \
___  ___  ___  _*) \[IndentingNewLine]\(per = 
        38;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Undulator\ Period\ in\ [mm]\ *) \), "\[IndentingNewLine]", 
    \(\(lx = 25*2;\)\ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Total\ Horizontal\ width\ of\ the\ magnet\ array\ in\ [
          mm]\ *) \), "\[IndentingNewLine]", 
    \(\(lz = 19;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Vertical\ height\ of\ the\ magnet\ blocks\ *) \), \
"\[IndentingNewLine]", 
    \(\(gapx = 1;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Horizontal\ gap\ between\ magnet\ arrays\ in\ [
          mm]\ *) \), "\[IndentingNewLine]", 
    \(\(gap = 16;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Magnetic\ Gap\ in[mm]\ *) \), "\[IndentingNewLine]", 
    \(\(p1 = per*0;\)\ \ \ \ \ \ \ \ \  (*\ 
      Antisym . \ \ motion\ of\ the\ \(girders\ \  : \ 
          Rotate\ the\ Linear\ \(\(Pol\)\(.\)\)\)\ *) \), \
"\[IndentingNewLine]", 
    \(\(p2 = per/2;\)\ \  (*\ 
      Symmetric\ L\ motion\ of\ the\ \(girders\  : \ 
            Linear\) \[Rule] \ \(Circular \[Rule] \ 
          Linear\)\ \ *) \), "\[IndentingNewLine]", 
    \(\(br = 1.2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Remanent\ field\ of\ the\ magnet\ blocks\ in\ [
          T]\ *) \), "\[IndentingNewLine]", 
    \(\(nper = 4;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Number\ of\ periods\ *) \), "\[IndentingNewLine]", 
    \(\(airgap = 0;\)\ \ \ \ \ \ \ \ \ \ \  (*\ 
      longitudinal\ airgap\ between\ magnets\ in\ [
          mm]\ *) \[IndentingNewLine] (*___  ___  ___  ___  ___  _\ \ Start\ \
Computations\ ___  ___  ___  ___  ___  ___  _*) \[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(radUtiDelAll[];\)\), "\[IndentingNewLine]", 
    \(\(g = 
        apple2G[{0, 0, 0}, per, gap, 
          gapx, {\(-p1\) + p2/2, \(-p2\)/2, \(-p2\)/2, p1 + p2/2}, lx, lz, 
          airgap, br, nper];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<B (0,0,0) = \>", \(harm[g, "\<b\>", per, {0, 0, 0}, 
            1]\)[\([1]\)], "\< T\>"];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("B (0,0,0) = "\[InvisibleSpace]{0.3152660226850883`, 
          2.734850792299973`*^-10, 
          0.00038349151905083955`}\[InvisibleSpace]" T"\),
      SequenceForm[ 
      "B (0,0,0) = ", {0.3152660226850883, 2.7348507922999732*^-10, 
        0.00038349151905083955}, " T"],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["  \"Spring8\"  Type Helical/Planar", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*___  ___  __\ \ Input\ Parameters\ \((to\ edit\ )\)\ ___  ___  ___  \
___  ___  ___  _*) \[IndentingNewLine]\(per = 
        88;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Undulator\ Period\ in\ [mm]\ *) \), "\[IndentingNewLine]", 
    \(\(gapx = 1;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Horizontal\ gap\ between\ magnet\ arrays\ in\ [
          mm]\ *) \), "\[IndentingNewLine]", 
    \(\(gap = 16;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Magnetic\ Gap\ in[mm]\ *) \), "\[IndentingNewLine]", 
    \(\(phase = per/4;\)\ \ \  (*\ 
      Phase\ in\ [mm]\ *) \), "\[IndentingNewLine]", 
    \(\(lxc = 14;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Horizontal\ size\ of\ the\ magnets\ of\ the\ middle\ array\ *) \), "\
\[IndentingNewLine]", 
    \(\(lzc = 12;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Vertical\ size\ of\ the\ magnets\ of\ the\ middle\ array\ *) \), "\
\[IndentingNewLine]", 
    \(colc = {1, 0, 0}; \  (*\ 
      RGB\ color\ of\ the\ middle\ array\ *) \[IndentingNewLine]lxs = 
      25; \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Horizontal\ size\ of\ the\ magnets\ of\ the\ side\ arrays\ *) \), "\
\[IndentingNewLine]", 
    \(\(lzs = 16;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Vertical\ size\ of\ the\ magnets\ of\ the\ side\ arrays\ *) \), "\
\[IndentingNewLine]", 
    \(\(cols = {0, 1, 0};\)\ \  (*\ 
      RGB\ color\ of\ the\ side\ arrays\ *) \), "\[IndentingNewLine]", 
    \(\(br = 1.2;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Remanent\ field\ of\ the\ magnet\ blocks\ in\ [
          T]\ *) \), "\[IndentingNewLine]", 
    \(\(nper = 4;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Number\ of\ periods\ *) \), "\[IndentingNewLine]", 
    \(\(airgap = 0.1;\)\ \ \ \ \ \ \ \ \ \ \  (*\ 
      longitudinal\ airgap\ between\ magnets\ in\ [
          mm]\ *) \[IndentingNewLine]\[IndentingNewLine] (*___  ___  ___  ___ \
 ___  _\ \ Start\ Computations\ ___  ___  ___  ___  ___  ___  _*) \), "\
\[IndentingNewLine]", 
    \(\(radUtiDelAll[];\)\), "\[IndentingNewLine]", 
    \(\(g = 
        sp8[{0, 0, 0}, per, gap, gapx, 
          phase, {lxc, lzc, colc}, {lxs, lzs, cols}, airgap, br, 
          nper];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<B (0,0,0) = \>", \(harm[g, "\<b\>", per, {0, 0, 0}, 
            1]\)[\([1]\)], "\< T\>"];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("B (0,0,0) = "\[InvisibleSpace]{0.4629847627010405`, 
          1.0640370351104358`*^-10, 
          0.4547501493015015`}\[InvisibleSpace]" T"\),
      SequenceForm[ 
      "B (0,0,0) = ", {0.4629847627010405, 1.0640370351104358*^-10, 
        0.45475014930150148}, " T"],
      Editable->False]], "Print"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Display Geometry ", "Section"],

Cell["\<\
One Undulator must be created before executing any cell of this \
section \
\>", "Text"],

Cell[BoxData[
    \(\(\( (*\ 
      If\ QuickDraw3D\ is\ installed\ \
*) \)\(\[IndentingNewLine]\)\(radObjDrwQD3D[g];\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(SetOptions[
        Graphics3D, \[IndentingNewLine]Axes \[Rule] 
          True, \[IndentingNewLine]AxesLabel \[Rule] {"\<X[mm] \>", "\<S[mm] \
\>", "\<Z[mm] \>"}, \[IndentingNewLine]AxesStyle \[Rule] 
          Thickness[
            0.003`], \[IndentingNewLine]BoxStyle \[Rule] {Thickness[
              0.001`], \[IndentingNewLine]Dashing[{0.01`, 
                0.01`}]}, \[IndentingNewLine]AmbientLight \[Rule] 
          GrayLevel[0.1`], \[IndentingNewLine]PlotRange \[Rule] 
          All, \[IndentingNewLine]SphericalRegion \[Rule] 
          True, \[IndentingNewLine]ViewPoint \[Rule] {3.5`, \(-3\), 
            1.5`}];\)\[IndentingNewLine]\), "\n", 
    \(\(gra = Show[Graphics3D[radObjDrw[g]]];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.77335 .77607 -8.81901 0 ]
[.77335 .77607 9.18099 9 ]
[.8232 .76241 -2.92859 0 ]
[.8232 .76241 3.07141 9 ]
[.87426 .74841 -5.83446 0 ]
[.87426 .74841 6.16554 9 ]
[.82469 .82489 -19.585 0 ]
[.82469 .82489 20.54 12 ]
[.2785 .19362 -8.84677 -9 ]
[.2785 .19362 9.15323 0 ]
[.43215 .24093 -8.95323 -9 ]
[.43215 .24093 9.04677 0 ]
[.5775 .2857 -3.01774 -9 ]
[.5775 .2857 2.98226 0 ]
[.7152 .32811 -6.09823 -9 ]
[.7152 .32811 5.90177 0 ]
[.84584 .36834 -6.15738 -9 ]
[.84584 .36834 5.84262 0 ]
[.57713 .2232 -20.1812 -12 ]
[.57713 .2232 19.9438 0 ]
[.05722 .28438 -18 -5.77022 ]
[.05722 .28438 0 3.22978 ]
[.05477 .3577 -18 -5.71242 ]
[.05477 .3577 0 3.28758 ]
[.0523 .43184 -6 -5.65401 ]
[.0523 .43184 0 3.34599 ]
[.0498 .50682 -12 -5.595 ]
[.0498 .50682 0 3.405 ]
[.04728 .58266 -12 -5.53536 ]
[.04728 .58266 0 3.46464 ]
[-0.00824 .41632 -40.125 -7.53868 ]
[-0.00824 .41632 0 4.46132 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.74499 .77129 m
.90381 .72772 L
s
.25 Mabswid
.7731 .76357 m
.77298 .75733 L
s
[(-10)] .77335 .77607 -0.02011 -1 Mshowa
.82291 .74991 m
.82276 .74366 L
s
[(0)] .8232 .76241 -0.0238 -1 Mshowa
.87392 .73592 m
.87374 .72967 L
s
[(10)] .87426 .74841 -0.02759 -1 Mshowa
.125 Mabswid
.78297 .76087 m
.78289 .75712 L
s
.79288 .75815 m
.7928 .7544 L
s
.80284 .75542 m
.80276 .75167 L
s
.81285 .75267 m
.81276 .74892 L
s
.83301 .74714 m
.83292 .74339 L
s
.84316 .74435 m
.84307 .74061 L
s
.85337 .74156 m
.85327 .73781 L
s
.86362 .73874 m
.86352 .73499 L
s
.76328 .76627 m
.76321 .76252 L
s
.75351 .76895 m
.75344 .7652 L
s
.88427 .73308 m
.88416 .72933 L
s
.89466 .73023 m
.89456 .72648 L
s
gsave
.82469 .82489 -80.585 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.125 13.000 moveto
(D) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.21779 .1875 m
.8939 .39552 L
s
.25 Mabswid
.27828 .20611 m
.27818 .21236 L
s
[(-50)] .2785 .19362 -0.01703 1 Mshowa
.43208 .25343 m
.43205 .25968 L
s
[(-25)] .43215 .24093 -0.0052 1 Mshowa
.57757 .2982 m
.57761 .30445 L
s
[(0)] .5775 .2857 .00591 1 Mshowa
.71541 .3406 m
.71551 .34685 L
s
[(25)] .7152 .32811 .01637 1 Mshowa
.84617 .38084 m
.84633 .38708 L
s
[(50)] .84584 .36834 .02623 1 Mshowa
.125 Mabswid
.30974 .21579 m
.30969 .21954 L
s
.34085 .22536 m
.3408 .22911 L
s
.3716 .23482 m
.37156 .23857 L
s
.40201 .24418 m
.40198 .24793 L
s
.46182 .26258 m
.46181 .26633 L
s
.49124 .27163 m
.49124 .27538 L
s
.52033 .28058 m
.52034 .28433 L
s
.54911 .28944 m
.54912 .29319 L
s
.60573 .30686 m
.60576 .31061 L
s
.63359 .31543 m
.63363 .31918 L
s
.66115 .32391 m
.6612 .32766 L
s
.68842 .3323 m
.68848 .33605 L
s
.74211 .34882 m
.74217 .35257 L
s
.76853 .35695 m
.76861 .3607 L
s
.79468 .36499 m
.79476 .36874 L
s
.82056 .37296 m
.82065 .3767 L
s
.24646 .19632 m
.24639 .20007 L
s
.87152 .38864 m
.87163 .39239 L
s
gsave
.57713 .2232 -81.1812 -16 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.125 13.000 moveto
(D) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.07024 .25764 m
.05842 .61712 L
s
.25 Mabswid
.06925 .28777 m
.07526 .28947 L
s
[(-20)] .05722 .28438 1 .28227 Mshowa
.06684 .36095 m
.07288 .36258 L
s
[(-10)] .05477 .3577 1 .26943 Mshowa
.06441 .43495 m
.07046 .4365 L
s
[(0)] .0523 .43184 1 .25645 Mshowa
.06195 .50978 m
.06802 .51126 L
s
[(10)] .0498 .50682 1 .24333 Mshowa
.05946 .58546 m
.06555 .58686 L
s
[(20)] .04728 .58266 1 .23008 Mshowa
.125 Mabswid
.06877 .30234 m
.07238 .30335 L
s
.06829 .31695 m
.0719 .31795 L
s
.06781 .33158 m
.07142 .33257 L
s
.06732 .34625 m
.07094 .34723 L
s
.06636 .37568 m
.06998 .37665 L
s
.06587 .39045 m
.0695 .39141 L
s
.06538 .40525 m
.06901 .4062 L
s
.0649 .42008 m
.06853 .42102 L
s
.06392 .44985 m
.06755 .45077 L
s
.06343 .46478 m
.06706 .46569 L
s
.06294 .47974 m
.06658 .48065 L
s
.06244 .49475 m
.06608 .49564 L
s
.06145 .52485 m
.0651 .52573 L
s
.06096 .53995 m
.0646 .54082 L
s
.06046 .55509 m
.06411 .55595 L
s
.05996 .57026 m
.06361 .57111 L
s
.06972 .27324 m
.07333 .27426 L
s
.0702 .25873 m
.0738 .25977 L
s
.05896 .6007 m
.06262 .60153 L
s
.05846 .61598 m
.06212 .6168 L
s
gsave
-0.00824 .41632 -101.125 -11.5387 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Z) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.125 13.000 moveto
(D) show
99.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
[ .01 .01 ] 0 setdash
.07024 .25764 m
.05842 .61712 L
s
.05842 .61712 m
.74499 .77129 L
s
.74499 .77129 m
.7392 .45001 L
s
.7392 .45001 m
.07024 .25764 L
s
.21779 .1875 m
.8939 .39552 L
s
.8939 .39552 m
.90381 .72772 L
s
.90381 .72772 m
.2097 .56067 L
s
.2097 .56067 m
.21779 .1875 L
s
.07024 .25764 m
.05842 .61712 L
s
.05842 .61712 m
.2097 .56067 L
s
.2097 .56067 m
.21779 .1875 L
s
.21779 .1875 m
.07024 .25764 L
s
.7392 .45001 m
.8939 .39552 L
s
.8939 .39552 m
.90381 .72772 L
s
.90381 .72772 m
.74499 .77129 L
s
.74499 .77129 m
.7392 .45001 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
[ ] 0 setdash
.87611 .40024 m .72877 .45219 L .73081 .57065 L p 0 0 .75 r
F P
0 g
s
.68716 .44027 m .72877 .45219 L .87611 .40024 L p 0 0 1 r
F P
0 g
s
.72877 .45219 m .68716 .44027 L .68885 .5596 L p 0 0 .75 r
F P
0 g
s
.68885 .5596 m .73081 .57065 L .72877 .45219 L p 0 0 .75 r
F P
0 g
s
.87611 .40024 m .83426 .38745 L .68716 .44027 L p 0 0 1 r
F P
0 g
s
.68885 .5596 m .68716 .44027 L .83426 .38745 L p 0 0 .748 r
F P
0 g
s
.8317 .38667 m .68462 .43954 L .68628 .55892 L p 0 0 .748 r
F P
0 g
s
.64229 .42741 m .68462 .43954 L .8317 .38667 L p 0 0 1 r
F P
0 g
s
.68462 .43954 m .64229 .42741 L .64358 .54768 L p 0 0 .75 r
F P
0 g
s
.64358 .54768 m .68628 .55892 L .68462 .43954 L p 0 0 .75 r
F P
0 g
s
.73081 .57065 m .87959 .52248 L .87611 .40024 L p 0 0 .75 r
F P
0 g
s
.87959 .52248 m .73081 .57065 L .68885 .5596 L p 0 0 1 r
F P
0 g
s
.88513 .71719 m .88155 .59137 L .73196 .63738 L p 0 0 .75 r
F P
0 g
s
.73196 .63738 m .73406 .75918 L .88513 .71719 L p 0 0 .75 r
F P
0 g
s
.73406 .75918 m .73196 .63738 L .6898 .62683 L p 0 0 .75 r
F P
0 g
s
.6898 .62683 m .73196 .63738 L .88155 .59137 L p 0 0 1 r
F P
0 g
s
.8317 .38667 m .78909 .37365 L .64229 .42741 L p 0 0 1 r
F P
0 g
s
.64358 .54768 m .64229 .42741 L .78909 .37365 L p 0 0 .747 r
F P
0 g
s
.83426 .38745 m .83738 .51061 L .68885 .5596 L p 0 0 .748 r
F P
0 g
s
.68885 .5596 m .83738 .51061 L .87959 .52248 L p 0 0 1 r
F P
0 g
s
.78649 .37285 m .6397 .42667 L .64097 .54699 L p 0 0 .747 r
F P
0 g
s
.59662 .41433 m .6397 .42667 L .78649 .37285 L p 0 0 1 r
F P
0 g
s
.6397 .42667 m .59662 .41433 L .59751 .53554 L p 0 0 .75 r
F P
0 g
s
.59751 .53554 m .64097 .54699 L .6397 .42667 L p 0 0 .75 r
F P
0 g
s
.68628 .55892 m .8348 .50989 L .8317 .38667 L p 0 0 .748 r
F P
0 g
s
.8348 .50989 m .68628 .55892 L .64358 .54768 L p 0 0 1 r
F P
0 g
s
.6898 .62683 m .69153 .74955 L .73406 .75918 L p 0 0 .75 r
F P
0 g
s
.84235 .70684 m .69153 .74955 L .6898 .62683 L p 0 0 .748 r
F P
0 g
s
.88155 .59137 m .83914 .58004 L .6898 .62683 L p 0 0 1 r
F P
0 g
s
.6898 .62683 m .83914 .58004 L .84235 .70684 L p 0 0 .748 r
F P
0 g
s
.83973 .7062 m .83654 .57934 L .68722 .62618 L p 0 0 .748 r
F P
0 g
s
.68722 .62618 m .68893 .74896 L .83973 .7062 L p 0 0 .748 r
F P
0 g
s
.68893 .74896 m .68722 .62618 L .64431 .61544 L p 0 0 .75 r
F P
0 g
s
.64431 .61544 m .68722 .62618 L .83654 .57934 L p 0 0 1 r
F P
0 g
s
.88513 .71719 m .73406 .75918 L .69153 .74955 L p 0 0 1 r
F P
0 g
s
.78649 .37285 m .7431 .35959 L .59662 .41433 L p 0 0 1 r
F P
0 g
s
.59751 .53554 m .59662 .41433 L .7431 .35959 L p 0 0 .745 r
F P
0 g
s
.78909 .37365 m .79181 .49781 L .64358 .54768 L p 0 0 .747 r
F P
0 g
s
.64358 .54768 m .79181 .49781 L .8348 .50989 L p 0 0 1 r
F P
0 g
s
.74045 .35878 m .59399 .41357 L .59485 .53484 L p 0 0 .745 r
F P
0 g
s
.55014 .40101 m .59399 .41357 L .74045 .35878 L p 0 0 1 r
F P
0 g
s
.59399 .41357 m .55014 .40101 L .55061 .52319 L p 0 0 .75 r
F P
0 g
s
.55061 .52319 m .59485 .53484 L .59399 .41357 L p 0 0 .75 r
F P
0 g
s
.64097 .54699 m .78919 .49707 L .78649 .37285 L p 0 0 .747 r
F P
0 g
s
.78919 .49707 m .64097 .54699 L .59751 .53554 L p 0 0 1 r
F P
0 g
s
.64431 .61544 m .64564 .73916 L .68893 .74896 L p 0 0 .75 r
F P
0 g
s
.79615 .69566 m .64564 .73916 L .64431 .61544 L p 0 0 .747 r
F P
0 g
s
.83654 .57934 m .79335 .5678 L .64431 .61544 L p 0 0 1 r
F P
0 g
s
.64431 .61544 m .79335 .5678 L .79615 .69566 L p 0 0 .747 r
F P
0 g
s
.69153 .74955 m .84235 .70684 L .88513 .71719 L p 0 0 1 r
F P
0 g
s
.79349 .69502 m .79071 .5671 L .64168 .61478 L p 0 0 .747 r
F P
0 g
s
.64168 .61478 m .64299 .73856 L .79349 .69502 L p 0 0 .747 r
F P
0 g
s
.64299 .73856 m .64168 .61478 L .59801 .60385 L p 0 0 .75 r
F P
0 g
s
.59801 .60385 m .64168 .61478 L .79071 .5671 L p 0 0 1 r
F P
0 g
s
.83973 .7062 m .68893 .74896 L .64564 .73916 L p 0 0 1 r
F P
0 g
s
.74045 .35878 m .69625 .34528 L .55014 .40101 L p 0 0 1 r
F P
0 g
s
.55061 .52319 m .55014 .40101 L .69625 .34528 L p 0 0 .743 r
F P
0 g
s
.7431 .35959 m .74541 .48477 L .59751 .53554 L p 0 0 .745 r
F P
0 g
s
.59751 .53554 m .74541 .48477 L .78919 .49707 L p 0 0 1 r
F P
0 g
s
.87611 .40024 m .87959 .52248 L .83738 .51061 L p 0 0 .744 r
F P
0 g
s
.83738 .51061 m .83426 .38745 L .87611 .40024 L p 0 0 .744 r
F P
0 g
s
.69355 .34445 m .54746 .40024 L .5479 .52248 L p 0 0 .743 r
F P
0 g
s
.50283 .38745 m .54746 .40024 L .69355 .34445 L p 0 0 1 r
F P
0 g
s
.54746 .40024 m .50283 .38745 L .50285 .51061 L p 0 0 .75 r
F P
0 g
s
.50285 .51061 m .5479 .52248 L .54746 .40024 L p 0 0 .75 r
F P
0 g
s
.59485 .53484 m .74273 .48401 L .74045 .35878 L p 0 0 .745 r
F P
0 g
s
.74273 .48401 m .59485 .53484 L .55061 .52319 L p 0 0 1 r
F P
0 g
s
.59801 .60385 m .59892 .72858 L .64299 .73856 L p 0 0 .75 r
F P
0 g
s
.74909 .68428 m .59892 .72858 L .59801 .60385 L p 0 0 .745 r
F P
0 g
s
.79071 .5671 m .74671 .55534 L .59801 .60385 L p 0 0 1 r
F P
0 g
s
.59801 .60385 m .74671 .55534 L .74909 .68428 L p 0 0 .745 r
F P
0 g
s
.64564 .73916 m .79615 .69566 L .83973 .7062 L p 0 0 1 r
F P
0 g
s
.74637 .68362 m .74402 .55462 L .59534 .60318 L p 0 0 .745 r
F P
0 g
s
.59534 .60318 m .59622 .72797 L .74637 .68362 L p 0 0 .745 r
F P
0 g
s
.59622 .72797 m .59534 .60318 L .55087 .59205 L p 0 0 .75 r
F P
0 g
s
.55087 .59205 m .59534 .60318 L .74402 .55462 L p 0 0 1 r
F P
0 g
s
.79349 .69502 m .64299 .73856 L .59892 .72858 L p 0 0 1 r
F P
0 g
s
.69355 .34445 m .64854 .33069 L .50283 .38745 L p 0 0 1 r
F P
0 g
s
.50285 .51061 m .50283 .38745 L .64854 .33069 L p 0 0 .741 r
F P
0 g
s
.69625 .34528 m .69814 .47148 L .55061 .52319 L p 0 0 .743 r
F P
0 g
s
.55061 .52319 m .69814 .47148 L .74273 .48401 L p 0 0 1 r
F P
0 g
s
.8317 .38667 m .8348 .50989 L .79181 .49781 L p 0 0 .744 r
F P
0 g
s
.79181 .49781 m .78909 .37365 L .8317 .38667 L p 0 0 .744 r
F P
0 g
s
.64578 .32985 m .5001 .38667 L .5001 .50989 L p 0 0 .741 r
F P
0 g
s
.45465 .37365 m .5001 .38667 L .64578 .32985 L p 0 0 1 r
F P
0 g
s
.5001 .38667 m .45465 .37365 L .45423 .49781 L p 0 0 .75 r
F P
0 g
s
.45423 .49781 m .5001 .50989 L .5001 .38667 L p 0 0 .75 r
F P
0 g
s
.5479 .52248 m .69541 .47071 L .69355 .34445 L p 0 0 .743 r
F P
0 g
s
.69541 .47071 m .5479 .52248 L .50285 .51061 L p 0 0 1 r
F P
0 g
s
.55087 .59205 m .55134 .71781 L .59622 .72797 L p 0 0 .75 r
F P
0 g
s
.70114 .67268 m .55134 .71781 L .55087 .59205 L p 0 0 .743 r
F P
0 g
s
.74402 .55462 m .6992 .54264 L .55087 .59205 L p 0 0 1 r
F P
0 g
s
.55087 .59205 m .6992 .54264 L .70114 .67268 L p 0 0 .743 r
F P
0 g
s
.59892 .72858 m .74909 .68428 L .79349 .69502 L p 0 0 1 r
F P
0 g
s
.83914 .58004 m .88155 .59137 L .88513 .71719 L p 0 0 .744 r
F P
0 g
s
.69837 .67201 m .69646 .54191 L .54815 .59137 L p 0 0 .743 r
F P
0 g
s
.54815 .59137 m .5486 .71719 L .69837 .67201 L p 0 0 .743 r
F P
0 g
s
.5486 .71719 m .54815 .59137 L .50287 .58004 L p 0 0 .75 r
F P
0 g
s
.50287 .58004 m .54815 .59137 L .69646 .54191 L p 0 0 1 r
F P
0 g
s
.74637 .68362 m .59622 .72797 L .55134 .71781 L p 0 0 1 r
F P
0 g
s
.64578 .32985 m .59992 .31584 L .45465 .37365 L p 0 0 1 r
F P
0 g
s
.45423 .49781 m .45465 .37365 L .59992 .31584 L p 0 0 .739 r
F P
0 g
s
.64854 .33069 m .64998 .45794 L .50285 .51061 L p 0 0 .741 r
F P
0 g
s
.50285 .51061 m .64998 .45794 L .69541 .47071 L p 0 0 1 r
F P
0 g
s
.78649 .37285 m .78919 .49707 L .74541 .48477 L p 0 0 .744 r
F P
0 g
s
.74541 .48477 m .7431 .35959 L .78649 .37285 L p 0 0 .744 r
F P
0 g
s
.59712 .31498 m .45187 .37285 L .45142 .49707 L p 0 0 .739 r
F P
0 g
s
.4056 .35959 m .45187 .37285 L .59712 .31498 L p 0 0 1 r
F P
0 g
s
.45187 .37285 m .4056 .35959 L .4047 .48477 L p 0 0 .75 r
F P
0 g
s
.4047 .48477 m .45142 .49707 L .45187 .37285 L p 0 0 .75 r
F P
0 g
s
.5001 .50989 m .6472 .45716 L .64578 .32985 L p 0 0 .741 r
F P
0 g
s
.6472 .45716 m .5001 .50989 L .45423 .49781 L p 0 0 1 r
F P
0 g
s
.88513 .71719 m .84235 .70684 L .83914 .58004 L p 0 0 .744 r
F P
0 g
s
.50287 .58004 m .5029 .70684 L .5486 .71719 L p 0 0 .75 r
F P
0 g
s
.65227 .66086 m .5029 .70684 L .50287 .58004 L p 0 0 .741 r
F P
0 g
s
.69646 .54191 m .65079 .52971 L .50287 .58004 L p 0 0 1 r
F P
0 g
s
.50287 .58004 m .65079 .52971 L .65227 .66086 L p 0 0 .741 r
F P
0 g
s
.55134 .71781 m .70114 .67268 L .74637 .68362 L p 0 0 1 r
F P
0 g
s
.79335 .5678 m .83654 .57934 L .83973 .7062 L p 0 0 .744 r
F P
0 g
s
.64945 .66018 m .64799 .52896 L .5001 .57934 L p 0 0 .741 r
F P
0 g
s
.5001 .57934 m .5001 .7062 L .64945 .66018 L p 0 0 .741 r
F P
0 g
s
.5001 .7062 m .5001 .57934 L .45399 .5678 L p 0 0 .75 r
F P
0 g
s
.45399 .5678 m .5001 .57934 L .64799 .52896 L p 0 0 1 r
F P
0 g
s
.69837 .67201 m .5486 .71719 L .5029 .70684 L p 0 0 1 r
F P
0 g
s
.59712 .31498 m .55038 .3007 L .4056 .35959 L p 0 0 1 r
F P
0 g
s
.4047 .48477 m .4056 .35959 L .55038 .3007 L p 0 0 .737 r
F P
0 g
s
.59992 .31584 m .6009 .44415 L .45423 .49781 L p 0 0 .739 r
F P
0 g
s
.45423 .49781 m .6009 .44415 L .6472 .45716 L p 0 0 1 r
F P
0 g
s
.54753 .29982 m .40277 .35878 L .40184 .48401 L p 0 0 .737 r
F P
0 g
s
.35564 .34528 m .40277 .35878 L .54753 .29982 L p 0 0 1 r
F P
0 g
s
.40277 .35878 m .35564 .34528 L .35425 .47148 L p 0 0 .75 r
F P
0 g
s
.35425 .47148 m .40184 .48401 L .40277 .35878 L p 0 0 .75 r
F P
0 g
s
.74045 .35878 m .74273 .48401 L .69814 .47148 L p 0 0 .744 r
F P
0 g
s
.69814 .47148 m .69625 .34528 L .74045 .35878 L p 0 0 .744 r
F P
0 g
s
.45142 .49707 m .59807 .44335 L .59712 .31498 L p 0 0 .739 r
F P
0 g
s
.59807 .44335 m .45142 .49707 L .4047 .48477 L p 0 0 1 r
F P
0 g
s
.83973 .7062 m .79615 .69566 L .79335 .5678 L p 0 0 .744 r
F P
0 g
s
.45399 .5678 m .45355 .69566 L .5001 .7062 L p 0 0 .75 r
F P
0 g
s
.60246 .64881 m .45355 .69566 L .45399 .5678 L p 0 0 .739 r
F P
0 g
s
.64799 .52896 m .60145 .51652 L .45399 .5678 L p 0 0 1 r
F P
0 g
s
.45399 .5678 m .60145 .51652 L .60246 .64881 L p 0 0 .739 r
F P
0 g
s
.5029 .70684 m .65227 .66086 L .69837 .67201 L p 0 0 1 r
F P
0 g
s
.74671 .55534 m .79071 .5671 L .79349 .69502 L p 0 0 .744 r
F P
0 g
s
.59958 .64811 m .5986 .51576 L .45117 .5671 L p 0 0 .739 r
F P
0 g
s
.45117 .5671 m .4507 .69502 L .59958 .64811 L p 0 0 .739 r
F P
0 g
s
.4507 .69502 m .45117 .5671 L .4042 .55534 L p 0 0 .75 r
F P
0 g
s
.4042 .55534 m .45117 .5671 L .5986 .51576 L p 0 0 1 r
F P
0 g
s
.64945 .66018 m .5001 .7062 L .45355 .69566 L p 0 0 1 r
F P
0 g
s
.54753 .29982 m .4999 .28527 L .35564 .34528 L p 0 0 1 r
F P
0 g
s
.35425 .47148 m .35564 .34528 L .4999 .28527 L p 0 0 .735 r
F P
0 g
s
.55038 .3007 m .55088 .43009 L .4047 .48477 L p 0 0 .737 r
F P
0 g
s
.4047 .48477 m .55088 .43009 L .59807 .44335 L p 0 0 1 r
F P
0 g
s
.49698 .28438 m .35276 .34445 L .35134 .47071 L p 0 0 .735 r
F P
0 g
s
.30475 .33069 m .35276 .34445 L .49698 .28438 L p 0 0 1 r
F P
0 g
s
.35276 .34445 m .30475 .33069 L .30286 .45794 L p 0 0 .75 r
F P
0 g
s
.30286 .45794 m .35134 .47071 L .35276 .34445 L p 0 0 .75 r
F P
0 g
s
.69355 .34445 m .69541 .47071 L .64998 .45794 L p 0 0 .744 r
F P
0 g
s
.64998 .45794 m .64854 .33069 L .69355 .34445 L p 0 0 .744 r
F P
0 g
s
.40184 .48401 m .54799 .42928 L .54753 .29982 L p 0 0 .737 r
F P
0 g
s
.54799 .42928 m .40184 .48401 L .35425 .47148 L p 0 0 1 r
F P
0 g
s
.79349 .69502 m .74909 .68428 L .74671 .55534 L p 0 0 .744 r
F P
0 g
s
.4042 .55534 m .40327 .68428 L .4507 .69502 L p 0 0 .75 r
F P
0 g
s
.55167 .63653 m .40327 .68428 L .4042 .55534 L p 0 0 .737 r
F P
0 g
s
.5986 .51576 m .55116 .50309 L .4042 .55534 L p 0 0 1 r
F P
0 g
s
.4042 .55534 m .55116 .50309 L .55167 .63653 L p 0 0 .737 r
F P
0 g
s
.45355 .69566 m .60246 .64881 L .64945 .66018 L p 0 0 1 r
F P
0 g
s
.54874 .63582 m .54826 .50231 L .40132 .55462 L p 0 0 .737 r
F P
0 g
s
.40132 .55462 m .40037 .68362 L .54874 .63582 L p 0 0 .737 r
F P
0 g
s
.40037 .68362 m .40132 .55462 L .35347 .54264 L p 0 0 .75 r
F P
0 g
s
.35347 .54264 m .40132 .55462 L .54826 .50231 L p 0 0 1 r
F P
0 g
s
.6992 .54264 m .74402 .55462 L .74637 .68362 L p 0 0 .744 r
F P
0 g
s
.59958 .64811 m .4507 .69502 L .40327 .68428 L p 0 0 1 r
F P
0 g
s
.49698 .28438 m .44843 .26954 L .30475 .33069 L p 0 0 1 r
F P
0 g
s
.30286 .45794 m .30475 .33069 L .44843 .26954 L p 0 0 .732 r
F P
0 g
s
.4999 .28527 m .49989 .41576 L .35425 .47148 L p 0 0 .735 r
F P
0 g
s
.35425 .47148 m .49989 .41576 L .54799 .42928 L p 0 0 1 r
F P
0 g
s
.44546 .26863 m .30181 .32985 L .29989 .45716 L p 0 0 .732 r
F P
0 g
s
.2529 .31584 m .30181 .32985 L .44546 .26863 L p 0 0 1 r
F P
0 g
s
.30181 .32985 m .2529 .31584 L .25048 .44415 L p 0 0 .75 r
F P
0 g
s
.25048 .44415 m .29989 .45716 L .30181 .32985 L p 0 0 .75 r
F P
0 g
s
.64578 .32985 m .6472 .45716 L .6009 .44415 L p 0 0 .744 r
F P
0 g
s
.6009 .44415 m .59992 .31584 L .64578 .32985 L p 0 0 .744 r
F P
0 g
s
.35134 .47071 m .49695 .41493 L .49698 .28438 L p 0 0 .735 r
F P
0 g
s
.49695 .41493 m .35134 .47071 L .30286 .45794 L p 0 0 1 r
F P
0 g
s
.35347 .54264 m .35205 .67268 L .40037 .68362 L p 0 0 .75 r
F P
0 g
s
.49989 .624 m .35205 .67268 L .35347 .54264 L p 0 0 .735 r
F P
0 g
s
.54826 .50231 m .49989 .48939 L .35347 .54264 L p 0 0 1 r
F P
0 g
s
.35347 .54264 m .49989 .48939 L .49989 .624 L p 0 0 .735 r
F P
0 g
s
.74637 .68362 m .70114 .67268 L .6992 .54264 L p 0 0 .744 r
F P
0 g
s
.40327 .68428 m .55167 .63653 L .59958 .64811 L p 0 0 1 r
F P
0 g
s
.4969 .62328 m .49693 .4886 L .35055 .54191 L p 0 0 .735 r
F P
0 g
s
.35055 .54191 m .34909 .67201 L .4969 .62328 L p 0 0 .735 r
F P
0 g
s
.34909 .67201 m .35055 .54191 L .30179 .52971 L p 0 0 .75 r
F P
0 g
s
.30179 .52971 m .35055 .54191 L .49693 .4886 L p 0 0 1 r
F P
0 g
s
.65079 .52971 m .69646 .54191 L .69837 .67201 L p 0 0 .744 r
F P
0 g
s
.54874 .63582 m .40037 .68362 L .35205 .67268 L p 0 0 1 r
F P
0 g
s
.44546 .26863 m .39596 .2535 L .2529 .31584 L p 0 0 1 r
F P
0 g
s
.25048 .44415 m .2529 .31584 L .39596 .2535 L p 0 0 .73 r
F P
0 g
s
.44843 .26954 m .44791 .40115 L .30286 .45794 L p 0 0 .732 r
F P
0 g
s
.30286 .45794 m .44791 .40115 L .49695 .41493 L p 0 0 1 r
F P
0 g
s
.39293 .25258 m .24991 .31498 L .24746 .44335 L p 0 0 .73 r
F P
0 g
s
.20006 .3007 m .24991 .31498 L .39293 .25258 L p 0 0 1 r
F P
0 g
s
.24991 .31498 m .20006 .3007 L .19711 .43009 L p 0 0 .75 r
F P
0 g
s
.19711 .43009 m .24746 .44335 L .24991 .31498 L p 0 0 .75 r
F P
0 g
s
.59712 .31498 m .59807 .44335 L .55088 .43009 L p 0 0 .744 r
F P
0 g
s
.55088 .43009 m .55038 .3007 L .59712 .31498 L p 0 0 .744 r
F P
0 g
s
.29989 .45716 m .44491 .40031 L .44546 .26863 L p 0 0 .732 r
F P
0 g
s
.44491 .40031 m .29989 .45716 L .25048 .44415 L p 0 0 1 r
F P
0 g
s
.30179 .52971 m .29984 .66086 L .34909 .67201 L p 0 0 .75 r
F P
0 g
s
.44708 .61123 m .29984 .66086 L .30179 .52971 L p 0 0 .732 r
F P
0 g
s
.49693 .4886 m .44762 .47542 L .30179 .52971 L p 0 0 1 r
F P
0 g
s
.30179 .52971 m .44762 .47542 L .44708 .61123 L p 0 0 .732 r
F P
0 g
s
.69837 .67201 m .65227 .66086 L .65079 .52971 L p 0 0 .744 r
F P
0 g
s
.35205 .67268 m .49989 .624 L .54874 .63582 L p 0 0 1 r
F P
0 g
s
.44403 .61049 m .4446 .47461 L .29881 .52896 L p 0 0 .732 r
F P
0 g
s
.29881 .52896 m .29683 .66018 L .44403 .61049 L p 0 0 .732 r
F P
0 g
s
.29683 .66018 m .29881 .52896 L .24912 .51652 L p 0 0 .75 r
F P
0 g
s
.24912 .51652 m .29881 .52896 L .4446 .47461 L p 0 0 1 r
F P
0 g
s
.60145 .51652 m .64799 .52896 L .64945 .66018 L p 0 0 .744 r
F P
0 g
s
.4969 .62328 m .34909 .67201 L .29984 .66086 L p 0 0 1 r
F P
0 g
s
.39293 .25258 m .34245 .23715 L .20006 .3007 L p 0 0 1 r
F P
0 g
s
.19711 .43009 m .20006 .3007 L .34245 .23715 L p 0 0 .727 r
F P
0 g
s
.39596 .2535 m .3949 .38625 L .25048 .44415 L p 0 0 .73 r
F P
0 g
s
.25048 .44415 m .3949 .38625 L .44491 .40031 L p 0 0 1 r
F P
0 g
s
.33936 .2362 m .19701 .29982 L .19402 .42928 L p 0 0 .727 r
F P
0 g
s
.14622 .28527 m .19701 .29982 L .33936 .2362 L p 0 0 1 r
F P
0 g
s
.19701 .29982 m .14622 .28527 L .14269 .41576 L p 0 0 .75 r
F P
0 g
s
.14269 .41576 m .19402 .42928 L .19701 .29982 L p 0 0 .75 r
F P
0 g
s
.54753 .29982 m .54799 .42928 L .49989 .41576 L p 0 0 .744 r
F P
0 g
s
.49989 .41576 m .4999 .28527 L .54753 .29982 L p 0 0 .744 r
F P
0 g
s
.24746 .44335 m .39184 .38539 L .39293 .25258 L p 0 0 .73 r
F P
0 g
s
.39184 .38539 m .24746 .44335 L .19711 .43009 L p 0 0 1 r
F P
0 g
s
.64945 .66018 m .60246 .64881 L .60145 .51652 L p 0 0 .744 r
F P
0 g
s
.24912 .51652 m .24663 .64881 L .29683 .66018 L p 0 0 .75 r
F P
0 g
s
.39321 .5982 m .24663 .64881 L .24912 .51652 L p 0 0 .73 r
F P
0 g
s
.4446 .47461 m .3943 .46117 L .24912 .51652 L p 0 0 1 r
F P
0 g
s
.24912 .51652 m .3943 .46117 L .39321 .5982 L p 0 0 .73 r
F P
0 g
s
.29984 .66086 m .44708 .61123 L .4969 .62328 L p 0 0 1 r
F P
0 g
s
.3901 .59744 m .39123 .46035 L .24608 .51576 L p 0 0 .73 r
F P
0 g
s
.24608 .51576 m .24356 .64811 L .3901 .59744 L p 0 0 .73 r
F P
0 g
s
.24356 .64811 m .24608 .51576 L .19544 .50309 L p 0 0 .75 r
F P
0 g
s
.19544 .50309 m .24608 .51576 L .39123 .46035 L p 0 0 1 r
F P
0 g
s
.55116 .50309 m .5986 .51576 L .59958 .64811 L p 0 0 .744 r
F P
0 g
s
.44403 .61049 m .29683 .66018 L .24663 .64881 L p 0 0 1 r
F P
0 g
s
.33936 .2362 m .28787 .22047 L .14622 .28527 L p 0 0 1 r
F P
0 g
s
.14269 .41576 m .14622 .28527 L .28787 .22047 L p 0 0 .724 r
F P
0 g
s
.34245 .23715 m .34083 .37105 L .19711 .43009 L p 0 0 .727 r
F P
0 g
s
.19711 .43009 m .34083 .37105 L .39184 .38539 L p 0 0 1 r
F P
0 g
s
.28472 .21951 m .14311 .28438 L .13955 .41493 L p 0 0 .724 r
F P
0 g
s
.09133 .26954 m .14311 .28438 L .28472 .21951 L p 0 0 1 r
F P
0 g
s
.14311 .28438 m .09133 .26954 L .08722 .40115 L p 0 0 .75 r
F P
0 g
s
.08722 .40115 m .13955 .41493 L .14311 .28438 L p 0 0 .75 r
F P
0 g
s
.49698 .28438 m .49695 .41493 L .44791 .40115 L p 0 0 .744 r
F P
0 g
s
.44791 .40115 m .44843 .26954 L .49698 .28438 L p 0 0 .744 r
F P
0 g
s
.19402 .42928 m .33771 .37018 L .33936 .2362 L p 0 0 .727 r
F P
0 g
s
.33771 .37018 m .19402 .42928 L .14269 .41576 L p 0 0 1 r
F P
0 g
s
.19544 .50309 m .19238 .63653 L .24356 .64811 L p 0 0 .75 r
F P
0 g
s
.33825 .5849 m .19238 .63653 L .19544 .50309 L p 0 0 .727 r
F P
0 g
s
.39123 .46035 m .33992 .44664 L .19544 .50309 L p 0 0 1 r
F P
0 g
s
.19544 .50309 m .33992 .44664 L .33825 .5849 L p 0 0 .727 r
F P
0 g
s
.59958 .64811 m .55167 .63653 L .55116 .50309 L p 0 0 .744 r
F P
0 g
s
.24663 .64881 m .39321 .5982 L .44403 .61049 L p 0 0 1 r
F P
0 g
s
.33508 .58413 m .33678 .4458 L .19234 .50231 L p 0 0 .727 r
F P
0 g
s
.19234 .50231 m .18925 .63582 L .33508 .58413 L p 0 0 .727 r
F P
0 g
s
.18925 .63582 m .19234 .50231 L .1407 .48939 L p 0 0 .75 r
F P
0 g
s
.1407 .48939 m .19234 .50231 L .33678 .4458 L p 0 0 1 r
F P
0 g
s
.49989 .48939 m .54826 .50231 L .54874 .63582 L p 0 0 .744 r
F P
0 g
s
.3901 .59744 m .24356 .64811 L .19238 .63653 L p 0 0 1 r
F P
0 g
s
.28472 .21951 m .2322 .20346 L .09133 .26954 L p 0 0 1 r
F P
0 g
s
.08722 .40115 m .09133 .26954 L .2322 .20346 L p 0 0 .721 r
F P
0 g
s
.28787 .22047 m .28568 .35555 L .14269 .41576 L p 0 0 .724 r
F P
0 g
s
.14269 .41576 m .28568 .35555 L .33771 .37018 L p 0 0 1 r
F P
0 g
s
.44546 .26863 m .44491 .40031 L .3949 .38625 L p 0 0 .744 r
F P
0 g
s
.3949 .38625 m .39596 .2535 L .44546 .26863 L p 0 0 .744 r
F P
0 g
s
.13955 .41493 m .28249 .35466 L .28472 .21951 L p 0 0 .724 r
F P
0 g
s
.28249 .35466 m .13955 .41493 L .08722 .40115 L p 0 0 1 r
F P
0 g
s
.1407 .48939 m .13707 .624 L .18925 .63582 L p 0 0 .75 r
F P
0 g
s
.28217 .57133 m .13707 .624 L .1407 .48939 L p 0 0 .724 r
F P
0 g
s
.33678 .4458 m .28444 .43181 L .1407 .48939 L p 0 0 1 r
F P
0 g
s
.1407 .48939 m .28444 .43181 L .28217 .57133 L p 0 0 .724 r
F P
0 g
s
.54874 .63582 m .49989 .624 L .49989 .48939 L p 0 0 .744 r
F P
0 g
s
.19238 .63653 m .33825 .5849 L .3901 .59744 L p 0 0 1 r
F P
0 g
s
.27893 .57055 m .28123 .43096 L .13755 .4886 L p 0 0 .724 r
F P
0 g
s
.13755 .4886 m .13388 .62328 L .27893 .57055 L p 0 0 .724 r
F P
0 g
s
.13388 .62328 m .13755 .4886 L .0849 .47542 L p 0 0 .75 r
F P
0 g
s
.0849 .47542 m .13755 .4886 L .28123 .43096 L p 0 0 1 r
F P
0 g
s
.44762 .47542 m .49693 .4886 L .4969 .62328 L p 0 0 .744 r
F P
0 g
s
.33508 .58413 m .18925 .63582 L .13707 .624 L p 0 0 1 r
F P
0 g
s
.2322 .20346 m .2294 .33973 L .08722 .40115 L p 0 0 .721 r
F P
0 g
s
.08722 .40115 m .2294 .33973 L .28249 .35466 L p 0 0 1 r
F P
0 g
s
.39293 .25258 m .39184 .38539 L .34083 .37105 L p 0 0 .744 r
F P
0 g
s
.34083 .37105 m .34245 .23715 L .39293 .25258 L p 0 0 .744 r
F P
0 g
s
.0849 .47542 m .08066 .61123 L .13388 .62328 L p 0 0 .75 r
F P
0 g
s
.22492 .55749 m .08066 .61123 L .0849 .47542 L p 0 0 .721 r
F P
0 g
s
.28123 .43096 m .22781 .41668 L .0849 .47542 L p 0 0 1 r
F P
0 g
s
.0849 .47542 m .22781 .41668 L .22492 .55749 L p 0 0 .721 r
F P
0 g
s
.4969 .62328 m .44708 .61123 L .44762 .47542 L p 0 0 .744 r
F P
0 g
s
.13707 .624 m .28217 .57133 L .33508 .58413 L p 0 0 1 r
F P
0 g
s
.3943 .46117 m .4446 .47461 L .44403 .61049 L p 0 0 .744 r
F P
0 g
s
.27893 .57055 m .13388 .62328 L .08066 .61123 L p 0 0 1 r
F P
0 g
s
.33936 .2362 m .33771 .37018 L .28568 .35555 L p 0 0 .744 r
F P
0 g
s
.28568 .35555 m .28787 .22047 L .33936 .2362 L p 0 0 .744 r
F P
0 g
s
.44403 .61049 m .39321 .5982 L .3943 .46117 L p 0 0 .744 r
F P
0 g
s
.08066 .61123 m .22492 .55749 L .27893 .57055 L p 0 0 1 r
F P
0 g
s
.33992 .44664 m .39123 .46035 L .3901 .59744 L p 0 0 .744 r
F P
0 g
s
.28472 .21951 m .28249 .35466 L .2294 .33973 L p 0 0 .744 r
F P
0 g
s
.2294 .33973 m .2322 .20346 L .28472 .21951 L p 0 0 .744 r
F P
0 g
s
.3901 .59744 m .33825 .5849 L .33992 .44664 L p 0 0 .744 r
F P
0 g
s
.28444 .43181 m .33678 .4458 L .33508 .58413 L p 0 0 .744 r
F P
0 g
s
.33508 .58413 m .28217 .57133 L .28444 .43181 L p 0 0 .744 r
F P
0 g
s
.22781 .41668 m .28123 .43096 L .27893 .57055 L p 0 0 .744 r
F P
0 g
s
.27893 .57055 m .22492 .55749 L .22781 .41668 L p 0 0 .744 r
F P
0 g
s
[ .01 .01 ] 0 setdash
.21779 .1875 m
.8939 .39552 L
s
.8939 .39552 m
.90381 .72772 L
s
.90381 .72772 m
.2097 .56067 L
s
.2097 .56067 m
.21779 .1875 L
s
.07024 .25764 m
.05842 .61712 L
s
.05842 .61712 m
.2097 .56067 L
s
.2097 .56067 m
.21779 .1875 L
s
.21779 .1875 m
.07024 .25764 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000182000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00K03oool3000000@0oooo0P00002[0?ooo`00J`3oool01@000000oooo0?ooo`3oool00000
0080oooo00@000000?ooo`3oool00000ZP3oool006D0oooo1@0000050?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0Z03oool006l0oooo00@000000?ooo`3oool000000P3oool0
0`000000oooo0?ooo`2X0?ooo`00J`3oool4000000<0oooo00@000000?ooo`3oool00000ZP3oool0
06/0oooo00<000000?ooo`3oool0103oool010000000oooo0?ooo`00000h0?ooo`8000003P3oool2
00000600oooo001O0?ooo`<000002@3oool5000000<0oooo0P00000i0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0GP3oool005h0oooo0P0000000`3oool000000000000200000440
oooo0`0000050?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000030?ooo`030000003oool0oooo05h0oooo001M0?ooo`030000003oool0000000@0
oooo1000000n0?ooo`040000003oool0oooo000000@0oooo00h000000?ooo`3oool000000?ooo`00
0000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0GP3oool0
05X0oooo0P0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`0000000P00000n0?oo
o`030000003oool0oooo0080oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool0
00000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0GP3oool005P0oooo0P0000050?oo
o`030000003oool0oooo00D00000103oool4000003P0oooo0P0000050?ooo`0>0000003oool0oooo
0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool0
oooo05h0oooo001E0?ooo`8000002@3oool2000000040000^0000000002n0000_P<00000103oool5
000003@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`02000000040?ooo`000000
oooo0?ooo`80000000<0oooo0000003oool00`3oool00`000000oooo0?ooo`1N0?ooo`00E03oool0
0`000000oooo0?ooo`070?ooo`8000000`000;P00`000000002n0000_P030000_P<000000P3oool2
00000080oooo0`00000K0?ooo`D000000P3oool3000000`0oooo00@000000?ooo`3oool00000103o
ool2000000h0oooo0P00001P0?ooo`00D@3oool2000000T0oooo0P0000000`000;P000000000^002
0000^003000000000;h0002n00H0002n0`0000050?ooo`@000006@3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00<000000?ooo`3oool02P3oool3000007H0oooo001?0?ooo`8000002@3o
ool2000000<0002h00D000000000^0000;P0002h0000000;0000_P030000003oool0oooo00<0oooo
1`00000>0?ooo`D000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo08<0oooo
001<0?ooo`8000002P3oool2000000D0002h00D000000000^0000;P0002h0000000;0000_P@00000
203oool4000001@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`230?ooo`00B`3o
ool00`000000oooo0?ooo`080?ooo`8000002`000;P00`000000002n0000_P090000_P8000000P00
0;h5000000D0oooo00<000000?ooo`0000000P00000>0?ooo`060000003oool0oooo0?ooo`000000
oooo100000260?ooo`00B03oool2000000X0oooo0P0000090000^005000000000;P0002h0000^000
00002`000;h2000000L0002n10000000103oool000000?ooo`3oool5000000/0oooo00L000000?oo
o`3oool0oooo0000003oool0000008T0oooo00170?ooo`030000003oool0oooo00L0oooo0`00000;
0000^005000000000;P0002h0000^00000002`000;h2000000/0002n0P0000060?ooo`D00000203o
ool300000080oooo1@0000250?ooo`00@`3oool2000000X0oooo0P00000>0000^005000000000;P0
002h0000^00000002`000;h2000000`0002n0`0000050?ooo`040000003oool000000?ooo`<00000
U03oool00480oooo00<000000?ooo`3oool0203oool200000100002h00D000000000^0000;P0002h
0000000;0000_P80000030000;h00`000000002n0000_P05000000H0oooo1000002A0?ooo`00?`3o
ool2000000X0oooo0P00000F0000^003000000000;h0002n00T0002n0P00000<0000_P0300000000
0;h0002n00D0002n100000030?ooo`030000003oool0000000<00000SP3oool003h0oooo00<00000
0?ooo`3oool0203oool2000001@0002h00D000000000^0000;P0002h0000000;0000_P8000003000
0;h00`000000002n0000_P090000_P8000001@3oool00`000000oooo00000003000008X0oooo000l
0?ooo`030000003oool0oooo00P0oooo0P00000F0000^005000000000;P0002h0000^00000002`00
0;h2000000`0002n00<000000000_P000;h02P000;h4000000D0oooo00<000000?ooo`0000000`00
000M0?ooo`800000J03oool003/0oooo100000060?ooo`80000060000;P01@000000002h0000^000
0;P0000000/0002n0P00000<0000_P03000000000;h0002n00X0002n0P0000020000_P@0000000<0
oooo0000003oool00P3oool5000001T0oooo00@000000?ooo`3oool00000I`3oool003/0oooo00H0
00000?ooo`3oool0oooo0000003oool4000001h0002h00<000000000_P000;h02@000;h2000000`0
002n00<000000000_P000;h02P000;h2000000H0002n100000050?ooo`@000005P3oool010000000
oooo0?ooo`00001W0?ooo`00;03oool5000000<0oooo0P0000050?ooo`030000003oool0oooo00<0
oooo0P00000P0000^003000000000;h0002n00T0002n0P00000<0000_P03000000000;h0002n00X0
002n0P00000:0000_P8000000`3oool00`000000oooo0?ooo`0500000180oooo00@000000?ooo`3o
ool00000I`3oool002d0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`000004
0?ooo`030000003oool0oooo0080oooo00<000000000^0000;P06`000;P00`000000002h0000^002
0000^003000000000;h0002n00T0002n0P00000<0000_P03000000000;h0002n00X0002n0P00000;
0000_P<000001P3oool6000000l0oooo00@000000?ooo`3oool00000I`3oool002H0oooo1@000003
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool2000000<0oooo00<0
00000000^0000;P06`000;P01@000000002h0000^0000;P0000000`0002n0P00000<0000_P030000
00000;h0002n00X0002n0P00000;0000_P03000000000;h0002n00@00000103oool00`000000oooo
0?ooo`04000000`0oooo00@000000?ooo`3oool00000I`3oool002l0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool00P3oool00`000000
002h0000^00K0000^005000000000;P0002h0000^000000030000;h2000000`0002n00<000000000
_P000;h02P000;h2000000/0002n00<000000000_P000;h010000;h4000000D0oooo00<000000?oo
o`0000000P00000:0?ooo`800000J03oool002`0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo000000@0oooo00<000000?ooo`3oool00P3oool00`000000002h0000^00O
0000^003000000000;h0002n00X0002n0P00000<0000_P03000000000;h0002n00X0002n0P00000;
0000_P03000000000;h0002n00P0002n1@0000020?ooo`L00000L03oool002`0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000@0oooo0P0000030?ooo`0300000000
0;P0002h01l0002h00<000000000_P000;h02P000;h2000000`0002n00<000000000_P000;h02P00
0;h2000000/0002n00<000000000_P000;h02@000;h200000080002n0`0000050?ooo`@00000K@3o
ool002d0oooo0`0000040?ooo`8000001@3oool00`000000oooo0?ooo`020?ooo`03000000000;P0
002h01/0002h00D000000000^0000;P0002h0000000<0000_P80000030000;h00`000000002n0000
_P0:0000_P8000002`000;h00`000000002n0000_P090000_P8000001@000;h3000000<0oooo0P00
0000103oool0000000000000001Z0?ooo`00>P3oool2000000@0oooo00<000000000^0000;P06`00
0;P01@000000002h0000^0000;P0000000`0002n0P00000<0000_P03000000000;h0002n00X0002n
0P00000;0000_P03000000000;h0002n00T0002n0P0000080000_P<000001P3oool4000001T0oooo
1@0000020?ooo`<00000@`3oool003X0oooo0P0000040?ooo`03000000000;P0002h01/0002h00D0
00000000^0000;P0002h0000000<0000_P80000030000;h00`000000002n0000_P0:0000_P800000
2`000;h00`000000002n0000_P090000_P8000002`000;h3000000@0oooo1P00000G0?ooo`060000
003oool0oooo0000003oool000000`3oool00`000000oooo0?ooo`100?ooo`00>P3oool2000000@0
oooo00<000000000^0000;P07`000;P00`000000002n0000_P0:0000_P8000002`000;h2000000`0
002n0P00000;0000_P03000000000;h0002n00T0002n0P00000;0000_P03000000000;h0002n00<0
000000D0oooo0000003oool0oooo000000020?ooo`<000005@3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0400oooo000j0?ooo`800000103oool00`000000002h0000^00O0000^003
000000000;h0002n00X0002n0P00000;0000_P80000030000;h2000000/0002n00<000000000_P00
0;h02@000;h2000000/0002n00<000000000_P000;h00`000;h3000000D0oooo1@00000C0?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool0@03oool003/0oooo00<000000?ooo`3oool0
0P3oool00`000000002h0000^00K0000^005000000000;P0002h0000^000000030000;h2000000/0
002n0P00000<0000_P8000002`000;h00`000000002n0000_P090000_P8000002`000;h00`000000
002n0000_P060000_P<000000P3oool00`000000oooo0?ooo`06000000`0oooo00H000000?ooo`3o
ool0oooo0000003oool4000004<0oooo000j0?ooo`800000103oool00`000000002h0000^00K0000
^005000000000;P0002h0000^000000030000;h2000000/0002n0P00000<0000_P8000002`000;h0
0`000000002n0000_P090000_P8000002`000;h00`000000002n0000_P090000_P@000001@3oool5
000000T0oooo00L000000?ooo`3oool0oooo0000003oool0000004H0oooo000j0?ooo`800000103o
ool00`000000002h0000^00K0000^005000000000;P0002h0000^000000030000;h2000000/0002n
0P00000<0000_P8000002`000;h00`000000002n0000_P090000_P8000002`000;h00`000000002n
0000_P090000_P8000000P000;h4000000060?ooo`000000oooo0?ooo`000000oooo0`0000070?oo
o`<000000P3oool500000480oooo000j0?ooo`030000003oool0oooo00<0oooo00<000000000^000
0;P07`000;P00`000000002n0000_P0:0000_P8000002`000;h2000000`0002n00<000000000_P00
0;h02P000;h00`000000002n0000_P090000_P8000002`000;h00`000000002n0000_P090000_P80
00001P000;h3000000@0oooo1@00001@0?ooo`00>P3oool00`000000oooo0?ooo`030?ooo`030000
00000;P0002h01l0002h00<000000000_P000;h02P000;h2000000/0002n0P00000<0000_P030000
00000;h0002n00X0002n00<000000000_P000;h02@000;h2000000/0002n00<000000000_P000;h0
2@000;h2000000T0002n0P0000030?ooo`030000003oool0oooo00D00000C03oool003X0oooo0P00
00040?ooo`03000000000;P0002h01/0002h00D000000000^0000;P0002h0000000<0000_P800000
2`000;h2000000`0002n00<000000000_P000;h02P000;h00`000000002n0000_P090000_P800000
2`000;h00`000000002n0000_P090000_P8000002P000;h3000000L0oooo00<000000?ooo`000000
0P0000190?ooo`00>P3oool00`000000oooo0?ooo`030?ooo`03000000000;P0002h01/0002h00D0
00000000^0000;P0002h0000000<0000_P8000002`000;h2000000`0002n00<000000000_P000;h0
2P000;h00`000000002n0000_P090000_P8000002`000;h00`000000002n0000_P090000_P800000
2P000;h00`000000002n0000_P04000000<0oooo00@000000?ooo`3oool0oooo1000000J0?ooo`<0
0000103oool2000002<0oooo000/0?ooo`<00000103oool2000000D0oooo00<000000?ooo`3oool0
0P3oool00`000000002h0000^00L0000^003000000000;P0002h00@000002P000;h2000000/0002n
0P00000<0000_P03000000000;h0002n00X0002n00<000000000_P000;h02@000;h2000000/0002n
00<000000000_P000;h02@000;h2000000X0002n00<000000000_P000;h010000;h3000000L0oooo
1000000F0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000R0?oo
o`00;@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00P3oool00`000000002h0000^00L0000^0<0000010000?l5000000D0002n0P00000;0000
_P80000030000;h00`000000002n0000_P0:0000_P03000000000;h0002n00T0002n0P00000;0000
_P03000000000;h0002n00T0002n0P00000:0000_P03000000000;h0002n00L0002n1@0000020?oo
o`040000003oool000000?ooo`@000005P3oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0200oooo000U0?ooo`D000000`3oool00`000000oooo0?ooo`020?ooo`040000003oool0
oooo000000@0oooo0P0000030?ooo`03000000000;P0002h01X0002h0`00000;0000o`@0000000<0
002n0000000000002`000;h2000000`0002n00<000000000_P000;h02P000;h00`000000002n0000
_P090000_P8000002`000;h00`000000002n0000_P090000_P8000002P000;h00`000000002n0000
_P080000_P8000000P000;h4000000@0oooo1@00000C0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool0803oool002d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`0000040?ooo`030000003oool0oooo0080oooo00<000000000^0000;P060000;P200000080003o
00<000000000o`000?l03@000?l3000000/0002n0P00000<0000_P03000000000;h0002n00X0002n
00<000000000_P000;h02@000;h2000000/0002n00<000000000_P000;h02@000;h2000000X0002n
00<000000000_P000;h020000;h2000000H0002n0`000000103oool000000?ooo`3oool5000000`0
oooo100000030?ooo`040000003oool0oooo00000280oooo000]0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`03000000000;P0002h
01D0002h0`0000040000o`03000000000?l0003o00`0003o00<000000000^@0000000`0000090000
_P80000030000;h00`000000002n0000_P0:0000_P03000000000;h0002n00T0002n0P00000;0000
_P03000000000;h0002n00T0002n0P00000:0000_P03000000000;h0002n00P0002n0P0000090000
_P800000103oool00`000000oooo00000003000000T0oooo00<000000?ooo`3oool0103oool01000
0000oooo0?ooo`00000R0?ooo`00;03oool2000000@0oooo00@000000?ooo`3oool00000103oool2
000000<0oooo00<000000000^0000;P04`000;P2000000L0003o00<000000000o`000?l020000?l2
000000040000^@0000000000000000@0003o100000050000_P80000030000;h00`000000002n0000
_P0:0000_P03000000000;h0002n00T0002n0P00000;0000_P03000000000;h0002n00T0002n0P00
000:0000_P03000000000;h0002n00P0002n0P00000:0000_P@000000`3oool00`000000oooo0?oo
o`05000000D0oooo1@0000030?ooo`8000008`3oool002d0oooo00<000000?ooo`3oool00`3oool2
000000D0oooo00<000000?ooo`3oool00P3oool00`000000002h0000^00A0000^08000004P000?l2
000000030000^@000000000000/0003o100000000`000;h000000000000<0000_P03000000000;h0
002n00X0002n00<000000000_P000;h02@000;h2000000/0002n00<000000000_P000;h02@000;h2
000000X0002n00<000000000_P000;h020000;h2000000X0002n0P0000020000_P<000001@3oool6
000002l0oooo000j0?ooo`030000003oool0oooo0080oooo00<000000000^0000;P03P000;P30000
00/0003o00<000000000o`000?l00`000?l600000140003o1@00000:0000_P03000000000;h0002n
00X0002n00<000000000_P000;h02@000;h2000000/0002n0P00000:0000_P8000002P000;h00`00
0000002n0000_P080000_P8000002P000;h2000000D0002n0`0000030?ooo`040000003oool0oooo
0?ooo`@00000;03oool003X0oooo00<000000?ooo`3oool00P3oool00`000000002h0000^00<0000
^08000003P000?l010000000003o0000o`000?l2000000030000^@000000000001<0003o0P000004
0000o`<000001`000;h00`000000002n0000_P0:0000_P03000000000;h0002n00T0002n0P00000;
0000_P8000002P000;h2000000X0002n00<000000000_P000;h020000;h2000000X0002n0P000008
0000_PD00000103oool5000002T0oooo000j0?ooo`8000000`3oool00`000000002h0000^00:0000
^080000040000?l00`000000003o0000000400000140003o0`00000:0000o`<0000010000;h00`00
0000002n0000_P0:0000_P03000000000;h0002n00T0002n0P00000;0000_P8000002P000;h20000
00X0002n00<000000000_P000;h020000;h2000000X0002n0P0000090000_P8000000P000;h30000
0080oooo00<000000?ooo`0000001@00000U0?ooo`00>P3oool00`000000oooo0?ooo`020?ooo`03
000000000;P0002h00L0002h0`00000A0000o`D000004P000?l3000000l0003o0`0000000`000;h0
00000000_P0;0000_P03000000000;h0002n00T0002n0P00000;0000_P8000002P000;h2000000X0
002n00<000000000_P000;h020000;h2000000X0002n0P0000090000_P8000001@000;h3000000D0
oooo1@00000R0?ooo`00>P3oool00`000000oooo0?ooo`020?ooo`03000000000;P0002h00D0002h
0P00000B0000o`D000004@000?l4000001@0003o1000000:0000_P03000000000;h0002n00T0002n
0P00000;0000_P8000002P000;h2000000X0002n00<000000000_P000;h020000;h2000000X0002n
0P0000090000_P80000020000;h4000000060?ooo`000000oooo0?ooo`000000oooo0`00000O0?oo
o`00>P3oool2000000<0oooo00<000000000^0000;P00`000;P200000180003o100000000`000?l0
00000000o`0?0000o`<000005P000?l00`000000003o0000o`020000o`<000001`000;h00`000000
002n0000_P090000_P8000002`000;h2000000X0002n0P00000:0000_P03000000000;h0002n00P0
002n0P00000:0000_P8000002@000;h2000000T0002n0P00000010000;h000000000000000040?oo
o`D00000703oool000/0oooo0P00000>0?ooo`8000007@3oool00`000000oooo0?ooo`020?ooo`03
000000000;P0002h00<000004@000?l5000000<0003o00<000000000o`000?l030000?l3000001@0
003o0P00000:0000o`<0000010000;h00`000000002n0000_P090000_P8000002`000;h2000000X0
002n0P00000:0000_P03000000000;h0002n00P0002n0P00000:0000_P8000002@000;h2000000T0
002n0P0000040000_P8000000P3oool010000000oooo0?ooo`3oool3000001X0oooo000;0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`020?ooo`<0
00004P000?l4000000H0003o00<000000000o`000?l02@000?l4000001<0003o0`00000?0000o`<0
000000<0002n000000000;h02P000;h2000000/0002n0P00000:0000_P8000002P000;h2000000T0
002n0P00000:0000_P8000002@000;h2000000T0002n0P0000060000_P<00000103oool2000001X0
oooo00020?ooo`D00000103oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0080
oooo00<000000000o`00000040000?l4000000P0003o00<000000000o`000?l01`000?l3000001<0
003o0`00000E0000o`@000002@000;h2000000/0002n0P00000:0000_P8000002P000;h2000000T0
002n0P00000:0000_P8000002@000;h2000000T0002n0P0000090000_P8000000`3oool00`000000
oooo0?ooo`0H0?ooo`000P3oool01@000000oooo0?ooo`3oool0000000@0oooo00h000000?ooo`3o
ool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?oo
o`3oool06`3oool2000000H0oooo1@0000080000o`@000004`000?l3000001<0003o0`00000F0000
o`03000000000?l0003o0080003o100000050000_P8000002`000;h2000000X0002n0P00000:0000
_P8000002@000;h2000000X0002n0P0000090000_P8000002@000;h2000000T0002n00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`000`3oool00`000000oooo0?ooo`050?ooo`0>
0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?oo
o`030000003oool0oooo01/0oooo00<000000?ooo`3oool02P3oool400000080003o1000000=0000
o`03000000000?l0003o0080003o1000000B0000o`<000005@000?l2000000/0003o100000000`00
0;h000000000000;0000_P8000002P000;h2000000X0002n0P00000:0000_P8000002@000;h20000
00T0002n0P0000090000_P8000002@000;h00`000000oooo0?ooo`0M0?ooo`00103oool00`000000
oooo0?ooo`040?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool0
00000?ooo`0000030?ooo`030000003oool0oooo01<0oooo0P0000060?ooo`030000003oool0oooo
00h0oooo0`0000000`000?l000000000o`0=0000o`03000000000?l0003o00<000004`000?l30000
01@0003o0`00000A0000o`D000002@000;h2000000X0002n0P00000:0000_P8000002P000;h20000
00T0002n0P0000090000_P8000002@000;h2000000T0002n00<000000?ooo`3oool00P3oool00`00
0000oooo0?ooo`0H0?ooo`001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080
000000@0oooo0000003oool0oooo0P0000000`3oool000000?ooo`030?ooo`030000003oool0oooo
0180oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0C0?ooo`<000002`000?l6
00000100003o0`00000D0000o`<000004`000?l2000000@0003o0`0000060000_P8000002P000;h2
000000X0002n0P00000:0000_P8000002@000;h2000000T0002n0P0000090000_P8000002@000;h0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01P0oooo00020?ooo`050000003oool0oooo
0?ooo`000000103oool2000000h0oooo0P00000D0?ooo`040000003oool0oooo000000D0oooo00<0
00000?ooo`3oool05P3oool3000000H0003o1000000010000;P000000000_P000;h5000000T0003o
0`00000D0000o`<000004@000?l3000000X0003o0`0000030000_P8000002P000;h2000000X0002n
0P00000:0000_P8000002P000;h00`000000002n0000_P070000_P8000002@000;h2000000T0002n
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`000P3oool5000002X0oooo00@0
00000?ooo`3oool00000103oool2000001/0oooo0`00000010000?l000000000000000040000^003
000000000;h0002n00D0002n1@00000010000?l0000000000000000D0000o`<000004@000?l40000
00l0003o1@00000:0000_P8000002P000;h2000000X0002n0P00000:0000_P03000000000;h0002n
00L0002n0P0000090000_P8000002@000;h00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01P0oooo000a0?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool06`3oool30000
00<0002h00@000000000^0000;P0000030000;h400000180003o0`00000A0000o`<000005@000?l4
000000P0002n0P00000:0000_P8000002P000;h2000000X0002n00<000000000_P000;h01`000;h2
000000T0002n0P0000090000_P030000003oool0oooo01d0oooo000a0?ooo`040000003oool0oooo
000000@0oooo0`00000J0?ooo`8000001P000;P010000000002h0000^000000=0000_P0300000000
0;h0002n00<0000030000?l300000140003o0`00000F0000o`80000010000?l4000000@0002n0P00
000:0000_P8000002P000;h2000000X0002n00<000000000_P000;h01`000;h2000000T0002n0P00
00090000_P030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool00380oooo0P000005
0?ooo`800000603oool3000000P0002h00@000000000^0000;P000003@000;h00`000000002n0000
_P030000_P<000001`000?l300000140003o0`00000C0000o`@000002`000?l3000000030000_P00
0000000000X0002n0P00000:0000_P8000002P000;h00`000000002n0000_P080000_P8000002000
0;h2000000T0002n00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`00>@3oool0
0`000000oooo0?ooo`0E0?ooo`8000003P000;P00`000000002n0000_P0;0000_P03000000000;h0
002n00H0002n0`00000010000?l0000000000000000A0000o`<000004`000?l400000140003o1000
00090000_P8000002P000;h2000000X0002n00<000000000_P000;h020000;h2000000P0002n0P00
00090000_P030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool003T0oooo00<00000
0?ooo`3oool04P3oool300000100002h00<000000000_P000;h02`000;h00`000000002n0000_P09
0000_PD000003P000?l3000001<0003o0`00000C0000o`8000000`000?l3000000H0002n0P00000:
0000_P8000002P000;h00`000000002n0000_P080000_P80000020000;h2000000T0002n00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`0H0?ooo`00>@3oool200000140oooo0P00000@0000
^004000000000;P0002h000000d0002n00<000000000_P000;h02P000;h200000080002n10000007
0000o`<000004`000?l400000100003o100000090000o`<000000`000;h2000000X0002n0P00000:
0000_P03000000000;h0002n00P0002n0P0000090000_P80000020000;h00`000000oooo0?ooo`0M
0?ooo`00>@3oool00`000000oooo0?ooo`0=0?ooo`<000004P000;P010000000002h0000^000000=
0000_P03000000000;h0002n00X0002n0P0000060000_P@0000000@0003o00000000000000004P00
0?l400000100003o1000000?0000o`D000002P000;h2000000X0002n00<000000000_P000;h02000
0;h2000000T0002n0P0000080000_P030000003oool0oooo0080oooo00<000000?ooo`3oool0603o
ool003T0oooo00<000000?ooo`3oool02`3oool2000001@0002h00D000000000^0000;P0002h0000
000=0000_P03000000000;h0002n00X0002n0P00000:0000_PD000003P000?l400000140003o0`00
000E0000o`@0000020000;h2000000X0002n00<000000000_P000;h020000;h2000000T0002n0P00
00080000_P030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool003T0oooo00<00000
0?ooo`3oool0203oool3000001X0002h00<000000000_P000;h02`000;h00`000000002n0000_P0:
0000_P8000002`000;h200000080002n0`0000080000o`@000004@000?l4000001@0003o0`000004
0000o`@0000010000;h2000000X0002n00<000000000_P000;h020000;h2000000T0002n0P000008
0000_P030000003oool0oooo0080oooo00<000000?ooo`3oool0603oool003T0oooo0P0000070?oo
o`8000007@000;P00`000000002n0000_P0;0000_P03000000000;h0002n00X0002n0P00000;0000
_P8000001@000;h3000000<0003o0`00000A0000o`@000004`000?l4000000/0003o0`0000000`00
0;h000000000000:0000_P03000000000;h0002n00P0002n0P0000090000_P8000002@000;h01@00
0000oooo0?ooo`3oool0000001X0oooo000i0?ooo`030000003oool0oooo00<0oooo0`00000K0000
^005000000000;P0002h0000^00000003@000;h00`000000002n0000_P0:0000_P8000002`000;h2
000000P0002n1000000@0000o`@000004`000?l400000140003o1@0000080000_P03000000000;h0
002n00P0002n0P0000090000_P8000002@000;h00`000000oooo0?ooo`0L0?ooo`00>@3oool00`00
0000oooo0?ooo`020?ooo`03000000000;P0002h01`0002h00D000000000^0000;P0002h0000000=
0000_P03000000000;h0002n00X0002n0P00000;0000_P8000002`000;h4000000X0003o1000000C
0000o`@000004`000?l2000000@0003o100000040000_P03000000000;h0002n00P0002n0P000009
0000_P8000002@000;h01@000000oooo0?ooo`3oool0000001X0oooo000i0?ooo`8000000`3oool0
0`000000002h0000^00L0000^005000000000;P0002h0000^00000003@000;h00`000000002n0000
_P0:0000_P8000002`000;h2000000`0002n00<000000000_P000;h0100000040000o`<000004`00
0?l500000100003o1000000;0000o`<0000000<0002n000000000;h02@000;h2000000T0002n0P00
00090000_P050000003oool0oooo0?ooo`0000006P3oool003T0oooo00<000000?ooo`3oool00P3o
ool00`000000002h0000^00P0000^003000000000;h0002n00/0002n00<000000000_P000;h02P00
0;h2000000/0002n0P00000<0000_P03000000000;h0002n00@0002n1@00000B0000o`D000004000
0?l400000140003o100000080000_P8000002@000;h2000000T0002n00D000000?ooo`3oool0oooo
0000000J0?ooo`00>@3oool00`000000oooo0?ooo`020?ooo`03000000000;P0002h0200002h00<0
00000000_P000;h02`000;h00`000000002n0000_P0:0000_P8000002`000;h2000000`0002n00<0
00000000_P000;h020000;h5000000/0003o1@00000A0000o`<000004`000?l00`000000003o0000
o`020000o`@0000010000;h2000000T0002n0P0000090000_P030000003oool0oooo01`0oooo000[
0?ooo`<00000103oool2000000D0oooo00<000000?ooo`3oool00P3oool00`000000002h0000^00L
0000^005000000000;P0002h0000^00000003@000;h00`000000002n0000_P0:0000_P8000002`00
0;h2000000`0002n00<000000000_P000;h02@000;h200000080002n0`0000050000o`D000004@00
0?l300000140003o0`00000;0000o`<0000000<0002n0000000000002@000;h2000000T0002n00<0
00000?ooo`3oool0703oool002`0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00
00040?ooo`8000000`3oool00`000000002h0000^00L0000^005000000000;P0002h0000^0000000
3@000;h00`000000002n0000_P0:0000_P8000002`000;h2000000`0002n00<000000000_P000;h0
2@000;h2000000D0002n1`00000A0000o`<000004@000?l300000140003o1@0000070000_P800000
2@000;h01@000000oooo0?ooo`3oool0000001X0oooo000/0?ooo`030000003oool0oooo0080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`020?ooo`03000000000;P0002h01`0
002h00D000000000^0000;P0002h0000000=0000_P03000000000;h0002n00X0002n0P00000;0000
_P80000030000;h00`000000002n0000_P090000_P80000020000;h3000000l0003o0`00000A0000
o`<000004`000?l2000000@0003o0`0000040000_P8000002@000;h01@000000oooo0?ooo`3oool0
000001X0oooo000/0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000103oool0
0`000000oooo0?ooo`020?ooo`03000000000;P0002h0200002h00<000000000_P000;h02P000;h2
000000`0002n0P00000;0000_P80000030000;h00`000000002n0000_P090000_P8000002`000;h4
000000P0003o1000000@0000o`@0000040000?l4000000X0003o0`0000000`000;h0000000000009
0000_P050000003oool0oooo0?ooo`0000006P3oool002`0oooo00<000000?ooo`3oool00P3oool0
10000000oooo0?ooo`0000040?ooo`030000003oool0oooo0080oooo00<000000000^0000;P08000
0;P00`000000002n0000_P0:0000_P80000030000;h2000000/0002n0P00000<0000_P0300000000
0;h0002n00T0002n0P00000;0000_P8000000P000;h400000080003o0`00000@0000o`@000004000
0?l400000100003o0`0000090000_P030000003oool0oooo01`0oooo000[0?ooo`800000103oool0
10000000oooo0?ooo`0000040?ooo`8000000`3oool00`000000002h0000^00L0000^00500000000
0;P0002h0000^000000030000;h2000000`0002n0P00000;0000_P80000030000;h00`000000002n
0000_P090000_P8000002`000;h2000000H0002n0`00000@0000o`<000004@000?l300000180003o
1P0000070000_P030000003oool0oooo01`0oooo000/0?ooo`030000003oool0oooo00<0oooo0P00
00050?ooo`030000003oool0oooo0080oooo00<000000000^0000;P070000;P01@000000002h0000
^0000;P0000000`0002n0P00000<0000_P8000002`000;h2000000`0002n00<000000000_P000;h0
2@000;h2000000/0002n0P0000090000_PD0000020000?l300000140003o0`00000@0000o`H00000
1@000?l3000000@0002n00D000000?ooo`3oool0oooo0000000J0?ooo`00>@3oool00`000000oooo
0?ooo`020?ooo`03000000000;P0002h01`0002h00D000000000^0000;P0002h0000000<0000_P80
000030000;h00`000000002n0000_P0:0000_P80000030000;h00`000000002n0000_P090000_P80
00002`000;h2000000X0002n0P0000020000_P@0000000@0003o00000000000000004@000?l30000
0100003o1P00000;0000o`<0000000<0002n0000003oool00P3oool00`000000oooo0?ooo`0H0?oo
o`00>@3oool2000000<0oooo00<000000000^0000;P080000;P00`000000002n0000_P0:0000_P80
000030000;h00`000000002n0000_P0:0000_P80000030000;h00`000000002n0000_P090000_P80
00002`000;h2000000X0002n0P0000060000_P<000003`000?l300000100003o1P00000A0000o`80
00000`3oool00`000000oooo0?ooo`0H0?ooo`00>@3oool00`000000oooo0?ooo`020?ooo`030000
00000;P0002h0200002h00<000000000_P000;h02P000;h2000000`0002n00<000000000_P000;h0
2P000;h2000000`0002n00<000000000_P000;h02@000;h2000000/0002n0P00000:0000_P800000
2@000;h5000000L0003o1000000?0000o`H000004P000?l00`000000oooo0?ooo`0O0?ooo`00>@3o
ool00`000000oooo0?ooo`020?ooo`03000000000;P0002h01`0002h00D000000000^0000;P0002h
0000000<0000_P80000030000;h00`000000002n0000_P0:0000_P80000030000;h00`000000002n
0000_P090000_P8000002`000;h2000000X0002n0P00000:0000_P8000000P000;h4000000040000
o`0000000000000000l0003o1P00000@0000o`<00000903oool003T0oooo00<000000?ooo`3oool0
0P3oool00`000000002h0000^00L0000^005000000000;P0002h0000^000000030000;h2000000`0
002n00<000000000_P000;h02P000;h2000000`0002n00<000000000_P000;h02@000;h2000000/0
002n0P00000:0000_P8000002P000;h2000000H0002n0`00000=0000o`H0000040000?l3000000d0
oooo00<000000?ooo`3oool05`3oool003T0oooo00<000000?ooo`3oool00P3oool00`000000002h
0000^00L0000^005000000000;P0002h0000^000000030000;h2000000`0002n00<000000000_P00
0;h02P000;h2000000`0002n00<000000000_P000;h02@000;h2000000/0002n0P00000:0000_P80
00002P000;h2000000T0002n1@0000050000o`H000003`000?l400000100oooo00<000000?ooo`3o
ool05`3oool003P0oooo0P0000030?ooo`03000000000;P0002h0240002h00<000000000_P000;h0
2P000;h2000000`0002n00<000000000_P000;h02P000;h2000000/0002n0P00000;0000_P800000
2`000;h2000000X0002n0P00000:0000_P8000002P000;h200000080002n2000000?0000o`<00000
503oool00`000000oooo0?ooo`0G0?ooo`00>03oool2000000<0oooo00<000000000^0000;P07@00
0;P01@000000002h0000^0000;P0000000`0002n0P00000<0000_P03000000000;h0002n00X0002n
0P00000;0000_P8000002`000;h2000000/0002n0P00000:0000_P8000002P000;h2000000X0002n
0P0000060000_P<000003@000?l300000340oooo000h0?ooo`8000000`3oool00`000000002h0000
^00M0000^005000000000;P0002h0000^000000030000;h2000000`0002n00<000000000_P000;h0
2P000;h2000000/0002n0P00000;0000_P8000002`000;h2000000X0002n0P00000:0000_P800000
2P000;h2000000T0002n0P0000070000o`@00000=03oool003P0oooo0P0000030?ooo`0300000000
0;P0002h01d0002h00<000000000^0000;P01000000:0000_P80000030000;h00`000000002n0000
_P0:0000_P8000002`000;h2000000/0002n0P00000;0000_P8000002P000;h2000000X0002n0P00
000:0000_P8000002P000;h4000000040000o`0000000000000001h0oooo00<000000?ooo`3oool0
5`3oool003P0oooo00<000000?ooo`3oool00P3oool00`000000002h0000^00M0000^0<000001000
0?l5000000D0002n0P00000<0000_P03000000000;h0002n00X0002n0P00000;0000_P8000002`00
0;h2000000/0002n0P00000:0000_P8000002P000;h2000000X0002n0P00000:0000_P0400000000
0;h0002n0000_PD000007@3oool00`000000oooo0?ooo`0G0?ooo`00:@3oool5000000<0oooo0P00
00050?ooo`030000003oool0oooo0080oooo00<000000000^0000;P06@000;P4000000<0003o00<0
00000000o`000?l00P0000040000o`@0000000<0002n00000000000030000;h00`000000002n0000
_P0:0000_P8000002`000;h2000000/0002n0P00000;0000_P8000002P000;h2000000X0002n0P00
000:0000_P8000002P000;h00`000000002n0000_P060000_P<000006P3oool00`000000oooo0?oo
o`0G0?ooo`00:P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo
0P0000030?ooo`03000000000;P0002h01L0002h0`00000;0000o`03000000000?l0000000800000
0`000?l5000000X0002n00<000000000_P000;h02P000;h2000000/0002n0P00000;0000_P800000
2`000;h2000000X0002n0P00000:0000_P8000002P000;h2000000X0002n00<000000000_P000;h0
20000;h500000300oooo000[0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000
103oool00`000000oooo0?ooo`020?ooo`03000000000;P0002h01<0002h1000000C0000o`040000
00000?l00000000000@0003o0`0000070000_P03000000000;h0002n00X0002n0P00000;0000_P80
00002`000;h2000000/0002n0P00000:0000_P8000002P000;h2000000X0002n0P00000:0000_P03
000000000;h0002n00P0002n0P0000030000_PD000004@3oool00`000000oooo0?ooo`0G0?ooo`00
;03oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00P3oool00`000000
oooo0?ooo`020?ooo`03000000000;P0002h0100002h1@00000B0000o`@0000000<0003o00000000
00000P0000050000o`<0000010000;h00`000000002n0000_P0:0000_P8000002`000;h2000000/0
002n0P00000;0000_P8000002P000;h2000000X0002n0P00000:0000_P8000002P000;h00`000000
002n0000_P080000_P80000020000;h2000000l0oooo00<000000?ooo`3oool05`3oool002T0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000000@0oooo00<000000?oo
o`3oool00P3oool00`000000002h0000^00?0000^0<000004P000?l4000000T0003o0`0000040000
o`<0000000<0002n000000000;h02`000;h2000000/0002n0P00000;0000_P8000002`000;h20000
00X0002n0P00000:0000_P8000002P000;h2000000X0002n00<000000000_P000;h020000;h20000
00T0002n1@00000;0?ooo`030000003oool0oooo01L0oooo000Y0?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000040?ooo`<000000P3oool00`000000002h0000^00<
0000^0<000004`000?l300000140003o0`0000020000o`@000002P000;h2000000/0002n0P00000;
0000_P8000002`000;h2000000X0002n0P00000:0000_P8000002P000;h2000000X0002n00<00000
0000_P000;h020000;h2000000T0002n0P0000030000_PD000001P3oool00`000000oooo0?ooo`0G
0?ooo`00:P3oool3000000@0oooo0P0000050?ooo`030000003oool0oooo0080oooo00<000000000
^0000;P02@000;P3000001<0003o1000000F0000o`@000000P000?l5000000D0002n0P00000;0000
_P8000002`000;h2000000/0002n0P00000:0000_P8000002P000;h2000000X0002n0P00000:0000
_P03000000000;h0002n00P0002n0P0000090000_P80000020000;h2000001h0oooo000h0?ooo`03
0000003oool0oooo0080oooo00<000000000^0000;P01`000;P2000001<0003o1000000E0000o`<0
00001@000?l00`000000003o0000000200000080003o100000000`000;h000000000000;0000_P80
00002`000;h2000000/0002n0P00000:0000_P8000002P000;h2000000X0002n0P00000:0000_P03
000000000;h0002n00P0002n0P0000090000_P8000002@000;h00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo01L0oooo000h0?ooo`030000003oool0oooo0080oooo00<000000000^0000;P0
0P000;P500000180003o1000000E0000o`<000003@000?l010000000003o0000000000020000o`D0
00002@000;h2000000/0002n0P00000;0000_P8000002P000;h2000000/0002n00<000000000_P00
0;h020000;h2000000X0002n00<000000000_P000;h020000;h2000000T0002n0P0000090000_P03
0000003oool0oooo0080oooo00<000000?ooo`3oool05`3oool003P0oooo0P0000030?ooo`040000
00000;P0002h0000^0<000004P000?l4000001D0003o0`00000D0000o`D000000P000?l4000000D0
002n0P00000;0000_P8000002`000;h2000000X0002n0P00000;0000_P03000000000;h0002n00P0
002n0P00000:0000_P03000000000;h0002n00P0002n0P0000090000_P8000002@000;h00`000000
oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo000h0?ooo`030000003oool0oooo0080oooo
1000000C0000o`<000005@000?l3000001<0003o100000050000o`03000000000?l0003o00<0003o
100000000`000;h000000000000;0000_P8000002`000;h2000000X0002n0P00000;0000_P030000
00000;h0002n00P0002n0P00000:0000_P03000000000;h0002n00P0002n0P0000090000_P800000
2@000;h00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo000h0?ooo`030000003o
ool0oooo0080oooo00<000000000o`0000004@000?l4000001@0003o0`00000C0000o`@000002`00
0?l3000000@0003o1@0000090000_P8000002`000;h2000000X0002n0P00000;0000_P0300000000
0;h0002n00T0002n00<000000000_P000;h020000;h00`000000002n0000_P080000_P8000002@00
0;h2000000T0002n00<000000?ooo`3oool0703oool003P0oooo0`0000050?ooo`D000002@000?l4
000001@0003o0`00000C0000o`@000004P000?l4000000@0003o100000050000_P8000002`000;h2
000000X0002n0P00000;0000_P03000000000;h0002n00T0002n00<000000000_P000;h020000;h0
0`000000002n0000_P080000_P8000002@000;h2000000T0002n00<000000?ooo`3oool00P3oool0
0`000000oooo0?ooo`0G0?ooo`00>03oool3000000X0oooo100000020000o`@0000050000?l30000
01<0003o1000000B0000o`@0000010000?l3000000@0003o100000000`000;h000000000000;0000
_P8000002P000;h2000000/0002n00<000000000_P000;h02@000;h00`000000002n0000_P080000
_P03000000000;h0002n00P0002n0P0000090000_P8000002@000;h00`000000oooo0?ooo`020?oo
o`030000003oool0oooo01L0oooo000m0?ooo`<000002@3oool3000001@0003o0`00000C0000o`@0
00004P000?l4000000`0003o0P0000040000o`D000002@000;h2000000X0002n0P00000;0000_P03
000000000;h0002n00T0002n00<000000000_P000;h020000;h2000000T0002n0P0000090000_P80
00002@000;h00`000000oooo0?ooo`020?ooo`030000003oool0oooo01L0oooo00110?ooo`@00000
2@3oool5000000X0003o0`00000C0000o`@000004P000?l400000140003o00<000000000o`000000
0P0000040000o`@000001@000;h2000000X0002n0P00000;0000_P03000000000;h0002n00T0002n
00<000000000_P000;h020000;h2000000T0002n0P0000090000_P8000002@000;h00`000000oooo
0?ooo`020?ooo`030000003oool0oooo01L0oooo00160?ooo`@000002@3oool4000000<0003o0`00
000C0000o`@000004P000?l400000180003o100000030000o`03000000000?l00000008000000`00
0?l4000000030000_P000000000000X0002n0P00000;0000_P03000000000;h0002n00T0002n00<0
00000000_P000;h020000;h2000000T0002n0P0000090000_P8000002@000;h00`000000oooo0?oo
o`0L0?ooo`00B`3oool2000000X0oooo0`00000C0000o`@000004P000?l400000180003o1000000;
0000o`04000000000?l00000000000<0003o1@0000080000_P8000002`000;h00`000000002n0000
_P090000_P03000000000;h0002n00P0002n0P00000:0000_P80000020000;h2000000T0002n00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0G0?ooo`00C@3oool00`000000oooo0?ooo`02
000000X0oooo1000000:0000o`@000004P000?l400000180003o1000000B0000o`<000001@000?l4
000000@0002n0P00000;0000_P03000000000;h0002n00T0002n00<000000000_P000;h020000;h2
000000X0002n0P0000080000_P8000002@000;h00`000000oooo0?ooo`020?ooo`030000003oool0
oooo01L0oooo001B0?ooo`030000003oool0oooo008000002@3oool4000000<0003o1000000B0000
o`@000004P000?l400000180003o0`0000030000o`<000001P000?l3000000030000_P0000000000
00/0002n00<000000000_P000;h02@000;h00`000000002n0000_P080000_P8000002P000;h20000
00T0002n00<000000000_P000;h01`000;h00`000000oooo0?ooo`020?ooo`030000003oool0oooo
01L0oooo001G0?ooo`030000003oool0000000800000203oool400000180003o1000000B0000o`@0
00004P000?l3000000/0003o0`0000040000o`D000002@000;h00`000000002n0000_P090000_P03
000000000;h0002n00P0002n0P00000:0000_P8000002@000;h2000000P0002n00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`0G0?ooo`00G03oool00`000000oooo00000002000000P0oooo
1000000:0000o`@000004P000?l400000180003o0`00000B0000o`@0000010000?l4000000D0002n
00<000000000_P000;h02@000;h00`000000002n0000_P080000_P8000002P000;h2000000T0002n
0P0000080000_P030000003oool0oooo01`0oooo001Q0?ooo`040000003oool00000000000P0oooo
100000030000o`@000004P000?l400000180003o0`00000B0000o`@0000010000?l3000000@0003o
100000000`000;h000000000_P0:0000_P03000000000;h0002n00P0002n0P00000:0000_P800000
2@000;h2000000T0002n00D000000?ooo`3oool0oooo0000000I0?ooo`00I@3oool00`000000oooo
0?ooo`02000000L0oooo1000000B0000o`@000004P000?l300000180003o1000000:0000o`040000
00000?l00000000000@0003o100000090000_P03000000000;h0002n00P0002n0P00000:0000_P80
00002@000;h2000000T0002n00D000000?ooo`3oool0oooo0000000I0?ooo`00JP3oool00`000000
oooo00000002000000L0oooo1000000:0000o`@000004P000?l300000180003o1000000A0000o`03
000000000?l00000008000000`000?l4000000D0002n00<000000000_P000;h020000;h2000000X0
002n0P0000090000_P8000002@000;h01@000000oooo0?ooo`3oool0000001T0oooo001_0?ooo`03
0000003oool0oooo00P0oooo100000030000o`@000004P000?l300000180003o1000000A0000o`@0
000010000?l00`000000003o0000000200000080003o100000000`000;h000000000_P090000_P80
00002P000;h2000000T0002n0P0000090000_P050000003oool0oooo0?ooo`0000006@3oool00740
oooo100000090?ooo`@000004P000?l300000180003o1000000@0000o`D0000030000?l00`000000
003o0000o`030000o`@0000020000;h2000000X0002n0P0000090000_P8000002@000;h00`000000
oooo0?ooo`0K0?ooo`00MP3oool3000000X0oooo1000000:0000o`<000004P000?l400000100003o
1@00000A0000o`@0000010000?l4000000@0002n0P00000:0000_P8000002@000;h2000000T0002n
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F0?ooo`00N`3oool3000000T0oooo1000
00030000o`<000004P000?l4000000l0003o1P00000A0000o`<000001@000?l3000000@0003o0`00
00000`000;h000000000000:0000_P8000002@000;h2000000T0002n00<000000?ooo`3oool00P3o
ool00`000000oooo0?ooo`0F0?ooo`00P03oool3000000P0oooo0`00000B0000o`@000003`000?l6
00000100003o1000000=0000o`<000000P000?l5000000P0002n0P0000090000_P8000002@000;h0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01H0oooo00240?ooo`@000001`3oool40000
00X0003o1000000?0000o`H0000040000?l4000001<0003o100000030000o`@0000010000;h20000
00T0002n0P0000090000_P030000003oool0oooo01/0oooo00290?ooo`@000001P3oool4000000<0
003o1000000>0000o`L000003`000?l400000180003o100000050000o`03000000000?l000000080
00000P000?l3000000030000_P000000000000T0002n0P0000090000_P030000003oool0oooo01/0
oooo002>0?ooo`8000001`3oool4000000030000o`000000003o00/0003o0`00000010000;d00000
00000000000?0000o`@000004P000?l4000000d0003o00D000000000o`00000000000000o`060000
00H0002n0P0000090000_P030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool00900
oooo00<000000?ooo`3oool00P0000080?ooo`D0000010000?l3000000040000_@00000000000000
00l0003o1000000A0000o`@0000050000?l2000000H0003o1@0000000`000;h00000000000090000
_P030000003oool0oooo0080oooo00<000000?ooo`3oool05P3oool009D0oooo00<000000?ooo`3o
ool00P0000080?ooo`@0000000@0002m00000000000000003P000?l400000180003o1000000A0000
o`D000001@000?l3000000H0003o0`0000090000_P030000003oool0oooo0080oooo00<000000?oo
o`3oool05P3oool009X0oooo00<000000?ooo`0000000P0000060?ooo`80000000<0003o00000000
0?l02`000?l400000180003o0`00000A0000o`H000003@000?l3000000030000_`000000000000@0
00001P000;h00`000000oooo0?ooo`0K0?ooo`00W`3oool010000000oooo0000000000060?ooo`D0
000010000?l400000140003o1000000@0000o`H000003P000?l;00000080003o1@0000000`000;h0
00000?ooo`0L0?ooo`00X`3oool00`000000oooo0?ooo`02000000H0oooo1@00000A0000o`@00000
40000?l6000000d0003o1`0000090000o`80000010000?l2000000@0oooo00<000000?ooo`3oool0
5P3oool00:P0oooo00<000000?ooo`3oool00P0000070?ooo`@000002@000?l300000100003o1P00
000>0000o`L000003P000?l00`000000003o00000002000000D0oooo00<000000?ooo`3oool05P3o
ool00:d0oooo00<000000?ooo`3oool0203oool3000000<0003o0`00000?0000o`L000003@000?l7
000000h0003o0`0000060?ooo`030000003oool0oooo00<00000603oool00:l0oooo100000080?oo
o`<0000000<0003o000000000?l030000?l7000000d0003o1P00000>0000o`@000001`3oool00`00
0000oooo000000020?ooo`<00000603oool00;@0oooo100000080?ooo`D0000010000?l7000000h0
003o1P00000=0000o`@000002`3oool5000001/0oooo002i0?ooo`<000002@3oool4000000040000
_`0000000000000000d0003o1P00000>0000o`<000002P3oool6000001l0oooo002n0?ooo`<00000
1`3oool2000000030000o`000000003o00X0003o1@00000>0000o`@000002P3oool5000002<0oooo
00330?ooo`<000001P3oool5000000<0003o1@00000=0000o`@000002@3oool00`000000oooo0000
0004000002H0oooo00370?ooo`@000001P3oool4000000030000o`000000003o00/0003o0`00000;
0?ooo`@0000000<0oooo0000003oool0:03oool00<`0oooo0`0000080?ooo`D000000`000?l40000
00T0oooo00<000000?ooo`0000001000000]0?ooo`00d@3oool2000000T0oooo0`0000080?ooo`03
0000003oool0000000D00000<@3oool00=<0oooo00<000000?ooo`3oool00P0000080?ooo`030000
003oool0oooo0080oooo1`00000?0?ooo`<00000103oool2000001`0oooo003H0?ooo`030000003o
ool00000008000000`3oool00`000000oooo00000005000001@0oooo00<000000?ooo`3oool00P3o
ool010000000oooo0?ooo`00000K0?ooo`00g@3oool00`000000oooo00000003000001T0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000K0?ooo`00lP3oool2000000P0oooo00<0
00000?ooo`3oool00P3oool010000000oooo0?ooo`00000K0?ooo`00l@3oool010000000oooo0?oo
o`0000070?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000006`3oool00?40oooo
00@000000?ooo`3oool000001P3oool2000000@0oooo00@000000?ooo`3oool000006`3oool00?40
oooo00@000000?ooo`3oool000001`3oool00`000000oooo0?ooo`030?ooo`800000703oool00>D0
oooo0`0000040?ooo`8000000`3oool010000000oooo0?ooo`00000[0?ooo`00iP3oool00`000000
oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool00000:`3oool0
0=h0oooo1@0000030?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool000000`3oool2
000002`0oooo003V0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000<@3oool0
0>H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000a0?ooo`00i@3oool20000
00@0oooo00@000000?ooo`3oool00000<@3oool00>H0oooo00<000000?ooo`3oool00`3oool20000
0380oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003[0?oo
o`8000003P3oool2000002<0oooo003[0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool08@3oool00>80oooo0P0000000`3oool00000000000040?ooo`0>0000003oool0oooo0000003o
ool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000003oool0oooo0240
oooo003S0?ooo`030000003oool0000000D0oooo00h000000?ooo`3oool000000?ooo`000000oooo
0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool08@3oool00>@0oooo
00<000000?ooo`3oool0103oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool000000`3oool00`000000oooo0?ooo`0Q0?ooo`00i03oool00`000000oooo
0?ooo`040?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool00000
0?ooo`0000030?ooo`030000003oool0oooo0240oooo003T0?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00P000000103oool000000?ooo`3oool2000000030?ooo`000000oooo00<0
oooo00<000000?ooo`3oool08@3oool00><0oooo00<000000?ooo`0000001@3oool2000000h0oooo
0P00000S0?ooo`00hP3oool2000000030?ooo`000000000003T0oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?oo
ob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {287, 0}} -> {-0.172118, -0.0860613, \
0.00408405, 0.00408405}}]
}, Open  ]],

Cell[BoxData[
    \(\(\( (*\ 
      Only\ with\ Mathematica\ 4.0\ or\ later\ \ *) \)\(\[IndentingNewLine]\)\
\( (*\ type\ ' Directory[]'\ \ to\ get\ the\ directory\  . \ ' 
        form'\ must\ be\ one\ \(of\  : \ gif\), \ eps, \ pict, \ 
      pdf\ *) \)\(\[IndentingNewLine]\)\(dir = "\<\>"; file = "\<aa\>"; 
    form = "\<gif\>"; 
    Export[dir <> file <> "\<.\>" <> form, gra, form];\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ 
      Only\ with\ Mathematica\ 4.0\ or\ later\ \ *) \[IndentingNewLine]\(<< 
        RealTime3D`;\)\), "\[IndentingNewLine]", 
    \(\(Show[Graphics3D[radObjDrw[g]]];\)\), "\[IndentingNewLine]", 
    \(\(<< Default3D`;\)\)}], "Input"],

Cell[BoxData[
  Graphics3D[{
    Polygon[{{-20.000000, -44.125000, 8.000000},{-20.000000, -39.875000, 
        8.000000},{20.000000, -39.875000, 8.000000},{
      20.000000, -44.125000, 8.000000}}],
    Polygon[{{-20.000000, -44.125000, 8.000000},{
      20.000000, -44.125000, 8.000000},{
      20.000000, -44.125000, 29.000000},{-20.000000, -44.125000, 29.000000}}],
    
    Polygon[{{-20.000000, -44.125000, 8.000000},{-20.000000, -44.125000, 
        29.000000},{-20.000000, -39.875000, 
        29.000000},{-20.000000, -39.875000, 8.000000}}],
    Polygon[{{-20.000000, -44.125000, 29.000000},{
      20.000000, -44.125000, 29.000000},{
      20.000000, -39.875000, 29.000000},{-20.000000, -39.875000, 29.000000}}],
    
    Polygon[{{-20.000000, -39.875000, 8.000000},{-20.000000, -39.875000, 
        29.000000},{20.000000, -39.875000, 29.000000},{
      20.000000, -39.875000, 8.000000}}],
    Polygon[{{20.000000, -44.125000, 8.000000},{
      20.000000, -39.875000, 8.000000},{20.000000, -39.875000, 29.000000},{
      20.000000, -44.125000, 29.000000}}],
    Polygon[{{-20.000000, -38.875000, 8.000000},{-20.000000, -24.125000, 
        8.000000},{20.000000, -24.125000, 8.000000},{
      20.000000, -38.875000, 8.000000}}],
    Polygon[{{-20.000000, -38.875000, 8.000000},{
      20.000000, -38.875000, 8.000000},{
      20.000000, -38.875000, 29.000000},{-20.000000, -38.875000, 29.000000}}],
    
    Polygon[{{-20.000000, -38.875000, 8.000000},{-20.000000, -38.875000, 
        29.000000},{-20.000000, -24.125000, 
        29.000000},{-20.000000, -24.125000, 8.000000}}],
    Polygon[{{-20.000000, -38.875000, 29.000000},{
      20.000000, -38.875000, 29.000000},{
      20.000000, -24.125000, 29.000000},{-20.000000, -24.125000, 29.000000}}],
    
    Polygon[{{-20.000000, -24.125000, 8.000000},{-20.000000, -24.125000, 
        29.000000},{20.000000, -24.125000, 29.000000},{
      20.000000, -24.125000, 8.000000}}],
    Polygon[{{20.000000, -38.875000, 8.000000},{
      20.000000, -24.125000, 8.000000},{20.000000, -24.125000, 29.000000},{
      20.000000, -38.875000, 29.000000}}],
    Polygon[{{-20.000000, -23.125000, 8.000000},{-20.000000, -18.875000, 
        8.000000},{20.000000, -18.875000, 8.000000},{
      20.000000, -23.125000, 8.000000}}],
    Polygon[{{-20.000000, -23.125000, 8.000000},{
      20.000000, -23.125000, 8.000000},{
      20.000000, -23.125000, 29.000000},{-20.000000, -23.125000, 29.000000}}],
    
    Polygon[{{-20.000000, -23.125000, 8.000000},{-20.000000, -23.125000, 
        29.000000},{-20.000000, -18.875000, 
        29.000000},{-20.000000, -18.875000, 8.000000}}],
    Polygon[{{-20.000000, -23.125000, 29.000000},{
      20.000000, -23.125000, 29.000000},{
      20.000000, -18.875000, 29.000000},{-20.000000, -18.875000, 29.000000}}],
    
    Polygon[{{-20.000000, -18.875000, 8.000000},{-20.000000, -18.875000, 
        29.000000},{20.000000, -18.875000, 29.000000},{
      20.000000, -18.875000, 8.000000}}],
    Polygon[{{20.000000, -23.125000, 8.000000},{
      20.000000, -18.875000, 8.000000},{20.000000, -18.875000, 29.000000},{
      20.000000, -23.125000, 29.000000}}],
    Polygon[{{-20.000000, -17.875000, 8.000000},{-20.000000, -3.125000, 
        8.000000},{20.000000, -3.125000, 8.000000},{
      20.000000, -17.875000, 8.000000}}],
    Polygon[{{-20.000000, -17.875000, 8.000000},{
      20.000000, -17.875000, 8.000000},{
      20.000000, -17.875000, 29.000000},{-20.000000, -17.875000, 29.000000}}],
    
    Polygon[{{-20.000000, -17.875000, 8.000000},{-20.000000, -17.875000, 
        29.000000},{-20.000000, -3.125000, 29.000000},{-20.000000, -3.125000, 
        8.000000}}],
    Polygon[{{-20.000000, -17.875000, 29.000000},{
      20.000000, -17.875000, 29.000000},{
      20.000000, -3.125000, 29.000000},{-20.000000, -3.125000, 29.000000}}],
    Polygon[{{-20.000000, -3.125000, 8.000000},{-20.000000, -3.125000, 
        29.000000},{20.000000, -3.125000, 29.000000},{
      20.000000, -3.125000, 8.000000}}],
    Polygon[{{20.000000, -17.875000, 8.000000},{
      20.000000, -3.125000, 8.000000},{20.000000, -3.125000, 29.000000},{
      20.000000, -17.875000, 29.000000}}],
    Polygon[{{-20.000000, -2.125000, 8.000000},{-20.000000, 2.125000, 
        8.000000},{20.000000, 2.125000, 8.000000},{
      20.000000, -2.125000, 8.000000}}],
    Polygon[{{-20.000000, -2.125000, 8.000000},{
      20.000000, -2.125000, 8.000000},{
      20.000000, -2.125000, 29.000000},{-20.000000, -2.125000, 29.000000}}],
    Polygon[{{-20.000000, -2.125000, 8.000000},{-20.000000, -2.125000, 
        29.000000},{-20.000000, 2.125000, 29.000000},{-20.000000, 2.125000, 
        8.000000}}],
    Polygon[{{-20.000000, -2.125000, 29.000000},{
      20.000000, -2.125000, 29.000000},{
      20.000000, 2.125000, 29.000000},{-20.000000, 2.125000, 29.000000}}],
    Polygon[{{-20.000000, 2.125000, 8.000000},{-20.000000, 2.125000, 
        29.000000},{20.000000, 2.125000, 29.000000},{
      20.000000, 2.125000, 8.000000}}],
    Polygon[{{20.000000, -2.125000, 8.000000},{
      20.000000, 2.125000, 8.000000},{20.000000, 2.125000, 29.000000},{
      20.000000, -2.125000, 29.000000}}],
    Polygon[{{-20.000000, 3.125000, 8.000000},{-20.000000, 17.875000, 
        8.000000},{20.000000, 17.875000, 8.000000},{
      20.000000, 3.125000, 8.000000}}],
    Polygon[{{-20.000000, 3.125000, 8.000000},{
      20.000000, 3.125000, 8.000000},{
      20.000000, 3.125000, 29.000000},{-20.000000, 3.125000, 29.000000}}],
    Polygon[{{-20.000000, 3.125000, 8.000000},{-20.000000, 3.125000, 
        29.000000},{-20.000000, 17.875000, 29.000000},{-20.000000, 17.875000, 
        8.000000}}],
    Polygon[{{-20.000000, 3.125000, 29.000000},{
      20.000000, 3.125000, 29.000000},{
      20.000000, 17.875000, 29.000000},{-20.000000, 17.875000, 29.000000}}],
    Polygon[{{-20.000000, 17.875000, 8.000000},{-20.000000, 17.875000, 
        29.000000},{20.000000, 17.875000, 29.000000},{
      20.000000, 17.875000, 8.000000}}],
    Polygon[{{20.000000, 3.125000, 8.000000},{
      20.000000, 17.875000, 8.000000},{20.000000, 17.875000, 29.000000},{
      20.000000, 3.125000, 29.000000}}],
    Polygon[{{-20.000000, 18.875000, 8.000000},{-20.000000, 23.125000, 
        8.000000},{20.000000, 23.125000, 8.000000},{
      20.000000, 18.875000, 8.000000}}],
    Polygon[{{-20.000000, 18.875000, 8.000000},{
      20.000000, 18.875000, 8.000000},{
      20.000000, 18.875000, 29.000000},{-20.000000, 18.875000, 29.000000}}],
    Polygon[{{-20.000000, 18.875000, 8.000000},{-20.000000, 18.875000, 
        29.000000},{-20.000000, 23.125000, 29.000000},{-20.000000, 23.125000, 
        8.000000}}],
    Polygon[{{-20.000000, 18.875000, 29.000000},{
      20.000000, 18.875000, 29.000000},{
      20.000000, 23.125000, 29.000000},{-20.000000, 23.125000, 29.000000}}],
    Polygon[{{-20.000000, 23.125000, 8.000000},{-20.000000, 23.125000, 
        29.000000},{20.000000, 23.125000, 29.000000},{
      20.000000, 23.125000, 8.000000}}],
    Polygon[{{20.000000, 18.875000, 8.000000},{
      20.000000, 23.125000, 8.000000},{20.000000, 23.125000, 29.000000},{
      20.000000, 18.875000, 29.000000}}],
    Polygon[{{-20.000000, 24.125000, 8.000000},{-20.000000, 38.875000, 
        8.000000},{20.000000, 38.875000, 8.000000},{
      20.000000, 24.125000, 8.000000}}],
    Polygon[{{-20.000000, 24.125000, 8.000000},{
      20.000000, 24.125000, 8.000000},{
      20.000000, 24.125000, 29.000000},{-20.000000, 24.125000, 29.000000}}],
    Polygon[{{-20.000000, 24.125000, 8.000000},{-20.000000, 24.125000, 
        29.000000},{-20.000000, 38.875000, 29.000000},{-20.000000, 38.875000, 
        8.000000}}],
    Polygon[{{-20.000000, 24.125000, 29.000000},{
      20.000000, 24.125000, 29.000000},{
      20.000000, 38.875000, 29.000000},{-20.000000, 38.875000, 29.000000}}],
    Polygon[{{-20.000000, 38.875000, 8.000000},{-20.000000, 38.875000, 
        29.000000},{20.000000, 38.875000, 29.000000},{
      20.000000, 38.875000, 8.000000}}],
    Polygon[{{20.000000, 24.125000, 8.000000},{
      20.000000, 38.875000, 8.000000},{20.000000, 38.875000, 29.000000},{
      20.000000, 24.125000, 29.000000}}],
    Polygon[{{-20.000000, 39.875000, 8.000000},{-20.000000, 44.125000, 
        8.000000},{20.000000, 44.125000, 8.000000},{
      20.000000, 39.875000, 8.000000}}],
    Polygon[{{-20.000000, 39.875000, 8.000000},{
      20.000000, 39.875000, 8.000000},{
      20.000000, 39.875000, 29.000000},{-20.000000, 39.875000, 29.000000}}],
    Polygon[{{-20.000000, 39.875000, 8.000000},{-20.000000, 39.875000, 
        29.000000},{-20.000000, 44.125000, 29.000000},{-20.000000, 44.125000, 
        8.000000}}],
    Polygon[{{-20.000000, 39.875000, 29.000000},{
      20.000000, 39.875000, 29.000000},{
      20.000000, 44.125000, 29.000000},{-20.000000, 44.125000, 29.000000}}],
    Polygon[{{-20.000000, 44.125000, 8.000000},{-20.000000, 44.125000, 
        29.000000},{20.000000, 44.125000, 29.000000},{
      20.000000, 44.125000, 8.000000}}],
    Polygon[{{20.000000, 39.875000, 8.000000},{
      20.000000, 44.125000, 8.000000},{20.000000, 44.125000, 29.000000},{
      20.000000, 39.875000, 29.000000}}],
    Polygon[{{-20.000000, -44.125000, -8.000000},{
      20.000000, -44.125000, -8.000000},{
      20.000000, -39.875000, -8.000000},{-20.000000, -39.875000, -8.000000}}],
    
    Polygon[{{-20.000000, -44.125000, -8.000000},{-20.000000, -44.125000, \
-29.000000},{20.000000, -44.125000, -29.000000},{
      20.000000, -44.125000, -8.000000}}],
    Polygon[{{-20.000000, -44.125000, -8.000000},{-20.000000, -39.875000, \
-8.000000},{-20.000000, -39.875000, -29.000000},{-20.000000, -44.125000, \
-29.000000}}],
    Polygon[{{-20.000000, -44.125000, -29.000000},{-20.000000, -39.875000, \
-29.000000},{20.000000, -39.875000, -29.000000},{
      20.000000, -44.125000, -29.000000}}],
    Polygon[{{-20.000000, -39.875000, -8.000000},{
      20.000000, -39.875000, -8.000000},{
      20.000000, -39.875000, -29.000000},{-20.000000, -39.875000, \
-29.000000}}],
    Polygon[{{20.000000, -44.125000, -8.000000},{
      20.000000, -44.125000, -29.000000},{20.000000, -39.875000, -29.000000},{
      20.000000, -39.875000, -8.000000}}],
    Polygon[{{-20.000000, -38.875000, -8.000000},{
      20.000000, -38.875000, -8.000000},{
      20.000000, -24.125000, -8.000000},{-20.000000, -24.125000, -8.000000}}],
    
    Polygon[{{-20.000000, -38.875000, -8.000000},{-20.000000, -38.875000, \
-29.000000},{20.000000, -38.875000, -29.000000},{
      20.000000, -38.875000, -8.000000}}],
    Polygon[{{-20.000000, -38.875000, -8.000000},{-20.000000, -24.125000, \
-8.000000},{-20.000000, -24.125000, -29.000000},{-20.000000, -38.875000, \
-29.000000}}],
    Polygon[{{-20.000000, -38.875000, -29.000000},{-20.000000, -24.125000, \
-29.000000},{20.000000, -24.125000, -29.000000},{
      20.000000, -38.875000, -29.000000}}],
    Polygon[{{-20.000000, -24.125000, -8.000000},{
      20.000000, -24.125000, -8.000000},{
      20.000000, -24.125000, -29.000000},{-20.000000, -24.125000, \
-29.000000}}],
    Polygon[{{20.000000, -38.875000, -8.000000},{
      20.000000, -38.875000, -29.000000},{20.000000, -24.125000, -29.000000},{
      20.000000, -24.125000, -8.000000}}],
    Polygon[{{-20.000000, -23.125000, -8.000000},{
      20.000000, -23.125000, -8.000000},{
      20.000000, -18.875000, -8.000000},{-20.000000, -18.875000, -8.000000}}],
    
    Polygon[{{-20.000000, -23.125000, -8.000000},{-20.000000, -23.125000, \
-29.000000},{20.000000, -23.125000, -29.000000},{
      20.000000, -23.125000, -8.000000}}],
    Polygon[{{-20.000000, -23.125000, -8.000000},{-20.000000, -18.875000, \
-8.000000},{-20.000000, -18.875000, -29.000000},{-20.000000, -23.125000, \
-29.000000}}],
    Polygon[{{-20.000000, -23.125000, -29.000000},{-20.000000, -18.875000, \
-29.000000},{20.000000, -18.875000, -29.000000},{
      20.000000, -23.125000, -29.000000}}],
    Polygon[{{-20.000000, -18.875000, -8.000000},{
      20.000000, -18.875000, -8.000000},{
      20.000000, -18.875000, -29.000000},{-20.000000, -18.875000, \
-29.000000}}],
    Polygon[{{20.000000, -23.125000, -8.000000},{
      20.000000, -23.125000, -29.000000},{20.000000, -18.875000, -29.000000},{
      20.000000, -18.875000, -8.000000}}],
    Polygon[{{-20.000000, -17.875000, -8.000000},{
      20.000000, -17.875000, -8.000000},{
      20.000000, -3.125000, -8.000000},{-20.000000, -3.125000, -8.000000}}],
    Polygon[{{-20.000000, -17.875000, -8.000000},{-20.000000, -17.875000, \
-29.000000},{20.000000, -17.875000, -29.000000},{
      20.000000, -17.875000, -8.000000}}],
    Polygon[{{-20.000000, -17.875000, -8.000000},{-20.000000, -3.125000, \
-8.000000},{-20.000000, -3.125000, -29.000000},{-20.000000, -17.875000, \
-29.000000}}],
    Polygon[{{-20.000000, -17.875000, -29.000000},{-20.000000, -3.125000, \
-29.000000},{20.000000, -3.125000, -29.000000},{
      20.000000, -17.875000, -29.000000}}],
    Polygon[{{-20.000000, -3.125000, -8.000000},{
      20.000000, -3.125000, -8.000000},{
      20.000000, -3.125000, -29.000000},{-20.000000, -3.125000, -29.000000}}],
    
    Polygon[{{20.000000, -17.875000, -8.000000},{
      20.000000, -17.875000, -29.000000},{20.000000, -3.125000, -29.000000},{
      20.000000, -3.125000, -8.000000}}],
    Polygon[{{-20.000000, -2.125000, -8.000000},{
      20.000000, -2.125000, -8.000000},{
      20.000000, 2.125000, -8.000000},{-20.000000, 2.125000, -8.000000}}],
    Polygon[{{-20.000000, -2.125000, -8.000000},{-20.000000, -2.125000, \
-29.000000},{20.000000, -2.125000, -29.000000},{
      20.000000, -2.125000, -8.000000}}],
    Polygon[{{-20.000000, -2.125000, -8.000000},{-20.000000, 
        2.125000, -8.000000},{-20.000000, 
        2.125000, -29.000000},{-20.000000, -2.125000, -29.000000}}],
    Polygon[{{-20.000000, -2.125000, -29.000000},{-20.000000, 
        2.125000, -29.000000},{20.000000, 2.125000, -29.000000},{
      20.000000, -2.125000, -29.000000}}],
    Polygon[{{-20.000000, 2.125000, -8.000000},{
      20.000000, 2.125000, -8.000000},{
      20.000000, 2.125000, -29.000000},{-20.000000, 2.125000, -29.000000}}],
    Polygon[{{20.000000, -2.125000, -8.000000},{
      20.000000, -2.125000, -29.000000},{20.000000, 2.125000, -29.000000},{
      20.000000, 2.125000, -8.000000}}],
    Polygon[{{-20.000000, 3.125000, -8.000000},{
      20.000000, 3.125000, -8.000000},{
      20.000000, 17.875000, -8.000000},{-20.000000, 17.875000, -8.000000}}],
    Polygon[{{-20.000000, 3.125000, -8.000000},{-20.000000, 
        3.125000, -29.000000},{20.000000, 3.125000, -29.000000},{
      20.000000, 3.125000, -8.000000}}],
    Polygon[{{-20.000000, 3.125000, -8.000000},{-20.000000, 
        17.875000, -8.000000},{-20.000000, 17.875000, -29.000000},{-20.000000,
         3.125000, -29.000000}}],
    Polygon[{{-20.000000, 3.125000, -29.000000},{-20.000000, 
        17.875000, -29.000000},{20.000000, 17.875000, -29.000000},{
      20.000000, 3.125000, -29.000000}}],
    Polygon[{{-20.000000, 17.875000, -8.000000},{
      20.000000, 17.875000, -8.000000},{
      20.000000, 17.875000, -29.000000},{-20.000000, 17.875000, -29.000000}}],
    
    Polygon[{{20.000000, 3.125000, -8.000000},{
      20.000000, 3.125000, -29.000000},{20.000000, 17.875000, -29.000000},{
      20.000000, 17.875000, -8.000000}}],
    Polygon[{{-20.000000, 18.875000, -8.000000},{
      20.000000, 18.875000, -8.000000},{
      20.000000, 23.125000, -8.000000},{-20.000000, 23.125000, -8.000000}}],
    Polygon[{{-20.000000, 18.875000, -8.000000},{-20.000000, 
        18.875000, -29.000000},{20.000000, 18.875000, -29.000000},{
      20.000000, 18.875000, -8.000000}}],
    Polygon[{{-20.000000, 18.875000, -8.000000},{-20.000000, 
        23.125000, -8.000000},{-20.000000, 23.125000, -29.000000},{-20.000000,
         18.875000, -29.000000}}],
    Polygon[{{-20.000000, 18.875000, -29.000000},{-20.000000, 
        23.125000, -29.000000},{20.000000, 23.125000, -29.000000},{
      20.000000, 18.875000, -29.000000}}],
    Polygon[{{-20.000000, 23.125000, -8.000000},{
      20.000000, 23.125000, -8.000000},{
      20.000000, 23.125000, -29.000000},{-20.000000, 23.125000, -29.000000}}],
    
    Polygon[{{20.000000, 18.875000, -8.000000},{
      20.000000, 18.875000, -29.000000},{20.000000, 23.125000, -29.000000},{
      20.000000, 23.125000, -8.000000}}],
    Polygon[{{-20.000000, 24.125000, -8.000000},{
      20.000000, 24.125000, -8.000000},{
      20.000000, 38.875000, -8.000000},{-20.000000, 38.875000, -8.000000}}],
    Polygon[{{-20.000000, 24.125000, -8.000000},{-20.000000, 
        24.125000, -29.000000},{20.000000, 24.125000, -29.000000},{
      20.000000, 24.125000, -8.000000}}],
    Polygon[{{-20.000000, 24.125000, -8.000000},{-20.000000, 
        38.875000, -8.000000},{-20.000000, 38.875000, -29.000000},{-20.000000,
         24.125000, -29.000000}}],
    Polygon[{{-20.000000, 24.125000, -29.000000},{-20.000000, 
        38.875000, -29.000000},{20.000000, 38.875000, -29.000000},{
      20.000000, 24.125000, -29.000000}}],
    Polygon[{{-20.000000, 38.875000, -8.000000},{
      20.000000, 38.875000, -8.000000},{
      20.000000, 38.875000, -29.000000},{-20.000000, 38.875000, -29.000000}}],
    
    Polygon[{{20.000000, 24.125000, -8.000000},{
      20.000000, 24.125000, -29.000000},{20.000000, 38.875000, -29.000000},{
      20.000000, 38.875000, -8.000000}}],
    Polygon[{{-20.000000, 39.875000, -8.000000},{
      20.000000, 39.875000, -8.000000},{
      20.000000, 44.125000, -8.000000},{-20.000000, 44.125000, -8.000000}}],
    Polygon[{{-20.000000, 39.875000, -8.000000},{-20.000000, 
        39.875000, -29.000000},{20.000000, 39.875000, -29.000000},{
      20.000000, 39.875000, -8.000000}}],
    Polygon[{{-20.000000, 39.875000, -8.000000},{-20.000000, 
        44.125000, -8.000000},{-20.000000, 44.125000, -29.000000},{-20.000000,
         39.875000, -29.000000}}],
    Polygon[{{-20.000000, 39.875000, -29.000000},{-20.000000, 
        44.125000, -29.000000},{20.000000, 44.125000, -29.000000},{
      20.000000, 39.875000, -29.000000}}],
    Polygon[{{-20.000000, 44.125000, -8.000000},{
      20.000000, 44.125000, -8.000000},{
      20.000000, 44.125000, -29.000000},{-20.000000, 44.125000, -29.000000}}],
    
    Polygon[{{20.000000, 39.875000, -8.000000},{
      20.000000, 39.875000, -29.000000},{20.000000, 44.125000, -29.000000},{
      20.000000, 44.125000, -8.000000}}]},
    ViewPoint -> {2.108663, -2.234543, 1.417871}
  ]
], "Graphics",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P000181000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00KGoo00<007ooOol0/7oo001[Ool5002`Ool006Uoo`80009o
o`03001oogoo00800:ioo`00J7oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol0Zgoo001V
Ool20005Ool00`00Oomoo`03Ool2002[Ool006Aoo`8000Moo`03001oogoo00Eoo`800:Uoo`00HWoo
0P002Goo00<007ooOol01goo00<007ooOol0YWoo001QOol00`00Oomoo`09Ool00`00Oomoo`08Ool2
002VOol005moo`8000aoo`03001oogoo00Yoo`800:Aoo`00GGoo0P003Woo00<007ooOol037oo0P00
XWoo001LOol00`00Oomoo`0>Ool00`00Oomoo`0>Ool00`00Oomoo`2OOol005Yoo`80015oo`03001o
ogoo008000eoo`8009moo`00F7oo0P004goo1`003Goo0P00WGoo001GOol00`00Oomoo`0BOol20002
6<H00`00HZIRYP03000=Ool00`00Oomoo`2JOol005Eoo`8001=oo`8000056<H001S66<H00004HZH2
000=Ool2002JOol005=oo`8001=oo`80008HaP05000HaQS66<H00005HZH00`00Ool0000=Ool2002H
Ool0059oo`03001oogoo019oo`03000HaQS6008HaP05000HaQS66<H00005HZH5000=Ool00`00Oomo
o`2EOol0051oo`8001=oo`8000DHaP05000HaQS66<H00005HZH00`006<H00002HZH2000<Ool2002E
Ool004ioo`8001=oo`8000LHaP05000HaQS66<H00005HZH00`006<H00004HZH2000<Ool2002COol0
04aoo`8001=oo`8000THaP05000HaQS66<H00005HZH00`006<H00006HZH2000<Ool00`00Oomoo`2@
Ool004]oo`03001oogoo019oo`03000HaQS600THaP05000HaQS66<H00005HZH00`006<H00008HZH2
000;Ool2002@Ool004Uoo`8001=oo`8000`HaP05000HaQS66<H00005HZH00`006<H00009HZH2000<
Ool2002>Ool004Moo`8001=oo`8000hHaP05000HaQS66<H00005HZH00`006<H0000;HZH2000<Ool2
002<Ool004Ioo`03001oogoo015oo`80010HaP05000HaQS66<H00005HZH00`006<H0000=HZH2000<
Ool00`00Oomoo`29Ool004Aoo`80019oo`80018HaP05000HaQS66<H00005HZH00`006<H0000?HZH2
000;Ool20029Ool0049oo`8001=oo`03000HaQS6018HaP05000HaQS66<H00005HZH00`006<H0000A
HZH2000;Ool20027Ool0045oo`03001oogoo015oo`8001DHaP05000HaQS66<H00005HZH00`006<H0
000BHZH00goo001oo`0;Ool00`00Oomoo`24Ool003moo`80019oo`8001LHaP05000HaQS66<H00005
HZH00`006<H0000CHZH2000<Ool20024Ool003eoo`80019oo`8001THaP05000HaQS66<H00005HZH0
0`006<H0000CHZH4000<Ool20022Ool003]oo`80019oo`8001/HaP03000HaQS6008000ERYP03000H
aP0001=RYP80009RYP8000aoo`03001oogoo07moo`00>Woo00<007ooOol04Goo00<001S66<H06aS6
00@001S66<H000IRYP03000HaP0001=RYP8000ARYP03001oogoo00Yoo`8007moo`00>7oo0P004Woo
0P007QS600@001S66<H000IRYP03000HaP0001=RYP8000ARYP03001oo`0000aoo`8007eoo`00=Woo
0P004Woo0P0081S600@001S66<H000ERYP8000036<H006:V019RYP8000ARYPD000aoo`03001oogoo
07Yoo`00=Goo0P004Goo0P008QS600@001S66<H000ERYP04000HaP00000CHZH20004HZH00`006<H0
0002HZH2000;Ool2001jOol003Eoo`04001oo`00000>Ool00`006<HHaP0R6<H010006<HHaP001F:V
00<001S6000056:V0P0016:V00<001S6000016:V00<007ooOol02Woo0P00N7oo000eOol01000Oomo
ogoo0P002Woo0P009AS600@001S66<H000ERYP03000HaP0001ARYP8000ARYP03000HaP0000ERYP80
00aoo`8007Ioo`00=Goo00<007ooOol00goo0P001Woo0P009aS600@001S66<H000ERYP03000HaP00
01ARYP8000ARYP03000HaP0000MRYP8000aoo`03001oogoo07=oo`00=Goo00<007ooOol01Goo0P00
0Woo0P00:AS600@001S66<H000ERYP03000HaP0001ARYP8000ARYP03000HaP0000QRYP8000aoo`80
07=oo`00=Goo00<007ooOol01goo0P00:aS600@001S66<H000ERYP03000HaP0001ARYP8000ARYP03
000HaP0000YRYP8000aoo`80075oo`00=Goo00<007ooOol01Woo00<001S66<H0:aS600@001S66<H0
00ERYP03000HaP0001ARYP8000ARYP03000HaP0000aRYP03001oogoo00]oo`03001oogoo06ioo`00
=7oo00<007ooOol01goo00<001S66<H0:aS600@001S66<H000ERYP03000HaP0001ARYP8000ARYP03
000HaP0000eRYP8000aoo`8006ioo`00=7oo00<007ooOol01goo00<001S66<H0:aS600@001S66<H0
00ERYP03000HaP0001ARYP8000ARYP03000HaP0000mRYP8000aoo`8006aoo`00=7oo00<007ooOol0
1goo00<001S66<H0:aS600@001S66<H000ERYP03000HaP0001ARYP8000ARYP03000HaP00015RYP80
00aoo`03001oogoo06Uoo`00=7oo00<007ooOol01goo00<001S66<H0:aS600@001S66<H000ERYP03
000HaP0001ARYP8000ARYP03000HaP00015RYP@000]oo`8006Uoo`00=7oo00<007ooOol01goo00<0
01S66<H0:aS600@001S66<H000ERYP03000HaP0001ARYP8000ARYP03000HaP00015RYP80009RYP80
00]oo`8006Moo`00=7oo00<007ooOol01Woo00<001S66<H0:aS600D001S66<HHaP0000ERYP03000H
aP0001ARYP8000ARYP03000HaP00015RYP8000ARYP03001oogoo00Yoo`03001oogoo06Aoo`00=7oo
00<007ooOol01Woo00<001S66<H0:aS600D001S66<HHaP0000ERYP03000HaP0001ARYP8000ARYP03
000HaP00015RYP8000ARYP8000aoo`8006Aoo`00=7oo00<007ooOol01Woo00<001S66<H0:aS600<0
01S66<H00`0016:V00<001S6000056:V0P0016:V00<001S600004F:V0P0016:V100037oo0P00HWoo
000dOol00`00Oomoo`06Ool00`006<HHaP0[6<H4000016Ji000000000V:V00<001S6000056:V0P00
1F:V0P004F:V0P0016:V0P000V:V0P0037oo0P00H7oo000dOol00`00Oomoo`06Ool00`006<HHaP0Z
6<H30005I[T400000aS6001RYP0CHZH20005HZH2000AHZH20004HZH20004HZH2000<Ool00`00Oomo
o`1MOol003Aoo`03001oogoo00Ioo`03000HaQS602PHaP@000QV^@8000036<H006:V01=RYP8000ER
YP80015RYP8000ARYP8000IRYP8000]oo`8005eoo`00=7oo00<007ooOol01Woo00<001S66<H09QS6
0`000VJi00<006JiI[T01FJi0P000QS60P004f:V0P001F:V0P004F:V0P0016:V0P0026:V0P002goo
0P00Fgoo000cOol00`00Oomoo`07Ool00`006<HHaP0T6<H30004I[T00`00I[UV^@03I[T200026<H2
0002I[T2000AHZH20005HZH2000AHZH20004HZH2000:HZH2000;Ool00`00Oomoo`1HOol003=oo`03
001oogoo00Moo`03000HaQS6028HaP<000IV^@04001V^FJiI[T200026<H20006I[T2000?HZH20005
HZH2000AHZH20004HZH2000<HZH2000:Ool2001HOol003=oo`03001oogoo00Moo`03000HaQS6020H
aP<000QV^@04001V^@0000026<H2000:I[T2000=HZH20005HZH2000AHZH20004HZH2000>HZH2000:
Ool2001FOol003=oo`03001oogoo00Moo`03000HaQS601hHaP<000YV^@80008HaP8000iV^@8000]R
YP8000ERYP80015RYP8000ARYP80011RYP03001oogoo00Uoo`03001oogoo05=oo`00<goo00<007oo
Ool01Woo0P007QS60`002VJi0`0000<HaP0000004VJi0P002F:V0P001F:V0P004F:V0P0016:V0P00
46:V0P002goo0P00Dgoo000cOol00`00Oomoo`06Ool00`006<HHaP0K6<H3000:I[T200026<H2000F
I[T20007HZH20005HZH2000AHZH20004HZH2000@HZH4000;Ool2001AOol003=oo`03001oogoo00Io
o`03000HaQS601THaP<000YV^@80008HaP<001UV^@8000ERYP8000ERYP80015RYP8000ARYP80011R
YP80009RYP8000]oo`03001oogoo04ioo`00<goo00<007ooOol01Woo00<001S66<H05aS60`002VJi
0P000QS60P000VJi00<006JiI[T06FJi0P000f:V0P001F:V0P004V:V0P000f:V0P0046:V0P0016:V
0P002Woo0P00CWoo000cOol00`00Oomoo`06Ool00`006<HHaP0E6<H3000:I[T200026<H20004I[T0
0`00I[UV^@0KI[T200000f:V00000005HZH2000BHZH20003HZH2000@HZH20004HZH4000:Ool2001<
Ool003=oo`03001oogoo00Ioo`03000HaQS601<HaP<000YV^@80008HaP8000IV^@03001V^FJi01eV
^@<000ERYP80019RYP8000=RYP80011RYP8000ARYP80009RYP8000Yoo`8004Yoo`00<goo00<007oo
Ool01Woo00<001S66<H04AS60`002VJi0P000QS60P0026Ji00<006JiI[T06fJi0P0000@HaP000000
00ARYP80019RYP8000ARYP03001RYV:V00iRYP8000ARYP8000ARYP03001oogoo00Uoo`03001oogoo
04Moo`00<goo00<007ooOol01Woo00<001S66<H03aS60`002VJi0P000QS60P002VJi00<006JiI[T0
6FJi0P0000<HaP0000000VJi0`000V:V0P004V:V0P0016:V0P003f:V0P0016:V0P001F:V0P002Woo
0P00Agoo000bOol00`00Oomoo`07Ool00`006<HHaP0=6<H3000:I[T200026<H2000<I[T00`00I[UV
^@0GI[T200000aS600000006I[T5000BHZH20004HZH2000?HZH20004HZH20007HZH2000:Ool20015
Ool0039oo`03001oogoo00Moo`03000HaQS600/HaP<000YV^@80008HaP8000iV^@03001V^FJi01EV
^@8000036<H0000000YV^@<0019RYP8000ARYP8000mRYP8000ARYP8000URYP03001oogoo00Uoo`03
001oogoo049oo`00<Woo00<007ooOol01goo00<001S66<H02AS60`002VJi0P000QS60P0046Ji00<0
06JiI[T04fJi0P0000<HaP0000002VJi0P0000@HaP000000015RYP8000ARYP8000mRYP8000ARYP80
00YRYP8000Yoo`80049oo`00<Woo00<007ooOol01goo00<001S66<H01aS60`002VJi0P000QS60P00
4VJi00<006JiI[T04FJi0P0000<HaP0000002VJi0P0000<HaP0000000fJi0P003f:V0P0016:V0P00
3f:V0P0016:V0P0036:V0P002Woo0P00@7oo000bOol00`00Oomoo`06Ool00`006<HHaP066<H3000:
I[T200026<H2000DI[T00`00I[UV^@0?I[T5000:I[T200000aS600000007I[T2000=HZH20004HZH2
000?HZH20004HZH2000>HZH00`00Oomoo`08Ool2000oOol0039oo`03001oogoo00Ioo`03000HaQS6
00@HaP<000YV^@80008HaP8001IV^@03001V^FJi00eV^@@000]V^@8000036<H0000000]V^@8000]R
YP8000ARYP8000mRYP8000ARYP8000iRYP<000Ioo`800003Ool007oo03ioo`00<Woo00<007ooOol0
1Woo00<001S66<H00QS60`002VJi0P000QS60P0066Ji00<006JiI[T02fJi10002fJi1@003fJi0P00
2F:V0P0016:V0P003f:V0P0016:V0P003V:V1@0000Aoo`00000000=oo`03001oogoo03eoo`00<Woo
00<007ooOol01Woo00<001S66<H00`002VJi0P000QS60P006VJi00<006JiI[T02FJi10002VJi1@00
56Ji0P001f:V0P0016:V0P003f:V0P0016:V0P003V:V0P000V:V0P001Woo00<007ooOol0?Goo000b
Ool00`00Oomoo`06Ool4000:I[T200026<H2000LI[T00`00I[UV^@07I[T4000:I[T200000aS60000
000HI[T20005HZH20004HZH2000@HZH00`00HZIRYP02HZH2000>HZH20003HZH00`00Oomoo`04Ool0
0`00Oomoo`0mOol0039oo`03001oogoo00Ioo`8000YV^@80008HaP8001iV^@03001V^FJi00EV^@@0
00YV^@8000036<H0000001aV^@8000=RYP8000ARYP80011RYP8000=RYP8000iRYP8000=RYP03001o
ogoo00Aoo`03001oogoo03eoo`00<Woo00<007ooOol01goo0`001VJi0P000QS60P0086Ji00<006Ji
I[T00VJi1@002VJi1@0086Ji0P0000=RYP00000016:V0P0046:V0P000f:V0P003V:V0P000f:V00<0
07ooOol017oo00<007ooOol0?Goo000bOol00`00Oomoo`09Ool200000f:VI[UV^@0200026<H2000Q
I[T01000I[UV^FJi10002fJi10009FJi0`0016:V0P0046:V0P0016:V00<006:VHZH036:V0P000f:V
00<007ooOol017oo00<007ooOol0?Goo000aOol00`00Oomoo`0<Ool400000aS60000000SI[T00`00
I[T00003000;I[T4000UI[T200000aS600000004HZH2000@HZH20004HZH2000>HZH01@00HZIRYV:V
00001goo00<007ooOol0?7oo000aOol00`00Oomoo`0?Ool2000UI[T300000aS6001RYP020006I[T5
000UI[T200000aS600000002I[T20002HZH2000@HZH20004HZH2000>HZH20002HZH00`00Oomoo`05
Ool00`00Oomoo`0lOol0035oo`03001oogoo015oo`80025V^@<000<HaP04001RYV:VHZH20002I[T5
000TI[T300000aS600000006I[T4000@HZH20004HZH2000>HZH20002HZH00`00Oomoo`05Ool00`00
Oomoo`0lOol0035oo`03001oogoo01=oo`8001eV^@<000036<H001S6008HaP03001RYV:V00=RYP@0
02EV^@8000046<H000000009I[T3000@HZH20004HZH2000>HZH20003HZH00`00Oomoo`04Ool00`00
Oomoo`0lOol0035oo`03001oogoo01Eoo`<001QV^@<000<HaP05000HaQS66<H00006HZH3000SI[T2
00000aS60000000:I[T30002I[T2000>HZH20004HZH2000>HZH20003HZH00`00Oomoo`04Ool00`00
Oomoo`0lOol0035oo`03001oogoo01Qoo`8001AV^@<000DHaP05000HaQS66<H00006HZH200000f:V
0000000NI[T60009I[T40006I[T2000<HZH20004HZH2000>HZH20003HZH00`00Oomoo`04Ool00`00
Oomoo`0lOol0035oo`03001oogoo01Yoo`80011V^@<000LHaP05000HaQS66<H00006HZH20003HZH2
000JI[T2000011S6000000002FJi10002VJi0P002V:V0P0016:V0P003V:V0P000f:V00<007ooOol0
17oo00<007ooOol0?7oo000aOol00`00Oomoo`0LOol3000;I[T300096<H01@006<HHaQS600001V:V
0P001F:V0P005FJi0`0000<HaP0000002FJi10003fJi0P0026:V0P0016:V0P003V:V0P000f:V00<0
07ooOol017oo00<007ooOol0?7oo000aOol00`00Oomoo`0OOol20006I[T011S6000000002aS600D0
01S66<HHaP0000IRYP8000MRYP80015V^@8000046<H000000009I[T4000CI[T20006HZH20004HZH2
000>HZH20003HZH00`00Oomoo`04Ool00`00Oomoo`0lOol0035oo`03001oogoo025oo`80009V^@<0
00hHaP05000HaQS66<H00006HZH20009HZH2000=I[T200000aS600000009I[T5000GI[T20004HZH2
0004HZH2000>HZH20003HZH00`00Oomoo`04Ool00`00Oomoo`0lOol0035oo`03001oogoo02=oo`<0
010HaP05000HaQS66<H00006HZH2000;HZH20008I[T300000aS600000009I[T4000LI[T20002HZH2
0004HZH2000>HZH20003HZH00`00Oomoo`04Ool00`00Oomoo`0lOol0035oo`03001oogoo029oo`80
018HaP05000HaQS66<H00006HZH2000=HZH20004I[T2000011S60000000026Ji1@0086Ji100016:V
0P003V:V0P000f:V00<007ooOol017oo00<007ooOol0?7oo000`Ool00`00Oomoo`0QOol2000D6<H0
1@006<HHaQS600001V:V0P003f:V100000<HaP0000002FJi100096Ji0`0016:V0P003V:V0P000f:V
00<007ooOol017oo00<007ooOol0?7oo000`Ool00`00Oomoo`0OOol2000F6<H01@006<HHaQS60000
1V:V0P004F:V0`002FJi100096Ji0P0000@HaP00000000=RYP8000iRYP8000=RYP03001oogoo00Ao
o`03001oogoo03aoo`00<7oo00<007ooOol07Goo0P0061S600D001S66<HHaP0000IRYP8001=RYPD0
009V^@D002=V^@H000=V^@800003HZH0000000iRYP8000=RYP03001oogoo00Eoo`03001oogoo03]o
o`00<7oo00<007ooOol06goo0P006QS600D001S66<HHaP0000IRYP8001ARYP03000HaP0000D002AV
^@8000036<H0000000QV^@<000iRYP8000=RYP03001oogoo00Eoo`03001oogoo03]oo`00<7oo00<0
07ooOol06Goo0P0071S600D001S66<HHaP0000IRYP8001ARYP03000HaP00009RYP<0025V^@H000QV
^@8000046<H00000I[T>HZH01@00HZIRYV:V00001goo00<007ooOol0>goo000`Ool00`00Oomoo`0F
Ool3000N6<H01@006<HHaQS600001V:V0P0056:V00<001S6000016:V0P007FJi1P0026Ji1P000VJi
0P0000=V^F:VHZH02V:V0P000V:V00<007ooOol01Goo00<007ooOol0>goo000`Ool00`00Oomoo`0D
Ool2000Q6<H01@006<HHaQS600001V:V0P0056:V00<001S600001F:V0`006FJi0P0000<HaP000000
2FJi0P0000<HaP0000001fJi0P0000=V^F:VHZH026:V0P000V:V00<007ooOol01Goo00<007ooOol0
>goo000`Ool00`00Oomoo`0BOol2000S6<H01@006<HHaQS600001V:V0P0056:V00<001S600001F:V
0P0000=RYP00000056Ji1P0026Ji1P002fJi0`0026:V0P000f:V00<007ooOol017oo00<007ooOol0
>goo000`Ool00`00Oomoo`0@Ool2000U6<H01@006<HHaQS600001V:V0P0056:V00<001S600001F:V
0P000f:V0P0046Ji1@0026Ji1P0046Ji0`001V:V0P000f:V00<007ooOol017oo00<007ooOol0>goo
000`Ool00`00Oomoo`0>Ool2000W6<H010006<HHaP001f:V0P0056:V00<001S600001F:V0P001F:V
0P002fJi1@002FJi0P0000<HaP0000005FJi0`0016:V0P000f:V00<007ooOol017oo00<007ooOol0
>goo000`Ool00`00Oomoo`0<Ool2000Y6<H010006<HHaP001f:V0P0056:V00<001S600001F:V0P00
1f:V0P001fJi1@0026Ji1P006FJi0`000V:V0P000f:V00<007ooOol017oo00<007ooOol0>goo000`
Ool00`00Oomoo`0:Ool2000[6<H010006<HHaP001f:V0P0056:V00<001S600001F:V0P002F:V0P00
0VJi1@002FJi1@007VJi1@000f:V00<007ooOol017oo00<007ooOol0>goo000`Ool00`00Oomoo`08
Ool2000]6<H010006<HHaP001V:V0`0056:V00<001S600001F:V0P002f:V10002FJi1@008fJi1000
0V:V00<007ooOol017oo00<007ooOol0>goo000_Ool00`00Oomoo`07Ool2000_6<H010006<HHaP00
1V:V0P005F:V00<001S600001F:V0P003F:V0P001fJi1@008VJi10000VJi10001Woo00<007ooOol0
>goo000_Ool00`00Oomoo`07Ool00`006<HHaP0^6<H010006<HHaP001V:V0P005F:V00<001S60000
1F:V0P003f:V0P0000=RYVJi000010008VJi10001fJi0P001Woo00<007ooOol0>goo000_Ool00`00
Oomoo`07Ool00`006<HHaP0^6<H010006<HHaP001V:V0P005F:V00<001S600001F:V0P004F:V1000
8fJi0`001fJi0`0027oo00<007ooOol0>goo000_Ool00`00Oomoo`07Ool00`006<HHaP0^6<H01000
6<HHaP001V:V0P005F:V00<001S600001F:V0P004V:V1@007VJi10001VJi0`0037oo00<007ooOol0
>Woo000_Ool00`00Oomoo`07Ool00`006<HHaP0]6<H01@006<HHaQS600001V:V0P005F:V00<001S6
00001F:V0P004V:V0P000V:V0`006FJi10001fJi0P003goo00<007ooOol0>Woo000_Ool00`00Oomo
o`07Ool00`006<HHaP0]6<H01@006<HHaQS600001V:V0P005F:V00<001S600001F:V0P004V:V0P00
16:V10004fJi10001fJi0`004Goo00<007ooOol0>Woo000_Ool00`00Oomoo`07Ool00`006<HHaP0]
6<H01@006<HHaQS600001V:V0P005F:V00<001S600001F:V0P004V:V0P001F:V0P0000=RYP000000
3VJi10001fJi0`0057oo00<007ooOol0>Woo000_Ool00`00Oomoo`06Ool00`006<HHaP0^6<H01@00
6<HHaQS600001V:V0P005F:V00<001S600001F:V0P004V:V0P001F:V0P000f:V0P002FJi10001fJi
0`005goo00<007ooOol0>Woo000_Ool00`00Oomoo`06Ool00`006<HHaP0^6<H01@006<HHaQS60000
1V:V0P005F:V00<001S600001F:V0P004V:V0P001F:V0P001F:V0P001FJi0`001fJi0`006Woo00<0
07ooOol0>Woo000_Ool00`00Oomoo`06Ool00`006<HHaP0^6<H01@006<HHaQS600001V:V0P005F:V
00<001S600001F:V0P004V:V0P001F:V0P001f:V1P001VJi0`007Goo00<007ooOol0>Woo000_Ool0
0`00Oomoo`06Ool00`006<HHaP0^6<H01@006<HHaQS600001V:V0P005F:V00<001S600001F:V0P00
4V:V0P001F:V0P002F:V0P001VJi0P0087oo00<007ooOol0>Woo000_Ool00`00Oomoo`06Ool00`00
6<HHaP0^6<H01@006<HHaQS600001V:V0P005F:V00<001S600001F:V0P004V:V0P001F:V0P002f:V
0P0000AV^@000000029oo`03001oogoo03Yoo`00;Woo00<007ooOol01goo00<001S66<H0;QS600D0
01S66<HHaP0000IRYP8001ERYP03000HaP0000ERYP80019RYP8000ERYP8000eRYP8002Aoo`03001o
ogoo03Yoo`00;Woo00<007ooOol01goo00<001S66<H0;QS600D001S66<HHaP0000IRYP8001ERYP03
000HaP0000ERYP80019RYP8000ERYP8000mRYP80029oo`03001oogoo03Yoo`00;Woo00<007ooOol0
1goo00<001S66<H0;QS600D001S66<HHaP0000IRYP8001ERYP03000HaP0000ERYP80019RYP8000ER
YP80011RYP@001moo`03001oogoo03Yoo`00;Woo00<007ooOol01goo00<001S66<H0;QS600D001S6
6<HHaP0000IRYP8001ERYP03000HaP0000ERYP80019RYP8000ERYP80011RYP03000HaP0000<001eo
o`03001oogoo03Yoo`00;Woo00<007ooOol01goo00<001S66<H0;QS600<001S66<H00`001F:V0P00
5F:V00<001S600001F:V0P004V:V0P001F:V0P0046:V00<001S600000V:V10006Woo00<007ooOol0
>Woo000^Ool00`00Oomoo`07Ool00`006<HHaP0^6<H30003I[T20003HZH2000EHZH00`006<H00005
HZH2000BHZH20005HZH2000@HZH00`006<H00003HZH5000HOol00`00Oomoo`0jOol002ioo`03001o
ogoo00Moo`03000HaQS602`HaP@000IV^@800003HZH0000001ERYP03000HaP0000ERYP80019RYP80
00ERYP80011RYP03000HaP0000=RYP80009RYP<001Moo`03001oogoo03Uoo`00;Woo00<007ooOol0
1Woo0P00;1S60`000fJi0P001VJi100056:V00<001S600001F:V0P004V:V0P001F:V0P0046:V00<0
01S600000f:V0P0016:V0`005Goo00<007ooOol0>Goo000^Ool00`00Oomoo`06Ool00`006<HHaP0X
6<H40007I[T3000016Ji000000000fJi0P004V:V00<001S600001F:V0P004V:V0P001F:V0P0046:V
00<001S600000f:V0P001V:V0`004goo00<007ooOol0>Goo000^Ool00`00Oomoo`06Ool00`006<HH
aP0V6<H3000;I[T40007I[T3000?HZH00`006<H00005HZH2000CHZH20004HZH2000@HZH00`006<H0
0003HZH20008HZH3000AOol00`00Oomoo`0iOol002ioo`03001oogoo00Ioo`03000HaQS602<HaP@0
00YV^@@000=V^@<000MV^@8000eRYP03000HaP0000ERYP8001=RYP8000ARYP80015RYP8000=RYP80
00YRYP<000moo`03001oogoo03Uoo`00;Woo00<007ooOol01Woo00<001S66<H08AS60`002fJi0`00
2FJi0`001VJi0`002V:V00<001S600001F:V0P004f:V0P0016:V0P004F:V0P000f:V0P0036:V0`00
3Goo00<007ooOol0>Goo000]Ool00`00Oomoo`07Ool00`006<HHaP0N6<H4000:I[T4000>I[T20006
I[T30008HZH00`006<H00005HZH2000CHZH20005HZH2000@HZH20003HZH2000>HZH4000:Ool00`00
Oomoo`0iOol002eoo`03001oogoo00Moo`03000HaQS601`HaP<000YV^@@001=V^@<000IV^@8000IR
YP03000HaP0000ERYP8001=RYP8000ERYP80011RYP8000ARYP8000iRYP800003HZH0000000Qoo`03
001oogoo03Uoo`00;Goo00<007ooOol01goo00<001S66<H06AS60`002fJi0`006FJi0P001VJi0`00
0f:V00<001S600001F:V0P004f:V0P001F:V0P0046:V0P0016:V0P003V:V0P000f:V0P001Woo00<0
07ooOol0>Goo000]Ool00`00Oomoo`07Ool00`006<HHaP0G6<H3000:I[T4000MI[T30006I[T20000
16:V000HaP001F:V0P004f:V0P001F:V0P0046:V0P0016:V0P003V:V0P0016:V00<007ooOol017oo
00<007ooOol0>Goo000]Ool00`00Oomoo`07Ool00`006<HHaP0D6<H3000;I[T3000SI[T20006I[T2
00000aS6001RYP04HZH2000CHZH20005HZH2000@HZH20004HZH2000>HZH20004HZH00`00Oomoo`04
Ool00`00Oomoo`0iOol002eoo`03001oogoo00Moo`03000HaQS6018HaP<000YV^@@002MV^@H0008H
aP<000ARYP8001=RYP8000ERYP80011RYP8000ARYP8000iRYP8000ARYP03001oogoo00Aoo`03001o
ogoo03Uoo`00;Goo00<007ooOol01goo00<001S66<H03aS60`002VJi1000:VJi20000fJi0`0000=R
YP0000004f:V0P001F:V0P0046:V0P0016:V0P003V:V0P0016:V00<007ooOol017oo00<007ooOol0
>Goo000]Ool00`00Oomoo`07Ool00`006<HHaP0=6<H3000:I[T3000ZI[T300026<H300000fJi0000
0006I[T3000CHZH20005HZH2000@HZH20004HZH2000>HZH20004HZH00`00Oomoo`04Ool00`00Oomo
o`0iOol002eoo`03001oogoo00Ioo`03000HaQS600/HaP<000YV^@@002UV^@<0008HaP<000IV^@H0
00046<H00000000BHZH20005HZH2000@HZH30003HZH2000>HZH20004HZH00`00Oomoo`05Ool00`00
Oomoo`0hOol002eoo`03001oogoo00Ioo`03000HaQS600THaP<000YV^@<002YV^@80008HaP<000UV
^@L000=V^@<000mRYP8000ERYP80011RYP03000HaP0000=RYP8000mRYP8000=RYP03001oogoo00Eo
o`03001oogoo03Qoo`00;Goo00<007ooOol01Woo00<001S66<H01QS60`002VJi1000:FJi0`000QS6
0P002FJi0`0000DHaP00000006Ji00<000EV^@<000aRYP8000ERYP80011RYP03000HaP0000=RYP80
00mRYP8000=RYP03001oogoo00Eoo`03001oogoo03Qoo`00;Goo00<007ooOol01Woo00<001S66<H0
11S60`002FJi1000:FJi0`000QS60`0026Ji0`0000@HaP00000000MV^@8000IV^@<000URYP8000ER
YP80011RYP03000HaP0000=RYP8000mRYP8000ARYP03001oogoo00Aoo`03001oogoo03Qoo`00;7oo
00<007ooOol01goo00@001S66<HHaP<000YV^@<002UV^@<0008HaP<000UV^@8000046<H00000000<
I[T30005I[T30007HZH20005HZH2000@HZH00`006<H00003HZH2000?HZH20004HZH00`00Oomoo`04
Ool00`00Oomoo`0hOol002aoo`03001oogoo00Moo`04000HaP00000:I[T4000XI[T300026<H30009
I[T6000BI[T30005I[T30004HZH20005HZH2000@HZH00`006<H00003HZH2000?HZH20004HZH00`00
Oomoo`04Ool00`00Oomoo`0hOol002aoo`03001oogoo00Ioo`<000UV^@@002QV^@<0008HaP<000UV
^@H001QV^@8000IV^@<00003HZH0000000ERYP80011RYP03000HaP0000=RYP8000mRYP8000ARYP03
001oogoo00Aoo`03001oogoo03Qoo`00;7oo00<007ooOol017oo0P000goo10000fJi0`00:6Ji0`00
0QS60`002FJi1P007FJi0`001VJi0`001F:V0P0046:V00<001S600000f:V0P003f:V0P0016:V00<0
07ooOol017oo00<007ooOol0>7oo000/Ool01000Oomoogoo0`002Goo10009fJi0`000QS60`002FJi
1P008fJi0P0000EV^@00000001S600<000ARYP80015RYP8000=RYP8000mRYP8000ARYP03001oogoo
00Aoo`03001oogoo03Qoo`00;7oo00@007oo0000011oo`<0025V^@<0008HaP<000UV^@H002IV^@L0
00=V^@<00003HZH00000015RYP8000=RYP8000mRYP8000ARYP03001oogoo00Aoo`03001oogoo03Qo
o`00;7oo0P005Goo0`0076Ji0P000QS60`002FJi1@009fJi0`0000DHaP00000006Ji008000IV^@@0
011RYP8000=RYP8000mRYP8000ARYP03001oogoo00Aoo`03001oogoo03Qoo`00;Woo0`005Goo0`00
00=RYVJiI[T04fJi0`000QS60P002FJi1@009fJi1`001VJi1`000fJi0P003V:V0P0016:V0P003V:V
0P0016:V00<007ooOol017oo00<007ooOol0>7oo000aOol4000DOol4000?I[T300026<H30008I[T5
000WI[T60009I[T70006I[T3000;HZH20004HZH2000>HZH20004HZH00`00Oomoo`04Ool00`00Oomo
o`0hOol003Eoo`<001Eoo`<000UV^@<0008HaP<000UV^@@002MV^@H000UV^@@000IV^@8000MV^@<0
00QRYP8000ARYP8000iRYP8000ARYP03001oogoo00Aoo`03001oogoo03Qoo`00>7oo0`005Goo0`00
0fJi0`000QS60`002FJi10009fJi1P002FJi10002fJi0`001VJi0`001V:V0P0016:V0P003V:V0P00
16:V00<007ooOol01Goo00<007ooOol0=goo000kOol3000EOol4000011S6000000002FJi10009fJi
1P002FJi10004FJi0P001fJi0`000f:V0P0016:V0P003V:V0P0016:V00<007ooOol01Goo00<007oo
Ool0=goo000nOol3000EOol20009I[T4000VI[T70008I[T5000FI[T30007I[T200000f:V00000004
HZH2000>HZH20004HZH00`00Oomoo`05Ool00`00Oomoo`0gOol0045oo`@001=oo`<000=V^@@002IV
^@L000QV^@@001eV^@8000MV^@<000ARYP8000iRYP8000ARYP03001oogoo00Eoo`03001oogoo03Mo
o`00AGoo0`004goo10009VJi1P002FJi10008VJi1`0000@HaP00000000=RYP8000iRYP8000ARYP03
001oogoo00Eoo`03001oogoo03Moo`00B7oo0`0057oo0`0086Ji1P002FJi10009FJi20000fJi0P00
00=RYP0000003f:V0P000f:V00<007ooOol01Goo00<007ooOol0=goo001;Ool3000DOol3000JI[T6
0009I[T4000UI[T3000011S6000000000VJi0P001FJi10003V:V0P000f:V00<007ooOol01Goo00<0
07ooOol0=goo001>Ool3000DOol200000f:VI[UV^@0BI[T60008I[T5000TI[T4000011S600000000
1fJi1P000fJi0P0036:V0P0016:V00<007ooOol017oo00<007ooOol0=goo001AOol4000BOol3000?
I[T60008I[T4000UI[T300000aS6000000020008I[T400000fJi00000006I[T2000:HZH20004HZH0
0`00Oomoo`04Ool00`00Oomoo`0gOol005Eoo`<0019oo`<000UV^@D000UV^@@002EV^@<000046<H0
00000008I[T50006I[T30005I[T30007HZH20004HZH00`00Oomoo`04Ool00`00Oomoo`0gOol005Qo
o`<0019oo`<000=V^@D000UV^@@002AV^@@000046<H000000007I[T6000<I[T20005I[T30005HZH2
0004HZH00`00Oomoo`04Ool00`00Oomoo`0gOol005]oo`<0019oo`D000QV^@D002AV^@<000036<H0
0000008000MV^@D0019V^@<000EV^@8000=RYP8000ARYP03001oogoo00Aoo`03001oogoo03Moo`00
GWoo0`0057oo0P000fJi100000<HaVJiI[T08FJi100000@HaP00000000MV^@H001QV^@<000AV^@80
0003HZH0000000ARYP03001oogoo00Aoo`03001oogoo03Moo`00HGoo10004Woo100096Ji0`0000<H
aP0000000P001fJi1P007VJi0P0016Ji10000f:V00<007ooOol017oo00<007ooOol0=goo001UOol3
000COol3000NI[T3000011S6000000001fJi1P0096Ji1@000fJi0P0000=RYP00Ool01Woo00<007oo
Ool0=Woo001XOol3000COol3000GI[T4000011S6000000001VJi1`008fJi1@000VJi0P001FJi0P00
1goo00<007ooOol0=Woo001[Ool3000COol4000@I[T300000aS6000000020006I[T6000SI[T60007
I[T50009Ool00`00Oomoo`0fOol006ioo`<001Aoo`<000YV^@<000046<H000000006I[T7000RI[T6
0008I[T40002Ool20009Ool00`00Oomoo`0fOol0075oo`@001=oo`<000=V^@@000046<H000000006
I[T7000RI[T60007I[T40008Ool30006Ool00`00Oomoo`0fOol007Eoo`<001=oo`<000036<H00000
008000EV^@L0029V^@H000MV^@@000moo`<000=oo`03001oogoo03Ioo`00N7oo0`004Woo0`0016Ji
100000@HaP000000025V^@L000IV^@@001Ioo`800003Ool007oo03Moo`00Ngoo0`004Woo100000<H
aP0000000P0086Ji1`001VJi100077oo0P00>7oo001nOol3000BOol2000QI[T60007I[T3000LOol4
000jOol0085oo`@0011oo`@001UV^@L000IV^@@001]oo`@003ioo`00QGoo0`004Goo0`004VJi1`00
1VJi10006goo1000@Woo0028Ool3000AOol3000;I[T80005I[T4000KOol40016Ool008]oo`<0015o
o`@000=V^@@000046<H000000005I[T4000KOol4001:Ool008ioo`<0019oo`<000036<H000000080
00AV^@@001]oo`@004ioo`00TGoo100047oo0`000fJi10006goo1000DWoo002EOol3000?Ool40000
0goo001oo`0HOol4001FOol009Qoo`<0015oo`03001oogoo01=oo`@005Yoo`00Vgoo0`003Woo00<0
07ooOol03goo1000GWoo002NOol3000;Ool00`00Oomoo`0;Ool4001ROol00:5oo`@000Moo`03001o
ogoo00Moo`@006Ioo`00YGoo0`0017oo00<007ooOol00goo1000JWoo002XOol300000goo001oo`04
001^Ool00:]oo`<0079oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?mo
ob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo
003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00001\
\>"]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot Magnetic Fields ", "Section"],

Cell["\<\
One Undulator must  be created before executing any cell of this \
section \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{\(x = 0; z = 0;\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"gra", "=", 
        RowBox[{"Plot", "[", 
          RowBox[{
            RowBox[{
              StyleBox["radFld",
                FontColor->RGBColor[1, 0, 0]], 
              "[", \(g, "\<Bz\>", {x, y, z}\), "]"}], 
            ",", \({y, \(-\((nper + 1)\)\)/2*per, \((nper + 1)\)/2*per}\), 
            ",", \(PlotLabel \[Rule] {"\<Vertical Field [T] vs Long.Position \
[mm]\>"}\)}], "]"}]}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{
            StyleBox["radFld",
              FontColor->RGBColor[1, 0, 0]], "[", \(g, "\<Bz\>", {x, 0, z}\), 
            "]"}], ",", \({x, \(-20\), 20}\)}], "]"}], ";"}]}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00501253 0.320605 0.554554 [
[.12406 -0.0125 -9 -9 ]
[.12406 -0.0125 9 0 ]
[.24937 -0.0125 -9 -9 ]
[.24937 -0.0125 9 0 ]
[.37469 -0.0125 -9 -9 ]
[.37469 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.62531 -0.0125 -6 -9 ]
[.62531 -0.0125 6 0 ]
[.75063 -0.0125 -6 -9 ]
[.75063 -0.0125 6 0 ]
[.87594 -0.0125 -6 -9 ]
[.87594 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09878 -24 -4.5 ]
[-0.0125 .09878 0 4.5 ]
[-0.0125 .20969 -24 -4.5 ]
[-0.0125 .20969 0 4.5 ]
[-0.0125 .3206 -6 -4.5 ]
[-0.0125 .3206 0 4.5 ]
[-0.0125 .43152 -18 -4.5 ]
[-0.0125 .43152 0 4.5 ]
[-0.0125 .54243 -18 -4.5 ]
[-0.0125 .54243 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -128.062 0 ]
[.5 .63053 128.062 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.12406 0 m
.12406 .00625 L
s
[(-75)] .12406 -0.0125 0 1 Mshowa
.24937 0 m
.24937 .00625 L
s
[(-50)] .24937 -0.0125 0 1 Mshowa
.37469 0 m
.37469 .00625 L
s
[(-25)] .37469 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.62531 0 m
.62531 .00625 L
s
[(25)] .62531 -0.0125 0 1 Mshowa
.75063 0 m
.75063 .00625 L
s
[(50)] .75063 -0.0125 0 1 Mshowa
.87594 0 m
.87594 .00625 L
s
[(75)] .87594 -0.0125 0 1 Mshowa
.125 Mabswid
.02381 0 m
.02381 .00375 L
s
.04887 0 m
.04887 .00375 L
s
.07393 0 m
.07393 .00375 L
s
.099 0 m
.099 .00375 L
s
.14912 0 m
.14912 .00375 L
s
.17419 0 m
.17419 .00375 L
s
.19925 0 m
.19925 .00375 L
s
.22431 0 m
.22431 .00375 L
s
.27444 0 m
.27444 .00375 L
s
.2995 0 m
.2995 .00375 L
s
.32456 0 m
.32456 .00375 L
s
.34962 0 m
.34962 .00375 L
s
.39975 0 m
.39975 .00375 L
s
.42481 0 m
.42481 .00375 L
s
.44987 0 m
.44987 .00375 L
s
.47494 0 m
.47494 .00375 L
s
.52506 0 m
.52506 .00375 L
s
.55013 0 m
.55013 .00375 L
s
.57519 0 m
.57519 .00375 L
s
.60025 0 m
.60025 .00375 L
s
.65038 0 m
.65038 .00375 L
s
.67544 0 m
.67544 .00375 L
s
.7005 0 m
.7005 .00375 L
s
.72556 0 m
.72556 .00375 L
s
.77569 0 m
.77569 .00375 L
s
.80075 0 m
.80075 .00375 L
s
.82581 0 m
.82581 .00375 L
s
.85088 0 m
.85088 .00375 L
s
.901 0 m
.901 .00375 L
s
.92607 0 m
.92607 .00375 L
s
.95113 0 m
.95113 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09878 m
.00625 .09878 L
s
[(-0.4)] -0.0125 .09878 1 0 Mshowa
0 .20969 m
.00625 .20969 L
s
[(-0.2)] -0.0125 .20969 1 0 Mshowa
0 .3206 m
.00625 .3206 L
s
[(0)] -0.0125 .3206 1 0 Mshowa
0 .43152 m
.00625 .43152 L
s
[(0.2)] -0.0125 .43152 1 0 Mshowa
0 .54243 m
.00625 .54243 L
s
[(0.4)] -0.0125 .54243 1 0 Mshowa
.125 Mabswid
0 .12651 m
.00375 .12651 L
s
0 .15424 m
.00375 .15424 L
s
0 .18197 m
.00375 .18197 L
s
0 .23742 m
.00375 .23742 L
s
0 .26515 m
.00375 .26515 L
s
0 .29288 m
.00375 .29288 L
s
0 .34833 m
.00375 .34833 L
s
0 .37606 m
.00375 .37606 L
s
0 .40379 m
.00375 .40379 L
s
0 .45924 m
.00375 .45924 L
s
0 .48697 m
.00375 .48697 L
s
0 .5147 m
.00375 .5147 L
s
0 .07106 m
.00375 .07106 L
s
0 .04333 m
.00375 .04333 L
s
0 .0156 m
.00375 .0156 L
s
0 .57015 m
.00375 .57015 L
s
0 .59788 m
.00375 .59788 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.12406 .61178 m
.12406 .61803 L
s
.24937 .61178 m
.24937 .61803 L
s
.37469 .61178 m
.37469 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.62531 .61178 m
.62531 .61803 L
s
.75063 .61178 m
.75063 .61803 L
s
.87594 .61178 m
.87594 .61803 L
s
.125 Mabswid
.02381 .61428 m
.02381 .61803 L
s
.04887 .61428 m
.04887 .61803 L
s
.07393 .61428 m
.07393 .61803 L
s
.099 .61428 m
.099 .61803 L
s
.14912 .61428 m
.14912 .61803 L
s
.17419 .61428 m
.17419 .61803 L
s
.19925 .61428 m
.19925 .61803 L
s
.22431 .61428 m
.22431 .61803 L
s
.27444 .61428 m
.27444 .61803 L
s
.2995 .61428 m
.2995 .61803 L
s
.32456 .61428 m
.32456 .61803 L
s
.34962 .61428 m
.34962 .61803 L
s
.39975 .61428 m
.39975 .61803 L
s
.42481 .61428 m
.42481 .61803 L
s
.44987 .61428 m
.44987 .61803 L
s
.47494 .61428 m
.47494 .61803 L
s
.52506 .61428 m
.52506 .61803 L
s
.55013 .61428 m
.55013 .61803 L
s
.57519 .61428 m
.57519 .61803 L
s
.60025 .61428 m
.60025 .61803 L
s
.65038 .61428 m
.65038 .61803 L
s
.67544 .61428 m
.67544 .61803 L
s
.7005 .61428 m
.7005 .61803 L
s
.72556 .61428 m
.72556 .61803 L
s
.77569 .61428 m
.77569 .61803 L
s
.80075 .61428 m
.80075 .61803 L
s
.82581 .61428 m
.82581 .61803 L
s
.85088 .61428 m
.85088 .61803 L
s
.901 .61428 m
.901 .61803 L
s
.92607 .61428 m
.92607 .61803 L
s
.95113 .61428 m
.95113 .61803 L
s
.97619 .61428 m
.97619 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .09878 m
1 .09878 L
s
.99375 .20969 m
1 .20969 L
s
.99375 .3206 m
1 .3206 L
s
.99375 .43152 m
1 .43152 L
s
.99375 .54243 m
1 .54243 L
s
.125 Mabswid
.99625 .12651 m
1 .12651 L
s
.99625 .15424 m
1 .15424 L
s
.99625 .18197 m
1 .18197 L
s
.99625 .23742 m
1 .23742 L
s
.99625 .26515 m
1 .26515 L
s
.99625 .29288 m
1 .29288 L
s
.99625 .34833 m
1 .34833 L
s
.99625 .37606 m
1 .37606 L
s
.99625 .40379 m
1 .40379 L
s
.99625 .45924 m
1 .45924 L
s
.99625 .48697 m
1 .48697 L
s
.99625 .5147 m
1 .5147 L
s
.99625 .07106 m
1 .07106 L
s
.99625 .04333 m
1 .04333 L
s
.99625 .0156 m
1 .0156 L
s
.99625 .57015 m
1 .57015 L
s
.99625 .59788 m
1 .59788 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .3206 m
1 .3206 L
s
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -189.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.000 moveto
(8) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Vertical) show
123.000 13.000 moveto
(Field) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
159.000 13.000 moveto
(@) show
165.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
171.000 13.000 moveto
(D) show
183.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(vs) show
201.000 13.000 moveto
(Long) show
225.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
231.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Position) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
285.000 13.000 moveto
(@) show
291.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
303.125 13.000 moveto
(D) show
309.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
309.125 13.000 moveto
(<) show
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .34271 m
.03279 .34782 L
.04262 .355 L
.05288 .36478 L
.06244 .37654 L
.0828 .41141 L
.09324 .43256 L
.09875 .44305 L
.10458 .45252 L
.10712 .45586 L
.10985 .45879 L
.11142 .46011 L
.11285 .46108 L
.11354 .46146 L
.11429 .46181 L
.11499 .46207 L
.11566 .46225 L
.1163 .46238 L
.117 .46245 L
.11822 .4624 L
.11892 .46228 L
.11965 .46207 L
.12096 .46149 L
.12218 .46071 L
.12331 .45976 L
.12589 .45679 L
.1285 .45257 L
.13097 .44739 L
.13561 .43443 L
.1406 .41563 L
.14603 .38962 L
.1658 .25746 L
.17591 .18009 L
.18681 .10311 L
.19176 .07381 L
.19697 .0485 L
.20141 .03213 L
.20393 .02517 L
.20628 .02025 L
.20742 .0184 L
.20866 .01682 L
.20983 .01573 L
.21091 .01506 L
.21188 .01475 L
.21295 .01472 L
.21407 .01503 L
.21512 .01565 L
.21634 .01678 L
.21749 .01824 L
.21967 .02203 L
Mistroke
.22201 .02762 L
.22456 .03549 L
.22989 .05782 L
.2349 .08573 L
.24427 .15324 L
.26526 .34417 L
.27415 .42546 L
.28367 .50198 L
.28914 .53791 L
.29412 .56415 L
.29652 .57438 L
.29912 .58362 L
.30158 .59053 L
.30386 .59531 L
.305 .59713 L
.30624 .59865 L
.3074 .59967 L
.30847 .60024 L
.30965 .60047 L
.31095 .60024 L
.3116 .59993 L
.3123 .59946 L
.31355 .59825 L
.31488 .59644 L
.31633 .59388 L
.31894 .58766 L
.32149 .57967 L
.32384 .57065 L
.32872 .547 L
.33408 .514 L
.34491 .42971 L
.36603 .23732 L
.37604 .15364 L
.38531 .09189 L
.38994 .06885 L
.39231 .05934 L
.39486 .05087 L
.39741 .04433 L
.39855 .04202 L
.3998 .03994 L
.40119 .03818 L
.40195 .03746 L
.40265 .03695 L
.40391 .0364 L
.40462 .0363 L
.40526 .03634 L
.40644 .03674 L
.40769 .03761 L
.40875 .03873 L
.40993 .04035 L
Mistroke
.41254 .04545 L
.41499 .05205 L
.41942 .06841 L
.42418 .09208 L
.4343 .1605 L
.44533 .25476 L
.46543 .4381 L
.47557 .51659 L
.48054 .54748 L
.48511 .57034 L
.48764 .58049 L
.4904 .58953 L
.49318 .59635 L
.4947 .59911 L
.49612 .60107 L
.49741 .60232 L
.49864 .60305 L
.49974 .60332 L
.50093 .6032 L
.50223 .60258 L
.50289 .60207 L
.50361 .60137 L
.50489 .59973 L
.50609 .59776 L
.50853 .59242 L
.51079 .58589 L
.51593 .5656 L
.52094 .53889 L
.52629 .50363 L
.5448 .34616 L
.56473 .16819 L
.57019 .12745 L
.57596 .09127 L
.58089 .06707 L
.58368 .05638 L
.58632 .0483 L
.58881 .04256 L
.59022 .04013 L
.59153 .0384 L
.59274 .03726 L
.59383 .03661 L
.5951 .0363 L
.59629 .03645 L
.59759 .03711 L
.59825 .03763 L
.59897 .03835 L
.60024 .04001 L
.60143 .04199 L
.60412 .04802 L
.60699 .05681 L
Mistroke
.61219 .07872 L
.61711 .10611 L
.62632 .17211 L
.64459 .33498 L
.65498 .42882 L
.66472 .50573 L
.66962 .5375 L
.67427 .56225 L
.67684 .5734 L
.67964 .58344 L
.68218 .59059 L
.68455 .59551 L
.68587 .59752 L
.68656 .59838 L
.6873 .59912 L
.68794 .59964 L
.68864 .60006 L
.68988 .60045 L
.69109 .60037 L
.69239 .59981 L
.69361 .59881 L
.69472 .5975 L
.69611 .59536 L
.69739 .59287 L
.7003 .58541 L
.70285 .57678 L
.70557 .56555 L
.71494 .51175 L
.72504 .43253 L
.74331 .26324 L
.75369 .1701 L
.76334 .09695 L
.76862 .06544 L
.77342 .04305 L
.77616 .03309 L
.77875 .02564 L
.78148 .01986 L
.78302 .01754 L
.7837 .01674 L
.78444 .01601 L
.78569 .01515 L
.78688 .01474 L
.78804 .01473 L
.78911 .01507 L
.79039 .0159 L
.79154 .01705 L
.79287 .01885 L
.79413 .02099 L
.7964 .02599 L
.79849 .03182 L
Mistroke
.8032 .04919 L
.80798 .0724 L
.81324 .10338 L
.82383 .17813 L
.83471 .26134 L
.84501 .33549 L
.85503 .39512 L
.85944 .41578 L
.8643 .4341 L
.86655 .44097 L
.86897 .44724 L
.87106 .45173 L
.87335 .45569 L
.8758 .45886 L
.87713 .46015 L
.87837 .46109 L
.87953 .46174 L
.88059 .46214 L
.88181 .4624 L
.88296 .46245 L
.88413 .4623 L
.88542 .46192 L
.88607 .46165 L
.88677 .4613 L
.88803 .46052 L
.89047 .45848 L
.8927 .45608 L
.89811 .44842 L
.90324 .43938 L
.9218 .40245 L
.93197 .38478 L
.94153 .37131 L
.95799 .3545 L
.96675 .34812 L
.97619 .34271 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00?@3oool00`000000oooo0?ooo`020?ooo`<000005@3oool3000000@0oooo0P00000E0?oo
o`D000000P3oool3000001H0oooo0P00000G0?ooo`D000000P3oool3000001H0oooo0`0000040?oo
o`8000005P3oool00`000000oooo0?ooo`020?ooo`<00000:03oool003d0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`030000003oool0oooo0140oooo00D000000?ooo`3oool0oooo00000002
0?ooo`040000003oool0oooo000001D0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`03
0000003oool0oooo0180oooo00@000000?ooo`3oool000005`3oool01P000000oooo0?ooo`000000
oooo000000<0oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool000005@3oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`3oool09@3oool003D0oooo1@0000040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool02`3oool5000000D0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0<0?oo
o`D000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0180oooo00@000000?oo
o`3oool00000603oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01H0oooo00@00000
0?ooo`3oool000000P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool09@3oool003h0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0E
0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool05@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0180oooo00@000000?ooo`3oool000006@3oool00`000000oooo
0?ooo`040?ooo`030000003oool0oooo01H0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool09@3oool003l0oooo
00<000000?ooo`0000000`00000D0?ooo`@000000`3oool010000000oooo0?ooo`00000D0?ooo`06
0000003oool0oooo0?ooo`000000oooo1000000E0?ooo`040000003oool0oooo000001H0oooo00H0
00000?ooo`3oool0oooo0000003oool4000001D0oooo100000030?ooo`040000003oool0oooo0000
01L0oooo00<000000?ooo`0000000`00000X0?ooo`00>`3oool01`000000oooo0?ooo`3oool00000
0?ooo`0000005`3oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo000001@0oooo00L0
00000?ooo`3oool0oooo0000003oool0000001P0oooo00@000000?ooo`3oool000005P3oool01`00
0000oooo0?ooo`3oool000000?ooo`000000603oool00`000000oooo0?ooo`040?ooo`040000003o
ool0oooo000001<0oooo00L000000?ooo`3oool0oooo0000003oool0000002/0oooo000k0?ooo`D0
000000<0oooo0000000000000`00000C0?ooo`D000000`3oool2000001H0oooo0`0000020?ooo`D0
00005@3oool2000001P0oooo0`0000020?ooo`D00000503oool5000000<0oooo0P00000D0?ooo`D0
000000<0oooo0000000000000`00000W0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00803ooooc000000d0oooo000P0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool02`3oool00200oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?oo
o`1f0?ooo`030000003oool0oooo00/0oooo000P0?ooo`800000<@3oool2000004@0oooo00<00000
0?ooo`3oool0@P3oool300000300oooo0P00000=0?ooo`00803oool00`000000oooo0?ooo`0_0?oo
o`040000003oool00000000004<0oooo00<000000?ooo`3oool0@@3oool2000000030?ooo`000000
oooo0300oooo00<000000?ooo`3oool02`3oool00200oooo00<000000?ooo`3oool0;`3oool01000
0000oooo0?ooo`0000130?ooo`030000003oool0oooo0440oooo00@000000?ooo`3oool00000<@3o
ool00`000000oooo0?ooo`0;0?ooo`00803oool00`000000oooo0?ooo`0^0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`110?ooo`050000003oool0
oooo0?ooo`000000<03oool00`000000oooo0?ooo`0;0?ooo`00803oool00`000000oooo0?ooo`0^
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`11
0?ooo`050000003oool0oooo0?ooo`000000<03oool00`000000oooo0?ooo`0;0?ooo`00803oool0
0`000000oooo0?ooo`0^0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool02`3oool0
0200oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
02P0oooo0`00000E0?ooo`030000003oool0oooo01<0oooo0`00000Z0?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0;0?ooo`00803oool2000002h0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0V0?ooo`80000000<0oooo0000003o
ool0503oool00`000000oooo0?ooo`0C0?ooo`040000003oool0oooo000002P0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0/0?ooo`8000003@3oool00200oooo00<000000?ooo`3o
ool0;@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02H0oooo00D000000?ooo`3o
ool0oooo0000000D0?ooo`030000003oool0oooo0180oooo00D000000?ooo`3oool0oooo0000000X
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0;
0?ooo`00803oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool09P3oool01@000000oooo0?ooo`3oool0000001@0oooo00<000000?ooo`3oool04P3oool0
1@000000oooo0?ooo`3oool0000002P0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`0/0?ooo`030000003oool0oooo00/0oooo000P0?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0U0?ooo`050000003oool0oooo0?ooo`000000503o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0903o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo02`0oooo00<000000?ooo`3oool02`3o
ool00200oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`060?ooo`030000003oool0
oooo02@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0;0?ooo`00803oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0[0?ooo`030000003oool0oooo00/0oooo000P0?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo02/0
oooo00<000000?ooo`3oool02`3oool00200oooo0P00000/0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0100oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo02<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Z0?ooo`8000003@3oool00200oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo0280oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0:`3oool00`000000oooo0?ooo`0;0?ooo`00803oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0[
0?ooo`030000003oool0oooo00/0oooo000P0?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool08P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02/0oooo00<000000?oo
o`3oool02`3oool000d0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0`0000040?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool02`3oool000`0oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3o
ool08@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3o
ool02`3oool000D0oooo1@0000020?ooo`040000003oool0oooo000000L0oooo1@0000040?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Q0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0@0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo02X0oooo00<000000?ooo`3oool02`3oool000`0oooo00@000000?ooo`3oool0
00001`3oool010000000oooo0?ooo`0000050?ooo`800000:`3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo0100oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0:@3oool2000000d0oooo000<0?ooo`04
0000003oool0oooo000000P0oooo00<000000?ooo`0000001@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0200oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0Z0?oo
o`030000003oool0oooo00/0oooo000<0?ooo`040000003oool0oooo000000T0oooo0P0000050?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0P0?oo
o`030000003oool0oooo00L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0?0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo02X0oooo00<000000?ooo`3oool02`3oool000d0oooo0P00000;0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo01l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo00l0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0P0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0;0?ooo`00
803oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0
2P3oool00`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo00/0oooo000P0?ooo`030000003o
ool0oooo02X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0O0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0;0?ooo`030000003o
ool0oooo02T0oooo00<000000?ooo`3oool02`3oool00200oooo0P00000Z0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0X0?ooo`8000003@3oool0
0200oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
01l0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0;0?ooo`00803oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool07`3oool00`000000
oooo0?ooo`090?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0Y0?ooo`030000003oool0oooo00/0oooo000P0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00X0oooo
00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo02T0oooo
00<000000?ooo`3oool02`3oool00200oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?oo
o`0;0?ooo`00803oool00`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool0303oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00/0oooo000P0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0M0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo00/0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo02P0oooo00<000000?ooo`3oool02`3oool00200oooo0P00000Z0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo01d0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0W0?ooo`80
00003@3oool00200oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo01d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0=0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0;0?ooo`00803o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool07@3o
ool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool03@3o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00/0oooo000P0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0=0?ooo`030000003oool0
oooo02P0oooo00<000000?ooo`3oool02`3oool00200oooo00<000000?ooo`3oool0:03oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool09`3oool00`00
0000oooo0?ooo`0;0?ooo`00803oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00d0
oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00/0
oooo000P0?ooo`030000003oool0oooo02P0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0K0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo
0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0703oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo02L0oooo00<000000?ooo`3oool02`3oool00200oooo0P00
000Y0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0V0?ooo`8000003@3oool00200oooo00<000000?ooo`3oool0:03oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0<
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0L
0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0;
0?ooo`00803oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00/0oooo000P0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0K0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool02`3oool000d0oooo0P0000040?ooo`040000
003oool0oooo0?ooo`D00000103oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo00/0
oooo000<0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0W0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`0=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0303oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool0403oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00/0oooo00050?ooo`D000000P3oool010000000
oooo0?ooo`0000090?ooo`030000003oool0oooo00@0oooo0P00000X0?ooo`030000003oool0oooo
00l0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
00`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0U0?ooo`8000003@3oool000`0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
02L0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
02H0oooo00<000000?ooo`3oool02`3oool000`0oooo00@000000?ooo`3oool000001`3oool01@00
0000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool09`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0;
0?ooo`00303oool010000000oooo0?ooo`0000070?ooo`050000003oool0oooo0?ooo`000000103o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3o
ool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`0V0?ooo`030000003oool0oooo00/0oooo000=0?ooo`8000002@3oool3
000000D0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo01T0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0;0?ooo`00803oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool02`3oool00`00
0000oooo0?ooo`0?0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0V0?ooo`030000003oool0oooo00/0oooo000P0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00l0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo02H0
oooo00<000000?ooo`3oool02`3oool00200oooo0P00000W0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01P0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0U0?ooo`8000003@3oool00200oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01T0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo00<0
00000?ooo`3oool0403oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool09P3oool00`000000oooo0?ooo`0;0?ooo`00803oool00`000000oooo0?ooo`0V
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0@
0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0U
0?ooo`030000003oool0oooo00/0oooo000P0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool04P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0100oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02D0oooo00<000000?oo
o`3oool02`3oool00200oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0C0?ooo`03
0000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0;0?ooo`00
803oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
2`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0
4`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo00/0oooo000P0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0C0?ooo`030000003o
ool0oooo02D0oooo00<000000?ooo`3oool02`3oool00200oooo0P00000V0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo01L0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0T0?ooo`8000003@3oool0
0200oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0;0?ooo`00803oool00`000000
oooo0?ooo`0T0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool05`3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`0A0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04`3oool00`000000
oooo0?ooo`0U0?ooo`030000003oool0oooo00/0oooo000P0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0180oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo02@0oooo
00<000000?ooo`3oool02`3oool00200oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0F0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0;0?ooo`00803oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo01@0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool02P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00/0oooo000P0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0E0?oo
o`030000003oool0oooo02@0oooo00<000000?ooo`3oool02`3oool00200oooo0P00000U0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01D0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0S0?ooo`80
00003@3oool00200oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo01D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0;0?ooo`00803o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo00/0oooo000P0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo01<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo02<0oooo00<000000?ooo`3oool02`3oool001T0oooo0P0000050?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool02`3oool001P0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool05@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0C0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`0S0?ooo`030000003oool0oooo00/0oooo000H0?ooo`040000003oool0oooo0000
00@0ooool`00000=0?ooo`00603oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo
02<0oooo00<000000?ooo`3oool02`3oool001P0oooo00@000000?ooo`3oool00000103oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0603oool00`00
0000oooo0?ooo`0R0?ooo`030000003oool0oooo00/0oooo000H0?ooo`040000003oool0oooo0000
00@0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00T0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
01P0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0;0?ooo`006@3oool2000000D0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01P0
oooo00<000000?ooo`3oool08P3oool00`000000oooo0?ooo`0;0?ooo`00803oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`0E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0603oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo00/0oooo000P0?ooo`030000003oool0oooo00<0oooo0P00
000M0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0203oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0L0?ooo`800000103oool00`000000oooo0?ooo`0;0?ooo`00803oool2000000H0oooo00<00000
0?ooo`3oool06P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool05P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool06P3oool2000000D0oooo0P00000=0?ooo`00803oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0C0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo01D0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0;0?oo
o`00803oool00`000000oooo0?ooo`070?ooo`800000603oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00/0oooo000P0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0
5P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00/0oooo000P0?ooo`030000003o
ool0oooo00X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0I0?ooo`030000003o
ool0oooo01<0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo00/0oooo000P0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00/0oooo000P0?ooo`030000003oool0oooo
00/0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
01X0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
00/0oooo000P0?ooo`8000003@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo01X0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo00X0
oooo0P00000=0?ooo`00803oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01L0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0140oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`00803oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool06`3oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0;0?ooo`00803oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo00l0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01P0oooo00<00000
0?ooo`3oool0403oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0100oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0;0?ooo`00803oool00`000000oooo0?ooo`0>0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0;0?oo
o`00803oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool06`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3o
ool0403oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`0;0?ooo`00803oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0A0?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01T0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0;0?ooo`00803o
ool200000140oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo01`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0?0?ooo`8000003@3o
ool00200oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo01d0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0H0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0
oooo0100oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0;0?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool02`3oool00200oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool03`3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0I0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`0;0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool02`3oool00200
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool02`3oool000d0oooo0P0000040?ooo`040000003oool0oooo0?ooo`D0
0000103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool07@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01X0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0;0?ooo`00303oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo000000@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`090?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool02`3oool000`0oooo00@000000?ooo`3o
ool000002@3oool00`000000oooo0?ooo`040?ooo`800000503oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0180oooo0P00000=0?ooo`00303oool010000000oooo0?ooo`00000:0?oo
o`030000003oool0oooo00<0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0K0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool000`0oooo00@000000?ooo`3o
ool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool03`3oool0
0`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool07P3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02`3oool0
00`0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<0
00000?ooo`3oool05@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo00D0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool07`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool02`3oool000d0oooo0P0000090?ooo`<000001@3oool00`000000oooo0?ooo`0E
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`05
0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0Q
0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0;
0?ooo`00803oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool08@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo01`0oooo00<000000?oo
o`3oool0303oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00<0oooo00<000000?oo
o`3oool05P3oool00`000000oooo0?ooo`0;0?ooo`00803oool00`000000oooo0?ooo`0G0?ooo`05
0000003oool0oooo0?ooo`000000903oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0R0?ooo`050000003oool0oooo
0?ooo`0000006@3oool00`000000oooo0?ooo`0;0?ooo`00803oool2000001P0oooo0P0000000`3o
ool000000000000T0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool06`3oool00`00
0000oooo0?ooo`050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0703oool00`00
0000oooo0?ooo`0<0?ooo`030000003oool0oooo0280oooo0P0000000`3oool000000000000H0?oo
o`8000003@3oool00200oooo00<000000?ooo`3oool06@3oool2000002D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool08`3oool3000001X0oooo00<000000?ooo`3oool02`3oool00200oooo00<000000?ooo`3oool0
@@3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0
303oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo00/0oooo000P0?ooo`030000003o
ool0oooo0440oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0L0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0M0?ooo`030000003o
ool0oooo00`0oooo00<000000?ooo`3oool0@03oool00`000000oooo0?ooo`0;0?ooo`00803oool0
0`000000oooo0?ooo`110?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`040?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool07@3oool0
0`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool02`3oool0
0200oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
01d0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`110?ooo`030000003oool0oooo
00/0oooo000P0?ooo`030000003oool0oooo0440oooo00<000000?ooo`3oool02`3oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0M0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0@@3oool00`000000
oooo0?ooo`0;0?ooo`00803oool200000480oooo00<000000?ooo`3oool02`3oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo
0?ooo`0N0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0@03oool2000000d0oooo
000P0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool02P3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`0O0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0;0?ooo`00803oool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00X0oooo00<00000
0?ooo`3oool07@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool07`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0440oooo00<00000
0?ooo`3oool02`3oool00200oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo01h0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo01l0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`110?oo
o`030000003oool0oooo00/0oooo000P0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3o
ool02@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool0@P3oool00`000000oooo0?ooo`0;0?ooo`00803oool00`000000oooo0?ooo`120?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`030000
003oool0oooo0480oooo00<000000?ooo`3oool02`3oool00200oooo0P0000130?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo0440oooo0P00000=0?ooo`00803oool00`000000oooo0?ooo`120?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo0480oooo00<000000?ooo`3oool02`3oool00200oooo00<000000?ooo`3oool0@`3oool00`00
0000oooo0?ooo`080?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`030?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool02@3oool00`00
0000oooo0?ooo`120?ooo`030000003oool0oooo00/0oooo000P0?ooo`030000003oool0oooo04<0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0;0?ooo`00803oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool07`3oool00`000000oooo
0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool08@3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool02`3oool000d0oooo0P00
00040?ooo`030000003oool0oooo00<0oooo0`0000040?ooo`030000003oool0oooo04<0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0@`3oool00`000000oooo0?ooo`0;0?ooo`00303oool010000000oooo0?ooo`00
000:0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool00P3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`130?ooo`030000003oool0oooo00/0oooo000<0?ooo`040000003oool0oooo000000L0oooo1@00
00040?ooo`800000A03oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool00P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0240oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`120?ooo`8000003@3oool000`0oooo00@00000
0?ooo`3oool000001`3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo04<0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0080oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0;0?ooo`00303oool010000000oooo0?oo
o`0000080?ooo`030000003oool0000000D0oooo00<000000?ooo`3oool0@`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`130?ooo`030000003oool0oooo00/0oooo000<0?ooo`040000003oool0oooo000000T0oooo
0P0000050?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool01@3oool00`000000oooo
0?ooo`0S0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`0S0?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0;0?ooo`00
3@3oool2000000/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`140?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool08`3oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04@0
oooo00<000000?ooo`3oool02`3oool00200oooo00<000000?ooo`3oool0A03oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo02<0oooo00D000000?ooo`3oool0oooo000000030?ooo`03
0000003oool0oooo02<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`140?ooo`03
0000003oool0oooo00/0oooo000P0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0U0?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3o
ool08`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3o
ool02`3oool00200oooo0P0000160?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
9@3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`130?ooo`8000003@3oool00200oooo00<000000?ooo`3oool0
A@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo02D0oooo00@000000?ooo`3oool0
00000`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0A@3oool00`000000oooo0?ooo`0;0?ooo`00803oool00`000000oooo0?ooo`150?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool09@3oool010000000oooo0?ooo`0000020?ooo`03
0000003oool0oooo02D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`150?ooo`03
0000003oool0oooo00/0oooo000P0?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3oool0
0`3oool00`000000oooo0?ooo`0U0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3o
ool09P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo04D0oooo00<000000?ooo`3o
ool02`3oool00200oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`020?ooo`030000
003oool0oooo02L0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0V0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0A@3oool00`000000oooo0?ooo`0;0?ooo`00803o
ool00`000000oooo0?ooo`160?ooo`050000003oool0oooo0?ooo`000000:@3oool01@000000oooo
0000003oool0000002T0oooo00D000000?ooo`3oool0oooo000000180?ooo`030000003oool0oooo
00/0oooo000P0?ooo`030000003oool0oooo04L0oooo00@000000?ooo`0000000000:@3oool01@00
0000oooo0000003oool0000002X0oooo00@000000?ooo`0000000000B03oool00`000000oooo0?oo
o`0;0?ooo`00803oool2000004P0oooo0`00000[0?ooo`@00000:P3oool3000004P0oooo0P00000=
0?ooo`00803oool00`000000oooo0?ooo`1e0?ooo`<00000M`3oool00`000000oooo0?ooo`0;0?oo
o`00803oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3o
ool02`3oool00200oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo01`0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0K0?ooo`030000
003oool0oooo00/0oooo000P0?oooo<000003@3oool00?l0oooo8@3oool00?l0oooo8@3oool00?l0
oooo8@3oool00?l0oooo8@3oool001l0oooo00<000000?ooo`3oool0G03oool2000000P0oooo0P00
000^0?ooo`<00000@@3oool2000000h0oooo0P0000040?ooo`030000003oool0oooo00/0oooo000N
0?ooo`030000003oool0oooo05d0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0_
0?ooo`030000003oool0oooo03h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`03
0?ooo`030000003oool0oooo00X0oooo000N0?ooo`030000003oool0oooo0080oooo00<000000?oo
o`3oool00P3oool300000080oooo0`0000050?ooo`8000000P3oool500000080oooo0`0000030?oo
o`@0000000<0oooo0000000000000`0000070?ooo`<000000`3oool500000080oooo0`0000020?oo
o`D000000P3oool4000000X0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`030000003oool0
oooo00T0oooo00@000000?ooo`3oool0oooo100000080?ooo`D000000P3oool300000080oooo0`00
0000103oool000000000003oool4000000<0oooo00@000000?ooo`3oool0oooo0`0000040?ooo`<0
00000P3oool400000080oooo1@0000030?ooo`8000000P3oool500000080oooo0`0000020?ooo`<0
000000<0oooo0000000000002@3oool03P000000oooo0?ooo`000000oooo0000003oool000000?oo
o`000000oooo0000003oool000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00X0oooo000N0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000060?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003o
ool0oooo00P0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000L0oooo
00D000000?ooo`3oool0oooo000000020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`060?ooo`060000003oool0oooo0000003oool000000`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001@3oool01@000000oooo
0?ooo`3oool0000000@0oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0
000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`080?ooo`0>0000003o
ool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000030?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool001d0oooo00<000000?ooo`3oool00`3o
ool010000000oooo0?ooo`3oool500000080oooo00<000000?ooo`3oool00`3oool00`000000oooo
0?ooo`040?ooo`050000003oool0oooo0?ooo`0000001P3oool3000000@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`040?ooo`040000003oool0oooo0?ooo`D000000`3oool01@00
0000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0203oool00`000000oooo00000003
0?ooo`<000002@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00<000000?ooo`3oool01P3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool3000000@0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`040?ooo`050000003oool0oooo0?ooo`0000000`3oool0
10000000oooo0?ooo`0000020?ooo`030000003oool0oooo00P0oooo00h000000?ooo`3oool00000
0?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`090?ooo`007P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00000P3oool01@000000oooo0?ooo`3oool000000080oooo0P0000040?ooo`030000003oool0oooo
00@0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool000000080oooo00<00000
0?ooo`3oool00P3oool00`000000oooo0?ooo`080?ooo`<00000103oool01@000000oooo0?ooo`3o
ool0000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`040000003oool0oooo000000/0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0080
oooo00D000000?ooo`3oool0oooo000000020?ooo`060000003oool0oooo0000003oool000000`3o
ool00`000000oooo0?ooo`060?ooo`<000000P3oool01`000000oooo0?ooo`3oool000000?ooo`00
00001`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00@0oooo00D000000?ooo`3o
ool0oooo000000030?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0203oool0
3P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000`3o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00X0oooo000N0?ooo`070000003oool0
oooo0?ooo`000000oooo000000030?ooo`<000000P3oool2000000040?ooo`00000000000?ooo`@0
00000P3oool3000000@0oooo0`0000030?ooo`8000001@3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo0`0000040?ooo`<00000103oool00`000000oooo0?ooo`020?ooo`<0
00002`3oool020000000oooo0?ooo`000000oooo0000003oool000000`3oool00`000000oooo0?oo
o`070?ooo`80000000<0oooo0000000000000P3oool4000000P0oooo00<000000?ooo`3oool00`3o
ool300000080oooo100000030?ooo`D000001`3oool010000000oooo0?ooo`0000020?ooo`<00000
0`3oool4000000040?ooo`0000000000000000<0oooo100000020?ooo`<00000103oool300000080
oooo1000000;0?ooo`030000003oool0oooo0080000000@0oooo0000003oool0oooo0P0000000`3o
ool000000?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool02P3oool001l0
oooo00H000000?ooo`3oool000000?ooo`00000?0?ooo`030000003oool0oooo01H0oooo00<00000
0?ooo`3oool0203oool010000000oooo0?ooo`00000?0?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool02@3oool2000000060?ooo`000000oooo0000003oool000000P3oool2000001`0
oooo00<000000?ooo`3oool06`3oool010000000oooo0?ooo`00000D0?ooo`030000003oool0oooo
01d0oooo0P00000>0?ooo`800000103oool00`000000oooo0?ooo`0;0?ooo`008@3oool5000000h0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0=0?ooo`<000002@3oool5000000<0
oooo00<000000?ooo`3oool01`3oool3000000D0oooo0P00000>0?ooo`D000007`3oool3000001/0
oooo1000000@0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`0j0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-126.371, -0.667602, \
0.822674, 0.00743603}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0238095 -2.86017 6.60043 [
[.02381 -0.0125 -9 -9 ]
[.02381 -0.0125 9 0 ]
[.2619 -0.0125 -9 -9 ]
[.2619 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.7381 -0.0125 -6 -9 ]
[.7381 -0.0125 6 0 ]
[.97619 -0.0125 -6 -9 ]
[.97619 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04402 -24 -4.5 ]
[-0.0125 .04402 0 4.5 ]
[-0.0125 .17603 -24 -4.5 ]
[-0.0125 .17603 0 4.5 ]
[-0.0125 .30804 -24 -4.5 ]
[-0.0125 .30804 0 4.5 ]
[-0.0125 .44004 -18 -4.5 ]
[-0.0125 .44004 0 4.5 ]
[-0.0125 .57205 -24 -4.5 ]
[-0.0125 .57205 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-20)] .02381 -0.0125 0 1 Mshowa
.2619 0 m
.2619 .00625 L
s
[(-10)] .2619 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.7381 0 m
.7381 .00625 L
s
[(10)] .7381 -0.0125 0 1 Mshowa
.97619 0 m
.97619 .00625 L
s
[(20)] .97619 -0.0125 0 1 Mshowa
.125 Mabswid
.07143 0 m
.07143 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.35714 0 m
.35714 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.45238 0 m
.45238 .00375 L
s
.54762 0 m
.54762 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.64286 0 m
.64286 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.92857 0 m
.92857 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04402 m
.00625 .04402 L
s
[(0.44)] -0.0125 .04402 1 0 Mshowa
0 .17603 m
.00625 .17603 L
s
[(0.46)] -0.0125 .17603 1 0 Mshowa
0 .30804 m
.00625 .30804 L
s
[(0.48)] -0.0125 .30804 1 0 Mshowa
0 .44004 m
.00625 .44004 L
s
[(0.5)] -0.0125 .44004 1 0 Mshowa
0 .57205 m
.00625 .57205 L
s
[(0.52)] -0.0125 .57205 1 0 Mshowa
.125 Mabswid
0 .07702 m
.00375 .07702 L
s
0 .11002 m
.00375 .11002 L
s
0 .14302 m
.00375 .14302 L
s
0 .20903 m
.00375 .20903 L
s
0 .24203 m
.00375 .24203 L
s
0 .27503 m
.00375 .27503 L
s
0 .34104 m
.00375 .34104 L
s
0 .37404 m
.00375 .37404 L
s
0 .40704 m
.00375 .40704 L
s
0 .47305 m
.00375 .47305 L
s
0 .50605 m
.00375 .50605 L
s
0 .53905 m
.00375 .53905 L
s
0 .01102 m
.00375 .01102 L
s
0 .60505 m
.00375 .60505 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.2619 .61178 m
.2619 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.7381 .61178 m
.7381 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.07143 .61428 m
.07143 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.16667 .61428 m
.16667 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.35714 .61428 m
.35714 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.45238 .61428 m
.45238 .61803 L
s
.54762 .61428 m
.54762 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.64286 .61428 m
.64286 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.83333 .61428 m
.83333 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.92857 .61428 m
.92857 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04402 m
1 .04402 L
s
.99375 .17603 m
1 .17603 L
s
.99375 .30804 m
1 .30804 L
s
.99375 .44004 m
1 .44004 L
s
.99375 .57205 m
1 .57205 L
s
.125 Mabswid
.99625 .07702 m
1 .07702 L
s
.99625 .11002 m
1 .11002 L
s
.99625 .14302 m
1 .14302 L
s
.99625 .20903 m
1 .20903 L
s
.99625 .24203 m
1 .24203 L
s
.99625 .27503 m
1 .27503 L
s
.99625 .34104 m
1 .34104 L
s
.99625 .37404 m
1 .37404 L
s
.99625 .40704 m
1 .40704 L
s
.99625 .47305 m
1 .47305 L
s
.99625 .50605 m
1 .50605 L
s
.99625 .53905 m
1 .53905 L
s
.99625 .01102 m
1 .01102 L
s
.99625 .60505 m
1 .60505 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
.5 0 m
.5 .61803 L
s
.5 Mabswid
.02381 .01472 m
.06244 .20885 L
.08255 .28918 L
.10458 .36303 L
.14415 .46427 L
.16372 .50178 L
.18466 .53415 L
.20597 .55982 L
.22611 .57809 L
.2358 .58498 L
.24608 .59101 L
.25571 .59552 L
.26452 .59872 L
.26902 .60002 L
.27393 .60119 L
.27912 .60214 L
.28171 .60251 L
.28405 .60278 L
.28642 .603 L
.28865 .60316 L
.28987 .60322 L
.291 .60326 L
.29224 .6033 L
.29354 .60332 L
.29459 .60332 L
.29572 .60331 L
.29678 .60329 L
.29774 .60326 L
.29888 .60322 L
.30011 .60315 L
.30236 .603 L
.30469 .60279 L
.3072 .6025 L
.31175 .60183 L
.31717 .60078 L
.32213 .59958 L
.33236 .59641 L
.34314 .59212 L
.36288 .58193 L
.38125 .5702 L
.42029 .54144 L
.4402 .52726 L
.45069 .52065 L
.46179 .51465 L
.47169 .51035 L
.47695 .50854 L
.48259 .50698 L
.48525 .50639 L
.48777 .50592 L
.49022 .50555 L
Mistroke
.4925 .50527 L
.49465 .50508 L
.49585 .505 L
.49694 .50494 L
.49813 .5049 L
.49943 .50488 L
.50065 .50488 L
.50177 .5049 L
.50304 .50494 L
.50424 .505 L
.50532 .50508 L
.50648 .50517 L
.50911 .50546 L
.51153 .50581 L
.51595 .50665 L
.52063 .50782 L
.53047 .5112 L
.54131 .51621 L
.5607 .52786 L
.58157 .54283 L
.62276 .57291 L
.64332 .58543 L
.65334 .59051 L
.66243 .59446 L
.6713 .59765 L
.6809 .60034 L
.68618 .60146 L
.69104 .60227 L
.69568 .60283 L
.69802 .60303 L
.69936 .60312 L
.70059 .60319 L
.70181 .60324 L
.7031 .60329 L
.70439 .60331 L
.70513 .60332 L
.70582 .60332 L
.70707 .60331 L
.70821 .60329 L
.70946 .60325 L
.71078 .60319 L
.71308 .60304 L
.71522 .60286 L
.72008 .60226 L
.7228 .60182 L
.72537 .60133 L
.73018 .60023 L
.74099 .59682 L
.75069 .59264 L
.76098 .58701 L
Mistroke
.77942 .57362 L
.79897 .55448 L
.81728 .53147 L
.85607 .46381 L
.87722 .4142 L
.89731 .35722 L
.93552 .21756 L
.97619 .01472 L
.97619 .01472 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`007P3oool5000000<0oooo0P00000e0?ooo`<00000
103oool2000003H0oooo0P00000g0?ooo`<00000103oool2000003@0oooo1@0000030?ooo`800000
103oool001l0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00000e0?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool00000=03oool010000000oooo0?ooo`00000g
0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000=03oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000<0oooo000H0?ooo`D000000`3oool00`000000oooo
0?ooo`020?ooo`040000003oool0oooo000002d0oooo1@0000030?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000=03oool010000000oooo0?ooo`00000g0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000=@3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000000<0oooo000Q0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo
0?ooo`0c0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000=03oool010000000
oooo0?ooo`00000g0?ooo`030000003oool0oooo0080oooo00@000000?ooo`3oool00000=P3oool0
1@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3oool00@3oool001h0oooo00D00000
0?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000003D0oooo00<000000?ooo`3oool0
0P3oool010000000oooo0?ooo`00000d0?ooo`040000003oool0oooo000003L0oooo00<000000?oo
o`3oool00P3oool010000000oooo0?ooo`00000c0?ooo`050000003oool0oooo0?ooo`0000000P3o
ool010000000oooo0?ooo`0000030?ooo`007P3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool00000=03oool2000000@0oooo00@000000?ooo`3oool00000=03oool01000
0000oooo0?ooo`00000f0?ooo`800000103oool010000000oooo0?ooo`00000c0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`0000030?ooo`007`3oool3000000@0oooo
0P00000f0?ooo`030000003oool0oooo00<0oooo0P00000f0?ooo`800000>03oool00`000000oooo
0?ooo`030?ooo`800000=@3oool3000000@0oooo0P0000040?ooo`00o`3ooolQ0?ooo`00o`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`006`3ooooo000000D000000@3oool001/0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00X0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool00`3oool100000040oooo000K0?ooo`030000003oool0oooo00<0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo03X0oooo00<00000
0?ooo`3oool0>`3oool00`000000oooo0?ooo`030?ooo`4000000@3oool001/0oooo0P0000200?oo
o`030000003oool0oooo07P0oooo00<000000?ooo`3oool00P3oool200000040oooo000K0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool0N@3oool00`000000oooo0?ooo`1h0?ooo`03
0000003oool0oooo00<0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo07T0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`030?ooo`400000
0@3oool001/0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`1i0?ooo`030000003o
ool0oooo07P0oooo00<000000?ooo`3oool00`3oool100000040oooo000K0?ooo`030000003oool0
oooo00@0oooo00<000000?ooo`3oool0N03oool00`000000oooo0?ooo`1h0?ooo`030000003oool0
oooo00<0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo
07P0oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`040?ooo`4000000@3oool00080
oooo0P0000040?ooo`030000003oool0oooo00<0oooo0`0000030?ooo`<00000103oool00`000000
oooo0?ooo`040?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`040?ooo`4000000@3oool000050?ooo`000000oooo0?ooo`0000002P3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`1h0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0103oool100000040
oooo00001@3oool000000?ooo`3oool0000000L0oooo1@0000000`3oool0000000000003000000@0
oooo0P0000050?ooo`030000003oool0oooo07P0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`030?ooo`8000000@3oool000050?ooo`000000oooo0?ooo`0000001`3oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo000000D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo07L0oooo00<000000?ooo`3oool0103oool1
00000040oooo00001@3oool000000?ooo`3oool0000000P0oooo00<000000?ooo`0000000`3oool0
0`000000oooo000000050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0M`3oool0
0`000000oooo0?ooo`1f0?ooo`030000003oool0oooo00D0oooo0@0000010?ooo`0000D0oooo0000
003oool0oooo000000090?ooo`800000103oool2000000D0oooo00<000000?ooo`3oool01@3oool0
0`000000oooo0?ooo`1g0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool01@3oool1
00000040oooo00020?ooo`8000002`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`1g0?ooo`030000003oool0oooo
07H0oooo00<000000?ooo`3oool01@3oool100000040oooo000K0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo00D0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo07H0oooo
00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`050?ooo`4000000@3oool001/0oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`1f0?ooo`030000003oool0oooo07D0oooo00<0
00000?ooo`3oool01P3oool100000040oooo000K0?ooo`030000003oool0oooo00H0oooo00<00000
0?ooo`3oool0MP3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo00H0oooo0@000001
0?ooo`006`3oool2000000L0oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`1e0?oo
o`030000003oool0oooo00D0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`060?ooo`03
0000003oool0oooo07H0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`060?ooo`40
00000@3oool001/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1e0?ooo`030000
003oool0oooo07D0oooo00<000000?ooo`3oool01P3oool100000040oooo000K0?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1d0?ooo`030000003o
ool0oooo00L0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`070?ooo`030000003oool0
oooo07D0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`070?ooo`4000000@3oool0
01/0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`1e0?ooo`030000003oool0oooo
07@0oooo00<000000?ooo`3oool01`3oool100000040oooo000K0?ooo`030000003oool0oooo00L0
oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`1d0?ooo`030000003oool0oooo00L0
oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo07@0oooo
00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`070?ooo`4000000@3oool001/0oooo0P00
00090?ooo`030000003oool0oooo07@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?oo
o`070?ooo`8000000@3oool001/0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`1d
0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool0203oool100000040oooo000K0?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`1c0?oo
o`030000003oool0oooo00P0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`080?ooo`40
00000@3oool001/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1c0?ooo`030000
003oool0oooo07<0oooo00<000000?ooo`3oool0203oool100000040oooo000K0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1c0?ooo`030000003o
ool0oooo00P0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo07<0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`090?ooo`4000000@3oool0
01/0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo
0780oooo00<000000?ooo`3oool02@3oool100000040oooo000K0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0L`3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo00T0
oooo0@0000010?ooo`006`3oool2000000/0oooo00<000000?ooo`3oool0LP3oool00`000000oooo
0?ooo`1b0?ooo`030000003oool0oooo00P0oooo0P0000010?ooo`006`3oool00`000000oooo0?oo
o`0:0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?oo
o`090?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`1b
0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool02P3oool100000040oooo000K0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0LP3oool00`000000oooo0?ooo`1a0?oo
o`030000003oool0oooo00X0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0:0?ooo`03
0000003oool0oooo0780oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`0:0?ooo`40
00000@3oool001/0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`1a0?ooo`030000
003oool0oooo0740oooo00<000000?ooo`3oool02P3oool100000040oooo00020?ooo`800000103o
ool00`000000oooo0?ooo`030?ooo`<000000P3oool3000000D0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0740oooo00<000000?ooo`3oool02P3o
ool100000040oooo00001@3oool000000?ooo`3oool0000000X0oooo00@000000?ooo`3oool00000
0`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0
L@3oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00/0oooo0@0000010?ooo`0000D0
oooo0000003oool0oooo000000070?ooo`D0000000<0oooo0000003oool00P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0L@3oool00`000000oooo
0?ooo`1`0?ooo`030000003oool0oooo00/0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo
000000070?ooo`040000003oool0oooo00000080oooo100000050?ooo`800000303oool00`000000
oooo0?ooo`1a0?ooo`030000003oool0oooo0700oooo00<000000?ooo`3oool02P3oool200000040
oooo00001@3oool000000?ooo`3oool0000000P0oooo00<000000?ooo`0000000P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0L03oool00`000000
oooo0?ooo`1`0?ooo`030000003oool0oooo00/0oooo0@0000010?ooo`0000D0oooo0000003oool0
oooo000000090?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0L03oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo00/0
oooo0@0000010?ooo`000P3oool2000000/0oooo00<000000?ooo`3oool00P3oool2000000D0oooo
00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1`0?ooo`030000003oool0oooo06l0oooo
00<000000?ooo`3oool0303oool100000040oooo000K0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0L03oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00`0oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0700oooo00<00000
0?ooo`3oool0K`3oool00`000000oooo0?ooo`0<0?ooo`4000000@3oool001/0oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo06l0oooo00<000000?oo
o`3oool0303oool100000040oooo000K0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0K`3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0oooo00`0oooo0@0000010?ooo`00
6`3oool2000000h0oooo00<000000?ooo`3oool0K`3oool00`000000oooo0?ooo`1^0?ooo`030000
003oool0oooo00`0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`0=0?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0=0?ooo`4000000@3o
ool001/0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`1_0?ooo`030000003oool0
oooo06h0oooo00<000000?ooo`3oool03@3oool100000040oooo000K0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo
00d0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo06h0
oooo00<000000?ooo`3oool0KP3oool00`000000oooo0?ooo`0=0?ooo`4000000@3oool001/0oooo
00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`1^0?ooo`030000003oool0oooo06d0oooo
00<000000?ooo`3oool03P3oool100000040oooo000K0?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0KP3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo00h0oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo06d0oooo00<00000
0?ooo`3oool0K@3oool00`000000oooo0?ooo`0>0?ooo`4000000@3oool001/0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo06d0oooo00<000000?oo
o`3oool03P3oool100000040oooo000K0?ooo`800000403oool00`000000oooo0?ooo`1]0?ooo`03
0000003oool0oooo06`0oooo00<000000?ooo`3oool03P3oool200000040oooo000K0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0K@3oool00`000000oooo0?ooo`1/0?ooo`030000
003oool0oooo00l0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo06`0oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`0?0?ooo`4000000@3o
ool001/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1/0?ooo`030000003oool0
oooo06/0oooo00<000000?ooo`3oool0403oool100000040oooo000K0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo
0100oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo06`0
oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`0@0?ooo`4000000@3oool001/0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo06/0oooo
00<000000?ooo`3oool0403oool100000040oooo000K0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0J`3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo0140oooo0@00
00010?ooo`006`3oool200000180oooo00<000000?ooo`3oool0J`3oool00`000000oooo0?ooo`1Z
0?ooo`030000003oool0oooo0100oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`0A0?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`0A0?oo
o`4000000@3oool001/0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1[0?ooo`03
0000003oool0oooo06X0oooo00<000000?ooo`3oool04@3oool100000040oooo000K0?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0JP3oool00`000000oooo0?ooo`1Y0?ooo`030000
003oool0oooo0180oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo06X0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`0B0?ooo`4000000@3o
ool001/0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1Z0?ooo`030000003oool0
oooo06T0oooo00<000000?ooo`3oool04P3oool100000040oooo00020?ooo`800000103oool00`00
0000oooo0?ooo`030?ooo`<000000P3oool3000000D0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`1Z0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool04`3oool10000
0040oooo00001@3oool000000?ooo`3oool0000000X0oooo00@000000?ooo`3oool000000`3oool0
0`000000oooo0?ooo`020?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`1X0?ooo`030000003oool0oooo01<0oooo0@0000010?ooo`0000D0oooo0000
003oool0oooo000000070?ooo`D0000000<0oooo0000003oool00P3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0J@3oool00`000000oooo0?ooo`1X
0?ooo`030000003oool0oooo01<0oooo0@0000010?ooo`0000D0oooo0000003oool0oooo00000007
0?ooo`040000003oool0oooo000000<0oooo0`0000050?ooo`800000503oool00`000000oooo0?oo
o`1Y0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool04P3oool200000040oooo0000
1@3oool000000?ooo`3oool0000000P0oooo00<000000?ooo`0000000P3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0oooo06L0oooo00<000000?ooo`3oool0503oool100000040oooo00001@3oool000000?oo
o`3oool0000000T0oooo0P0000020?ooo`050000003oool0oooo0?ooo`000000103oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3oool0I`3oool00`000000
oooo0?ooo`0D0?ooo`4000000@3oool00080oooo0P00000;0?ooo`040000003oool0oooo0?ooo`<0
00001@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3o
ool0I`3oool00`000000oooo0?ooo`0D0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0
5@3oool00`000000oooo0?ooo`1W0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0
503oool100000040oooo000K0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0I`3o
ool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo01D0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo06L0oooo00<000000?ooo`3oool0IP3oool0
0`000000oooo0?ooo`0E0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool05P3oool00`00
0000oooo0?ooo`1V0?ooo`030000003oool0oooo06H0oooo00<000000?ooo`3oool05@3oool10000
0040oooo000K0?ooo`8000005`3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo06D0
oooo00<000000?ooo`3oool05@3oool200000040oooo000K0?ooo`030000003oool0oooo01H0oooo
00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo01H0oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo06D0oooo00<0
00000?ooo`3oool0I@3oool00`000000oooo0?ooo`0F0?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo06D0oooo00<00000
0?ooo`3oool05P3oool100000040oooo000K0?ooo`030000003oool0oooo01L0oooo00<000000?oo
o`3oool0I@3oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo01L0oooo0@0000010?oo
o`006`3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3o
ool0I03oool00`000000oooo0?ooo`0G0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0
603oool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo06@0oooo00<000000?ooo`3oool0
5`3oool100000040oooo000K0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0I03o
ool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo01P0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo06<0oooo00<000000?ooo`3oool0H`3oool0
0`000000oooo0?ooo`0H0?ooo`4000000@3oool001/0oooo0P00000J0?ooo`030000003oool0oooo
06<0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`0H0?ooo`8000000@3oool001/0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1S0?ooo`030000003oool0oooo0680
oooo00<000000?ooo`3oool06@3oool100000040oooo000K0?ooo`030000003oool0oooo01X0oooo
00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01T0oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0680oooo00<0
00000?ooo`3oool0H@3oool00`000000oooo0?ooo`0J0?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool06`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo0640oooo00<00000
0?ooo`3oool06P3oool100000040oooo000K0?ooo`030000003oool0oooo01/0oooo00<000000?oo
o`3oool0H@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo01/0oooo0@0000010?oo
o`006`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo0640oooo00<000000?ooo`3o
ool0H03oool00`000000oooo0?ooo`0K0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0
703oool00`000000oooo0?ooo`1P0?ooo`030000003oool0oooo05l0oooo00<000000?ooo`3oool0
703oool100000040oooo000K0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0H03o
ool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo01`0oooo0@0000010?ooo`006`3oool2
000001d0oooo00<000000?ooo`3oool0H03oool00`000000oooo0?ooo`1O0?ooo`030000003oool0
oooo01/0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo
05l0oooo00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0M0?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool07@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo05h0
oooo00<000000?ooo`3oool07@3oool100000040oooo000K0?ooo`030000003oool0oooo01h0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`1M0?ooo`030000003oool0oooo01h0oooo
0@0000010?ooo`006`3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo05h0oooo00<0
00000?ooo`3oool0G@3oool00`000000oooo0?ooo`0N0?ooo`4000000@3oool001/0oooo00<00000
0?ooo`3oool07P3oool00`000000oooo0?ooo`1N0?ooo`030000003oool0oooo05d0oooo00<00000
0?ooo`3oool07P3oool100000040oooo00080?ooo`800000103oool00`000000oooo0?ooo`020?oo
o`<000001@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo05d0oooo00<000000?oo
o`3oool0G03oool00`000000oooo0?ooo`0O0?ooo`4000000@3oool000L0oooo00@000000?ooo`3o
ool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool07`3oool0
0`000000oooo0?ooo`1M0?ooo`030000003oool0oooo05`0oooo00<000000?ooo`3oool07`3oool1
00000040oooo00070?ooo`040000003oool0oooo000000/0oooo00<000000?ooo`3oool00P3oool2
00000240oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`1K0?ooo`030000003oool0
oooo01l0oooo0P0000010?ooo`001`3oool010000000oooo0?ooo`00000;0?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`1L0?ooo`030000003oool0
oooo05/0oooo00<000000?ooo`3oool0803oool100000040oooo00070?ooo`040000003oool0oooo
000000L0oooo100000050?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0G03oool0
0`000000oooo0?ooo`1K0?ooo`030000003oool0oooo0200oooo0@0000010?ooo`001`3oool01000
0000oooo0?ooo`0000070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool08@3oool0
0`000000oooo0?ooo`1K0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool08@3oool1
00000040oooo00080?ooo`800000203oool5000000@0oooo00<000000?ooo`3oool08@3oool00`00
0000oooo0?ooo`1K0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool08@3oool10000
0040oooo000K0?ooo`030000003oool0oooo0240oooo00<000000?ooo`3oool0F`3oool00`000000
oooo0?ooo`1J0?ooo`030000003oool0oooo0240oooo0@0000010?ooo`006`3oool00`000000oooo
0?ooo`0R0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool0F@3oool00`000000oooo
0?ooo`0R0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool08P3oool00`000000oooo0?oo
o`1J0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool08P3oool100000040oooo000K
0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`1H
0?ooo`030000003oool0oooo02<0oooo0@0000010?ooo`006`3oool2000002@0oooo00<000000?oo
o`3oool0F@3oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo0280oooo0P0000010?oo
o`006`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo05P0oooo00<000000?ooo`3o
ool0E`3oool00`000000oooo0?ooo`0T0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0
903oool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool0
9@3oool100000040oooo000K0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0E`3o
ool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo02D0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo05L0oooo00<000000?ooo`3oool0E@3oool0
0`000000oooo0?ooo`0V0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool09P3oool00`00
0000oooo0?ooo`1F0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool09P3oool10000
0040oooo000K0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool0EP3oool00`000000
oooo0?ooo`1D0?ooo`030000003oool0oooo02L0oooo0@0000010?ooo`006`3oool00`000000oooo
0?ooo`0W0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0E03oool00`000000oooo
0?ooo`0W0?ooo`4000000@3oool001/0oooo0P00000X0?ooo`030000003oool0oooo0540oooo2@00
001A0?ooo`030000003oool0oooo02L0oooo0P0000010?ooo`006`3oool00`000000oooo0?ooo`0X
0?ooo`030000003oool0oooo04`0oooo100000040?ooo`030000003oool0oooo0080oooo0P00001?
0?ooo`030000003oool0oooo02P0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0Y0?oo
o`030000003oool0oooo04X0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`040?oo
o`<00000B`3oool00`000000oooo0?ooo`0Y0?ooo`4000000@3oool001/0oooo00<000000?ooo`3o
ool0:@3oool00`000000oooo0?ooo`180?ooo`8000002@3oool00`000000oooo0?ooo`070?ooo`80
0000B03oool00`000000oooo0?ooo`0Z0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0
:P3oool00`000000oooo0?ooo`140?ooo`<000002`3oool00`000000oooo0?ooo`090?ooo`800000
AP3oool00`000000oooo0?ooo`0Z0?ooo`4000000@3oool001/0oooo00<000000?ooo`3oool0:`3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool02`3o
ool00`000000oooo0?ooo`120?ooo`030000003oool0oooo02/0oooo0@0000010?ooo`006`3oool0
0`000000oooo0?ooo`0[0?ooo`030000003oool0oooo0400oooo0P00000?0?ooo`030000003oool0
oooo00`0oooo0P0000120?ooo`030000003oool0oooo02/0oooo0@0000010?ooo`006`3oool00`00
0000oooo0?ooo`0/0?ooo`030000003oool0oooo03d0oooo0P00000A0?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool0?P3oool00`000000oooo0?ooo`0/0?ooo`4000000@3oool001/0
oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo0140
oooo00<000000?ooo`3oool03`3oool2000003h0oooo00<000000?ooo`3oool0;03oool100000040
oooo000K0?ooo`800000;P3oool00`000000oooo0?ooo`0i0?ooo`800000503oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo03X0oooo00<000000?ooo`3oool0;03oool200000040oooo
000K0?ooo`030000003oool0oooo02h0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo0180oooo0P00000i0?ooo`030000003oool0oooo02h0oooo0@00
00010?ooo`006`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03D0oooo00<00000
0?ooo`3oool0;`3oool100000040oooo000K0?ooo`030000003oool0oooo0300oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0<`3oool00`000000oooo0?ooo`0`0?ooo`4000000@3oool001/0oooo00<000000?ooo`3o
ool0<@3oool00`000000oooo0?ooo`0`0?ooo`8000006@3oool00`000000oooo0?ooo`0F0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0<@3oool100000040oooo000K0?ooo`030000
003oool0oooo0380oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo01L0oooo0P00000`0?ooo`030000003oool0oooo0380oooo0@0000010?ooo`000P3o
ool2000000@0oooo00<000000?ooo`3oool00P3oool300000080oooo1@0000040?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo01T0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`0c0?ooo`4000000@3o
ool000050?ooo`000000oooo0?ooo`0000001`3oool01@000000oooo0?ooo`3oool000000080oooo
00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo02X0
oooo00<000000?ooo`3oool0=03oool100000040oooo00001@3oool000000?ooo`3oool0000000/0
oooo00D000000?ooo`3oool0oooo000000060?ooo`800000=P3oool00`000000oooo0?ooo`0W0?oo
o`8000007P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo02P0oooo00<000000?oo
o`3oool0=03oool200000040oooo00001@3oool000000?ooo`3oool0000000/0oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo03H0oooo00<000000?oo
o`3oool0903oool200000200oooo00<000000?ooo`3oool0703oool2000002H0oooo0P00000h0?oo
o`4000000@3oool000050?ooo`000000oooo0?ooo`0000001`3oool400000080oooo00D000000?oo
o`3oool0oooo000000040?ooo`030000003oool0oooo03L0oooo0P00000S0?ooo`030000003oool0
oooo0200oooo00<000000?ooo`3oool07P3oool200000280oooo0P00000j0?ooo`4000000@3oool0
00050?ooo`000000oooo0?ooo`0000001`3oool00`000000oooo0?ooo`030?ooo`050000003oool0
oooo0?ooo`000000103oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo01h0oooo0P00
000S0?ooo`030000003oool0oooo0200oooo0P00000O0?ooo`030000003oool0oooo03X0oooo0@00
00010?ooo`000P3oool2000000P0oooo1@0000020?ooo`<000001@3oool00`000000oooo0?ooo`0j
0?ooo`<000006`3oool2000002D0oooo00<000000?ooo`3oool08P3oool2000001`0oooo00<00000
0?ooo`3oool0>`3oool100000040oooo000K0?ooo`030000003oool0oooo03d0oooo00<000000?oo
o`3oool05`3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo02@0oooo0`00000H0?oo
o`030000003oool0oooo03`0oooo0@0000010?ooo`006`3oool00`000000oooo0?ooo`0n0?ooo`03
0000003oool0oooo01@0oooo0P00000X0?ooo`030000003oool0oooo02L0oooo0P00000D0?ooo`80
0000?`3oool100000040oooo000K0?ooo`030000003oool0oooo03l0oooo1000000?0?ooo`<00000
:P3oool00`000000oooo0?ooo`0Y0?ooo`<000003P3oool300000440oooo0@0000010?ooo`006`3o
ool00`000000oooo0?ooo`130?ooo`D000000`3oool7000002d0oooo00<000000?ooo`3oool0;03o
ool5000000<0oooo1P0000140?ooo`4000000@3oool001/0oooo0P0000190?ooo`@00000<`3oool0
0`000000oooo0?ooo`0`0?ooo`@00000B@3oool200000040oooo000K0?ooo`030000003oool0oooo
07l0oooo00<000000?ooo`3oool0OP3oool100000040oooo000K0?ooo`030000003oool0oooo00<0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00<0
oooo0@0000010?ooo`006`3ooooo000000D000000@3oool00?l0oooo8@3oool00?l0oooo8@3oool0
0001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-25.4077, 0.424949, \
0.161771, 0.00058355}}]
}, Closed]],

Cell[BoxData[
    \(\(\( (*\ 
      Only\ with\ Mathematica\ 4.0\ or\ later\ \ *) \)\(\[IndentingNewLine]\)\
\( (*\ type\ ' Directory[]'\ \ to\ get\ the\ directory\  . \ ' 
        form'\ in\ gif, \ eps, \ pict, \ 
      pdf\ *) \)\(\[IndentingNewLine]\)\(dir = "\<\>"; file = "\<aa\>"; 
    form = "\<gif\>"; 
    Export[dir <> file <> "\<.\>" <> form, gx, form];\)\)\)], "Input"],

Cell[BoxData[{
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{
            StyleBox["radFld",
              FontColor->RGBColor[1, 0, 0]], "[", \(g, "\<Bx\>", {x, y, z}\), 
            "]"}], ",", \({y, \(-\((nper + 1)\)\)/2*per, \((nper + 1)\)/2*
              per}\)}], "]"}], ";"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Plot", "[", 
        RowBox[{
          RowBox[{
            StyleBox["radFld",
              FontColor->RGBColor[1, 0, 0]], "[", \(g, "\<Bx\>", {x, 0, z}\), 
            "]"}], ",", \({x, \(-20\), 20}\)}], "]"}], ";"}]}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Angle and Focussing ", "Section"],

Cell["\<\
One undulator (or wiggler)  must  be created before executing any \
cell of this section . It is also a good strategy to check that the undulator \
has the desired geometry and that it is producing the correct field using the \
two previous sections. 
In this section, one computes the 2nd order deflection, focusing, tune \
shifts,... induced by the undulator field on the beam. The field of the \
undulator is assumed to be periodic.As a result the field is only sampled \
over a single period and the effect is multiplied by the number of periods. \
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*___  ___  __\ \ Input\ Parameters\ \((to\ edit\ )\)\ ___  ___  ___  \
___  ___  ___  _*) \[IndentingNewLine]\[IndentingNewLine]\(len = 
        2200;\)\ \ \ \ \ \ \ \  (*\ \ Total\ Undulator\ Length\ in\ [
          mm]\ \ *) \), "\[IndentingNewLine]", 
    \(\(ener = 3;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Electron\ Energy\ in\ [GeV]\ *) \), "\[IndentingNewLine]", 
    \(\(betax = 21;\)\ \ \ \ \ \ \ \ \  (*\ 
      Average\ Horiz . \ Beta\ Function\ *) \), "\[IndentingNewLine]", 
    \(\(betaz = 1.75;\)\ \ \ \  (*\ 
      Average\ Vertic . \ Beta\ Function\ *) \), "\[IndentingNewLine]", 
    \(pt = {0, 0}; \ \ \ \ \ \ \  (*\ 
      Transverse\ coordinates\ {Hor, Vert}\ of\ the\ electron\ \ in\ [
          mm]\ *) \[IndentingNewLine] (*___  ___  ___  ___  ___  _\ \ Start\ \
Computations\ ___  ___  ___  ___  ___  ___  _*) \[IndentingNewLine]\
\[IndentingNewLine]vvx = 
      vx[g, pt, per, len, ener];\), "\[IndentingNewLine]", 
    \(\(vvz = vz[g, pt, per, len, ener];\)\), "\[IndentingNewLine]", 
    \(\(vvc = vc[g, pt, per, len, ener];\)\), "\[IndentingNewLine]", 
    \(\(dnux = \(1/4\)/Pi*betax*vvx;\)\), "\[IndentingNewLine]", 
    \(\(dnuz = \(1/4\)/Pi*betaz*vvz;\)\), "\[IndentingNewLine]", 
    \(\(dnuc = \(1/4\)/Pi*Sqrt[betaz*betax]*vvc;\)\), "\[IndentingNewLine]", 
    \(\(ax = angx[g, pt, per, len, ener];\)\), "\[IndentingNewLine]", 
    \(\(az = 
        angz[g, pt, per, len, 
          ener];\)\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Print["\<dNux, dNuz, dNuc = \>", \(-\ 
          dnux\), "\<,\>"\ , \(-dnuz\), "\<,\>"\ , \(-dnuc\)];\)\), "\
\[IndentingNewLine]", 
    \(\(Print["\<Equiv. Skew Quad = \>", \ 
        vvc*ener/0.3*10000, "\< G\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Horiz., Vert.  Angle = \>", \(-\ 
          ax\), "\<,\>"\ , \(-az\), "\< \[Mu]r\>"];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Equiv. Vert. , Hor.  Field Integral = \>", \(-\ ax\)*
          ener/0.3, "\<,\>"\ , \(-az\)*ener/0.3, "\< Gcm\>"];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("dNux, dNuz, dNuc = \
"\[InvisibleSpace]0.0016780081371940302`\[InvisibleSpace]","\[InvisibleSpace]\
\(-0.00029184845017451587`\)\[InvisibleSpace]","\[InvisibleSpace]1.\
0915770860616742`*^-10\),
      SequenceForm[ 
      "dNux, dNuz, dNuc = ", 0.0016780081371940302, 
        ",", -0.00029184845017451587, ",", 1.0915770860616742*^-10],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Equiv. Skew Quad = \
"\[InvisibleSpace]\(-0.000022627449425272055`\)\[InvisibleSpace]" G"\),
      SequenceForm[ "Equiv. Skew Quad = ", -2.2627449425272055*^-05, " G"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Horiz., Vert.  Angle = \
"\[InvisibleSpace]2.8317799660726447`*^-8\[InvisibleSpace]","\[InvisibleSpace]\
\(-2.7129294721817127`*^-8\)\[InvisibleSpace]" \[Mu]r"\),
      SequenceForm[ 
      "Horiz., Vert.  Angle = ", 2.8317799660726447*^-08, 
        ",", -2.7129294721817127*^-08, " \[Mu]r"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Equiv. Vert. , Hor.  Field Integral = "\
\[InvisibleSpace]2.8317799660726445`*^-7\[InvisibleSpace]","\[InvisibleSpace]\
\(-2.7129294721817127`*^-7\)\[InvisibleSpace]" Gcm"\),
      SequenceForm[ 
      "Equiv. Vert. , Hor.  Field Integral = ", 2.8317799660726445*^-07, 
        ",", -2.7129294721817127*^-07, " Gcm"],
      Editable->False]], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \( (*\ This\ cell\ must\ be\ executed\ after\ the\ previous\ ones . 
          It\ computes\ the\ angle, 
      and\ tune\ shifts\ as\ a\ function\ of\ the\ horizontal\ position\ of\ \
an\ electron\ in\ the\ undulator . \ By\ using\ such\ plots, \ 
      one\ may\ \ qualitatively\ identify\ undulator\ fields\ which\ may\ \
pose\ problems\ \[IndentingNewLine]during\ injections\ or\ may\ reduce\ the\ \
horizontal\ dynamic\ aperture\ of\ the\ \(\(lattice\)\(.\)\)*) \
\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Parameters\ defining\ the\ range\ and\ step\ over\ which\ the\ tune\ \
shift\ is\ computed\ and\ displayed\ *) \[IndentingNewLine]\(z = 
        0;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Height\ above\ axis\ in\ [mm]\ *) \), "\[IndentingNewLine]", 
    \(\(xmin = 0;\)\ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Minimum\ horizontal\ position\ in\ [mm]\ *) \), "\[IndentingNewLine]", 
    \(\(xmax = 45;\)\ \ \ \ \ \ \ \ \  (*\ 
      Maximum\ horizontal\ position\ in\ [mm]\ *) \), "\[IndentingNewLine]", 
    \(\(dx = 1;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Horizontal\ Step\ in\ [
          mm]\ *) \[IndentingNewLine] (*___  ___  ___  ___  ___  _\ \ Start\ \
Computations\ ___  ___  ___  ___  ___  ___  _*) \[IndentingNewLine]\
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(ax = 
        Table[{x, \(-angx[g, {x, z}, per, len, ener]\)}, {x, xmin, xmax, 
            dx}];\)\), "\[IndentingNewLine]", 
    \(\(gr = 
        ListPlot[ax, 
          PlotJoined \[Rule] 
            True, \[IndentingNewLine]PlotLabel \[Rule] "\<Horiz. Angle \
[\[Mu]r] vs Horiz. Pos. [mm]\>"];\)\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(dnx = 
        Table[{x, \(1/4\)/Pi*betax*vx[g, {x, z}, per, len, ener]}, {x, xmin, 
            xmax, dx}];\)\), "\[IndentingNewLine]", 
    \(\(gr = 
        ListPlot[dnx, 
          PlotJoined \[Rule] 
            True, \[IndentingNewLine]PlotLabel \[Rule] "\<Horizontal Tune \
Shift vs Horiz. Pos. [mm] \>"];\)\[IndentingNewLine]\), \
"\[IndentingNewLine]", 
    \(\(dnz = 
        Table[{x, \(1/4\)/Pi*betaz*vz[g, {x, z}, per, len, ener]}, {x, xmin, 
            xmax, dx}];\)\), "\[IndentingNewLine]", 
    \(\(gr = 
        ListPlot[dnz, 
          PlotJoined \[Rule] 
            True, \[IndentingNewLine]PlotLabel \[Rule] "\<Vertical Tune Shift \
vs Horiz. Pos. [mm] \>"];\)\[IndentingNewLine]\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.021164 0.141889 0.184102 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.23545 -0.0125 -6 -9 ]
[.23545 -0.0125 6 0 ]
[.44709 -0.0125 -6 -9 ]
[.44709 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.87037 -0.0125 -6 -9 ]
[.87037 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .04984 -24 -4.5 ]
[-0.0125 .04984 0 4.5 ]
[-0.0125 .14189 -6 -4.5 ]
[-0.0125 .14189 0 4.5 ]
[-0.0125 .23394 -18 -4.5 ]
[-0.0125 .23394 0 4.5 ]
[-0.0125 .32599 -6 -4.5 ]
[-0.0125 .32599 0 4.5 ]
[-0.0125 .41804 -18 -4.5 ]
[-0.0125 .41804 0 4.5 ]
[-0.0125 .51009 -6 -4.5 ]
[-0.0125 .51009 0 4.5 ]
[-0.0125 .60214 -18 -4.5 ]
[-0.0125 .60214 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -113.062 0 ]
[.5 .63053 113.062 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.23545 0 m
.23545 .00625 L
s
[(10)] .23545 -0.0125 0 1 Mshowa
.44709 0 m
.44709 .00625 L
s
[(20)] .44709 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(30)] .65873 -0.0125 0 1 Mshowa
.87037 0 m
.87037 .00625 L
s
[(40)] .87037 -0.0125 0 1 Mshowa
.125 Mabswid
.06614 0 m
.06614 .00375 L
s
.10847 0 m
.10847 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.19312 0 m
.19312 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.32011 0 m
.32011 .00375 L
s
.36243 0 m
.36243 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.48942 0 m
.48942 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.57407 0 m
.57407 .00375 L
s
.6164 0 m
.6164 .00375 L
s
.70106 0 m
.70106 .00375 L
s
.74339 0 m
.74339 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.82804 0 m
.82804 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.95503 0 m
.95503 .00375 L
s
.99735 0 m
.99735 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .04984 m
.00625 .04984 L
s
[(-0.5)] -0.0125 .04984 1 0 Mshowa
0 .14189 m
.00625 .14189 L
s
[(0)] -0.0125 .14189 1 0 Mshowa
0 .23394 m
.00625 .23394 L
s
[(0.5)] -0.0125 .23394 1 0 Mshowa
0 .32599 m
.00625 .32599 L
s
[(1)] -0.0125 .32599 1 0 Mshowa
0 .41804 m
.00625 .41804 L
s
[(1.5)] -0.0125 .41804 1 0 Mshowa
0 .51009 m
.00625 .51009 L
s
[(2)] -0.0125 .51009 1 0 Mshowa
0 .60214 m
.00625 .60214 L
s
[(2.5)] -0.0125 .60214 1 0 Mshowa
.125 Mabswid
0 .06825 m
.00375 .06825 L
s
0 .08666 m
.00375 .08666 L
s
0 .10507 m
.00375 .10507 L
s
0 .12348 m
.00375 .12348 L
s
0 .1603 m
.00375 .1603 L
s
0 .17871 m
.00375 .17871 L
s
0 .19712 m
.00375 .19712 L
s
0 .21553 m
.00375 .21553 L
s
0 .25235 m
.00375 .25235 L
s
0 .27076 m
.00375 .27076 L
s
0 .28917 m
.00375 .28917 L
s
0 .30758 m
.00375 .30758 L
s
0 .3444 m
.00375 .3444 L
s
0 .36281 m
.00375 .36281 L
s
0 .38122 m
.00375 .38122 L
s
0 .39963 m
.00375 .39963 L
s
0 .43645 m
.00375 .43645 L
s
0 .45486 m
.00375 .45486 L
s
0 .47327 m
.00375 .47327 L
s
0 .49168 m
.00375 .49168 L
s
0 .5285 m
.00375 .5285 L
s
0 .54691 m
.00375 .54691 L
s
0 .56532 m
.00375 .56532 L
s
0 .58373 m
.00375 .58373 L
s
0 .03143 m
.00375 .03143 L
s
0 .01302 m
.00375 .01302 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.23545 .61178 m
.23545 .61803 L
s
.44709 .61178 m
.44709 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.87037 .61178 m
.87037 .61803 L
s
.125 Mabswid
.06614 .61428 m
.06614 .61803 L
s
.10847 .61428 m
.10847 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.19312 .61428 m
.19312 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.32011 .61428 m
.32011 .61803 L
s
.36243 .61428 m
.36243 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.48942 .61428 m
.48942 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.57407 .61428 m
.57407 .61803 L
s
.6164 .61428 m
.6164 .61803 L
s
.70106 .61428 m
.70106 .61803 L
s
.74339 .61428 m
.74339 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.82804 .61428 m
.82804 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.95503 .61428 m
.95503 .61803 L
s
.99735 .61428 m
.99735 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .04984 m
1 .04984 L
s
.99375 .14189 m
1 .14189 L
s
.99375 .23394 m
1 .23394 L
s
.99375 .32599 m
1 .32599 L
s
.99375 .41804 m
1 .41804 L
s
.99375 .51009 m
1 .51009 L
s
.99375 .60214 m
1 .60214 L
s
.125 Mabswid
.99625 .06825 m
1 .06825 L
s
.99625 .08666 m
1 .08666 L
s
.99625 .10507 m
1 .10507 L
s
.99625 .12348 m
1 .12348 L
s
.99625 .1603 m
1 .1603 L
s
.99625 .17871 m
1 .17871 L
s
.99625 .19712 m
1 .19712 L
s
.99625 .21553 m
1 .21553 L
s
.99625 .25235 m
1 .25235 L
s
.99625 .27076 m
1 .27076 L
s
.99625 .28917 m
1 .28917 L
s
.99625 .30758 m
1 .30758 L
s
.99625 .3444 m
1 .3444 L
s
.99625 .36281 m
1 .36281 L
s
.99625 .38122 m
1 .38122 L
s
.99625 .39963 m
1 .39963 L
s
.99625 .43645 m
1 .43645 L
s
.99625 .45486 m
1 .45486 L
s
.99625 .47327 m
1 .47327 L
s
.99625 .49168 m
1 .49168 L
s
.99625 .5285 m
1 .5285 L
s
.99625 .54691 m
1 .54691 L
s
.99625 .56532 m
1 .56532 L
s
.99625 .58373 m
1 .58373 L
s
.99625 .03143 m
1 .03143 L
s
.99625 .01302 m
1 .01302 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .14189 m
1 .14189 L
s
gsave
.5 .63053 -174.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Horiz) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Angle) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
141.000 13.000 moveto
(@) show
147.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
159.000 13.000 moveto
(D) show
171.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(vs) show
189.000 13.000 moveto
(Horiz) show
219.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
231.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Pos) show
249.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
261.000 13.000 moveto
(@) show
267.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
279.125 13.000 moveto
(D) show
285.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .14189 m
.04497 .32097 L
.06614 .46826 L
.0873 .56366 L
.10847 .60332 L
.12963 .5963 L
.15079 .55752 L
.17196 .5017 L
.19312 .44024 L
.21429 .38043 L
.23545 .32608 L
.25661 .27855 L
.27778 .23766 L
.29894 .20243 L
.32011 .17153 L
.34127 .14361 L
.36243 .11751 L
.3836 .0925 L
.40476 .06846 L
.42593 .04618 L
.44709 .0276 L
.46825 .01583 L
.48942 .01472 L
.51058 .02771 L
.53175 .05597 L
.55291 .09671 L
.57407 .14303 L
.59524 .18621 L
.6164 .21902 L
.63757 .23813 L
.65873 .24421 L
.67989 .24038 L
.70106 .23043 L
.72222 .21766 L
.74339 .20441 L
.76455 .19207 L
.78571 .18132 L
.80688 .17237 L
.82804 .16514 L
.84921 .15944 L
.87037 .15503 L
.89153 .15166 L
.9127 .14912 L
.93386 .14721 L
.95503 .14579 L
.97619 .14474 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00:03oool2000002d0oooo0`0000040?ooo`800000:P3oool5000000<0oooo0P00000Z0?oo
o`<00000103oool2000002/0oooo0`0000030?ooo`8000009P3oool002L0oooo00@000000?ooo`3o
ool00000;@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000002X0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00000X0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0S0?ooo`009`3oool010000000oooo0?ooo`00000]0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000:`3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000002`0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0V0?ooo`D0
00000P3oool010000000oooo0?ooo`00000U0?ooo`009`3oool010000000oooo0?ooo`00000]0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000;03oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0:03oool2000000<0oooo00@000000?ooo`3oool00000
:03oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000002D0oooo000W0?ooo`04
0000003oool0oooo000002d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000Y
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000/0?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool09`3oool00`000000oooo000000030?ooo`04
0000003oool0oooo000002D0oooo000W0?ooo`040000003oool0oooo000002`0oooo0P0000040?oo
o`040000003oool0oooo000002T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000002P0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
02X0oooo0P0000030?ooo`040000003oool0oooo000002D0oooo000X0?ooo`800000;P3oool00`00
0000oooo0?ooo`030?ooo`800000:`3oool3000000@0oooo0P00000Z0?ooo`<00000103oool20000
02`0oooo00<000000?ooo`3oool00P3oool2000002H0oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo000S0?oooo@000002@3oool002<0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3o
ool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo0P0000090?ooo`00
8`3oool00`000000oooo0?ooo`3`0?ooo`030000003oool0oooo00L0oooo000S0?ooo`800000K`3o
ool8000007T0oooo0P0000090?ooo`008`3oool00`000000oooo0?ooo`1/0?ooo`800000203oool2
000007P0oooo00<000000?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool0J`3oool00`00
0000oooo0?ooo`0:0?ooo`030000003oool0oooo07D0oooo00<000000?ooo`3oool01`3oool002<0
oooo00<000000?ooo`3oool0J@3oool2000000h0oooo00<000000?ooo`3oool0M03oool00`000000
oooo0?ooo`070?ooo`008`3oool2000006T0oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`1c0?ooo`8000002@3oool002<0oooo00<000000?ooo`3oool0I`3oool00`000000oooo0?oo
o`0@0?ooo`030000003oool0oooo07<0oooo00<000000?ooo`3oool01`3oool00100oooo0P000004
0?ooo`030000003oool0oooo0080oooo0`0000050?ooo`030000003oool0oooo06H0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`1b0?ooo`030000003oool0oooo00L0oooo000?0?oo
o`040000003oool0oooo000000L0oooo00D000000?ooo`3oool0oooo000000040?ooo`030000003o
ool0oooo06D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`1a0?ooo`030000003o
ool0oooo00L0oooo00080?ooo`D000000P3oool010000000oooo0?ooo`00000;0?ooo`030000003o
ool0oooo0080oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo0740oooo00<000000?ooo`3oool01`3oool000l0oooo00@000000?ooo`3oool000002`3o
ool00`000000oooo0?ooo`020?ooo`<00000H`3oool00`000000oooo0?ooo`0G0?ooo`030000003o
ool0oooo06h0oooo0`0000090?ooo`003`3oool010000000oooo0?ooo`0000070?ooo`@000001@3o
ool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0K`3o
ool00`000000oooo0?ooo`070?ooo`003`3oool010000000oooo0?ooo`0000070?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`0J0?ooo`030000003o
ool0oooo06l0oooo00<000000?ooo`3oool01`3oool00100oooo0P0000080?ooo`D00000103oool0
0`000000oooo0?ooo`1P0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0KP3oool0
0`000000oooo0?ooo`070?ooo`008`3oool200000600oooo00<000000?ooo`3oool07@3oool00`00
0000oooo0?ooo`1]0?ooo`8000002@3oool002<0oooo00<000000?ooo`3oool0G`3oool00`000000
oooo0?ooo`0N0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool01`3oool002<0oooo
00<000000?ooo`3oool0GP3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo06d0oooo
00<000000?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?oo
o`0Q0?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool01`3oool002<0oooo00<00000
0?ooo`3oool0G03oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo06`0oooo00<00000
0?ooo`3oool01`3oool002<0oooo0P00001L0?ooo`030000003oool0oooo02@0oooo00<000000?oo
o`3oool0JP3oool2000000T0oooo000S0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`1[0?ooo`030000003oool0oooo00L0oooo000S0?ooo`030000
003oool0oooo05X0oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`1Z0?ooo`030000
003oool0oooo00L0oooo000S0?ooo`030000003oool0oooo05T0oooo00<000000?ooo`3oool09`3o
ool00`000000oooo0?ooo`1Z0?ooo`030000003oool0oooo00L0oooo000S0?ooo`800000F@3oool0
0`000000oooo0?ooo`0Y0?ooo`030000003oool0oooo06P0oooo0P0000090?ooo`008`3oool00`00
0000oooo0?ooo`1G0?ooo`030000003oool0oooo02X0oooo00<000000?ooo`3oool0J@3oool00`00
0000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo02`0
oooo00<000000?ooo`3oool0J03oool00`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool0J03oool00`000000oooo
0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`1E0?ooo`030000003oool0oooo02h0oooo00<0
00000?ooo`3oool0I`3oool00`000000oooo0?ooo`070?ooo`008`3oool2000005D0oooo00<00000
0?ooo`3oool0;`3oool00`000000oooo0?ooo`1V0?ooo`8000002@3oool002<0oooo00<000000?oo
o`3oool0D`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool01`3oool001`0oooo0P0000050?ooo`030000003oool0oooo0580oooo00<000000?ooo`3o
ool0<P3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo00L0oooo000K0?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0D@3oool00`000000oooo0?ooo`0c0?ooo`03
0000003oool0oooo06H0oooo00<000000?ooo`3oool01`3oool001/0oooo00@000000?ooo`3oool0
0000103ooood000000T0oooo000K0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`1:0?ooo`030000003oool0oooo03D0oooo00<000000?ooo`3o
ool0D`3oool=000000D0oooo00<000000?ooo`3oool01`3oool001/0oooo00@000000?ooo`3oool0
0000103oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3o
ool0=`3oool00`000000oooo0?ooo`170?ooo`/000004P3oool00`000000oooo0?ooo`070?ooo`00
6`3oool010000000oooo0?ooo`0000040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool0B03oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo0480oooo1@00000M0?ooo`03
0000003oool0oooo00L0oooo000L0?ooo`8000001@3oool2000000@0oooo00<000000?ooo`3oool0
A`3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo03d0oooo1000000Q0?ooo`800000
2@3oool002<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`160?ooo`030000003o
ool0oooo03X0oooo00<000000?ooo`3oool0>P3oool3000002H0oooo00<000000?ooo`3oool01`3o
ool002<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`150?ooo`030000003oool0
oooo03`0oooo00<000000?ooo`3oool0=P3oool3000002T0oooo00<000000?ooo`3oool01`3oool0
02<0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo
03h0oooo00<000000?ooo`3oool0<@3oool4000002`0oooo00<000000?ooo`3oool01`3oool002<0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo03h0
oooo00<000000?ooo`3oool0;`3oool200000300oooo00<000000?ooo`3oool01`3oool002<0oooo
0P0000050?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0@03oool00`000000oooo
0?ooo`0]0?ooo`030000003oool0oooo02l0oooo0P0000090?ooo`008`3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0@@3oool00`000000oooo0?oo
o`0[0?ooo`800000<`3oool00`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`04
0?ooo`030000003oool0oooo0480oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`0W
0?ooo`<00000=@3oool00`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0440oooo00<000000?ooo`3oool0@`3oool00`000000oooo0?ooo`0U0?oo
o`800000>03oool00`000000oooo0?ooo`070?ooo`008`3oool2000000D0oooo00<000000?ooo`3o
ool0@@3oool00`000000oooo0?ooo`140?ooo`030000003oool0oooo0280oooo0P00000i0?ooo`80
00002@3oool002<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0o0?ooo`030000
003oool0oooo04H0oooo00<000000?ooo`3oool07`3oool2000003`0oooo00<000000?ooo`3oool0
1`3oool002<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0n0?ooo`030000003o
ool0oooo04L0oooo00<000000?ooo`3oool07@3oool2000003h0oooo00<000000?ooo`3oool01`3o
ool002<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0n0?ooo`030000003oool0
oooo04P0oooo00<000000?ooo`3oool06P3oool200000400oooo00<000000?ooo`3oool01`3oool0
02<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo
04T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`100?ooo`030000003oool0oooo
00L0oooo000S0?ooo`8000001P3oool00`000000oooo0?ooo`0l0?ooo`030000003oool0oooo04/0
oooo00<000000?ooo`3oool05P3oool200000480oooo0P0000090?ooo`008`3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo03`0oooo00<000000?ooo`3oool0C03oool2000001@0oooo
0P0000150?ooo`030000003oool0oooo00L0oooo000@0?ooo`800000103oool00`000000oooo0?oo
o`020?ooo`<000001@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo03/0oooo00<0
00000?ooo`3oool0C`3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo04D0oooo00<0
00000?ooo`3oool01`3oool000l0oooo00@000000?ooo`3oool000001`3oool01@000000oooo0?oo
o`3oool0000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0k0?ooo`030000
003oool0oooo0500oooo00<000000?ooo`3oool03@3oool2000004P0oooo00<000000?ooo`3oool0
1`3oool000l0oooo00@000000?ooo`3oool000002`3oool00`000000oooo0?ooo`020?ooo`<00000
1P3oool00`000000oooo0?ooo`0i0?ooo`030000003oool0oooo0580oooo00<000000?ooo`3oool0
2P3oool2000004P0oooo0`0000090?ooo`003`3oool010000000oooo0?ooo`00000;0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0h0?ooo`030000
003oool0oooo05@0oooo0P0000090?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool0
1`3oool000l0oooo00@000000?ooo`3oool000001`3oool4000000D0oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`0h0?ooo`030000003oool0oooo05H0oooo0`0000030?ooo`<00000
C@3oool00`000000oooo0?ooo`070?ooo`003`3oool010000000oooo0?ooo`0000070?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0g0?ooo`030000
003oool0oooo05X0oooo0`00001@0?ooo`030000003oool0oooo00L0oooo000@0?ooo`800000203o
ool5000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0f0?ooo`030000003o
ool0oooo0:h0oooo00<000000?ooo`3oool01`3oool002<0oooo0P0000070?ooo`030000003oool0
oooo03H0oooo00<000000?ooo`3oool0[@3oool2000000T0oooo000S0?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool0=@3oool00`000000oooo0?ooo`2_0?ooo`030000003oool0oooo
00L0oooo000S0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0=@3oool00`000000
oooo0?ooo`2_0?ooo`030000003oool0oooo00L0oooo000S0?ooo`030000003oool0oooo00H0oooo
00<000000?ooo`3oool0=03oool00`000000oooo0?ooo`2`0?ooo`030000003oool0oooo00L0oooo
000S0?ooo`800000203oool00`000000oooo0?ooo`0b0?ooo`030000003oool0oooo0;00oooo0P00
00090?ooo`008`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0380oooo00<00000
0?ooo`3oool0/@3oool00`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo0340oooo00<000000?ooo`3oool0/P3oool00`000000oooo0?ooo`070?oo
o`008`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0340oooo00<000000?ooo`3o
ool0/P3oool00`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool0/`3oool00`000000oooo0?ooo`070?ooo`008`3o
ool2000000P0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`2b0?ooo`8000002@3o
ool002<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0`0?ooo`030000003oool0
oooo0;<0oooo00<000000?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`0_0?ooo`030000003oool0oooo0;@0oooo00<000000?ooo`3oool01`3oool002<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0_0?ooo`030000003oool0oooo0;@0
oooo00<000000?ooo`3oool01`3oool002<0oooo0P0000090?ooo`030000003oool0oooo02d0oooo
00<000000?ooo`3oool0]03oool2000000T0oooo000S0?ooo`030000003oool0oooo00P0oooo00<0
00000?ooo`3oool0;@3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo00L0oooo000K
0?ooo`<000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02`0oooo00<00000
0?ooo`3oool0]P3oool00`000000oooo0?ooo`070?ooo`00703oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo00P0oooo00<000000?ooo`3oool0;03oool00`000000oooo0?ooo`2f0?oo
o`030000003oool0oooo00L0oooo000L0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo0;H0oooo00<000000?ooo`3o
ool01`3oool001`0oooo00<000000?ooo`3oool0103oool3000000P0oooo00<000000?ooo`3oool0
:`3oool00`000000oooo0?ooo`2e0?ooo`<000002@3oool001`0oooo00<000000?ooo`3oool0103o
ool00`000000oooo0?ooo`080?ooo`030000003oool0oooo02/0oooo00<000000?ooo`3oool0]`3o
ool00`000000oooo0?ooo`070?ooo`006`3oool2000000H0oooo00<000000?ooo`3oool0203oool0
0`000000oooo0?ooo`0Z0?ooo`030000003oool0oooo0;P0oooo00<000000?ooo`3oool01`3oool0
01`0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
02T0oooo00<000000?ooo`3oool0^03oool00`000000oooo0?ooo`070?ooo`008`3oool2000000X0
oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`2g0?ooo`8000002@3oool002<0oooo
00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo0;T0oooo
00<000000?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?oo
o`0X0?ooo`030000003oool0oooo0;T0oooo00<000000?ooo`3oool01`3oool002<0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0W0?ooo`030000003oool0oooo0;X0oooo00<00000
0?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0W0?oo
o`030000003oool0oooo0;X0oooo00<000000?ooo`3oool01`3oool002<0oooo0P00000:0?ooo`03
0000003oool0oooo02L0oooo00<000000?ooo`3oool0^@3oool2000000T0oooo000S0?ooo`030000
003oool0oooo00X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`2k0?ooo`030000
003oool0oooo00L0oooo000S0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool09@3o
ool00`000000oooo0?ooo`2k0?ooo`030000003oool0oooo00L0oooo000S0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`2k0?ooo`030000003oool0
oooo00L0oooo000S0?ooo`8000002`3oool00`000000oooo0?ooo`0T0?ooo`030000003oool0oooo
0;/0oooo0P0000090?ooo`008`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02@0
oooo00<000000?ooo`3oool0_03oool00`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo
0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<000000?ooo`3oool0_@3oool00`000000oooo
0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo02<0oooo00<0
00000?ooo`3oool0_@3oool00`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`0;
0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0_@3oool00`000000oooo0?ooo`07
0?ooo`008`3oool2000000`0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2m0?oo
o`8000002@3oool000l0oooo0`0000040?ooo`030000003oool0oooo0080oooo0`0000050?ooo`03
0000003oool0oooo00/0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`2n0?ooo`03
0000003oool0oooo00L0oooo000@0?ooo`030000003oool0oooo00L0oooo00D000000?ooo`3oool0
oooo000000040?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool08@3oool00`000000
oooo0?ooo`2n0?ooo`030000003oool0oooo00L0oooo000@0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool0_`3oool00`000000oooo0?ooo`070?ooo`00403oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0080oooo0`00000;0?ooo`030000003oool0oooo0200oooo00<0
00000?ooo`3oool0_@3oool3000000T0oooo000@0?ooo`030000003oool0oooo00L0oooo10000005
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`2o
0?ooo`030000003oool0oooo00L0oooo000?0?ooo`8000002@3oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo00`0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`300?oo
o`030000003oool0oooo00L0oooo000@0?ooo`030000003oool0oooo00L0oooo1@0000040?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`300?ooo`03
0000003oool0oooo00L0oooo000S0?ooo`8000003@3oool00`000000oooo0?ooo`0N0?ooo`030000
003oool0oooo0;l0oooo0P0000090?ooo`008`3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo01d0oooo00<000000?ooo`3oool0`@3oool00`000000oooo0?ooo`070?ooo`008`3oool0
0`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0`@3oool0
0`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo
01`0oooo00<000000?ooo`3oool0`P3oool00`000000oooo0?ooo`070?ooo`008`3oool00`000000
oooo0?ooo`0<0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0`P3oool00`000000
oooo0?ooo`070?ooo`008`3oool2000000h0oooo00<000000?ooo`3oool06`3oool00`000000oooo
0?ooo`310?ooo`8000002@3oool002<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo0<<0oooo00<000000?ooo`3oool01`3oool002<0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo0<<0oooo00<00000
0?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo0<<0oooo00<000000?ooo`3oool01`3oool002<0oooo0P00000>0?ooo`03
0000003oool0oooo01T0oooo00<000000?ooo`3oool0``3oool2000000T0oooo000S0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`340?ooo`030000
003oool0oooo00L0oooo000S0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0603o
ool00`000000oooo0?ooo`340?ooo`030000003oool0oooo00L0oooo000S0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`350?ooo`030000003oool0
oooo00L0oooo000S0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool05`3oool00`00
0000oooo0?ooo`350?ooo`030000003oool0oooo00L0oooo000S0?ooo`8000003`3oool00`000000
oooo0?ooo`0G0?ooo`030000003oool0oooo0<@0oooo0P0000090?ooo`008`3oool00`000000oooo
0?ooo`0>0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0aP3oool00`000000oooo
0?ooo`070?ooo`006P3oool5000000@0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool01`3oool001/0oooo00@00000
0?ooo`3oool00000103oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0aP3oool00`000000oooo0?ooo`070?ooo`00703oool00`000000oooo0?ooo`04
0?ooo`<000003`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0<D0oooo0`000009
0?ooo`007@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0503oool00`000000oooo0?ooo`370?ooo`030000003oool0oooo00L0oooo000J0?ooo`05
0000003oool0oooo0?ooo`000000103oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0a`3oool00`000000oooo0?ooo`070?ooo`006P3oool01@000000
oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0B0?oo
o`030000003oool0oooo0<P0oooo00<000000?ooo`3oool01`3oool001/0oooo0`0000050?ooo`03
0000003oool0oooo0100oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`380?ooo`03
0000003oool0oooo00L0oooo000S0?ooo`8000004@3oool00`000000oooo0?ooo`0B0?ooo`030000
003oool0oooo0<L0oooo0P0000090?ooo`008`3oool00`000000oooo0?ooo`0@0?ooo`030000003o
ool0oooo0140oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`070?ooo`008`3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0b@3oool0
0`000000oooo0?ooo`070?ooo`008`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0b@3oool00`000000oooo0?ooo`070?ooo`008`3oool200000180
oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`390?ooo`8000002@3oool002<0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0<X0oooo
00<000000?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`0?0?ooo`030000003oool0oooo0<X0oooo00<000000?ooo`3oool01`3oool002<0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0</0oooo00<00000
0?ooo`3oool01`3oool002<0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0=0?oo
o`030000003oool0oooo0</0oooo00<000000?ooo`3oool01`3oool002<0oooo0P00000C0?ooo`03
0000003oool0oooo00`0oooo00<000000?ooo`3oool0b`3oool2000000T0oooo000S0?ooo`030000
003oool0oooo01<0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`3<0?ooo`030000
003oool0oooo00L0oooo000S0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3o
ool00`000000oooo0?ooo`3=0?ooo`030000003oool0oooo00L0oooo000S0?ooo`030000003oool0
oooo01@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3>0?ooo`030000003oool0
oooo00L0oooo000S0?ooo`8000005P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo
0<d0oooo0P0000090?ooo`008`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00H0
oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`070?ooo`003P3oool5000000<0oooo
00<000000?ooo`3oool00P3oool3000000D0oooo00<000000?ooo`3oool05P3oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool01`3oool000l0oooo00@0
00000?ooo`3oool000001`3oool01@000000oooo0?ooo`3oool0000000@0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`020?ooo`800000dP3oool00`000000oooo0?ooo`070?ooo`00
403oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
5`3oool00`000000oooo0000000200000=@0oooo00<000000?ooo`3oool01`3oool00140oooo00<0
00000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`<00000603oool00`000000oooo0?oo
o`3C0?ooo`<000002@3oool000h0oooo00D000000?ooo`3oool0oooo000000070?ooo`@000001@3o
ool00`000000oooo0?ooo`3`0?ooo`030000003oool0oooo00L0oooo000>0?ooo`050000003oool0
oooo0?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0a0?ooo`030000003oool0oooo0300oooo00<0
00000?ooo`3oool0<03oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo00L0oooo000?
0?ooo`<00000203oool5000000@0oooom00000090?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00
o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00I03oool3000001L0oooo0P0000000`3oool000000?ooo`0;
0?ooo`800000IP3oool2000000l0oooo0P00000G0?ooo`00I`3oool00`000000oooo0?ooo`0D0?oo
o`040000003oool0oooo000000d0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo01D0oooo000]0?ooo`<0000000@0oooo000000000000oooo0`000002
0?ooo`<000000`3oool5000000030?ooo`000000000000<000000`3oool00`000000oooo0?ooo`07
0?ooo`80000000<0oooo00000000000010000000103oool000000000003oool4000000030?ooo`00
0000000000<000000P3oool3000000/0oooo00<000000?ooo`3oool02@0000050?ooo`030000003o
ool0oooo00T0oooo00@000000?ooo`3oool0oooo100000080?ooo`<0000000@0oooo000000000000
oooo0`0000020?ooo`<000000`3oool5000000030?ooo`000000000000<000000`3oool00`000000
oooo0?ooo`070?ooo`<00000103oool300000080oooo100000040?ooo`030000003oool0oooo00X0
oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo0000
00@0oooo00<000000?ooo`3oool05@3oool002h0oooo00H000000?ooo`3oool000000?ooo`000003
0?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool00P3oool010000000oooo0?oo
o`00000=0?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`000000oooo
000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`030000003oool0oooo00`0oooo00@0
00000?ooo`3oool000000`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`060000003oool0oooo0000
003oool000000`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000003P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`00
00001@3oool00`000000oooo0?ooo`0>0?ooo`0>0000003oool0oooo0000003oool000000?ooo`00
0000oooo0000003oool000000?ooo`0000040?ooo`030000003oool0oooo01D0oooo000^0?ooo`06
0000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool03@3oool500000080oooo00H000000?ooo`3oool00000
0?ooo`0000030?ooo`050000003oool0oooo0?ooo`0000000`3oool5000000X0oooo00D000000?oo
o`3oool0oooo000000020?ooo`040000003oool0oooo000000H0oooo00<000000?ooo`3oool0203o
ool00`000000oooo000000030?ooo`<000002@3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
00h0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000080oooo0`00000A
0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`00
00040?ooo`030000003oool0oooo01D0oooo000^0?ooo`@0000000<0oooo0000003oool00P3oool0
0`000000oooo0?ooo`02000000D0oooo00D000000?ooo`3oool0oooo000000020?ooo`030000003o
ool0oooo00d0oooo00<000000?ooo`0000000`3oool01P000000oooo0?ooo`000000oooo000000<0
oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?ooo`0000002P3oool0
1@000000oooo0?ooo`3oool0000000<0oooo00@000000?ooo`00000000001@3oool00`000000oooo
0?ooo`080?ooo`030000003oool000000080oooo00<000000?ooo`3oool02P3oool4000000030?oo
o`000000oooo0080oooo00<000000?ooo`3oool00P0000050?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0=0?ooo`<000000P3oool01`000000oooo0?ooo`3oool00000
0?ooo`000000503oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool00000103oool00`000000oooo0?ooo`0E0?ooo`00;P3oool010000000oooo0?ooo`00
00020?ooo`<000000P3oool2000000040?ooo`00000000000?ooo`<000000`3oool5000000h0oooo
00<000000?ooo`0000000P3oool4000000<0oooo1@0000020?ooo`030000003oool0oooo0080oooo
0`00000;0?ooo`050000003oool0oooo0?ooo`0000000`3oool3000000030?ooo`000000000000<0
oooo00<000000?ooo`3oool01`3oool2000000030?ooo`00000000000080oooo100000080?ooo`04
0000003oool0oooo00000080oooo0`0000020?ooo`80000000@0oooo000000000000oooo0`000003
0?ooo`D000003P3oool010000000oooo0?ooo`0000020?ooo`<000000`3oool400000100oooo00<0
00000?ooo`3oool00P000000103oool000000?ooo`3oool2000000030?ooo`000000oooo00@0oooo
00<000000?ooo`3oool05@3oool002h0oooo00@000000?ooo`3oool000009`3oool00`000000oooo
0?ooo`0?0?ooo`030000003oool0oooo0100oooo0P00000>0?ooo`800000703oool010000000oooo
0?ooo`00000V0?ooo`040000003oool0oooo000001`0oooo0P00000?0?ooo`8000005`3oool002d0
oooo0`0000000`3oool000000000000>0?ooo`030000003oool0oooo01@0oooo0P00000?0?ooo`<0
0000?`3oool3000000030?ooo`000000000000h0oooo00<000000?ooo`3oool04`3oool4000004L0
oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-8.08137, -1.04021, \
0.194844, 0.0223989}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.021164 0.456317 263.171 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.23545 -0.0125 -6 -9 ]
[.23545 -0.0125 6 0 ]
[.44709 -0.0125 -6 -9 ]
[.44709 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.87037 -0.0125 -6 -9 ]
[.87037 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .06156 -42 -4.5 ]
[-0.0125 .06156 0 4.5 ]
[-0.0125 .19315 -36 -4.5 ]
[-0.0125 .19315 0 4.5 ]
[-0.0125 .32473 -42 -4.5 ]
[-0.0125 .32473 0 4.5 ]
[-0.0125 .45632 -6 -4.5 ]
[-0.0125 .45632 0 4.5 ]
[-0.0125 .5879 -36 -4.5 ]
[-0.0125 .5879 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -128.062 0 ]
[.5 .63053 128.062 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.23545 0 m
.23545 .00625 L
s
[(10)] .23545 -0.0125 0 1 Mshowa
.44709 0 m
.44709 .00625 L
s
[(20)] .44709 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(30)] .65873 -0.0125 0 1 Mshowa
.87037 0 m
.87037 .00625 L
s
[(40)] .87037 -0.0125 0 1 Mshowa
.125 Mabswid
.06614 0 m
.06614 .00375 L
s
.10847 0 m
.10847 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.19312 0 m
.19312 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.32011 0 m
.32011 .00375 L
s
.36243 0 m
.36243 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.48942 0 m
.48942 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.57407 0 m
.57407 .00375 L
s
.6164 0 m
.6164 .00375 L
s
.70106 0 m
.70106 .00375 L
s
.74339 0 m
.74339 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.82804 0 m
.82804 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.95503 0 m
.95503 .00375 L
s
.99735 0 m
.99735 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .06156 m
.00625 .06156 L
s
[(-0.0015)] -0.0125 .06156 1 0 Mshowa
0 .19315 m
.00625 .19315 L
s
[(-0.001)] -0.0125 .19315 1 0 Mshowa
0 .32473 m
.00625 .32473 L
s
[(-0.0005)] -0.0125 .32473 1 0 Mshowa
0 .45632 m
.00625 .45632 L
s
[(0)] -0.0125 .45632 1 0 Mshowa
0 .5879 m
.00625 .5879 L
s
[(0.0005)] -0.0125 .5879 1 0 Mshowa
.125 Mabswid
0 .08788 m
.00375 .08788 L
s
0 .1142 m
.00375 .1142 L
s
0 .14051 m
.00375 .14051 L
s
0 .16683 m
.00375 .16683 L
s
0 .21946 m
.00375 .21946 L
s
0 .24578 m
.00375 .24578 L
s
0 .2721 m
.00375 .2721 L
s
0 .29841 m
.00375 .29841 L
s
0 .35105 m
.00375 .35105 L
s
0 .37737 m
.00375 .37737 L
s
0 .40368 m
.00375 .40368 L
s
0 .43 m
.00375 .43 L
s
0 .48263 m
.00375 .48263 L
s
0 .50895 m
.00375 .50895 L
s
0 .53527 m
.00375 .53527 L
s
0 .56159 m
.00375 .56159 L
s
0 .03524 m
.00375 .03524 L
s
0 .00893 m
.00375 .00893 L
s
0 .61422 m
.00375 .61422 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.23545 .61178 m
.23545 .61803 L
s
.44709 .61178 m
.44709 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.87037 .61178 m
.87037 .61803 L
s
.125 Mabswid
.06614 .61428 m
.06614 .61803 L
s
.10847 .61428 m
.10847 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.19312 .61428 m
.19312 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.32011 .61428 m
.32011 .61803 L
s
.36243 .61428 m
.36243 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.48942 .61428 m
.48942 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.57407 .61428 m
.57407 .61803 L
s
.6164 .61428 m
.6164 .61803 L
s
.70106 .61428 m
.70106 .61803 L
s
.74339 .61428 m
.74339 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.82804 .61428 m
.82804 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.95503 .61428 m
.95503 .61803 L
s
.99735 .61428 m
.99735 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .06156 m
1 .06156 L
s
.99375 .19315 m
1 .19315 L
s
.99375 .32473 m
1 .32473 L
s
.99375 .45632 m
1 .45632 L
s
.99375 .5879 m
1 .5879 L
s
.125 Mabswid
.99625 .08788 m
1 .08788 L
s
.99625 .1142 m
1 .1142 L
s
.99625 .14051 m
1 .14051 L
s
.99625 .16683 m
1 .16683 L
s
.99625 .21946 m
1 .21946 L
s
.99625 .24578 m
1 .24578 L
s
.99625 .2721 m
1 .2721 L
s
.99625 .29841 m
1 .29841 L
s
.99625 .35105 m
1 .35105 L
s
.99625 .37737 m
1 .37737 L
s
.99625 .40368 m
1 .40368 L
s
.99625 .43 m
1 .43 L
s
.99625 .48263 m
1 .48263 L
s
.99625 .50895 m
1 .50895 L
s
.99625 .53527 m
1 .53527 L
s
.99625 .56159 m
1 .56159 L
s
.99625 .03524 m
1 .03524 L
s
.99625 .00893 m
1 .00893 L
s
.99625 .61422 m
1 .61422 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .45632 m
1 .45632 L
s
gsave
.5 .63053 -189.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Horizontal) show
129.000 13.000 moveto
(Tune) show
159.000 13.000 moveto
(Shift) show
195.000 13.000 moveto
(vs) show
213.000 13.000 moveto
(Horiz) show
243.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
255.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Pos) show
273.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
285.000 13.000 moveto
(@) show
291.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
303.125 13.000 moveto
(D) show
315.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .01472 m
.04497 .05537 L
.06614 .16165 L
.0873 .29656 L
.10847 .4227 L
.12963 .51733 L
.15079 .57467 L
.17196 .60011 L
.19312 .60332 L
.21429 .59363 L
.23545 .57818 L
.25661 .56165 L
.27778 .54674 L
.29894 .53475 L
.32011 .52606 L
.34127 .52045 L
.36243 .51718 L
.3836 .51502 L
.40476 .51216 L
.42593 .50613 L
.44709 .49403 L
.46825 .4733 L
.48942 .44321 L
.51058 .4068 L
.53175 .37189 L
.55291 .34895 L
.57407 .34596 L
.59524 .36334 L
.6164 .39384 L
.63757 .42714 L
.65873 .45515 L
.67989 .47426 L
.70106 .48459 L
.72222 .48813 L
.74339 .48728 L
.76455 .48405 L
.78571 .47987 L
.80688 .47558 L
.82804 .47166 L
.84921 .46829 L
.87037 .46552 L
.89153 .4633 L
.9127 .46157 L
.93386 .46024 L
.95503 .45922 L
.97619 .45846 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00<@3oool2
000002X0oooo0`0000040?ooo`8000009P3oool5000000<0oooo0P00000X0?ooo`<00000103oool2
000002P0oooo0`0000030?ooo`800000:@3oool00300oooo00@000000?ooo`3oool00000:P3oool0
0`000000oooo0?ooo`020?ooo`040000003oool0oooo000002H0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`00000V0?ooo`050000003oool0oooo0?ooo`0000000P3oool01000
0000oooo0?ooo`00000X0?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?oo
o`0V0?ooo`00<03oool010000000oooo0?ooo`00000Z0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000009`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000002X0
oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0S0?ooo`D000000P3oool01000
0000oooo0?ooo`00000X0?ooo`00<03oool010000000oooo0?ooo`00000Z0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000:03oool01@000000oooo0?ooo`3oool000000080oooo
00<000000?ooo`3oool09P3oool2000000<0oooo00@000000?ooo`3oool000009@3oool010000000
oooo0?ooo`0000030?ooo`040000003oool0oooo000002P0oooo000`0?ooo`040000003oool0oooo
000002X0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000U0?ooo`050000003o
ool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000Z0?ooo`040000003oool0oooo0000
0080oooo00<000000?ooo`3oool0903oool00`000000oooo000000030?ooo`040000003oool0oooo
000002P0oooo000`0?ooo`040000003oool0oooo000002T0oooo0P0000040?ooo`040000003oool0
oooo000002D0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000002H0
oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo000002L0oooo0P000003
0?ooo`040000003oool0oooo000002P0oooo000a0?ooo`800000:`3oool00`000000oooo0?ooo`03
0?ooo`8000009`3oool3000000@0oooo0P00000X0?ooo`<00000103oool2000002T0oooo00<00000
0?ooo`3oool00P3oool2000002T0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo000/0?ooonH000003P3oool002`0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo0P00000>0?ooo`00;03oool200000>80
oooo0P00000>0?ooo`00;03oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0=`0oooo
00<000000?ooo`3oool0303oool002`0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?oo
o`3L0?ooo`030000003oool0oooo00`0oooo000/0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0f`3oool00`000000oooo0?ooo`0<0?ooo`00;03oool00`000000oooo0?ooo`040?oo
o`030000003oool0oooo0=/0oooo00<000000?ooo`3oool0303oool002`0oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`3J0?ooo`030000003oool0oooo00`0oooo000/0?ooo`800000
1P3oool00`000000oooo0?ooo`3I0?ooo`8000003P3oool002`0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`3I0?ooo`030000003oool0oooo00`0oooo000/0?ooo`030000003oool0
oooo00H0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`0<0?ooo`00;03oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo0=P0oooo00<000000?ooo`3oool0303oool000P0
oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`8000000`3oool3000000<0
oooo0`0000040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0f03oool00`000000
oooo0?ooo`0<0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo0000
0080oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D0
00000?ooo`3oool0oooo0000000:0?ooo`030000003oool0oooo0=L0oooo00<000000?ooo`3oool0
303oool000D000000P3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo
0?ooo`<00000203oool00`000000oooo0?ooo`3E0?ooo`<000003P3oool000L0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo
00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool0000000X0oooo00<000000?ooo`3o
ool0e`3oool00`000000oooo0?ooo`0<0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool010000000oooo0?ooo`3o
ool4000000@0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3G0?ooo`030000003o
ool0oooo00`0oooo00070?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`8000000`3oool00`000000oooo0?ooo`050?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0<0?ooo`00
203oool2000000X0oooo0P0000040?ooo`800000103oool010000000oooo0?ooo`3oool5000000<0
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`3F0?ooo`030000003oool0oooo00`0
oooo000/0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0eP3oool00`000000oooo
0?ooo`0<0?ooo`00;03oool2000000X0oooo00<000000?ooo`3oool0e@3oool2000000h0oooo000/
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0eP3oool00`000000oooo0?ooo`0<
0?ooo`00;03oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0=H0oooo00<000000?oo
o`3oool0303oool002`0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`3E0?ooo`03
0000003oool0oooo00`0oooo000/0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
e@3oool00`000000oooo0?ooo`0<0?ooo`00;03oool00`000000oooo0?ooo`0:0?ooo`030000003o
ool0oooo0=D0oooo00<000000?ooo`3oool0303oool002`0oooo0P00000;0?ooo`030000003oool0
oooo0=@0oooo0P00000>0?ooo`00;03oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo
0=D0oooo00<000000?ooo`3oool0303oool002`0oooo00<000000?ooo`3oool02P3oool00`000000
oooo0?ooo`3E0?ooo`030000003oool0oooo00`0oooo000/0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0<0?ooo`00;03oool00`000000oooo0?oo
o`0;0?ooo`030000003oool0oooo0=@0oooo00<000000?ooo`3oool0303oool002`0oooo00<00000
0?ooo`3oool02`3oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00`0oooo000/0?oo
o`800000303oool00`000000oooo0?ooo`3C0?ooo`8000003P3oool002`0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`3D0?ooo`030000003oool0oooo00`0oooo000/0?ooo`030000
003oool0oooo00/0oooo00<000000?ooo`3oool0e03oool00`000000oooo0?ooo`0<0?ooo`00;03o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0=<0oooo00<000000?ooo`3oool0303o
ool002`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`3C0?ooo`030000003oool0
oooo00`0oooo000/0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0d`3oool00`00
0000oooo0?ooo`0<0?ooo`00;03oool2000000d0oooo00<000000?ooo`3oool0dP3oool2000000h0
oooo000/0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0d`3oool00`000000oooo
0?ooo`0<0?ooo`00;03oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0=<0oooo00<0
00000?ooo`3oool0303oool002`0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3B
0?ooo`030000003oool0oooo00`0oooo000>0?ooo`800000103oool00`000000oooo0?ooo`030?oo
o`800000103oool2000000<0oooo0`0000040?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0dP3oool00`000000oooo0?ooo`0<0?ooo`003@3oool010000000oooo0?ooo`0000080?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0dP3oool00`000000oooo0?oo
o`0<0?ooo`001P3oool500000080oooo00@000000?ooo`3oool00000203oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool3000000d0
oooo00<000000?ooo`3oool0d03oool3000000h0oooo000=0?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0
oooo00`0oooo000=0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0
3@3oool00`000000oooo0?ooo`3B0?ooo`030000003oool0oooo00`0oooo000=0?ooo`040000003o
ool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?oo
o`8000001@3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0=40oooo00<000000?oo
o`3oool0303oool000h0oooo0P00000:0?ooo`800000103oool2000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0=40oooo00<000000?ooo`3o
ool0303oool002`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3A0?ooo`030000
003oool0oooo00`0oooo000/0?ooo`8000003`3oool00`000000oooo0?ooo`3@0?ooo`8000003P3o
ool002`0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3A0?ooo`030000003oool0
oooo00`0oooo000/0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0d@3oool00`00
0000oooo0?ooo`0<0?ooo`00;03oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0=00
oooo00<000000?ooo`3oool0303oool002`0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`3@0?ooo`030000003oool0oooo00`0oooo000/0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool0d03oool00`000000oooo0?ooo`0<0?ooo`00;03oool200000100oooo00<00000
0?ooo`3oool0c`3oool2000000h0oooo000/0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0d03oool00`000000oooo0?ooo`0<0?ooo`00;03oool00`000000oooo0?ooo`0?0?ooo`03
0000003oool0oooo0=00oooo00<000000?ooo`3oool0303oool002`0oooo00<000000?ooo`3oool0
3`3oool00`000000oooo0?ooo`3@0?ooo`030000003oool0oooo00`0oooo000/0?ooo`030000003o
ool0oooo0100oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?ooo`0<0?ooo`00;03oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0303oool0
02`0oooo0P00000A0?ooo`030000003oool0oooo0<h0oooo0P00000>0?ooo`00;03oool00`000000
oooo0?ooo`0@0?ooo`030000003oool0oooo0<l0oooo00<000000?ooo`3oool0303oool002`0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`3?0?ooo`030000003oool0oooo00`0oooo
000/0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0c`3oool00`000000oooo0?oo
o`0<0?ooo`00;03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0<h0oooo00<00000
0?ooo`3oool0303oool002`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3>0?oo
o`030000003oool0oooo00`0oooo000/0?ooo`8000004P3oool00`000000oooo0?ooo`3=0?ooo`80
00003P3oool002`0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3>0?ooo`030000
003oool0oooo00`0oooo000/0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0cP3o
ool00`000000oooo0?ooo`0<0?ooo`00;03oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0<h0oooo00<000000?ooo`3oool0303oool000P0oooo0P0000040?ooo`030000003oool0oooo
00<0oooo0P0000040?ooo`800000103oool2000000<0oooo0`0000040?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0c@3oool00`000000oooo0?ooo`0<0?ooo`001`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool01P000000oooo0?ooo`000000oooo000000<0oooo00D000000?ooo`3oool0oooo0000000D0?oo
o`030000003oool0oooo0<d0oooo00<000000?ooo`3oool0303oool000D000000P3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo0?ooo`<000004P3oool00`000000
oooo0?ooo`3;0?ooo`<000003P3oool000L0oooo00@000000?ooo`3oool00000203oool010000000
oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001@3o
ool01@000000oooo0?ooo`3oool0000001@0oooo00<000000?ooo`3oool0c@3oool00`000000oooo
0?ooo`0<0?ooo`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080
oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`000000oooo00@00000103oool0
0`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0<d0oooo00<000000?ooo`3oool0303oool0
00L0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000070?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`0<0?ooo`00203oool2000000X0
oooo0P0000040?ooo`800000103oool200000080oooo1@0000030?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0c03oool00`000000oooo0?ooo`0<0?ooo`00;03oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo06P0oooo1000001P0?ooo`030000003oool0oooo00`0oooo
000/0?ooo`800000503oool00`000000oooo0?ooo`1V0?ooo`800000103oool00`000000oooo0?oo
o`1L0?ooo`8000003P3oool002`0oooo00<000000?ooo`3oool04`3oool00`000000oooo0?ooo`1U
0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?ooo`0<
0?ooo`00;03oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo06@0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`1K0?ooo`030000003oool0oooo00`0oooo000/0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0HP3oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo05X0oooo00<000000?ooo`3oool0303oool002`0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0
FP3oool00`000000oooo0?ooo`0<0?ooo`00;03oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo0600oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1I0?ooo`030000003o
ool0oooo00`0oooo000/0?ooo`8000005@3oool00`000000oooo0?ooo`1P0?ooo`030000003oool0
oooo00d0oooo00<000000?ooo`3oool0E`3oool2000000h0oooo000/0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo
05L0oooo00<000000?ooo`3oool0303oool002`0oooo00<000000?ooo`3oool0503oool00`000000
oooo0?ooo`1N0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0E`3oool00`000000
oooo0?ooo`0<0?ooo`00;03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05d0oooo
00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`1F0?ooo`030000003oool0oooo00`0oooo
000/0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0G03oool00`000000oooo0?oo
o`0C0?ooo`030000003oool0oooo05D0oooo00<000000?ooo`3oool0303oool002`0oooo00<00000
0?ooo`3oool05@3oool00`000000oooo0?ooo`1L0?ooo`030000003oool0oooo01<0oooo00<00000
0?ooo`3oool0E@3oool00`000000oooo0?ooo`0<0?ooo`00;03oool2000001H0oooo00<000000?oo
o`3oool0F`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05<0oooo0P00000>0?oo
o`00;03oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3o
ool05`3oool00`000000oooo0?ooo`1C0?ooo`030000003oool0oooo00`0oooo000/0?ooo`030000
003oool0oooo01H0oooo00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`0H0?ooo`030000
003oool0oooo0580oooo00<000000?ooo`3oool0303oool002`0oooo00<000000?ooo`3oool05P3o
ool00`000000oooo0?ooo`1H0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0DP3o
ool00`000000oooo0?ooo`0<0?ooo`00;03oool00`000000oooo0?ooo`0F0?ooo`030000003oool0
oooo05L0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`1A0?ooo`030000003oool0
oooo00`0oooo000/0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0E`3oool00`00
0000oooo0?ooo`0L0?ooo`030000003oool0oooo0500oooo00<000000?ooo`3oool0303oool002`0
oooo0P00000G0?ooo`030000003oool0oooo05H0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`1?0?ooo`8000003P3oool002`0oooo00<000000?ooo`3oool05`3oool00`000000oooo
0?ooo`1E0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`0<0?ooo`00;03oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo05@0oooo00<0
00000?ooo`3oool0803oool00`000000oooo0?ooo`1>0?ooo`030000003oool0oooo00`0oooo000/
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0R
0?ooo`030000003oool0oooo04d0oooo00<000000?ooo`3oool0303oool002H0oooo0P0000040?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0D`3oool00`000000oooo0?ooo`0R0?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool0303oool002D0oooo00@000000?ooo`3o
ool000000`3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo0580oooo00<000000?oo
o`3oool0903oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo00`0oooo000U0?ooo`04
0000003oool0oooo000000<0ooooiP00000>0?ooo`009@3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo01P0oooo00<000000?ooo`3oool0C`3oool00`000000oooo0?ooo`0X0?oo
o`030000003oool0oooo03@0oooo4@0000050?ooo`030000003oool0oooo00`0oooo000U0?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`1?0?oo
o`030000003oool0oooo02T0oooo00<000000?ooo`3oool0:@3oool:000001H0oooo00<000000?oo
o`3oool0303oool002D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`0H0?oo
o`030000003oool0oooo04h0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`0S0?oo
o`D00000803oool00`000000oooo0?ooo`0<0?ooo`009P3oool2000000@0oooo00<000000?ooo`3o
ool06@3oool00`000000oooo0?ooo`1<0?ooo`030000003oool0oooo02d0oooo0P00000N0?ooo`D0
00009@3oool00`000000oooo0?ooo`0<0?ooo`00;03oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo04/0oooo00<000000?ooo`3oool0<03oool2000001L0oooo1@00000Z0?ooo`030000
003oool0oooo00`0oooo000/0?ooo`8000006P3oool00`000000oooo0?ooo`1:0?ooo`030000003o
ool0oooo03<0oooo00<000000?ooo`3oool02`3oool9000002h0oooo0P00000>0?ooo`00;03oool0
0`000000oooo0?ooo`0I0?ooo`030000003oool0oooo04T0oooo00<000000?ooo`3oool0=@3oool=
000003P0oooo00<000000?ooo`3oool0303oool002`0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`170?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool0303oool002`0
oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`150?ooo`800000OP3oool00`000000
oooo0?ooo`0<0?ooo`00;03oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo04@0oooo
00<000000?ooo`3oool0OP3oool00`000000oooo0?ooo`0<0?ooo`00;03oool00`000000oooo0?oo
o`0J0?ooo`030000003oool0oooo04<0oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?oo
o`0<0?ooo`00;03oool2000001/0oooo00<000000?ooo`3oool0@03oool300000840oooo0P00000>
0?ooo`00;03oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03X0oooo1@0000250?oo
o`030000003oool0oooo00`0oooo000/0?ooo`030000003oool0oooo01/0oooo00<000000?ooo`3o
ool0<03oool:000008X0oooo00<000000?ooo`3oool0303oool002`0oooo00<000000?ooo`3oool0
6`3oool00`000000oooo0?ooo`0[0?ooo`D00000U03oool00`000000oooo0?ooo`0<0?ooo`00;03o
ool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02H0oooo1000002I0?ooo`030000003o
ool0oooo00`0oooo000/0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0903oool2
000009d0oooo00<000000?ooo`3oool0303oool002`0oooo0P00000M0?ooo`030000003oool0oooo
0280oooo0P00002N0?ooo`8000003P3oool002`0oooo00<000000?ooo`3oool07@3oool00`000000
oooo0?ooo`0O0?ooo`800000X@3oool00`000000oooo0?ooo`0<0?ooo`00;03oool00`000000oooo
0?ooo`0M0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0X@3oool00`000000oooo
0?ooo`0<0?ooo`00;03oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo01/0oooo0P00
002T0?ooo`030000003oool0oooo00`0oooo000/0?ooo`030000003oool0oooo01h0oooo00<00000
0?ooo`3oool06@3oool200000:H0oooo00<000000?ooo`3oool0303oool002`0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`0H0?ooo`030000003oool0oooo0:H0oooo00<000000?oo
o`3oool0303oool002`0oooo0P00000P0?ooo`030000003oool0oooo01D0oooo0P00002X0?ooo`80
00003P3oool002`0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo0:T0oooo00<000000?ooo`3oool0303oool002`0oooo00<000000?ooo`3oool07`3o
ool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo0:X0oooo00<000000?ooo`3oool0303o
ool002`0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0A0?ooo`030000003oool0
oooo0:/0oooo00<000000?ooo`3oool0303oool000P0oooo0P0000040?ooo`030000003oool0oooo
00<0oooo0P0000040?ooo`800000103oool2000000<0oooo0`0000040?ooo`030000003oool0oooo
0200oooo00<000000?ooo`3oool03`3oool200000:h0oooo00<000000?ooo`3oool0303oool000L0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`050000003oool0oooo0?oo
o`0000008`3oool00`000000oooo0?ooo`0<0?ooo`800000/03oool00`000000oooo0?ooo`0<0?oo
o`001`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo0?ooo`<0
00008P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo0:h0oooo0`00000>0?ooo`00
1`3oool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000050?ooo`050000003oool0oooo0?ooo`000000
9@3oool00`000000oooo0?ooo`070?ooo`800000/`3oool00`000000oooo0?ooo`0<0?ooo`001`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool01@000000oooo0?ooo`000000oooo00@00000103oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo00@0oooo0P00002e0?ooo`030000003oool0oooo00`0oooo00070?oo
o`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?oo
o`0000020?ooo`060000003oool0oooo0000003oool000001`3oool00`000000oooo0?ooo`0U0?oo
o`<000000P3oool00`000000oooo0?ooo`2e0?ooo`030000003oool0oooo00`0oooo00080?ooo`80
00002P3oool2000000@0oooo0P0000040?ooo`8000000P3oool5000000<0oooo00<000000?ooo`3o
ool0:03oool200000;P0oooo00<000000?ooo`3oool0303oool002`0oooo00<000000?ooo`3oool0
hP3oool00`000000oooo0?ooo`0<0?ooo`00;03oool2000000@0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`070?ooo`8000003P3oool002`0ooooiP00000>0?ooo`00o`3ooolQ0?oo
o`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3ooolQ0?ooo`00o`3oool20?ooo`8000003`3oool2
000000`0oooo003o0?ooo`80oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0:0?oo
o`00803oool3000000040?ooo`00000000000?ooo`<000000P3oool3000000<0oooo1@0000000`3o
ool000000000000300000080oooo0`0000020?ooo`<0000000<0oooo0000000000000P3oool20000
00<0oooo100000000`3oool0000000000003000000P0oooo0`0000040?ooo`80000000<0oooo0000
000000000P000000103oool000000000003oool3000000T0oooo0`0000020?ooo`/0000000<0oooo
0000000000000`0000030?ooo`8000002P3oool010000000oooo0?ooo`3oool4000000P0oooo0`00
0000103oool000000000003oool300000080oooo0`0000030?ooo`D0000000<0oooo000000000000
0`0000030?ooo`030000003oool0oooo00L0oooo0`0000040?ooo`<000000P3oool4000000@0oooo
00<000000?ooo`3oool02P3oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`00
0000oooo0000003oool00000103oool00`000000oooo0?ooo`0:0?ooo`008@3oool01P000000oooo
0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000001P3oool00`000000oooo0?ooo`02
0?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`000002
0?ooo`060000003oool0oooo0000003oool00000303oool010000000oooo0?ooo`0000020?ooo`04
0000003oool0oooo000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?oo
o`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo0?ooo`0000060?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000003P3oool00`000000oooo0?ooo`020?oo
o`050000003oool0oooo0?ooo`0000001@3oool00`000000oooo0?ooo`0>0?ooo`0>0000003oool0
oooo0000003oool000000?ooo`000000oooo0000003oool000000?ooo`0000040?ooo`030000003o
ool0oooo00X0oooo000Q0?ooo`060000003oool0oooo0000003oool000000`3oool010000000oooo
0?ooo`0000060?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo000000030?oo
o`040000003oool0oooo00000080oooo00@000000?ooo`3oool000001@3oool3000000@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo
00D000000?ooo`3oool000000?ooo`05000000/0oooo00@000000?ooo`3oool000000P3oool01@00
0000oooo0?ooo`3oool0000000D0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`09
0?ooo`030000003oool0000000<0oooo0`0000090?ooo`060000003oool0oooo0000003oool00000
0`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool30000
0140oooo00h000000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo
000000@0oooo00<000000?ooo`3oool02P3oool00240oooo100000000`3oool000000?ooo`020?oo
o`030000003oool0oooo008000001@3oool01@000000oooo0?ooo`3oool000000080oooo00@00000
0?ooo`3oool000000`3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0
oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
0080oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo000000<0oooo
00<000000?ooo`3oool01`3oool2000000<0oooo00@000000?ooo`3oool000000`3oool00`000000
oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool02@3oool00`000000
oooo000000020?ooo`030000003oool0oooo00X0oooo100000000`3oool000000?ooo`020?ooo`03
0000003oool0oooo008000001@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?oo
o`3oool03@3oool300000080oooo00L000000?ooo`3oool0oooo0000003oool0000001@0oooo00h0
00000?ooo`3oool000000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000@0oooo
00<000000?ooo`3oool02P3oool00240oooo00@000000?ooo`3oool000000P3oool300000080oooo
0P000000103oool000000000003oool3000000<0oooo1@0000020?ooo`<000000P3oool400000080
oooo100000030?ooo`8000001@3oool00`000000oooo0?ooo`070?ooo`060000003oool000000?oo
o`000000oooo0P000000103oool000000000003oool4000000<0oooo0`0000090?ooo`030000003o
ool0oooo00<0oooo0`0000020?ooo`<00000103oool4000000030?ooo`000000000000800000203o
ool2000000030?ooo`00000000000080oooo100000080?ooo`040000003oool0oooo00000080oooo
0`0000020?ooo`80000000@0oooo000000000000oooo0`0000030?ooo`D000003P3oool010000000
oooo0?ooo`0000020?ooo`<000000`3oool400000100oooo00<000000?ooo`3oool00P000000103o
ool000000?ooo`3oool2000000030?ooo`000000oooo00@0oooo00<000000?ooo`3oool02P3oool0
0240oooo00@000000?ooo`3oool000009P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0
oooo00L0oooo00D000000?ooo`000000oooo0000000J0?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo
00@000000?ooo`3oool000009P3oool010000000oooo0?ooo`00000L0?ooo`8000003`3oool20000
00`0oooo000P0?ooo`<0000000<0oooo0000000000003P3oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo00P0oooo0`0000090?ooo`D000006`3oool3000000030?ooo`000000000000H0
oooo00<000000?ooo`3oool0103oool200000080oooo00<000000?ooo`3oool06P3oool300000003
0?ooo`000000000000h0oooo00<000000?ooo`3oool04`3oool4000003`0oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-10.4132, -0.00200805, \
0.207083, 1.66535*^-5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.021164 0.0146767 1347.23 [
[.02381 -0.0125 -3 -9 ]
[.02381 -0.0125 3 0 ]
[.23545 -0.0125 -6 -9 ]
[.23545 -0.0125 6 0 ]
[.44709 -0.0125 -6 -9 ]
[.44709 -0.0125 6 0 ]
[.65873 -0.0125 -6 -9 ]
[.65873 -0.0125 6 0 ]
[.87037 -0.0125 -6 -9 ]
[.87037 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01468 -6 -4.5 ]
[-0.0125 .01468 0 4.5 ]
[-0.0125 .1494 -36 -4.5 ]
[-0.0125 .1494 0 4.5 ]
[-0.0125 .28412 -36 -4.5 ]
[-0.0125 .28412 0 4.5 ]
[-0.0125 .41885 -36 -4.5 ]
[-0.0125 .41885 0 4.5 ]
[-0.0125 .55357 -36 -4.5 ]
[-0.0125 .55357 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -122.062 0 ]
[.5 .63053 122.062 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(0)] .02381 -0.0125 0 1 Mshowa
.23545 0 m
.23545 .00625 L
s
[(10)] .23545 -0.0125 0 1 Mshowa
.44709 0 m
.44709 .00625 L
s
[(20)] .44709 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(30)] .65873 -0.0125 0 1 Mshowa
.87037 0 m
.87037 .00625 L
s
[(40)] .87037 -0.0125 0 1 Mshowa
.125 Mabswid
.06614 0 m
.06614 .00375 L
s
.10847 0 m
.10847 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.19312 0 m
.19312 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.32011 0 m
.32011 .00375 L
s
.36243 0 m
.36243 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.48942 0 m
.48942 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.57407 0 m
.57407 .00375 L
s
.6164 0 m
.6164 .00375 L
s
.70106 0 m
.70106 .00375 L
s
.74339 0 m
.74339 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.82804 0 m
.82804 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.95503 0 m
.95503 .00375 L
s
.99735 0 m
.99735 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01468 m
.00625 .01468 L
s
[(0)] -0.0125 .01468 1 0 Mshowa
0 .1494 m
.00625 .1494 L
s
[(0.0001)] -0.0125 .1494 1 0 Mshowa
0 .28412 m
.00625 .28412 L
s
[(0.0002)] -0.0125 .28412 1 0 Mshowa
0 .41885 m
.00625 .41885 L
s
[(0.0003)] -0.0125 .41885 1 0 Mshowa
0 .55357 m
.00625 .55357 L
s
[(0.0004)] -0.0125 .55357 1 0 Mshowa
.125 Mabswid
0 .04162 m
.00375 .04162 L
s
0 .06857 m
.00375 .06857 L
s
0 .09551 m
.00375 .09551 L
s
0 .12245 m
.00375 .12245 L
s
0 .17634 m
.00375 .17634 L
s
0 .20329 m
.00375 .20329 L
s
0 .23023 m
.00375 .23023 L
s
0 .25718 m
.00375 .25718 L
s
0 .31107 m
.00375 .31107 L
s
0 .33801 m
.00375 .33801 L
s
0 .36496 m
.00375 .36496 L
s
0 .3919 m
.00375 .3919 L
s
0 .44579 m
.00375 .44579 L
s
0 .47273 m
.00375 .47273 L
s
0 .49968 m
.00375 .49968 L
s
0 .52662 m
.00375 .52662 L
s
0 .58051 m
.00375 .58051 L
s
0 .60746 m
.00375 .60746 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
.02381 .61178 m
.02381 .61803 L
s
.23545 .61178 m
.23545 .61803 L
s
.44709 .61178 m
.44709 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.87037 .61178 m
.87037 .61803 L
s
.125 Mabswid
.06614 .61428 m
.06614 .61803 L
s
.10847 .61428 m
.10847 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.19312 .61428 m
.19312 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.32011 .61428 m
.32011 .61803 L
s
.36243 .61428 m
.36243 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.48942 .61428 m
.48942 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.57407 .61428 m
.57407 .61803 L
s
.6164 .61428 m
.6164 .61803 L
s
.70106 .61428 m
.70106 .61803 L
s
.74339 .61428 m
.74339 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.82804 .61428 m
.82804 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.95503 .61428 m
.95503 .61803 L
s
.99735 .61428 m
.99735 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01468 m
1 .01468 L
s
.99375 .1494 m
1 .1494 L
s
.99375 .28412 m
1 .28412 L
s
.99375 .41885 m
1 .41885 L
s
.99375 .55357 m
1 .55357 L
s
.125 Mabswid
.99625 .04162 m
1 .04162 L
s
.99625 .06857 m
1 .06857 L
s
.99625 .09551 m
1 .09551 L
s
.99625 .12245 m
1 .12245 L
s
.99625 .17634 m
1 .17634 L
s
.99625 .20329 m
1 .20329 L
s
.99625 .23023 m
1 .23023 L
s
.99625 .25718 m
1 .25718 L
s
.99625 .31107 m
1 .31107 L
s
.99625 .33801 m
1 .33801 L
s
.99625 .36496 m
1 .36496 L
s
.99625 .3919 m
1 .3919 L
s
.99625 .44579 m
1 .44579 L
s
.99625 .47273 m
1 .47273 L
s
.99625 .49968 m
1 .49968 L
s
.99625 .52662 m
1 .52662 L
s
.99625 .58051 m
1 .58051 L
s
.99625 .60746 m
1 .60746 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
gsave
.5 .63053 -183.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Vertical) show
117.000 13.000 moveto
(Tune) show
147.000 13.000 moveto
(Shift) show
183.000 13.000 moveto
(vs) show
201.000 13.000 moveto
(Horiz) show
231.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
243.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Pos) show
261.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
273.000 13.000 moveto
(@) show
279.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(mm) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
291.125 13.000 moveto
(D) show
303.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .40786 m
.04497 .41014 L
.06614 .41753 L
.0873 .43098 L
.10847 .45041 L
.12963 .47418 L
.15079 .49974 L
.17196 .52461 L
.19312 .54694 L
.21429 .56575 L
.23545 .58065 L
.25661 .59167 L
.27778 .59901 L
.29894 .60286 L
.32011 .60332 L
.34127 .60035 L
.36243 .59373 L
.3836 .58305 L
.40476 .56776 L
.42593 .54719 L
.44709 .52067 L
.46825 .48767 L
.48942 .44799 L
.51058 .40187 L
.53175 .35026 L
.55291 .29504 L
.57407 .23916 L
.59524 .1863 L
.6164 .13995 L
.63757 .10229 L
.65873 .07376 L
.67989 .05338 L
.70106 .03948 L
.72222 .03032 L
.74339 .02444 L
.76455 .02072 L
.78571 .0184 L
.80688 .01696 L
.82804 .01607 L
.84921 .01553 L
.87037 .01519 L
.89153 .01499 L
.9127 .01486 L
.93386 .01479 L
.95503 .01474 L
.97619 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/B000`400?l00000o`00003oo`3ooolQ
0?ooo`00;P3oool2000002d0oooo0`0000040?ooo`800000:@3oool5000000<0oooo0P00000[0?oo
o`<00000103oool2000002/0oooo0`0000030?ooo`800000803oool002d0oooo00@000000?ooo`3o
ool00000;@3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000002T0oooo00@00000
0?ooo`3oool000000P3oool010000000oooo0?ooo`00000Y0?ooo`050000003oool0oooo0?ooo`00
00000P3oool010000000oooo0?ooo`00000[0?ooo`050000003oool0oooo0?ooo`0000000P3oool0
0`000000oooo0?ooo`0M0?ooo`00;@3oool010000000oooo0?ooo`00000]0?ooo`030000003oool0
oooo0080oooo00@000000?ooo`3oool00000:P3oool00`000000oooo0?ooo`020?ooo`040000003o
ool0oooo000002d0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`0V0?ooo`D0
00000P3oool010000000oooo0?ooo`00000O0?ooo`00;@3oool010000000oooo0?ooo`00000]0?oo
o`030000003oool0oooo0080oooo00@000000?ooo`3oool00000:`3oool01@000000oooo0?ooo`3o
ool000000080oooo00<000000?ooo`3oool0:@3oool2000000<0oooo00@000000?ooo`3oool00000
:03oool010000000oooo0?ooo`0000030?ooo`040000003oool0oooo000001l0oooo000]0?ooo`04
0000003oool0oooo000002d0oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`00000X
0?ooo`050000003oool0oooo0?ooo`0000000P3oool010000000oooo0?ooo`00000]0?ooo`040000
003oool0oooo00000080oooo00<000000?ooo`3oool09`3oool00`000000oooo000000030?ooo`04
0000003oool0oooo000001l0oooo000]0?ooo`040000003oool0oooo000002`0oooo0P0000040?oo
o`040000003oool0oooo000002P0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003o
ool0oooo000002T0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo0000
02X0oooo0P0000030?ooo`040000003oool0oooo000001l0oooo000^0?ooo`800000;P3oool00`00
0000oooo0?ooo`030?ooo`800000:P3oool3000000@0oooo0P00000[0?ooo`<00000103oool20000
02`0oooo00<000000?ooo`3oool00P3oool200000200oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooob40oooo003o0?ooob40oooo000Y0?oooo<00000103oool00280oooo0P0000050?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00P0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`080?ooo`03
0000003oool0oooo0080oooo000Q0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool0k`3oool00`000000oooo0?ooo`020?ooo`008@3oool010000000oooo0?ooo`0000040?ooo`80
0000a@3ooolW000000<0oooo0P0000040?ooo`008@3oool010000000oooo0?ooo`0000040?ooo`03
0000003oool0oooo0;T0oooo2`00000[0?ooo`030000003oool0oooo0080oooo000Q0?ooo`040000
003oool0oooo000000@0oooo00<000000?ooo`3oool0]03oool5000003H0oooo00<000000?ooo`3o
ool00P3oool00240oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`2_0?ooo`D0
0000>`3oool00`000000oooo0?ooo`020?ooo`008P3oool2000000D0oooo00<000000?ooo`3oool0
Z`3oool400000400oooo00<000000?ooo`3oool00P3oool002T0oooo00<000000?ooo`3oool0Z03o
ool3000004@0oooo00<000000?ooo`3oool00P3oool002T0oooo00<000000?ooo`3oool0YP3oool2
000004L0oooo00<000000?ooo`3oool00P3oool002T0oooo0P00002V0?ooo`030000003oool0oooo
04H0oooo0P0000040?ooo`00:@3oool00`000000oooo0?ooo`2T0?ooo`030000003oool0oooo04P0
oooo00<000000?ooo`3oool00P3oool002T0oooo00<000000?ooo`3oool0X`3oool00`000000oooo
0?ooo`190?ooo`030000003oool0oooo0080oooo000Y0?ooo`030000003oool0oooo0:40oooo0P00
001<0?ooo`030000003oool0oooo0080oooo000Y0?ooo`030000003oool0oooo0:00oooo00<00000
0?ooo`3oool0C03oool00`000000oooo0?ooo`020?ooo`00:@3oool00`000000oooo0?ooo`2O0?oo
o`030000003oool0oooo04d0oooo00<000000?ooo`3oool00P3oool002T0oooo0P00002O0?ooo`03
0000003oool0oooo04d0oooo0P0000040?ooo`00:@3oool00`000000oooo0?ooo`2M0?ooo`030000
003oool0oooo04l0oooo00<000000?ooo`3oool00P3oool002T0oooo00<000000?ooo`3oool0W@3o
ool00`000000oooo0?ooo`1?0?ooo`030000003oool0oooo0080oooo000Y0?ooo`030000003oool0
oooo09`0oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`020?ooo`00:@3oool00`00
0000oooo0?ooo`2K0?ooo`030000003oool0oooo0540oooo00<000000?ooo`3oool00P3oool002T0
oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`1B0?ooo`030000003oool0oooo0080
oooo000Y0?ooo`030000003oool0oooo09T0oooo00<000000?ooo`3oool0D`3oool00`000000oooo
0?ooo`020?ooo`00:@3oool2000009T0oooo00<000000?ooo`3oool0D`3oool2000000@0oooo000Y
0?ooo`030000003oool0oooo09L0oooo00<000000?ooo`3oool0E@3oool00`000000oooo0?ooo`02
0?ooo`00:@3oool00`000000oooo0?ooo`2G0?ooo`030000003oool0oooo05D0oooo00<000000?oo
o`3oool00P3oool002T0oooo00<000000?ooo`3oool0UP3oool00`000000oooo0?ooo`1F0?ooo`03
0000003oool0oooo0080oooo000Y0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool0
EP3oool00`000000oooo0?ooo`020?ooo`00:@3oool00`000000oooo0?ooo`2E0?ooo`030000003o
ool0oooo05L0oooo00<000000?ooo`3oool00P3oool002T0oooo0P00002F0?ooo`030000003oool0
oooo05H0oooo0P0000040?ooo`00:@3oool00`000000oooo0?ooo`2D0?ooo`030000003oool0oooo
05P0oooo00<000000?ooo`3oool00P3oool002T0oooo00<000000?ooo`3oool0U03oool00`000000
oooo0?ooo`1H0?ooo`030000003oool0oooo0080oooo000Y0?ooo`030000003oool0oooo09<0oooo
00<000000?ooo`3oool0F@3oool00`000000oooo0?ooo`020?ooo`00103oool2000000@0oooo00<0
00000?ooo`3oool00`3oool2000000@0oooo0P0000040?ooo`8000000`3oool3000000D0oooo00<0
00000?ooo`3oool0T`3oool00`000000oooo0?ooo`1I0?ooo`030000003oool0oooo0080oooo0003
0?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<000000?ooo`3oool0103oool00`00
0000oooo0?ooo`2B0?ooo`030000003oool0oooo05X0oooo00<000000?ooo`3oool00P3oool000<0
oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0980oooo00<000000?ooo`3oool0FP3oool00`000000oooo0?ooo`020?ooo`000`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000030?ooo`030000003oool0oooo00@0oooo0P00002B
0?ooo`030000003oool0oooo05X0oooo0P0000040?ooo`000`3oool010000000oooo0?ooo`000008
0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000030?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0T@3oool00`000000
oooo0?ooo`1K0?ooo`030000003oool0oooo0080oooo00030?ooo`040000003oool0oooo000000P0
oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0
oooo00000080oooo0P0000060?ooo`030000003oool0oooo0900oooo00<000000?ooo`3oool0G03o
ool00`000000oooo0?ooo`020?ooo`00103oool2000000X0oooo0P0000040?ooo`800000103oool2
000000@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`2@0?ooo`030000003oool0
oooo05`0oooo00<000000?ooo`3oool00P3oool002T0oooo00<000000?ooo`3oool0S`3oool00`00
0000oooo0?ooo`1M0?ooo`030000003oool0oooo0080oooo000Y0?ooo`030000003oool0oooo08l0
oooo00<000000?ooo`3oool0G@3oool00`000000oooo0?ooo`020?ooo`00:@3oool200000900oooo
00<000000?ooo`3oool0G03oool2000000@0oooo000Y0?ooo`030000003oool0oooo08h0oooo00<0
00000?ooo`3oool0GP3oool00`000000oooo0?ooo`020?ooo`00:@3oool00`000000oooo0?ooo`2>
0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool00P3oool002T0oooo00<000000?oo
o`3oool0S@3oool00`000000oooo0?ooo`1O0?ooo`030000003oool0oooo0080oooo000Y0?ooo`03
0000003oool0oooo08d0oooo00<000000?ooo`3oool0G`3oool00`000000oooo0?ooo`020?ooo`00
:@3oool00`000000oooo0?ooo`2<0?ooo`030000003oool0oooo0600oooo00<000000?ooo`3oool0
0P3oool002T0oooo00<000000?ooo`3oool0S03oool00`000000oooo0?ooo`1P0?ooo`030000003o
ool0oooo0080oooo000Y0?ooo`800000S@3oool00`000000oooo0?ooo`1O0?ooo`800000103oool0
02T0oooo00<000000?ooo`3oool0R`3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0oooo
0080oooo000Y0?ooo`030000003oool0oooo08/0oooo00<000000?ooo`3oool0H@3oool00`000000
oooo0?ooo`020?ooo`00:@3oool00`000000oooo0?ooo`2:0?ooo`030000003oool0oooo0680oooo
00<000000?ooo`3oool00P3oool002T0oooo00<000000?ooo`3oool0RP3oool00`000000oooo0?oo
o`1R0?ooo`030000003oool0oooo0080oooo000Y0?ooo`030000003oool0oooo08X0oooo00<00000
0?ooo`3oool0HP3oool00`000000oooo0?ooo`020?ooo`00:@3oool2000008X0oooo00<000000?oo
o`3oool0HP3oool2000000@0oooo000Y0?ooo`030000003oool0oooo08T0oooo00<000000?ooo`3o
ool0H`3oool00`000000oooo0?ooo`020?ooo`00:@3oool00`000000oooo0?ooo`290?ooo`030000
003oool0oooo06<0oooo00<000000?ooo`3oool00P3oool002T0oooo00<000000?ooo`3oool0R03o
ool00`000000oooo0?ooo`1T0?ooo`030000003oool0oooo0080oooo000Y0?ooo`030000003oool0
oooo08P0oooo00<000000?ooo`3oool0I03oool00`000000oooo0?ooo`020?ooo`00:@3oool00`00
0000oooo0?ooo`270?ooo`030000003oool0oooo06D0oooo00<000000?ooo`3oool00P3oool002T0
oooo00<000000?ooo`3oool0Q`3oool00`000000oooo0?ooo`1U0?ooo`030000003oool0oooo0080
oooo000Y0?ooo`800000R03oool00`000000oooo0?ooo`1T0?ooo`800000103oool002T0oooo00<0
00000?ooo`3oool0QP3oool00`000000oooo0?ooo`1V0?ooo`030000003oool0oooo0080oooo000Y
0?ooo`030000003oool0oooo08H0oooo00<000000?ooo`3oool0IP3oool00`000000oooo0?ooo`02
0?ooo`00:@3oool00`000000oooo0?ooo`250?ooo`030000003oool0oooo06L0oooo00<000000?oo
o`3oool00P3oool000@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`80
0000103oool200000080oooo1@0000040?ooo`030000003oool0oooo08D0oooo00<000000?ooo`3o
ool0I`3oool00`000000oooo0?ooo`020?ooo`000`3oool010000000oooo0?ooo`0000080?ooo`04
0000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool0Q@3oool00`000000oooo
0?ooo`1W0?ooo`030000003oool0oooo0080oooo00030?ooo`040000003oool0oooo000000P0oooo
00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
000000<0oooo00<000000?ooo`3oool0103oool2000008D0oooo00<000000?ooo`3oool0I`3oool2
000000@0oooo00030?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool000000P3o
ool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`240?ooo`030000003oool0oooo06P0oooo00<000000?ooo`3o
ool00P3oool000<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool0Q03oool00`000000oooo0?ooo`1X0?ooo`030000
003oool0oooo0080oooo00030?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0J@3o
ool00`000000oooo0?ooo`020?ooo`00103oool2000000X0oooo0P0000040?ooo`800000103oool2
000000<0oooo0`0000050?ooo`030000003oool0oooo08<0oooo00<000000?ooo`3oool0J@3oool0
0`000000oooo0?ooo`020?ooo`00:@3oool00`000000oooo0?ooo`220?ooo`030000003oool0oooo
06X0oooo00<000000?ooo`3oool00P3oool002T0oooo00<000000?ooo`3oool0PP3oool00`000000
oooo0?ooo`1Z0?ooo`030000003oool0oooo0080oooo000Y0?ooo`800000P`3oool00`000000oooo
0?ooo`1Y0?ooo`800000103oool002T0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?oo
o`1[0?ooo`030000003oool0oooo0080oooo000Y0?ooo`030000003oool0oooo0840oooo00<00000
0?ooo`3oool0J`3oool00`000000oooo0?ooo`020?ooo`00:@3oool00`000000oooo0?ooo`210?oo
o`030000003oool0oooo06/0oooo00<000000?ooo`3oool00P3oool002T0oooo00<000000?ooo`3o
ool0P03oool00`000000oooo0?ooo`1/0?ooo`030000003oool0oooo0080oooo000Y0?ooo`030000
003oool0oooo0800oooo00<000000?ooo`3oool0K03oool00`000000oooo0?ooo`020?ooo`00:@3o
ool00`000000oooo0?ooo`200?ooo`030000003oool0oooo06`0oooo00<000000?ooo`3oool00P3o
ool002T0oooo0P0000200?ooo`030000003oool0oooo06`0oooo0P0000040?ooo`00:@3oool00`00
0000oooo0?ooo`1o0?ooo`030000003oool0oooo06d0oooo00<000000?ooo`3oool00P3oool002T0
oooo00<000000?ooo`3oool0O`3oool00`000000oooo0?ooo`1]0?ooo`030000003oool0oooo0080
oooo000Y0?ooo`030000003oool0oooo07h0oooo00<000000?ooo`3oool0KP3oool00`000000oooo
0?ooo`020?ooo`00:@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo06h0oooo00<0
00000?ooo`3oool00P3oool002T0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`1_
0?ooo`030000003oool0oooo0080oooo000Y0?ooo`800000OP3oool00`000000oooo0?ooo`1^0?oo
o`800000103oool002T0oooo00<000000?ooo`3oool0O@3oool00`000000oooo0?ooo`1_0?ooo`03
0000003oool0oooo0080oooo000Y0?ooo`030000003oool0oooo07`0oooo00<000000?ooo`3oool0
L03oool00`000000oooo0?ooo`020?ooo`00:@3oool00`000000oooo0?ooo`1l0?ooo`030000003o
ool0oooo0700oooo00<000000?ooo`3oool00P3oool002T0oooo00<000000?ooo`3oool0N`3oool0
0`000000oooo0?ooo`1a0?ooo`030000003oool0oooo0080oooo000Y0?ooo`030000003oool0oooo
07/0oooo00<000000?ooo`3oool0L@3oool00`000000oooo0?ooo`020?ooo`00:@3oool00`000000
oooo0?ooo`1j0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool00P3oool002T0oooo
0P00001k0?ooo`030000003oool0oooo0740oooo0P0000040?ooo`00:@3oool00`000000oooo0?oo
o`1j0?ooo`030000003oool0oooo0780oooo00<000000?ooo`3oool00P3oool002T0oooo00<00000
0?ooo`3oool0N@3oool00`000000oooo0?ooo`1c0?ooo`030000003oool0oooo0080oooo000Y0?oo
o`030000003oool0oooo00<0oooo1000001b0?ooo`030000003oool0oooo07<0oooo00<000000?oo
o`3oool00P3oool000@0oooo0P0000040?ooo`030000003oool0oooo00<0oooo0P0000040?ooo`80
0000103oool2000000<0oooo0`0000050?ooo`030000003oool0oooo00L0oooo0`00001^0?ooo`03
0000003oool0oooo07@0oooo00<000000?ooo`3oool00P3oool000<0oooo00@000000?ooo`3oool0
0000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00H00000
0?ooo`3oool000000?ooo`0000030?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
2P3oool3000006/0oooo00<000000?ooo`3oool0M03oool00`000000oooo0?ooo`020?ooo`000`3o
ool010000000oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo0P00000>
0?ooo`800000J03oool00`000000oooo0?ooo`1d0?ooo`800000103oool000<0oooo00@000000?oo
o`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo
00@000000?ooo`3oool000000`3oool2000000D0oooo00<000000?ooo`3oool03`3oool2000006H0
oooo00<000000?ooo`3oool0M@3oool00`000000oooo0?ooo`020?ooo`000`3oool010000000oooo
0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool0
10000000oooo0?ooo`0000050?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool04@3o
ool00`000000oooo0?ooo`1R0?ooo`030000003oool0oooo07H0oooo00<000000?ooo`3oool00P3o
ool000<0oooo00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000
003oool0oooo00000080oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`030000003oool0
oooo0080oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`1Q0?ooo`030000003oool0
oooo07H0oooo00<000000?ooo`3oool00P3oool000@0oooo0P00000:0?ooo`800000103oool20000
00@0oooo0P0000030?ooo`<000001@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo
0600oooo00<000000?ooo`3oool0MP3oool00`000000oooo0?ooo`020?ooo`00:@3oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo05h0oooo00<000000?ooo`3oool0M`3oool00`000000
oooo0?ooo`020?ooo`00:@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo05d0oooo
00<000000?ooo`3oool0M`3oool00`000000oooo0?ooo`020?ooo`00:@3oool2000001L0oooo00<0
00000?ooo`3oool0F`3oool00`000000oooo0?ooo`1g0?ooo`800000103oool002T0oooo00<00000
0?ooo`3oool05`3oool00`000000oooo0?ooo`1J0?ooo`030000003oool0oooo07P0oooo00<00000
0?ooo`3oool00P3oool002T0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`1I0?oo
o`030000003oool0oooo07T0oooo00<000000?ooo`3oool00P3oool002T0oooo00<000000?ooo`3o
ool0603oool00`000000oooo0?ooo`1G0?ooo`030000003oool0oooo07X0oooo00<000000?ooo`3o
ool00P3oool002T0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`1F0?ooo`030000
003oool0oooo07X0oooo00<000000?ooo`3oool00P3oool002T0oooo00<000000?ooo`3oool06P3o
ool00`000000oooo0?ooo`1D0?ooo`030000003oool0oooo07/0oooo00<000000?ooo`3oool00P3o
ool002T0oooo0P00000L0?ooo`030000003oool0oooo05<0oooo00<000000?ooo`3oool0NP3oool2
000000@0oooo000Y0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`3oool0D@3oool00`00
0000oooo0?ooo`1l0?ooo`030000003oool0oooo0080oooo000Y0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0D03oool00`000000oooo0?ooo`1m0?ooo`030000003oool0oooo0080
oooo000Y0?ooo`030000003oool0oooo01d0oooo00<000000?ooo`3oool0C`3oool00`000000oooo
0?ooo`1m0?ooo`030000003oool0oooo0080oooo000Y0?ooo`030000003oool0oooo01h0oooo00<0
00000?ooo`3oool0C@3oool00`000000oooo0?ooo`1n0?ooo`030000003oool0oooo0080oooo000Y
0?ooo`030000003oool0oooo01l0oooo00<000000?ooo`3oool0C03oool00`000000oooo0?ooo`1n
0?ooo`030000003oool0oooo0080oooo000Y0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0BP3oool00`000000oooo0?ooo`1o0?ooo`030000003oool0oooo0080oooo000Y0?ooo`80
00008P3oool00`000000oooo0?ooo`180?ooo`030000003oool0oooo07l0oooo0P0000040?ooo`00
:@3oool00`000000oooo0?ooo`0R0?ooo`030000003oool0oooo04L0oooo00<000000?ooo`3oool0
P03oool00`000000oooo0?ooo`020?ooo`00:@3oool00`000000oooo0?ooo`0S0?ooo`030000003o
ool0oooo04D0oooo00<000000?ooo`3oool0P@3oool00`000000oooo0?ooo`020?ooo`00:@3oool0
0`000000oooo0?ooo`0T0?ooo`030000003oool0oooo04@0oooo00<000000?ooo`3oool0P@3oool0
0`000000oooo0?ooo`020?ooo`00:@3oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo
0480oooo00<000000?ooo`3oool0PP3oool00`000000oooo0?ooo`020?ooo`00:@3oool00`000000
oooo0?ooo`0V0?ooo`030000003oool0oooo0400oooo00<000000?ooo`3oool0P`3oool00`000000
oooo0?ooo`020?ooo`00:@3oool2000002P0oooo00<000000?ooo`3oool0?`3oool00`000000oooo
0?ooo`220?ooo`800000103oool002T0oooo00<000000?ooo`3oool0:03oool00`000000oooo0?oo
o`0m0?ooo`030000003oool0oooo08@0oooo00<000000?ooo`3oool00P3oool002T0oooo00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0k0?ooo`030000003oool0oooo08D0oooo00<00000
0?ooo`3oool00P3oool002T0oooo00<000000?ooo`3oool0:P3oool00`000000oooo0?ooo`0i0?oo
o`030000003oool0oooo08H0oooo00<000000?ooo`3oool00P3oool000@0oooo0P0000040?ooo`03
0000003oool0oooo00<0oooo0P0000040?ooo`800000103oool2000000@0oooo0`0000040?ooo`03
0000003oool0oooo02/0oooo00<000000?ooo`3oool0=`3oool00`000000oooo0?ooo`270?ooo`03
0000003oool0oooo0080oooo00030?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3o
ool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000@0oooo00<0
00000?ooo`3oool00`3oool00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0R03oool00`000000oooo0?ooo`020?ooo`000`3oool010000000oooo0?ooo`00
00080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01@000000
oooo0?ooo`000000oooo00D00000103oool00`000000oooo0?ooo`0]0?ooo`030000003oool0oooo
03<0oooo00<000000?ooo`3oool0R@3oool00`000000oooo0?ooo`020?ooo`000`3oool010000000
oooo0?ooo`0000080?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3o
ool01P000000oooo0?ooo`000000oooo00000080oooo00<000000?ooo`3oool00`3oool2000002l0
oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`290?ooo`800000103oool000<0oooo
00@000000?ooo`3oool00000203oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo
00000080oooo00@000000?ooo`3oool000000P3oool00`000000oooo000000050?ooo`030000003o
ool0oooo02l0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2;0?ooo`030000003o
ool0oooo0080oooo00030?ooo`040000003oool0oooo000000P0oooo00@000000?ooo`3oool00000
0P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo0P0000050?oo
o`030000003oool0oooo0300oooo00<000000?ooo`3oool0;@3oool00`000000oooo0?ooo`2<0?oo
o`030000003oool0oooo0080oooo00040?ooo`8000002P3oool2000000@0oooo0P0000040?ooo`80
00001@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0340oooo0P00000[0?ooo`80
0000S`3oool00`000000oooo0?ooo`020?ooo`00:@3oool00`000000oooo0?ooo`0c0?ooo`800000
:03oool00`000000oooo0?ooo`2?0?ooo`030000003oool0oooo0080oooo000Y0?ooo`030000003o
ool0oooo03D0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`2@0?ooo`030000003o
ool0oooo0080oooo000Y0?ooo`800000=`3oool2000002<0oooo00<000000?ooo`3oool0T03oool2
000000@0oooo000Y0?ooo`030000003oool0oooo03P0oooo0P00000O0?ooo`800000U03oool00`00
0000oooo0?ooo`020?ooo`00:@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo01X0
oooo0P00002F0?ooo`030000003oool0oooo0080oooo000Y0?ooo`030000003oool0oooo03/0oooo
0P00000I0?ooo`030000003oool0oooo09H0oooo00<000000?ooo`3oool00P3oool002T0oooo00<0
00000?ooo`3oool0?@3oool3000001<0oooo0`00002I0?ooo`030000003oool0oooo0080oooo000Y
0?ooo`030000003oool0oooo0400oooo100000090?ooo`H00000W03oool00`000000oooo0?ooo`02
0?ooo`00:@3oool00`000000oooo0?ooo`140?ooo`T00000XP3oool00`000000oooo0?ooo`020?oo
o`00:@3oool200000>l0oooo0P0000040?ooo`00:@3oool00`000000oooo0?ooo`030?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`0a0?ooo`030000
003oool0oooo0300oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`020?ooo`00:@3o
oooc000000@0oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo003o0?ooob40oooo
003o0?ooo`8000003P3oool2000000l0oooo003o0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool03@3oool002`0oooo00<000000?ooo`3oool00P3oool300000080oooo0`0000050?oo
o`8000000P3oool500000080oooo0`0000030?ooo`@0000000<0oooo0000000000000`0000080?oo
o`<00000103oool2000000030?ooo`00000000000080000000@0oooo000000000000oooo0`000009
0?ooo`<000000P3oool;000000030?ooo`000000000000<000000`3oool2000000X0oooo00@00000
0?ooo`3oool0oooo100000080?ooo`<0000000@0oooo000000000000oooo0`0000020?ooo`<00000
0`3oool5000000030?ooo`000000000000<000000`3oool00`000000oooo0?ooo`070?ooo`<00000
103oool300000080oooo100000040?ooo`030000003oool0oooo00X0oooo00h000000?ooo`3oool0
00000?ooo`000000oooo0000003oool000000?ooo`000000oooo000000<0oooo00<000000?ooo`3o
ool03@3oool002`0oooo00D000000?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00<00000
0?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<00000
0?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool0
0000303oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000<0oooo00<00000
0?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`040000003oool0oooo000000T0oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`060000003oool0oooo0000003oool0
00000`3oool010000000oooo0?ooo`0000060?ooo`030000003oool0oooo0080oooo00@000000?oo
o`3oool000003P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001@3o
ool00`000000oooo0?ooo`0>0?ooo`0>0000003oool0oooo0000003oool000000?ooo`000000oooo
0000003oool000000?ooo`0000030?ooo`030000003oool0oooo00d0oooo000/0?ooo`040000003o
ool0oooo0?ooo`D000000P3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo
00D000000?ooo`3oool0oooo000000060?ooo`<00000103oool00`000000oooo0?ooo`090?ooo`03
0000003oool0oooo0080oooo00@000000?ooo`3oool000000P3oool01@000000oooo0?ooo`000000
oooo00D000002`3oool010000000oooo0?ooo`0000020?ooo`050000003oool0oooo0?ooo`000000
1@3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0oooo00<000000?ooo`000000
0`3oool3000000T0oooo00H000000?ooo`3oool000000?ooo`0000030?ooo`040000003oool0oooo
000000H0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0080oooo00D000000?ooo`3oool0oooo000000020?ooo`<000004@3oool03P000000oooo0?oo
o`000000oooo0000003oool000000?ooo`000000oooo0000003oool000000`3oool00`000000oooo
0?ooo`0=0?ooo`00:`3oool00`000000oooo000000020?ooo`050000003oool0oooo0?ooo`000000
0P3oool2000000@0oooo00<000000?ooo`3oool0103oool01@000000oooo0?ooo`3oool0000000<0
oooo00<000000?ooo`0000000P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool00P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo
0000003oool000000`3oool00`000000oooo0?ooo`070?ooo`8000000`3oool010000000oooo0?oo
o`0000030?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`090?ooo`030000003oool000000080oooo00<000000?ooo`3oool02P3oool4000000030?oo
o`000000oooo0080oooo00<000000?ooo`3oool00P0000050?ooo`050000003oool0oooo0?ooo`00
00000P3oool00`000000oooo0?ooo`0=0?ooo`<000000P3oool01`000000oooo0?ooo`3oool00000
0?ooo`000000503oool03P000000oooo0?ooo`000000oooo0000003oool000000?ooo`000000oooo
0000003oool000000`3oool00`000000oooo0?ooo`0=0?ooo`00:`3oool00`000000oooo00000003
0?ooo`<000000P3oool2000000040?ooo`00000000000?ooo`@000000P3oool3000000@0oooo0`00
00030?ooo`8000001@3oool00`000000oooo0?ooo`070?ooo`060000003oool000000?ooo`000000
oooo0P000000103oool000000000003oool4000000<0oooo0`0000090?ooo`030000003oool0oooo
00<0oooo0`0000020?ooo`<00000103oool4000000030?ooo`000000000000800000203oool20000
00030?ooo`00000000000080oooo100000080?ooo`040000003oool0oooo00000080oooo0`000002
0?ooo`80000000@0oooo000000000000oooo0`0000030?ooo`D000003P3oool010000000oooo0?oo
o`0000020?ooo`<000000`3oool400000100oooo00<000000?ooo`3oool00P000000103oool00000
0?ooo`3oool2000000030?ooo`000000oooo00<0oooo00<000000?ooo`3oool03@3oool002/0oooo
00<000000?ooo`0000003`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00L0oooo
00D000000?ooo`000000oooo0000000J0?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool02P3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo01/0oooo00@000000?oo
o`3oool000009P3oool010000000oooo0?ooo`00000L0?ooo`8000003P3oool2000000l0oooo000Z
0?ooo`D000003P3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00d0oooo0`000009
0?ooo`D000006`3oool3000000030?ooo`000000000000H0oooo00<000000?ooo`3oool0103oool2
00000080oooo00<000000?ooo`3oool06P3oool3000000030?ooo`000000000000h0oooo00<00000
0?ooo`3oool04`3oool4000003h0oooo003o0?ooob40oooo003o0?ooob40oooo0000\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-9.18359, -4.77224*^-5, \
0.194844, 3.06086*^-6}}]
}, Open  ]],

Cell[BoxData[{
    \( (*\ 
      Only\ works\ with\ Mathematica\ 4.0\ or\ later\ \ *) \
\[IndentingNewLine] (*\ 
      file\ is\ saved\ by\ default\ in\ the\ Mathematica\ folder\ *) \
\[IndentingNewLine]\[IndentingNewLine]\(Export["\<TuneX.dat\>", 
        dnx, "\<Table\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<TuneZ.dat\>", dnz, "\<Table\>"];\)\)}], "Input"],

Cell["Plot the potential of focusing vs x and z (see ref[2])", "Text"],

Cell[BoxData[
    \(\(Plot3D[
        pot[g, {x, z}, per, len], {x, \(-40\), 40}, {z, \(-5\), 
          5}, \[IndentingNewLine]AxesLabel \[Rule] {"\<X[mm]\>", "\<Z[mm]\>", \
"\<  [T2mm3]\>"}, \[IndentingNewLine]BoxRatios \[Rule] {40, 20, 
            10}, \[IndentingNewLine]PlotLabel \[Rule] "\<Potential of \
Focusing\>"];\)\)], "Input"],

Cell["\<\
Plot the horizontal angular kick induced to the beam as a function \
of thetransverse  injection cordinates x and z  (see ref[2])\
\>", "Text"],

Cell[BoxData[
    \(Plot3D[
      angx[g, {x, z}, per, len, ener], {x, \(-40\), 40}, {z, \(-5\), 
        5}]\)], "Input"],

Cell["\<\
Plot the vertical angular kick induced to the beam as a function of \
thetransverse  injection cordinates x and z  (see ref[2])\
\>", "Text"],

Cell[BoxData[
    \(\(Plot3D[
        angz[g, {x, z}, per, len, ener], {x, \(-40\), 40}, {z, \(-5\), 
          5}];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Generating an Undulator  Map File  ", "Section"],

Cell["\<\
An undulator (or wiggler)  must be created before executing any \
cell of this section. It is also a good strategy to check that the undulator \
has the desired geometry and that it is producing the correct field using the \
two previous sections before creating the tracking file. \
\>", "Text"],

Cell[CellGroupData[{

Cell["Important Informations ", "Subsection"],

Cell[TextData[{
  StyleBox["Description of the physics  ",
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "\nIn the map file, the undulator is replaced by a  length and the \
integrated horizontal and vertical angular kick ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_x\)]],
  "(x,z,\[Gamma]) and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_z\)]],
  "(x,z,\[Gamma]) which depend on the  transverse coordinates x and z and the \
normalized electron energy \[Gamma] = Total energy / m",
  Cell[BoxData[
      \(TraditionalForm\`c\^2\)]],
  ". Within some conditions of regularity concerning the simple and double \
field integrals (see ref[2]), the kicks can be expressed as :\n",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_x\)]],
  "(x,z,\[Gamma]) =-",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((e/\@\(\[Gamma]\^2 - 1\) mc)\)\^2\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_x\ \[CapitalPsi]\)]],
  "(x,z)+o",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Gamma]\^2 - 1)\)\^\(-6\)\)]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_z\)]],
  "(x,z,\[Gamma]) =-",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((e/\@\(\[Gamma]\^2 - 1\) mc)\)\^2\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_z\ \[CapitalPsi]\)]],
  "(x,z)+o",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Gamma]\^2 - 1)\)\^\(-6\)\)]],
  "\nwhere e and m are the charge and mass of the electron, o(x) is a small \
quantity  compared to x  and \[CapitalPsi](x,z) is a potential which is \
expressed as :\n\[CapitalPsi](x,z)=",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\(+\[Infinity]\)\((\
\[Integral]\_\(-\[Infinity]\)\%u\(\( B\_x\)(x, z, s)\) \
\[DifferentialD]s)\)\^2 + \(\((\[Integral]\_\(-\[Infinity]\)\%u\(\( B\_z\)(x, 
                      z, 
                      s)\) \[DifferentialD]s)\)\^2\) \[DifferentialD]u\)]],
  "\nwhere ",
  Cell[BoxData[
      \(TraditionalForm\`\(B\_x\)(x, z, s)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(B\_z\)(x, z, s)\)]],
  " are the horizontal and vertical fields of the undulator at the point of \
coordinate (x,z,s). s is the longitudinal coordinate along the axis of the \
undulator while x and z are the transverse horizontal and vertical \
coordinates. As a result, the rather complicated 3D magnetic field of the \
undulator is simplified into a two dimensionnal potential function  \
\[CapitalPsi](x,z). To maintain precision during the tracking and allow a \
more immediate interpretation of the file, ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_x\ \[CapitalPsi]\)]],
  "(x,z) and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_z\ \[CapitalPsi]\)]],
  "(x,z) are computed and output in the map file (rather \
than\[CapitalPsi](x,z) ) in the form of two tables for values of x and z \
equally spaced horizontally and vertically.  For any particle injected at a \
point x and z which is not on the grid, the tracking code must  interpolate \
with the adjacent nodes of the grid. To restore the thick nature of the \
undulator, the tracking code must  split the table into a number of thin \
elements regularly spaced along the undulator in the form of a sequence of \
drifts and thin elements. Such a scheme maintains the symplecticity of the \
tracking. The splitting into a number of thin elements is, in practice, only \
necessary when the horizontal or the vertical beta functions are smaller than \
the undulator length. \nIn the particular case of a  periodic magnetic field \
, the field can be expanded into Fourier series :\n",
  Cell[BoxData[
      \(TraditionalForm\`B\_x\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(n = 1\)\%\[Infinity] B\_\(x, n\)\)]],
  "sin(2n\[Pi]s/",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_0\)]],
  ")\n",
  Cell[BoxData[
      \(TraditionalForm\`B\_z\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(n = 1\)\%\[Infinity] B\_\(z, n\)\)]],
  "sin(2n\[Pi]s/",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_0\)]],
  "+\[CurlyPhi])\nwhere ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\_0\)]],
  " is the undulator period. The  potential becomes :\n\[CapitalPsi](x,z) = \
",
  Cell[BoxData[
      FormBox[
        FractionBox[
          RowBox[{"N", 
            FormBox[\(\[Lambda]\_0\^3\),
              "TraditionalForm"]}], \(\(\ \)\(8  \[Pi]\^2\)\)], 
        TraditionalForm]]],
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(n = 1\)\%\[Infinity]\( B\_\(x, n\)\%2 + \
B\_\(z, n\)\%2\)\/n\^2\)]],
  "\nwhere N is the number of periods and  ",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(x, n\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(z, n\)\)]],
  " depend on the transverse coordinates x and z. \nIn the large majority of \
undulators, the field is close to  sinusoidal with ",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(x, 1\)\)]],
  ">>",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(x, n\)\)]],
  " and  ",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(z, 1\)\)]],
  ">>",
  Cell[BoxData[
      \(TraditionalForm\`B\_\(z, n\)\)]],
  "  for n>1. As a result , the potential can be approximated as : \n\
\[CapitalPsi](x,z) = ",
  Cell[BoxData[
      FormBox[
        FractionBox[
          RowBox[{"N", 
            FormBox[\(\[Lambda]\_0\^3\),
              "TraditionalForm"]}], \(8  \[Pi]\^2\)], TraditionalForm]]],
  Cell[BoxData[
      \(TraditionalForm\`\((B\_\(x, 1\)\%2 + B\_\(z, 1\)\%2)\)\)]],
  ".\nTo speed up the computation, we use the latter expression for the \
potential in this note book. It is defined in the  function pot[]. Note that \
if  a more precise result is wanted, one  needs to modify pot[] to include \
more harmonics. \n",
  StyleBox["Format of the map file",
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "\nThe map file  is a text file that is best edited in a text editor or a \
spreadsheet software (such as Microsoft Excel, open in space delimited text \
file). Any line starting with a \"#\" is a comment. The first line without \
comment contains the undulator length in mm,  the next two lines give the \
total number of horizontal points and vertical points of the tables. Two \
groups of lines follow, each starting with a \"START\" marker. They \
correspond to the - ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_x\ \[CapitalPsi]\)]],
  "(x,z)  and   ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_z\ \[CapitalPsi]\)]],
  "(x,z)  tables. In each group, the first line lists the values of the \
horizontal coordinates of the grid  in mm (which must be equally spaced). \
Each value of the line is separated by one or several spaces. The next lines \
start with the vertical position of the grid in m followed by the values of - \
",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_x\ \[CapitalPsi]\)]],
  "(x,z)   or - ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_z\ \[CapitalPsi]\)]],
  "(x,z)   in units of ",
  Cell[BoxData[
      \(TraditionalForm\`T\^2\)]],
  Cell[BoxData[
      \(TraditionalForm\`m\^2\)]],
  ". The real horizontal and vertical angles are obtained by interpolating in \
the table and multiplying by ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[
            FormBox[\(e\^2\),
              "TraditionalForm"], \(\((\[Gamma]\^2 - 1)\) \(m\^2\) c\^2\)], "  ",
           "which", " ", "also", " ", "equal", " ", "to", 
          " ", \(1\/\((B\[Rho])\)\^2\)}], TraditionalForm]]],
  "in the usual limit of high energies.\n",
  StyleBox["Making use of the map file in BETA\n",
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "In the list of elements, an undulator is defined according to :",
  StyleBox["\n",
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  " Name   IT   n1   n2   d\n where Name is a name, n1 is an integer \
specifying the file number in which the tables are to be read (see below), n2 \
is an integer specifying the number of subdivisions into thin lenses within \
the undulator length and d is a real value which defines a scaling on the \
field of the undulator. For example the following line :\n WIG  IT    2   4   \
1.5\n defines an undulator called \"WIG\" the data of which  is in file #2 . \
The data is split into 4 equally spaced thin lenses over the length of the \
undulator (read from the file) and the field will be multiplied by 1.5. \
\"IT\" spcifie that particular type of optical element, others are \"SD\", \
\"QP\",... for straight sections, quadrupoles,...Note that the angular kick \
is proportional to the square of the field divided by the square of the \
electron energy. Therefore a field scaling is equivalent to an energy \
scaling.  In BETA, the undulator is entered as a thin element. This allows \
changing n2 at will without having to append different lengths of drift in \
front and after the undulator. In the tracking the undulator interaction is  \
spread over the length of the undulator, the length being read from the file. \
\nIn the input file of BETA, one must define the correspondance between the \
file numbers and their name on the disk using a sequence like :\n \
_____________________________",
  StyleBox["\n",
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  " *** TABLES ***\n 2\n \
HD3700:Logiciels:Scientifique:Beta:structures:HU88.dat\n \
HD3700:Logiciels:Scientifique:Beta:structures:HU38.dat\n\
_____________________________\n The number \"2\" specifies  the total number \
of available files, the next two lines indicate the full absolute path-name \
of the files. The directory separator depends on the  platform. The example \
given above is that of an input file for a Mac. On Unix, the file  \" \
HD3700:Logiciels:Scientifique:Beta:structures:HU88.dat\" would be named \
something like \" /users/myname/HU88.dat\" . A complete example of BETA input \
file + Undulator map files for an Apple II undulator with three different \
phases is included in the distribution. It should be noted that,  because of \
the absolute addressing of file directories, the directory separator problem  \
and the different format of text files in Mac Windows and Unix, the file \
\"ESRF.str\"  must first be edited and/or converted before being executed \
(see below).",
  StyleBox["\nRemarks",
    FontWeight->"Bold",
    FontVariations->{"Underline"->True}],
  "\nOne should be careful with the parameters dx, xmin,xmax,dz,zmin,zmax \
since they determine the total number of points in the grid  and therefore \
the duration of the computation. A typical step size of 1 mm should be \
adequate in most situations. The criteria for adequacy is the stability of \
the computed dynamic aperture following a refining of the mesh size.  The \
limits xmin, xmax,zmin and zmax should be larger than the dynamic or physical \
aperture of the lattice without undulator.  It is  good practice to first try \
to create the file with a limited number of points and then gradually \
increase it, once it has been checked that the process takes place normally. \
A typical computation time to generate the file can be as long as 15 minutes \
for a vertical field undulator and may be as long as 10 hours for a hybrid \
high field wiggler. At present BETA will only allow a grid with a maximum  \
number of 200 pts horizontal and 50 points vertical. \nFor educational \
purpose, the  user is STRONGLY  invited to open the file newly created with a \
spreadsheet and makes some sort of surface or contour plot of both \
rectangular arrays which are proportionnal to the horizontal and vertical \
angle induced on an electron upon traversing the undulator. The file is of \
ASCII (TEXT) type and therefore should be properly converted (to correctly \
handle linefeed and carriage return ). This is of prime importance if one \
runs ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and the tracking code on two different platforms (Mac, Windows, Unix,..). \
 The new line is coded differently on Mac (carriage-return), Windows \
(line-feed+carriage-return) and UNIX (line-feed). Such a convertion is \
automatically made by transfering the file by FTP in text mode. There exists \
a number of Mac, Windows and Unix utilities to perform such convertions \
(BBEdit on Mac,...). To maximize the compatibility, all text files in this \
distribution are of \"Windows\" type. "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["SPEAR BL11 Wiggler", "Subsection"],

Cell[BoxData[{
    \( (*\ 
      The\ following\ parameters\ are\ those\ used\ to\ generate\ the\ SPEAR \
. dat\ files\ *) \[IndentingNewLine] (*\ 
      the\ wiggler\ must\ have\ been\ generated\ before\ with\ a\ reference\ \
put\ into\ g\ *) \[IndentingNewLine]\[IndentingNewLine] (*___  ___  \
__\ \ Input\ Parameters\ \ \ ___  ___  ___  ___  ___  ___  _*) \
\[IndentingNewLine]\(len = 
        2200;\)\ \ \ \ \ \ \ \  (*\ \ Total\ Undulator\ Length\ in\ [
          mm]\ \ *) \), "\[IndentingNewLine]", 
    \(\(ener = 3;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Electron\ Energy\ in\ [GeV]\ *) \), "\[IndentingNewLine]", 
    \(\(betax = 21;\)\ \ \ \ \ \ \ \ \  (*\ 
      Average\ Horiz . \ Beta\ Function\ *) \), "\[IndentingNewLine]", 
    \(\(betaz = 1.75;\)\ \ \ \  (*\ 
      Average\ Vertic . \ 
          Beta\ Function\ *) \[IndentingNewLine]\[IndentingNewLine] (*\ 
      Parameters\ defining\ the\ range\ and\ step\ over\ which\ the\ kick\ \
tables\ are\ computed\ *) \), "\[IndentingNewLine]", 
    \(\(dx = 1;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Horizontal\ step\ size\ in\ [mm]\ *) \), "\[IndentingNewLine]", 
    \(\(xmin = \(-49\);\)\ \ \ \ \ \ \ \ \ \ \  (*\ 
      Minimum\ horizontal\ position\ in\ [mm]\ *) \), "\[IndentingNewLine]", 
    \(\(xmax = 50;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Maximum\ horizontal\ position\ in\ [mm]\ *) \), "\[IndentingNewLine]", 
    \(\(dz = 1;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Vertical\ step\ size\ in\ [mm]\ *) \), "\[IndentingNewLine]", 
    \(\(zmin = \(-7. \);\)\ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Minimum\ vertical\ position\ in\ [mm]\ *) \), "\[IndentingNewLine]", 
    \(\(zmax = 7. ;\)\ \ \ \ \ \ \ \ \ \ \ \ \ \  (*\ 
      Maximum\ vertical\ position\ in\ [
          mm]\ *) \[IndentingNewLine] (*___  ___  ___  ___  ___  ___  __*) \
\), "\[IndentingNewLine]", 
    \(\(file = "\<SPEAR\>"\ ;\)\ \), "\[IndentingNewLine]", 
    \(\(author = "\<P. Elleaume\>";\)\ \ \ \ \ \), "\[IndentingNewLine]", 
    \(\(comment = "\< .... \>";\)\), "\[IndentingNewLine]", 
    \(\(digit = 8;\)\ \ \ \ \  (*\ 
      number\ of\ digits\ in\ the\ truncation\ of\ real\ numbers\ in\ file*) \
\[IndentingNewLine]\[IndentingNewLine] (*___  ___  ___  ___  ___  _\ \ Start\ \
Computations\ ___  ___  ___  ___  ___  ___  _*) \[IndentingNewLine]\), "\
\[IndentingNewLine]", 
    \(\(t1 = AbsoluteTime[];\)\), "\[IndentingNewLine]", 
    \(\({gx, gz} = maketable[];\)\), "\[IndentingNewLine]", 
    \(\(t2 = AbsoluteTime[];\)\), "\[IndentingNewLine]", 
    \(\(Print[
        t2 - t1, "\< sec\>"];\)\[IndentingNewLine]\[IndentingNewLine] (*\ 
      Only\ works\ with\ Mathematica\ 4.0\ or\ later\ \ *) \
\[IndentingNewLine] (*\ 
      file\ is\ saved\ by\ default\ in\ the\ Mathematica\ folder\ *) \
\[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(\(Export[file <> "\<.dat\>", 
        exportable[author, comment]];\)\)}], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{756, 718},
WindowMargins->{{-9, Automatic}, {-5, Automatic}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
ShowCellLabel->False,
Magnification->1.5,
StyleDefinitions -> "Classroom.nb",
MacintoshSystemPageSetup->"\<\
00<0004/0B`000003;H8`_mooh/=<`Tk0fL5N`?P0080004/0B`000000]P2:001
0000I00000400`<30?l00BL?00400@P3lM0000000000060801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 106, 3, 126, "Title"],
Cell[1826, 54, 665, 18, 213, "Text"],

Cell[CellGroupData[{
Cell[2516, 76, 43, 0, 83, "Section"],
Cell[2562, 78, 3915, 61, 831, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6514, 144, 43, 0, 51, "Section"],
Cell[6560, 146, 672, 13, 189, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[7269, 164, 33, 0, 51, "Section"],

Cell[CellGroupData[{
Cell[7327, 168, 32, 0, 73, "Subsection"],

Cell[CellGroupData[{
Cell[7384, 172, 949, 18, 310, "Input"],
Cell[8336, 192, 220, 4, 105, "Print"],
Cell[8559, 198, 121, 2, 105, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8729, 206, 38, 0, 73, "Subsection"],
Cell[8770, 208, 5145, 100, 910, "Input"],
Cell[13918, 310, 1235, 21, 430, "Input"],
Cell[15156, 333, 1244, 22, 478, "Input"],
Cell[16403, 357, 950, 15, 358, "Input"],
Cell[17356, 374, 1618, 27, 526, "Input"],
Cell[18977, 403, 767, 12, 286, "Input"],
Cell[19747, 417, 485, 9, 214, "Input"],
Cell[20235, 428, 587, 11, 190, "Input"],
Cell[20825, 441, 495, 9, 190, "Input"],
Cell[21323, 452, 2919, 54, 1054, "Input"],
Cell[24245, 508, 2998, 50, 1270, "Input"],
Cell[27246, 560, 1523, 25, 550, "Input"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[28818, 591, 38, 0, 51, "Section"],
Cell[28859, 593, 572, 9, 129, "Text"],

Cell[CellGroupData[{
Cell[29456, 606, 66, 0, 73, "Subsection"],

Cell[CellGroupData[{
Cell[29547, 610, 1657, 34, 526, "Input"],
Cell[31207, 646, 198, 4, 33, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[31454, 656, 67, 0, 73, "Subsection"],

Cell[CellGroupData[{
Cell[31546, 660, 1886, 38, 526, "Input"],
Cell[33435, 700, 198, 4, 105, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[33682, 710, 52, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[33759, 714, 43, 0, 64, "Subsubsection"],

Cell[CellGroupData[{
Cell[33827, 718, 4084, 88, 742, "Input"],
Cell[37914, 808, 110, 2, 105, "Output"],
Cell[38027, 812, 182, 3, 105, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[38258, 821, 44, 0, 64, "Subsubsection"],

Cell[CellGroupData[{
Cell[38327, 825, 4094, 88, 738, "Input"],
Cell[42424, 915, 110, 2, 105, "Output"],
Cell[42537, 919, 209, 4, 105, "Print"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[42807, 930, 60, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[42892, 934, 2544, 46, 550, "Input"],
Cell[45439, 982, 327, 6, 105, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[45815, 994, 58, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[45898, 998, 42, 0, 64, "Subsubsection"],

Cell[CellGroupData[{
Cell[45965, 1002, 2174, 41, 478, "Input"],
Cell[48142, 1045, 336, 7, 105, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[48527, 1058, 43, 0, 52, "Subsubsection"],

Cell[CellGroupData[{
Cell[48595, 1062, 2127, 40, 454, "Input"],
Cell[50725, 1104, 350, 7, 105, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[51136, 1118, 56, 0, 49, "Subsection"],

Cell[CellGroupData[{
Cell[51217, 1122, 2366, 44, 502, "Input"],
Cell[53586, 1168, 344, 7, 105, "Print"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[53991, 1182, 36, 0, 51, "Section"],
Cell[54030, 1184, 98, 3, 39, "Text"],
Cell[54131, 1189, 134, 3, 94, "Input"],

Cell[CellGroupData[{
Cell[54290, 1196, 746, 13, 334, "Input"],
Cell[55039, 1211, 74828, 2348, 444, 31308, 1806, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[129882, 3562, 406, 7, 166, "Input"],

Cell[CellGroupData[{
Cell[130313, 3573, 261, 5, 142, "Input"],
Cell[130577, 3580, 41893, 637, 444, 18467, 346, "BoxData", "Graphics3D", \
"Graphics"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[172519, 4223, 40, 0, 51, "Section"],
Cell[172562, 4225, 99, 3, 39, "Text"],

Cell[CellGroupData[{
Cell[172686, 4232, 771, 18, 142, "Input"],
Cell[173460, 4252, 65192, 1493, 279, 12491, 838, "GraphicsData", \
"PostScript", "Graphics"],
Cell[238655, 5747, 32907, 788, 279, 5851, 449, "GraphicsData", "PostScript", \
"Graphics"]
}, Closed]],
Cell[271577, 6538, 381, 7, 136, "Input"],
Cell[271961, 6547, 598, 15, 94, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[272596, 6567, 39, 0, 51, "Section"],
Cell[272638, 6569, 577, 10, 129, "Text"],

Cell[CellGroupData[{
Cell[273240, 6583, 2034, 35, 598, "Input"],
Cell[275277, 6620, 410, 8, 36, "Print"],
Cell[275690, 6630, 241, 4, 33, "Print"],
Cell[275934, 6636, 366, 7, 36, "Print"],
Cell[276303, 6645, 390, 7, 36, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[276730, 6657, 2414, 47, 694, "Input"],
Cell[279147, 6706, 35621, 956, 279, 9502, 629, "GraphicsData", "PostScript", \
"Graphics"],
Cell[314771, 7664, 33557, 852, 279, 7631, 527, "GraphicsData", "PostScript", \
"Graphics"],
Cell[348331, 8518, 32502, 830, 279, 7564, 518, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[380848, 9351, 371, 7, 166, "Input"],
Cell[381222, 9360, 70, 0, 39, "Text"],
Cell[381295, 9362, 340, 6, 142, "Input"],
Cell[381638, 9370, 153, 3, 39, "Text"],
Cell[381794, 9375, 122, 3, 70, "Input"],
Cell[381919, 9380, 151, 3, 39, "Text"],
Cell[382073, 9385, 131, 3, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[382241, 9393, 54, 0, 51, "Section"],
Cell[382298, 9395, 306, 5, 87, "Text"],

Cell[CellGroupData[{
Cell[382629, 9404, 45, 0, 64, "Subsection"],
Cell[382677, 9406, 12777, 275, 3041, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[395491, 9686, 40, 0, 64, "Subsection"],
Cell[395534, 9688, 2933, 51, 1081, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

